<?php

function frenify_register_plugins( $plugins ) {
  $theme_plugins = [
	[ // A WordPress.org plugin repository example.
      'name'     	=> 'Contact Form 7', // Name of the plugin.
      'slug'     	=> 'contact-form-7', // Plugin slug - the same as on WordPress.org plugin repository.
      'required' 	=> false,
	  'preselected' => true,
    ],
	[ // A WordPress.org plugin repository example.
      'name'     	=> 'Woocommerce', // Name of the plugin.
      'slug'     	=> 'woocommerce', // Plugin slug - the same as on WordPress.org plugin repository.
      'required' 	=> false,
	  'preselected' => true,
    ],
	[ // A WordPress.org plugin repository example.
      'name'     	=> 'MC4WP: Mailchimp for WordPress', // Name of the plugin.
      'slug'     	=> 'mailchimp-for-wp', // Plugin slug - the same as on WordPress.org plugin repository.
      'required' 	=> false,
	  'preselected' => true,
    ],
  ];
 
  return array_merge( $plugins, $theme_plugins );
}
add_filter( 'ocdi/register_plugins', 'frenify_register_plugins' );


// ===============================================================================================================================
// ===============================================================================================================================
// ===============================================================================================================================


function frenify_after_import_setup() {
    // Assign menus to their locations.
    $main_menu     = get_term_by('name', 'Main Menu', 'nav_menu');
	$footer_menu   = get_term_by('name', 'Footer Menu', 'nav_menu');

	// Define possible names for the off-canvas menu
	$offcanvas_menu_names = ['Off-Canvas Menu', 'Off Canvas Menu', 'Offcanvas Menu'];

	// Try to find the offcanvas menu by looping through possible names
	$offcanvas_menu = null;
	foreach ($offcanvas_menu_names as $name) {
		$offcanvas_menu = get_term_by('name', $name, 'nav_menu');
		if ($offcanvas_menu) {
			break;
		}
	}

	// Set theme mod with retrieved menu IDs
	set_theme_mod('nav_menu_locations', [
		'main_menu'     => $main_menu->term_id ?? '',
		'mobile_menu'   => $main_menu->term_id ?? '',
		'offcanvas_menu'=> $offcanvas_menu->term_id ?? '',
		'footer_menu'   => $footer_menu->term_id ?? '',
	]);

 
    // Assign front page
    $front_page_id = get_page_by_title( 'Home' );
    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'permalink_structure', '/%postname%/' );
}
add_action( 'ocdi/after_import', 'frenify_after_import_setup' );


// ===============================================================================================================================
// ===============================================================================================================================
// ===============================================================================================================================


function frenify_import_files() {
	$demoURL = 'https://frenify.com/work/envato/frenify/wp/mow/';

	$assetsURL = 'https://raw.githubusercontent.com/Frenify/mowxml/main/';

	$demo_data = [
		'news',
		'times',
		'review',
		'relink',
		'game',
		'modern',
		'modern2',
		'fashion',
		'socialmediatrends',
		'wildlife',
		'movie',
		'creative',
		'education',
		'science',
		'business',
		'realestate',
		'health',
		'travel',
		'sport',
		'photography',
		'gadgets',
		'food',
		'entertainment',
		'auto'
	];

	$demo_output = [];

	// local
	// foreach ($demo_data as $demo) {
	// 	$demo_output[] = [
	// 		'import_file_name'           => ucfirst($demo) . ' Demo',
	// 		'import_file_url'            => sprintf(MOW_PLUGIN_URL . 'inc/demoassets/%s-content.xml', $demo),
	// 		'import_widget_file_url'     => sprintf(MOW_PLUGIN_URL . 'inc/demoassets/%s-widget.json', $demo),
	// 		'import_redux'               => [
	// 			[
	// 				'file_url'    => sprintf(MOW_PLUGIN_URL . 'inc/demoassets/%s-redux.json', $demo),
	// 				'option_name' => 'mow_fn_option',
	// 			],
	// 		],
	// 		'import_preview_image_url'  => sprintf(MOW_PLUGIN_URL . 'inc/demoassets/%s-image.jpg', $demo),
	// 		'preview_url'               => $demoURL . $demo,
	// 		'preview_URI'               => 'yеs',
	// 	];
	// }

	// online
	foreach ($demo_data as $demo) {
		$demo_output[] = [
			'import_file_name'           => ucfirst($demo) . ' Demo',
			'import_file_url'            => sprintf($assetsURL . '%s-content.xml', $demo),
			'import_widget_file_url'     => sprintf($assetsURL . '%s-widget.json', $demo),
			'import_redux'               => [
				[
					'file_url'    => sprintf($assetsURL . '%s-redux.json', $demo),
					'option_name' => 'mow_fn_option',
				],
			],
			'import_preview_image_url'  => sprintf($assetsURL . '%s-image.jpg', $demo),
			'preview_url'               => $demoURL . $demo,
			'preview_URI'               => 'yеs',
		];
	}

	return $demo_output;


}
add_filter( 'ocdi/import_files', 'frenify_import_files' );


function ocdi_plugin_page_setup( $default_settings ) {
    $default_settings['parent_slug'] = 'mow-core';
    $default_settings['page_title']  = esc_html__( 'Demo Import Page' , 'one-click-demo-import' );
    $default_settings['menu_title']  = esc_html__( 'Import Demo Data' , 'one-click-demo-import' );
    $default_settings['capability']  = 'manage_options';
    $default_settings['menu_slug']   = 'theme-demo-import';
 
    return $default_settings;
}
add_filter( 'ocdi/plugin_page_setup', 'ocdi_plugin_page_setup' );