<?php

/**
 * Plugin Name: Ad. Widget
 * Description: A widget that show ad.
 * Version: 1.0
 * Author: Frenify
 * Author URI: http://themeforest.net/user/frenify
 *
 */


/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Mow_Ad extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		parent::__construct(
			'mow_ad', // Base ID
			esc_html__( 'Frenify Ad.', MOW_TEXT_DOMAIN ), // Name
		);
		
		add_action( 'widgets_init', function() {
            register_widget( 'Mow_Ad' );
        });
	}
	

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		global $post;
		
		$title					= '';
		$ad_type				= 'image';
		$ad_url					= '';
		$ad_img_url				= '';
		$ad_area				= '';
		$min_height				= '';
				
		
		/* Our variables from the widget settings. */
		if ( !empty( $instance[ 'title' ] ) ) { $title 			= $instance[ 'title' ];}
		if ( !empty( $instance[ 'ad_type' ] ) ) {$ad_type		= $instance[ 'ad_type' ];}
		if ( !empty( $instance[ 'ad_url' ] ) ) {$ad_url			= $instance[ 'ad_url' ];}
		if ( !empty( $instance[ 'ad_img_url' ] ) ) {$ad_img_url	= $instance[ 'ad_img_url' ];}
		if ( !empty( $instance[ 'ad_area' ] ) ) {$ad_area		= $instance[ 'ad_area' ];}
		if ( !empty( $instance[ 'min_height' ] ) ) {$min_height	= $instance[ 'min_height' ];}

		if($min_height == ''){$min_height = 0;}


		if($title != ''){
			$title = '<div class="ad_title"><h3>'.$title.'</h3></div>';
		}

		// Get real image width and height
		$image_width = $image_height = 'auto';
		if ($ad_img_url) {
			$image_path = str_replace(site_url(), ABSPATH, $ad_img_url); // Convert URL to absolute path
			if (file_exists($image_path)) {
				list($image_width, $image_height) = getimagesize($image_path);
			}
		}
		
		/* Before widget (defined by themes). */
		echo wp_kses_post($before_widget);
		?>
           	<div class="mow_fn_widget_ad_wrapper" style="min-height:<?php echo esc_attr($min_height); ?>vh;">
				<div class="mow_fn_widget_ad">
					<?php echo $title; ?>
					<div class="ad_content">
						<?php if($ad_type == 'image'){ ?>
						<a href="<?php echo esc_url($ad_url); ?>" target="_blank" rel="nofollow" aria-label="/"><img src="<?php echo esc_url($ad_img_url); ?>" loading="lazy" decoding="async" alt="" width="<?php echo esc_attr($image_width); ?>" height="<?php echo esc_attr($image_height); ?>"></a>
						<?php }else{
							echo $ad_area;
						} ?>
					</div>
				</div>
            </div>
            
		<?php 
		/* After widget (defined by themes). */
		echo wp_kses_post($after_widget);
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = array();
 
        $instance['title']		= ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['ad_type']	= ( !empty( $new_instance['ad_type'] ) ) ? strip_tags( $new_instance['ad_type'] ) : '';
        $instance['ad_url']		= ( !empty( $new_instance['ad_url'] ) ) ? strip_tags( $new_instance['ad_url'] ) : '';
        $instance['ad_img_url']	= ( !empty( $new_instance['ad_img_url'] ) ) ? strip_tags( $new_instance['ad_img_url'] ) : '';
        $instance['ad_area']	= ( !empty( $new_instance['ad_area'] ) ) ?  $new_instance['ad_area'] : '';
        $instance['min_height']	= ( !empty( $new_instance['min_height'] ) ) ?  $new_instance['min_height'] : '';
 
        return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		/* Set up some default widget settings. */
		$title 					= ! empty( $instance['title'] ) ? $instance['title'] : '';
		$ad_type 				= ! empty( $instance['ad_type'] ) ? $instance['ad_type'] : '';
		$ad_url 				= ! empty( $instance['ad_url'] ) ? $instance['ad_url'] : '';
		$ad_img_url 			= ! empty( $instance['ad_img_url'] ) ? $instance['ad_img_url'] : '';
		$ad_area 				= ! empty( $instance['ad_area'] ) ? $instance['ad_area'] : '';
		$min_height 			= ! empty( $instance['min_height'] ) ? $instance['min_height'] : '';

		
		$imageSelect = $textareaSelect = '';
		if($ad_type == 'image'){$imageSelect = 'selected';}
		else if($ad_type == 'code'){$textareaSelect = 'selected';}

		
		?>
		<p class="mow_widget_divider"></p>
		<p class="mow_fn_followers_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" class="mow_fn_width100">
		</p>

		<p class="mow_fn_followers_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'ad_type' )); ?>"><?php esc_html_e('Ad. Type', MOW_TEXT_DOMAIN); ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'ad_type' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'ad_type' )); ?>">
				<option <?php echo esc_attr($imageSelect);?> value="image"><?php esc_html_e('Image', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($textareaSelect);?> value="code"><?php esc_html_e('Code', MOW_TEXT_DOMAIN); ?></option>
			</select>
		</p>

		<p class="mow_widget_divider"></p>
		<p class="mow_fn_followers_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'min_height' )); ?>"><?php esc_html_e('Min Height (vh)', MOW_TEXT_DOMAIN); ?></label>
			<input min="0" type="number" id="<?php echo esc_attr($this->get_field_id( 'min_height' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'min_height' )); ?>" value="<?php echo esc_attr($min_height); ?>" class="mow_fn_width100">
		</p>
		
		<p class="mow_widget_divider"><?php esc_html_e('Image Type', MOW_TEXT_DOMAIN); ?></p>
		<p class="mow_fn_followers_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'ad_url' )); ?>"><?php esc_html_e('Ad. URL', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'ad_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'ad_url' )); ?>" value="<?php echo esc_attr($ad_url); ?>" class="mow_fn_width100">
		</p>
		
		<p class="mow_fn_followers_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'ad_img_url' )); ?>"><?php esc_html_e('Ad. Image URL', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'ad_img_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'ad_img_url' )); ?>" value="<?php echo esc_attr($ad_img_url); ?>" class="mow_fn_width100">
		</p>

		<p class="mow_widget_divider"><?php esc_html_e('Code Type', MOW_TEXT_DOMAIN); ?></p>
		<p class="mow_fn_followers_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'ad_area' )); ?>"><?php esc_html_e('Ad. Code', MOW_TEXT_DOMAIN); ?></label>
			<textarea style="display: block;" rows="10" cols="10" id="<?php echo esc_attr($this->get_field_id( 'ad_area' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'ad_area' )); ?>" class="mow_fn_width100"><?php echo $ad_area; ?></textarea>
		</p>

		

	<?php
	}
}

$my_widget = new Mow_Ad();