<?php

/**
 * Plugin Name: Author
 * Description: A widget that show Author Information
 * Version: 1.0
 * Author: Frenify
 * Author URI: http://themeforest.net/user/frenify
 *
 */


/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Mow_Author extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		parent::__construct(
			'Mow_Author', // Base ID
			esc_html__( 'Frenify Author', MOW_TEXT_DOMAIN ), // Name
			array( 'description' => esc_html__( 'Frenify Author', MOW_TEXT_DOMAIN ), ) // Args
		);
		
		add_action( 'widgets_init', function() {
            register_widget( 'Mow_Author' );
        });
	}
	

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		global $post;
		
		$title		= '';
		$userID		= '';
				
		
		/* Our variables from the widget settings. */
		if ( !empty( $instance[ 'title' ] ) ) { 
			$title 	= $instance[ 'title' ];
		}
		$title 		= apply_filters(esc_html__('About Me', MOW_TEXT_DOMAIN), $title );
		
		if ( !empty( $instance[ 'author' ] ) ) {$userID = $instance[ 'author' ];}
		
		
		
		
		/* Before widget (defined by themes). */
		echo wp_kses_post($before_widget);
		if ( $title ) {
			echo wp_kses_post($before_title . $title . $after_title); 
		}
		
		$list = '';
		
		if($userID != ''){
			$authorURL 	 		= get_author_posts_url($userID);
			$social				= mow_fn_get_user_social($userID);
			$name 				= esc_html( get_the_author_meta( 'mow_fn_user_name', $userID ) );
			$description		= esc_html( get_the_author_meta( 'mow_fn_user_desc', $userID ) );
			$imageURL			= esc_url( get_the_author_meta( 'mow_fn_user_image', $userID ) );

			if($name == ''){	
				$firstName 		= get_user_meta( $userID, 'first_name', true );
				$lastName 		= get_user_meta( $userID, 'last_name', true );
				$name 			= $firstName . ' ' . $lastName;
				if($firstName == ''){
					$name 		= get_user_meta( $userID, 'nickname', true );
				}
			}
			if($description == ''){
				$description 	= get_user_meta( $userID, 'description', true );
			}
			if($imageURL == ''){
				$imageURL		= get_avatar_url( $userID, ['size' => 80] );
			}

			$image			= '<img loading="lazy" src="'.$imageURL.'" alt="'.esc_attr($name).'">';

			if($social != ''){
				$social = '<div class="social_list">'.$social.'</div>';
			}


			$title 			= '<h3 class="fn_title"><a href="'.esc_url($authorURL).'">'.$name.'</a></h3>';
			$description	= '<p class="fn_desc">'.$description.'</p>';
			$list  .= '<div class="info_top"><div class="info_img"><a href="'.esc_url($authorURL).'">'.$image.'</a></div>'.$title.'</div>';
			$list  .= '<div class="info_bottom">'.$description.$social.'</div>';
		}
		
		?>
           	<div class="mow_fn_widget_author">
				<?php echo wp_kses_post($list); ?>
            </div>
            
		<?php 
		/* After widget (defined by themes). */
		echo wp_kses_post($after_widget);
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = array();
 
        $instance['title'] 	= ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['author'] 	= ( !empty( $new_instance['author'] ) ) ? strip_tags( $new_instance['author'] ) : '';
 
        return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		/* Set up some default widget settings. */
		$title 	= ! empty( $instance['title'] ) ? $instance['title'] : esc_html__('About Me', MOW_TEXT_DOMAIN);
		$author = ! empty( $instance['author'] ) ? $instance['author'] : '';
		?>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" class="mow_fn_width100">
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'author' )); ?>"><?php esc_html_e('Author ID:', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'author' )); ?>" value="<?php echo esc_attr($author); ?>" class="mow_fn_width100">
		</p>

	<?php
	}
}

$my_widget = new Mow_Author();