<?php

/**
 * Plugin Name: Comments
 * Description: A widget that show Comments Information
 * Version: 1.0
 * Author: Frenify
 * Author URI: http://themeforest.net/user/frenify
 *
 */


/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Mow_Comments extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		parent::__construct(
			'Mow_Comments', // Base ID
			esc_html__( 'Frenify Comments', MOW_TEXT_DOMAIN ), // Name
			array( 'description' => esc_html__( 'Frenify Comments', MOW_TEXT_DOMAIN ), ) // Args
		);
		
		add_action( 'widgets_init', function() {
            register_widget( 'Mow_Comments' );
        });
	}
	

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		global $post;
		
		$title		= '';
		$count		= '';
				
		
		/* Our variables from the widget settings. */
		if ( !empty( $instance[ 'title' ] ) ) { $title 	= $instance[ 'title' ]; }
		if ( !empty( $instance[ 'count' ] ) ) {$userID = $instance[ 'count' ];}
		
		
		
		
		/* Before widget (defined by themes). */
		echo wp_kses_post($before_widget);
		if ( $title ) {
			echo wp_kses_post($before_title . $title . $after_title); 
		}
		$recent_comments = get_comments(array(
			'number'      => 5,        // Number of comments to retrieve
			'status'      => 'approve', // Only approved comments
			'post_status' => 'publish', // Only comments from published posts
		));
	
		$output = '<ul>';
	
		$icon = mow_fn_svg('svg__comment');
		foreach ($recent_comments as $comment) {
			$author = esc_html($comment->comment_author);
			$content = wp_strip_all_tags($comment->comment_content);
			$comment_link = esc_url(get_comment_link($comment));
	
			// Create the HTML for each comment
			$output .= '<li>';
			$output .= '<div class="item">';
			$output .= '<span class="icon">' . $icon . '</span>';
			$output .= '<h3>';
			$output .= '<a href="' . $comment_link . '">';
			$output .= '<span class="author">' . $author . ': </span>';
			$output .= '<span class="comment">' . $content . '</span>';
			$output .= '</a>';
			$output .= '</h3>';
			$output .= '</div>';
			$output .= '</li>';
		}
	
		$output .= '</ul>';
		
		
		?>
           	<div class="mow_fn_widget_comments">
				<?php echo wp_kses_post($output); ?>
            </div>
            
		<?php 
		/* After widget (defined by themes). */
		echo wp_kses_post($after_widget);
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = array();
 
        $instance['title'] 	= ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['count'] 	= ( !empty( $new_instance['count'] ) ) ? strip_tags( $new_instance['count'] ) : '';
 
        return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		/* Set up some default widget settings. */
		$title 	= ! empty( $instance['title'] ) ? $instance['title'] : '';
		$count = ! empty( $instance['count'] ) ? $instance['count'] : '';
		?>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" class="mow_fn_width100">
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'count' )); ?>"><?php esc_html_e('Comments Count', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'count' )); ?>" value="<?php echo esc_attr($count); ?>" class="mow_fn_width100">
		</p>

	<?php
	}
}

$my_widget = new Mow_Comments();