<?php

// Exit if accessed directly. 
if ( ! defined( 'ABSPATH' ) ) { exit; }


if ( ! class_exists( 'Frel_Core' ) ) 
{
	
	class Frel_Core {
		
		// ---------------------------------------------------------
		// VARIABLES
		// ---------------------------------------------------------
		private static $instance = null;
		
		public $version = '1.0.0.0';
		
		private $plugin_path = null;
		
		
		// ---------------------------------------------------------
		// FUNCTIONS
		// ---------------------------------------------------------
		
		// Disable class cloning
		public function __clone() 
		{

			// Cloning instances of the class is forbidden
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', MOW_TEXT_DOMAIN ));

		}
		
		
		// Disable unserializing the class.
		public function __wakeup() 
		{

			// Unserializing instances of the class is forbidden.
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', MOW_TEXT_DOMAIN ));

		}
		
		
		public function __construct() 
		{
			
			$this->includes();
			$this->init_hooks();
			
		
		}
		
		
		// Hook into actions and filters.
		private function init_hooks() 
		{

			add_action( 'plugins_loaded', [ $this, 'init' ] );

		}
		
		
		// Check if elementor exists
		public function init() 
		{
			
			// Frel Classes
			new \Frel\Frel_Plugin();
		}
		
		
		// Includes
		public function includes() 
		{
			require_once( __DIR__ . '/frel-plugin.php' );
			require_once( __DIR__ . '/includes/frel-helper.php' );
			require_once( __DIR__ . '/includes/mow_fn_vote.php' );
			require_once( __DIR__ . '/includes/mow_fn_reactions.php' );
		}
		
		
		
		// Warning when the site doesn't have Elementor installed or activated.
		public function admin_notice_missing_main_plugin() 
		{
			$message = sprintf(
				/* translators: 1: Frel 2: Elementor */
				esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', MOW_TEXT_DOMAIN ),
				'<strong>' . esc_html__( 'Frel', MOW_TEXT_DOMAIN ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', MOW_TEXT_DOMAIN ) . '</strong>'
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

		}
		
		
		
		
		// Returns the instance.
		public static function get_instance() 
		{
			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}
			return self::$instance;
		}
		
	}
	
}


if ( ! function_exists( 'frel_load' ) ) 
{
	// Returns instanse of the plugin class.
	function Frel_load() 
	{
		return frel_Core::get_instance();
	}
	
	frel_load();
}
// ---------------------------------------------------------
// REDUX remove demo mode
// ---------------------------------------------------------
function removeDemoModeLinkByFrenify() { 
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
	
}
add_action('init', 'removeDemoModeLinkByFrenify');


function mow_fn_shortcode__year() {
    $output = date('Y');
    return esc_html($output);
}
add_shortcode('current_year', 'mow_fn_shortcode__year');

add_shortcode( 'frenify_sidebar', 'frenify_sidebar_shortcode' );

function frenify_sidebar_shortcode( $atts ) {
    // Extract the attributes and set a default name
    $atts = shortcode_atts(
        array(
            'name' => '', // Default is empty; specify the name in the shortcode
        ),
        $atts,
        'frenify_sidebar'
    );


	// Get all registered sidebars
    global $wp_registered_sidebars;
    $sidebar_id = '';

    // Find the sidebar ID by its name
    foreach ( $wp_registered_sidebars as $id => $sidebar ) {
        if ( $sidebar['name'] === $atts['name'] ) {
            $sidebar_id = $id;
            break;
        }
    }
    // Check if the sidebar is active and output it
    if ( $sidebar_id && is_active_sidebar( $sidebar_id ) ) {
        ob_start(); // Start output buffering
        echo '<div class="frenify_sidebar">';
        dynamic_sidebar( $sidebar_id );
        echo '</div>';
        return ob_get_clean(); // Return the buffered output
    }

    return ''; // Return empty if the sidebar is not active
}


add_action( 'show_user_profile', 'mow_fn_user_social_fields' );
add_action( 'edit_user_profile', 'mow_fn_user_social_fields' );

function mow_fn_user_social_fields( $user ) {
		$userID				= $user->ID;
		// icons
		$facebook_icon     = mow_fn_svg('facebook');
		$twitter_icon      = mow_fn_svg('twitter');
		$pinterest_icon    = mow_fn_svg('pinterest');
		$linkedin_icon     = mow_fn_svg('linkedin');
		$behance_icon      = mow_fn_svg('behance');
		$vimeo_icon        = mow_fn_svg('vimeo');
		$google_icon       = mow_fn_svg('google');
		$youtube_icon      = mow_fn_svg('youtube');
		$instagram_icon    = mow_fn_svg('instagram');
		$github_icon       = mow_fn_svg('github');
		$flickr_icon       = mow_fn_svg('flickr');
		$dribbble_icon     = mow_fn_svg('dribbble');
		$dropbox_icon      = mow_fn_svg('dropbox');
		$paypal_icon       = mow_fn_svg('paypal');
		$picasa_icon       = mow_fn_svg('picasa');
		$soundcloud_icon   = mow_fn_svg('soundcloud');
		$whatsapp_icon     = mow_fn_svg('whatsapp');
		$skype_icon        = mow_fn_svg('skype');
		$slack_icon        = mow_fn_svg('slack');
		$wechat_icon       = mow_fn_svg('wechat');
		$icq_icon          = mow_fn_svg('icq');
		$rocket_icon       = mow_fn_svg('rocketchat');
		$telegram_icon     = mow_fn_svg('telegram');
		$vkontakte_icon    = mow_fn_svg('vk');
		$rss_icon          = mow_fn_svg('rss');
		$mastodon_icon     = mow_fn_svg('svg__mastodon');

?>
    <h3><?php esc_html_e("Mow extra profile Information", MOW_TEXT_DOMAIN); ?></h3>

    <table class="form-table">
		<tr>
			<th><label for="mow_fn_user_image"><?php esc_html_e("Image URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_image" id="mow_fn_user_image" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_image', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please insert your profile image URL (media URL or any website image URL)", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_name"><?php esc_html_e("Full Name", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_name" id="mow_fn_user_name" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_name', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your full name", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_desc"><?php esc_html_e("Information", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<textarea name="mow_fn_user_desc" cols="30" rows="5" id="mow_fn_user_desc" class="regular-text"><?php echo esc_html( get_the_author_meta( 'mow_fn_user_desc', $userID ) ); ?></textarea><br>
				<span class="description"><?php esc_html_e("Please enter some description name", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_facebook"><span><?php echo wp_kses($facebook_icon, 'post');?></span><?php esc_html_e("Facebook URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_facebook" id="mow_fn_user_facebook" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_facebook', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your facebook profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_twitter"><span><?php echo wp_kses($twitter_icon, 'post');?></span><?php esc_html_e("Twitter URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_twitter" id="mow_fn_user_twitter" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_twitter', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your twitter profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_pinterest"><span><?php echo wp_kses($pinterest_icon, 'post');?></span><?php esc_html_e("Pinterest URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_pinterest" id="mow_fn_user_pinterest" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_pinterest', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your pinterest profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_linkedin"><span><?php echo wp_kses($linkedin_icon, 'post');?></span><?php esc_html_e("Linkedin URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_linkedin" id="mow_fn_user_linkedin" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_linkedin', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your linkedin profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_behance"><span><?php echo wp_kses($behance_icon, 'post');?></span><?php esc_html_e("Behance URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_behance" id="mow_fn_user_behance" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_behance', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your linkedin profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_vimeo"><span><?php echo wp_kses($vimeo_icon, 'post');?></span><?php esc_html_e("Vimeo URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_vimeo" id="mow_fn_user_vimeo" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_vimeo', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your linkedin profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_google"><span><?php echo wp_kses($google_icon, 'post');?></span><?php esc_html_e("Google URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_google" id="mow_fn_user_google" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_google', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your google profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_youtube"><span><?php echo wp_kses($youtube_icon, 'post');?></span><?php esc_html_e("Youtube URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_youtube" id="mow_fn_user_youtube" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_youtube', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your youtube profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_instagram"><span><?php echo wp_kses($instagram_icon, 'post');?></span><?php esc_html_e("Instagram URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_instagram" id="mow_fn_user_instagram" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_instagram', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your instagram profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_github"><span><?php echo wp_kses($github_icon, 'post');?></span><?php esc_html_e("Github URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_github" id="mow_fn_user_github" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_github', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your github profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_flickr"><span><?php echo wp_kses($flickr_icon, 'post');?></span><?php esc_html_e("Flickr URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_flickr" id="mow_fn_user_flickr" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_flickr', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your flickr profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_dribbble"><span><?php echo wp_kses($dribbble_icon, 'post');?></span><?php esc_html_e("Dribbble URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_dribbble" id="mow_fn_user_dribbble" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_dribbble', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your dribbble profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_dropbox"><span><?php echo wp_kses($dropbox_icon, 'post');?></span><?php esc_html_e("Dropbox URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_dropbox" id="mow_fn_user_dropbox" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_dropbox', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your dropbox profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_paypal"><span><?php echo wp_kses($paypal_icon, 'post');?></span><?php esc_html_e("Paypal URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_paypal" id="mow_fn_user_paypal" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_paypal', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your paypal profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_picasa"><span><?php echo wp_kses($picasa_icon, 'post');?></span><?php esc_html_e("Picasa URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_picasa" id="mow_fn_user_picasa" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_picasa', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your picasa profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_soundcloud"><span><?php echo wp_kses($soundcloud_icon, 'post');?></span><?php esc_html_e("Soundcloud URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_soundcloud" id="mow_fn_user_soundcloud" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_soundcloud', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your soundcloud profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_whatsapp"><span><?php echo wp_kses($whatsapp_icon, 'post');?></span><?php esc_html_e("Whatsapp URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_whatsapp" id="mow_fn_user_whatsapp" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_whatsapp', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your whatsapp profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_skype"><span><?php echo wp_kses($skype_icon, 'post');?></span><?php esc_html_e("Skype URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_skype" id="mow_fn_user_skype" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_skype', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your skype profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_slack"><span><?php echo wp_kses($slack_icon, 'post');?></span><?php esc_html_e("Slack URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_slack" id="mow_fn_user_slack" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_slack', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your slack profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_wechat"><span><?php echo wp_kses($wechat_icon, 'post');?></span><?php esc_html_e("WeChat URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_wechat" id="mow_fn_user_wechat" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_wechat', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your wechat profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_icq"><span><?php echo wp_kses($icq_icon, 'post');?></span><?php esc_html_e("ICQ URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_icq" id="mow_fn_user_icq" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_icq', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your icq profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_rocketchat"><span><?php echo wp_kses($rocket_icon, 'post');?></span><?php esc_html_e("RocketChat URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_rocketchat" id="mow_fn_user_rocketchat" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_rocketchat', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your rocketchat profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_telegram"><span><?php echo wp_kses($telegram_icon, 'post');?></span><?php esc_html_e("Telegram URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_telegram" id="mow_fn_user_telegram" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_telegram', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your telegram profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_vkontakte"><span><?php echo wp_kses($vkontakte_icon, 'post');?></span><?php esc_html_e("Vkontakte URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_vkontakte" id="mow_fn_user_vkontakte" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_vkontakte', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your vkontakte profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_rss"><span><?php echo wp_kses($rss_icon, 'post');?></span><?php esc_html_e("RSS URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_rss" id="mow_fn_user_rss" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_rss', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your rss profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="mow_fn_user_mastodon"><span><?php echo wp_kses($mastodon_icon, 'post');?></span><?php esc_html_e("Mastodon URL", MOW_TEXT_DOMAIN); ?></label></th>
			<td>
				<input type="text" name="mow_fn_user_mastodon" id="mow_fn_user_mastodon" value="<?php echo esc_attr( get_the_author_meta( 'mow_fn_user_mastodon', $userID ) ); ?>" class="regular-text" ><br>
				<span class="description"><?php esc_html_e("Please enter your mastodon profile address", MOW_TEXT_DOMAIN); ?></span>
			</td>
		</tr>
    </table>
<?php }


add_action( 'personal_options_update', 'mow_fn_user_social_fields_save' );
add_action( 'edit_user_profile_update', 'mow_fn_user_social_fields_save' );

function mow_fn_user_social_fields_save( $user_id ) {
    if ( !current_user_can( 'edit_user', $user_id ) ) { 
        return false; 
    }
    update_user_meta( $user_id, 'mow_fn_user_image', 		$_POST['mow_fn_user_image'] );
    update_user_meta( $user_id, 'mow_fn_user_name', 		$_POST['mow_fn_user_name'] );
    update_user_meta( $user_id, 'mow_fn_user_desc', 		$_POST['mow_fn_user_desc'] );
    update_user_meta( $user_id, 'mow_fn_user_facebook', 	$_POST['mow_fn_user_facebook'] );
    update_user_meta( $user_id, 'mow_fn_user_twitter', 		$_POST['mow_fn_user_twitter'] );
    update_user_meta( $user_id, 'mow_fn_user_pinterest', 	$_POST['mow_fn_user_pinterest'] );
    update_user_meta( $user_id, 'mow_fn_user_linkedin', 	$_POST['mow_fn_user_linkedin'] );
    update_user_meta( $user_id, 'mow_fn_user_behance', 		$_POST['mow_fn_user_behance'] );
    update_user_meta( $user_id, 'mow_fn_user_vimeo', 		$_POST['mow_fn_user_vimeo'] );
    update_user_meta( $user_id, 'mow_fn_user_google', 		$_POST['mow_fn_user_google'] );
    update_user_meta( $user_id, 'mow_fn_user_youtube', 		$_POST['mow_fn_user_youtube'] );
    update_user_meta( $user_id, 'mow_fn_user_instagram', 	$_POST['mow_fn_user_instagram'] );
    update_user_meta( $user_id, 'mow_fn_user_github', 		$_POST['mow_fn_user_github'] );
    update_user_meta( $user_id, 'mow_fn_user_flickr', 		$_POST['mow_fn_user_flickr'] );
    update_user_meta( $user_id, 'mow_fn_user_dribbble', 	$_POST['mow_fn_user_dribbble'] );
    update_user_meta( $user_id, 'mow_fn_user_dropbox', 		$_POST['mow_fn_user_dropbox'] );
    update_user_meta( $user_id, 'mow_fn_user_paypal', 		$_POST['mow_fn_user_paypal'] );
    update_user_meta( $user_id, 'mow_fn_user_picasa', 		$_POST['mow_fn_user_picasa'] );
    update_user_meta( $user_id, 'mow_fn_user_soundcloud', 	$_POST['mow_fn_user_soundcloud'] );
    update_user_meta( $user_id, 'mow_fn_user_whatsapp', 	$_POST['mow_fn_user_whatsapp'] );
    update_user_meta( $user_id, 'mow_fn_user_skype', 		$_POST['mow_fn_user_skype'] );
    update_user_meta( $user_id, 'mow_fn_user_slack', 		$_POST['mow_fn_user_slack'] );
    update_user_meta( $user_id, 'mow_fn_user_wechat', 		$_POST['mow_fn_user_wechat'] );
    update_user_meta( $user_id, 'mow_fn_user_icq', 			$_POST['mow_fn_user_icq'] );
    update_user_meta( $user_id, 'mow_fn_user_rocketchat', 	$_POST['mow_fn_user_rocketchat'] );
    update_user_meta( $user_id, 'mow_fn_user_telegram', 	$_POST['mow_fn_user_telegram'] );
    update_user_meta( $user_id, 'mow_fn_user_vkontakte', 	$_POST['mow_fn_user_vkontakte'] );
    update_user_meta( $user_id, 'mow_fn_user_rss', 			$_POST['mow_fn_user_rss'] );
    update_user_meta( $user_id, 'mow_fn_user_mastodon', 	$_POST['mow_fn_user_mastodon'] );
}
add_filter( 'plugin_row_meta', 'mow_core_fn_plugin_row_meta', 10, 2 );

function mow_fn_check_theme(){
	if(get_option('mow_theme_status', 'active') == 'active' && get_option('mow_theme_purchasecode', '') != ''){
		return true;
	}else{
		return true;
	}
}

function mow_fn_theme_st(){
	$opt = get_option('mow_theme_status', 'active');
	return $opt;
}