<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Categories extends Widget_Base {

	public function get_name() {
		return 'frel-categories';
	}

	public function get_title() {
		return __( 'Categories/Tags', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-tags frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'categories',
            'category',
            'tags',
            'tag',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);
		
		$this->add_control(
			'layout',
			[
				'label' 		=> __( 'Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'list',
				'options' 		=> [
					'list'  			=> __( 'List', MOW_TEXT_DOMAIN ),
					'list_2'  			=> __( 'List 2', MOW_TEXT_DOMAIN ),
					'grid_box'  		=> __( 'Grid Box', MOW_TEXT_DOMAIN ),
					'big_marquee'		=> __( 'Big Marquee', MOW_TEXT_DOMAIN ),
					'small_marquee'  	=> __( 'Small Marquee', MOW_TEXT_DOMAIN ),
					'carousel'  		=> __( 'Carousel', MOW_TEXT_DOMAIN ),
					'v_interactive'  	=> __( 'Vertical Interactive', MOW_TEXT_DOMAIN ),
					'h_interactive'  	=> __( 'Horizontal Interactive', MOW_TEXT_DOMAIN ),
				],
			]
		);
		
		$this->add_control(
			'type',
			[
				'label' 		=> __( 'Type', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'categories',
				'options' 		=> [
					'categories'  	=> __( 'Categories', MOW_TEXT_DOMAIN ),
					'tags'			=> __( 'Tags', MOW_TEXT_DOMAIN ),
					'custom'  		=> __( 'Custom', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'v_interactive_font_family',
			[
				'label' => esc_html__( 'Font Family', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::FONT,
				'default' => "'Roboto', sans-serif",
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_v_interactive .text' => 'font-family: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'v_interactive',
				]
			]
		);

		$this->add_control(
			'h_interactive_font_family',
			[
				'label' => esc_html__( 'Font Family', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::FONT,
				'default' => "'Roboto', sans-serif",
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_h_interactive .text' => 'font-family: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'h_interactive',
				]
			]
		);

		$this->add_control(
			'ids',
			[
				'label' => __( 'IDs', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'condition' => [
					'type!' => 'custom',
				]
			]
		);
		
		$this->add_control(
			'prefix',
			[
				'label' => __( 'Prefix', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);

		$this->add_control(
			'suffix',
			[
				'label' => __( 'Suffix', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title',
			[
				'label' => __( 'List Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);

		$repeater->add_control(
			'list_image',
			[
				'label' => esc_html__( 'List Image', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'list_url',
			[
				'label' => __( 'List URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);


		$this->add_control(
			'custom_list',
			[
				'label' => __( 'Custom List', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
				'condition' => [
					'type' => 'custom',
				]
			]
		);
		
		$this->add_control(
			'small_marquee_bg',
			[
				'label' 		=> __( 'Background', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'main_color',
				'options' 		=> [
					'main_color'  	=> __( 'Main Color', MOW_TEXT_DOMAIN ),
					'gray'			=> __( 'Gray', MOW_TEXT_DOMAIN ),
					'custom'  		=> __( 'Custom', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'small_marquee',
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'small_marquee_bg_custom',
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .fn_cs_cats_small_marquee[data-bg="custom"] .small_marquee',
				'condition' => [
					'layout' => 'small_marquee',
					'small_marquee_bg' => 'custom',
				]
			]
		);

		$this->add_control(
			'small_marquee_bg_textcolor',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_small_marquee[data-bg="custom"] .item' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_small_marquee[data-bg="custom"] .item:after' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'small_marquee',
					'small_marquee_bg' => 'custom',
				]
			]
		);
		
		$this->add_control(
			'carousel_bg',
			[
				'label' 		=> __( 'Background', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'main_color',
				'options' 		=> [
					'main_color'  	=> __( 'Main Color', MOW_TEXT_DOMAIN ),
					'gray'			=> __( 'Gray', MOW_TEXT_DOMAIN ),
					'custom'  		=> __( 'Custom', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'carousel',
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'carousel_bg_custom',
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .fn_cs_cats_carousel[data-bg="custom"] .cats_carousel,{{WRAPPER}} .fn_cs_cats_carousel[data-bg="custom"] .slider_nav',
				'condition' => [
					'layout' => 'carousel',
					'carousel_bg' => 'custom',
				]
			]
		);

		$this->add_control(
			'carousel_bg_textcolor',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_carousel[data-bg="custom"] .item' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_carousel[data-bg="custom"] .item:after' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'carousel',
					'carousel_bg' => 'custom',
				]
			]
		);

		$this->add_control(
			'carousel_arrow_color',
			[
				'label' => esc_html__( 'Arrow Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_carousel .swiper-button-prev,{{WRAPPER}} .fn_cs_cats_carousel .swiper-button-next' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'carousel',
					'carousel_bg' => 'custom',
				]
			]
		);

		$this->add_control(
			'custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'list',
				]
			]
		);

		$this->add_control(
			'list_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_list[data-color="yes"] .name, {{WRAPPER}} .fn_cs_cats_list[data-color="yes"] .name a, {{WRAPPER}} .fn_cs_cats_list[data-color="yes"] .count' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'list',
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'list_2_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'list_2',
				]
			]
		);

		$this->add_control(
			'list_2_border_color',
			[
				'label' => esc_html__( 'Border Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_list2[data-color="yes"] .title_holder' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'list_2',
					'list_2_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'list_2_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_list2[data-color="yes"] .text' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'list_2',
					'list_2_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'list_2_count_bgcolor',
			[
				'label' => esc_html__( 'Count Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_list2[data-color="yes"] .count' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'list_2',
					'list_2_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'list_2_count_textcolor',
			[
				'label' => esc_html__( 'Count Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_list2[data-color="yes"] .count' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'list_2',
					'list_2_custom_color' => 'yes',
				]
			]
		);

		

		$this->add_control(
			'list_2_show_link',
			[
				'label' => esc_html__( 'Show Link', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'list_2',
				]
			]
		);

		$this->add_control(
			'list_2_or_text',
			[
				'label' => __( 'Or Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Or...', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'list_2_show_link' => 'yes',
				]
			]
		);


		$this->add_control(
			'list_2_link_text',
			[
				'label' => __( 'Link Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'See them All', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'list_2_show_link' => 'yes',
				]
			]
		);


		$this->add_control(
			'list_2_link_url',
			[
				'label' => __( 'Link URL', MOW_TEXT_DOMAIN ),
				'default' => '#',
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'list_2_show_link' => 'yes',
				]
			]
		);

		$this->add_control(
			'grid_box_show_link',
			[
				'label' => esc_html__( 'Show Link', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'grid_box',
				]
			]
		);

		$this->add_control(
			'grid_box_or_text',
			[
				'label' => __( 'Or Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Or', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'grid_box_show_link' => 'yes',
					'layout' => 'grid_box',
				]
			]
		);


		$this->add_control(
			'grid_box_link_text',
			[
				'label' => __( 'Link Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'See them All', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'grid_box_show_link' => 'yes',
					'layout' => 'grid_box',
				]
			]
		);


		$this->add_control(
			'grid_box_link_url',
			[
				'label' => __( 'Link URL', MOW_TEXT_DOMAIN ),
				'default' => '#',
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'grid_box_show_link' => 'yes',
					'layout' => 'grid_box',
				]
			]
		);

		$this->add_control(
			'grid_box_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'grid_box',
				]
			]
		);

		$this->add_control(
			'grid_box_border_color',
			[
				'label' => esc_html__( 'Border Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_grid_box[data-color="yes"] .item' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_grid_box[data-color="yes"] .title_holder' => 'border-top-color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_grid_box[data-color="yes"] .count' => 'border-left-color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_grid_box .or span:before,{{WRAPPER}} .fn_cs_cats_grid_box .or span:after' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'grid_box',
					'grid_box_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'grid_box_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_grid_box[data-color="yes"] .text' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'grid_box',
					'grid_box_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'grid_box_count_color',
			[
				'label' => esc_html__( 'Count Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_grid_box[data-color="yes"] .count, {{WRAPPER}} .fn_cs_cats_grid_box[data-color="yes"] .or span' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'grid_box',
					'grid_box_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'v_interactive_show_link',
			[
				'label' => esc_html__( 'Show Link', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => ['v_interactive','h_interactive'],
				]
			]
		);

		$this->add_control(
			'v_interactive_or_text',
			[
				'label' => __( 'Or Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Or', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'v_interactive_show_link' => 'yes',
				]
			]
		);


		$this->add_control(
			'v_interactive_link_text',
			[
				'label' => __( 'Link Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'See them All', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'v_interactive_show_link' => 'yes',
				]
			]
		);


		$this->add_control(
			'v_interactive_link_url',
			[
				'label' => __( 'Link URL', MOW_TEXT_DOMAIN ),
				'default' => '#',
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'v_interactive_show_link' => 'yes',
				]
			]
		);

		$this->add_control(
			'h_interactive_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'h_interactive',
				]
			]
		);

		$this->add_control(
			'h_interactive_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .text' => 'color: {{VALUE}};-webkit-text-stroke-color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .title:hover .text' => '-webkit-text-stroke-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'h_interactive',
					'h_interactive_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'h_interactive_countbg_color',
			[
				'label' => esc_html__( 'Count Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .count' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'h_interactive',
					'h_interactive_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'h_interactive_counttext_color',
			[
				'label' => esc_html__( 'Count Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .count' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'h_interactive',
					'h_interactive_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'h_interactive_ortext_color',
			[
				'label' => esc_html__( 'Or Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .or' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'h_interactive',
					'h_interactive_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'h_interactive_orline_color',
			[
				'label' => esc_html__( 'Or Line Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .or:after,{{WRAPPER}} .fn_cs_cats_h_interactive[data-color="yes"] .or:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'h_interactive',
					'h_interactive_custom_color' => 'yes',
				]
			]
		);
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$layout				= $settings['layout'];
		$type				= $settings['type'];
		$ids				= $settings['ids'];
		$prefix				= $settings['prefix'];
		$suffix				= $settings['suffix'];
		$list				= '';
		if($type == 'categories'){
			$ids = preg_replace('/[^0-9,]+/', '', $ids);
			$arr = explode (",", $ids);
			$arr = array_filter($arr, 'strlen');
			$args = array(
				'include' => $arr
			);
			if(empty($arr)){
				$args['number'] = 20;
			}
			$categories = get_categories($args);

			if($layout == 'list'){
				foreach( $categories as $term ) {
					$term_id 	= $term->term_id;
					$term_name 	= $term->name;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'thumbnail');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$count = sprintf( _n( '%d Article', '%d Articles', $term->count, 'mow-core' ), $term->count);
					$list .= '<li><div class="item">';
					$list .= '<div class="img_holder" data-bg-img="'.$term_img.'"><a href="'.$term_url.'" aria-label="/"></a></div>';
					$list .= '<div class="title_holder"><h3 class="name"><a href="'.$term_url.'">'.$prefix.$term_name.$suffix.'</a></h3><p class="count">'.$count.'</p></div>';
					$list .= '</div></li>';
				}
			}else if($layout == 'list_2'){
				foreach( $categories as $term ) {
					$term_id 	= $term->term_id;
					$term_name 	= $term->name;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'thumbnail');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$count = $term->count;
					$list .= '<li><div class="item">';
					$list .= '<div class="img_holder" data-bg-img="'.$term_img.'"><a href="'.$term_url.'" aria-label="/"></a></div>';
					$list .= '<div class="title_holder"><a href="'.$term_url.'"></a><span class="text">'.$prefix.$term_name.$suffix.'</span><span class="count">'.$count.'</span></div>';
					$list .= '</div></li>';
				}
			}else if($layout == 'grid_box'){
				foreach( $categories as $term ) {
					$term_id 	= $term->term_id;
					$term_name 	= $term->name;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'thumbnail');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$sub = '';
					if(!$term_img){
						$sub = mb_substr($term_name, 0, 1);
					}
					$count = $term->count;
					$list .= '<li><div class="item"><a href="'.$term_url.'" aria-label="/"></a>';
					$list .= '<div class="img_wrap"><div class="img_in"><div class="img_holder" style="background-image:url('.$term_img.')">'.$sub.'</div></div></div>';
					$list .= '<div class="title_holder"><span class="text">'.$prefix.$term_name.$suffix.'</span><span class="count">'.$count.'</span></div>';
					$list .= '</div></li>';
				}
			}else if($layout == 'big_marquee' || $layout == 'small_marquee'){
				foreach($categories as $term){
					$term_name = $term->name;
					$term_url = get_term_link($term);
					$list .= '<div class="item"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'">'.$prefix.$term_name.$suffix.'</a><div class="item_sep"></div></div>';
				}
			}else if($layout == 'carousel'){
				foreach($categories as $term){
					$term_name = $term->name;
					$term_url = get_term_link($term);
					$list .= '<div class="swiper-slide" style="width: auto;"><div class="item"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'">'.$prefix.$term_name.$suffix.'</a></div></div>';
				}
			}else if($layout == 'v_interactive'){
				foreach($categories as $key => $term){
					if ($key > 6) {
						break;
					}
					$term_name 	= $term->name;
					$term_count = $term->count;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term->term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'large');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$sub = '';
					if(!$term_img){
						$sub = mb_substr($term_name, 0, 1);
					}
					$img = '<div class="img_holder" data-url="'.$term_img.'"><img class="hidden" src="'.$term_img.'"><span class="sub">'.$sub.'</span></div>';
					$link = '<a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'"></a>';
					$count = '<span class="count">'.$term_count.'</span>';
					$title = '<div class="title_holder"><h3 class="title"><span class="text">'.$prefix.$term_name.$suffix.'</span>'.$count.'</h3></div>';
					$list .= '<div class="item item_list">'.$link.$img.$title.'</div>';
				}
			}else if($layout == 'h_interactive'){
				foreach($categories as $key => $term){
					$term_name 	= $term->name;
					$term_count = $term->count;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term->term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'large');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$sub = '';
					if(!$term_img){
						$sub = mb_substr($term_name, 0, 1);
					}
					$img = '<div class="img_holder" data-url="'.$term_img.'"><img class="hidden" src="'.$term_img.'"><span class="sub">'.$sub.'</span></div>';
					$count = '<span class="count">'.$term_count.'</span>';
					$title = '<h3 class="title"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'"><span class="text">'.$prefix.$term_name.$suffix.'</span>'.$count.'</a></h3>';
					$list .= '<div class="item item_list">'.$img.$title.'</div>';
				}
			}
			
		}else if($type == 'tags'){
			$ids = preg_replace('/[^0-9,]+/', '', $ids);
			$arr = explode (",", $ids);
			$arr = array_filter($arr, 'strlen');

			$args = array(
				'taxonomy' => 'post_tag',
				'include'  => $arr
			);
			if(empty($arr)){
				$args['number'] = 20;
			}
			$tags = get_terms($args);
			
			if($layout == 'list'){
				foreach( $tags as $term ) {
					$term_id 	= $term->term_id;
					$term_name 	= $term->name;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'thumbnail');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$count = sprintf( _n( '%d Article', '%d Articles', $term->count, 'mow' ), $term->count);
					$list .= '<li><div class="item">';
					$list .= '<div class="img_holder" data-bg-img="'.$term_img.'"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'"></a></div>';
					$list .= '<div class="title_holder"><h3 class="name"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'">'.$prefix.$term_name.$suffix.'</a></h3><p class="count">'.$count.'</p></div>';
					$list .= '</div></li>';
				}
			}else if($layout == 'list_2'){
				foreach( $tags as $term ) {
					$term_id 	= $term->term_id;
					$term_name 	= $term->name;
					$term_url 	= get_term_link($term);
					$term_img 	= get_term_meta($term_id, 'category-image-id', true);
					if ( $term_img ) {
						// Get the image URL based on the image ID
						$category_image_url = wp_get_attachment_url( $term_img );
						$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'thumbnail');
						if($imageData){
							$term_img = $imageData[0];
						}
					}
					$count = $term->count;
					$list .= '<li><div class="item">';
					$list .= '<div class="img_holder" data-bg-img="'.$term_img.'"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'"></a></div>';
					$list .= '<div class="title_holder"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'"></a><span class="text">'.$prefix.$term_name.$suffix.'</span><span class="count">'.$count.'</span></div>';
					$list .= '</div></li>';
				}
			}else if($layout == 'big_marquee' || $layout == 'small_marquee'){
				foreach($tags as $term){
					$term_name = $term->name;
					$term_url = get_term_link($term);
					$list .= '<div class="item"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'">'.$prefix.$term_name.$suffix.'</a><div class="item_sep"></div></div>';
				}
			}else if($layout == 'carousel'){
				foreach($tags as $term){
					$term_name = $term->name;
					$term_url = get_term_link($term);
					$list .= '<div class="swiper-slide" style="width: auto;"><div class="item"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'">'.$prefix.$term_name.$suffix.'</a></div></div>';
				}
			}
		}else if($type == 'custom'){
			$custom_list = $settings['custom_list'];
			
			if($layout == 'list'){
				if(!empty($custom_list)){
					foreach($custom_list as $item){
						$term_name 	= $item['list_title'];
						$term_url 	= $item['list_url'];
						$term_img 	= $item['list_image']['url'];

						$list .= '<li><div class="item">';
						$list .= '<div class="img_holder" data-bg-img="'.$term_img.'"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'"></a></div>';
						$list .= '<div class="title_holder"><h3 class="name"><a href="'.$term_url.'" aria-label="'.esc_attr(strip_tags($term_name)).'">'.$prefix.$term_name.$suffix.'</a></h3></div>';
						$list .= '</div></li>';
					}
				}
			}
		}

		if($layout == 'list'){
			$html .= '<div class="fn_cs_cats_list" data-color="'.$settings['custom_color'].'"><div class="container"><div class="cats_list"><ul>'.$list.'</ul></div></div></div>';
		}else if($layout == 'list_2'){
			$list_2_show_link = $settings['list_2_show_link'];
			if($list_2_show_link == 'yes'){
				$list .= '<li><div class="link_item"><span class="text">'.$settings['list_2_or_text'].'</span><a href="'.$settings['list_2_link_url'].'" aria-label="/">'.$settings['list_2_link_text'].'</a></div></li>';
			}
			$html .= '<div class="fn_cs_cats_list2" data-color="'.$settings['custom_color'].'"><div class="container"><div class="cats_list"><ul>'.$list.'</ul></div></div></div>';
		}else if($layout == 'grid_box'){
			$grid_box_show_link = $settings['grid_box_show_link'];
			$list = '<ul>'.$list.'</ul>';
			if($grid_box_show_link == 'yes'){
				$list .= '<div class="or"><span>'.$settings['grid_box_or_text'].'</span></div><div class="see"><a href="'.$settings['grid_box_link_url'].'" aria-label="/">'.$settings['grid_box_link_text'].'</a></div>';
			}
			$html .= '<div class="fn_cs_cats_grid_box" data-color="'.$settings['grid_box_custom_color'].'"><div class="container"><div class="cats_list">'.$list.'</div></div></div>';
		}else if($layout == 'big_marquee'){
			$list = str_repeat($list,10);
			$html .= '<div class="fn_cs_cats_big_marquee"><div class="marquee">'.$list.'</div></div>';
		}else if($layout == 'small_marquee'){
			$list = str_repeat($list,10);
			$html .= '<div class="fn_cs_cats_small_marquee" data-bg="'.$settings['small_marquee_bg'].'"><div class="container"><div class="small_marquee"><div class="marquee">'.$list.'</div></div></div></div>';
		}else if($layout == 'carousel'){
			$slider_nav = '<div class="slider_nav"><div class="swiper-button-prev">'.mow_fn_svg('svg__arrow_4').'</div><div class="swiper-button-next">'.mow_fn_svg('svg__arrow_4').'</div></div>';
			$html .= '<div class="fn_cs_cats_carousel" data-bg="'.$settings['carousel_bg'].'"><div class="container"><div class="cats_carousel"><div class="swiper"><div class="swiper-wrapper">'.$list.'</div>'.$slider_nav.'</div></div></div></div>';
		}else if($layout == 'v_interactive'){
			if($settings['v_interactive_show_link'] == 'yes'){
				$list .= '<div class="item link_item"><span class="or"><span></span>'.$settings['v_interactive_or_text'].'</span><a href="'.$settings['v_interactive_link_url'].'" aria-label="/">'.$settings['v_interactive_link_text'].'</a></div>';
			}
			$html .= '<div class="fn_cs_cats_v_interactive"><div class="container"><div class="v_interactive">'.$list.'</div></div></div>';
		}else if($layout == 'h_interactive'){
			if($settings['v_interactive_show_link'] == 'yes'){
				$extra = '<div class="link_item"><span class="or"><span></span>'.$settings['v_interactive_or_text'].'</span><a href="'.$settings['v_interactive_link_url'].'" aria-label="/">'.$settings['v_interactive_link_text'].'</a></div>';
			}else{
				$extra = '';
			}
			$html .= '<div class="fn_cs_cats_h_interactive" data-color="'.$settings['h_interactive_custom_color'].'"><div class="container"><div class="h_interactive_wrap"><div class="h_interactive">'.$list.'</div>'.$extra.'</div></div></div>';
		}
		
		
		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
