<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Divider extends Widget_Base {

	public function get_name() {
		return 'frel-divider';
	}

	public function get_title() {
		return __( 'Divider', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-divider frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'show_container',
			[
				'label' => esc_html__( 'Container Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'height',
			[
				'label' => esc_html__( 'Height (px)', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 1000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn_cs_divider_in' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$container_start = $container_end = '';
		if($settings['show_container'] == 'yes'){
			$container_start = '<div class="container">';
			$container_end = '</div>';
		}

		$html .= '<div class="fn_cs_divider">'.$container_start.'<div class="fn_cs_divider_in"></div>'.$container_end.'</div>';
		
		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
