<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }


class Frel_Gallery extends Widget_Base {

	public function get_name() {
		return 'frel-gallery';
	}

	public function get_title() {
		return __( 'Gallery', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-animated-headline frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' 	=> __( 'Layout', MOW_TEXT_DOMAIN ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'collage_a',
				'options' 	=> [
					'collage_a'		=> __( 'Collage Alpha', MOW_TEXT_DOMAIN ),
					'collage_b'		=> __( 'Collage Beta', MOW_TEXT_DOMAIN ),
					'collage_g'		=> __( 'Collage Gamma', MOW_TEXT_DOMAIN ),
					'justified'  	=> __( 'Justified', MOW_TEXT_DOMAIN ),
					'masonry'  		=> __( 'Masonry', MOW_TEXT_DOMAIN ),
					'grid'  		=> __( 'Grid', MOW_TEXT_DOMAIN ),
					'mosaic'  		=> __( 'Mosaic', MOW_TEXT_DOMAIN ),
					// 'slider'  		=> __( 'Slider', MOW_TEXT_DOMAIN ),
					// 'woto'  		=> __( 'Woto Slider', MOW_TEXT_DOMAIN ),
				],
			]
		);
		$this->add_control(
			'gallery',
			[
				'label' => __( 'Gallery', MOW_TEXT_DOMAIN ),
				'type' 	=> \Elementor\Controls_Manager::GALLERY,
			]
		);
		
		$this->add_control(
			'gutter',
			[
				'label' 		=> __( 'Gutter', MOW_TEXT_DOMAIN ),
				'description' 	=> __( 'In px. Default value: 20px', MOW_TEXT_DOMAIN ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px' ],
				'range' 		=> [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__cs_gallery_masonry .fn__masonry .mas__in, {{WRAPPER}} .fn__cs_gallery_grid li' => 'padding-left: {{SIZE}}{{UNIT}};margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .fn__cs_gallery_masonry .fn__masonry, {{WRAPPER}} .fn__cs_gallery_grid ul' => 'margin-left: -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .fn__cs_gallery_collage_a ul, {{WRAPPER}} .fn__cs_gallery_collage_b ul, {{WRAPPER}} .fn__cs_gallery_collage_g ul' => 'gap: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'justified_height',
			[
				'label' 		=> __( 'Height', MOW_TEXT_DOMAIN ),
				'description' 	=> __( 'In px. Default value: 400px', MOW_TEXT_DOMAIN ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px' ],
				'range' 		=> [
					'px' => [
						'min' => 0,
						'max' => 1500,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 300,
				],
				'condition' => [
					'layout' => 'justified',
				]
			]
		);
		
		$this->add_control(
			'cols',
			[
				'label' 	=> __( 'Columns', MOW_TEXT_DOMAIN ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '4',
				'options' 	=> [
					'1'			=> __( '1 Column', MOW_TEXT_DOMAIN ),
					'2'  		=> __( '2 Columns', MOW_TEXT_DOMAIN ),
					'3'  		=> __( '3 Columns', MOW_TEXT_DOMAIN ),
					'4'  		=> __( '4 Columns', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => ['masonry','grid'],
				]
			]
		);
		$this->add_responsive_control(
			'collage_ratio',
			[
				'label' => __( 'Image Ratio', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 0.66,
				],
				'tablet_default' => [
					'size' => '',
				],
				'mobile_default' => [
					'size' => 1,
				],
				'range' => [
					'px' => [
						'min' => 0.1,
						'max' => 2,
						'step' => 0.01,
					],
				],
				'condition' => [
					'layout' => ['collage_a','collage_b','collage_g','grid'],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__cs_gallery_collage_a li img, {{WRAPPER}} .fn__cs_gallery_collage_b li img, {{WRAPPER}} .fn__cs_gallery_collage_g li img, {{WRAPPER}} .fn__cs_gallery_grid li img, {{WRAPPER}} .fn__cs_gallery_grid li img' => 'aspect-ratio: calc(1 / {{SIZE}});',
				],
			]
		);
		
		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 5,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 2000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__cs_gallery_collage_a li img,{{WRAPPER}} .fn__cs_gallery_collage_b li img,{{WRAPPER}} .fn__cs_gallery_collage_g li img,{{WRAPPER}} .fn__cs_gallery_masonry .fn__masonry .mas__in img,{{WRAPPER}} .fn__cs_gallery_grid li img,{{WRAPPER}} .fn__cs_gallery_slider .item img' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .justified-gallery>a' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'lightbox',
			[
				'label' 	=> __( 'Lightbox', MOW_TEXT_DOMAIN ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> 'disabled',
				'options' 	=> [
					'enabled'	=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disabled'	=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
			]
		);
		
		$this->add_control(
			'fn_container',
			[
				'label' 	=> __( 'Page Width', MOW_TEXT_DOMAIN ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '',
				'options' 	=> [
					''  			=> __( 'Full', MOW_TEXT_DOMAIN ),
					'container'  	=> __( 'Contained', MOW_TEXT_DOMAIN ),
				],
			]
		);
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 		= $this->get_settings();
		$html 			= Frel_Helper::frel_open_wrap();
		$layout			= $settings['layout'];
		
		// ***************************************
		$lightbox		= $settings['lightbox'];
		$l__parent 		= $l__child = '';
		if($lightbox == 'enabled'){
			$l__parent 	= 'fn__lightbox_wrap';
			$l__child 	= 'fn__lightbox_item fn__link';
		}
		// ***************************************
		
		// ****************************** Container ***********************************
		$fnContainer	= $settings['fn_container'];								//*
		if($fnContainer == 'container'){											//*
			$fnC_Start	= '<div class="container">';								//*
			$fnC_End	= '</div>';													//*
		}else{																		//*
			$fnC_Start 	= $fnC_End = '';											//*
		}																			//*
		// ****************************************************************************

		if($layout == 'collage_a' || $layout == 'collage_b' || $layout == 'collage_g'){
			
			$html .= '<div class="fn__cs_gallery_'.$layout.' '.$l__parent.'">'.$fnC_Start.'<div class="'.$layout.'_inner"><ul>';
		
			foreach ( $settings['gallery'] as $image ) {
				$html .= '<li><div class="item">';
				if($lightbox == 'enabled'){
					$html .= '<a class="'.$l__child.'" data-src="'.$image['url'].'">';
				}
				$html .= '<img src="'.$image['url'].'" alt="">';
				if($lightbox == 'enabled'){
					$html .= '</a>';
				}
				$html .= '</div></li>';
			}

			$html .= '</ul></div>'.$fnC_End.'</div>';
			
		}else if($layout == 'justified'){
			
			$height			 = $settings['justified_height']['size'];
			$gutter			 = $settings['gutter']['size'];
			
			$html			.= '<div class="fn__cs_gallery_'.$layout.'">'.$fnC_Start.'<div class="inner"><div class="fn__justified_gallery '.$l__parent.'" data-gutter="'.$gutter.'" data-height="'.$height.'">';
			
			foreach ( $settings['gallery'] as $key => $image ) {
				$fullURL	= $image['url'];
				$imageID	= $image['id'];
				$img		= wp_get_attachment_image_src( $imageID, 'large');
				if(isset($img[0])){
					$imgURL = $img[0];
				}else if($fullURL != ''){
					$imgURL = $fullURL;
				}
				$html .= '<a class="'.$l__child.'" data-src="'.$fullURL.'">';
				$html .= '<img src="'.$imgURL.'" alt="">';
				$html .= '</a>';
			}
			
			$html 			.= '</div></div>'.$fnC_End.'</div>';
			
		}else if($layout == 'masonry'){
			$cols			= $settings['cols'];
			$html			.= '<div class="fn__cs_gallery_masonry" data-cols="'.$cols.'">'.$fnC_Start.'<div class="inner"><ul class="fn__masonry '.$l__parent.'">';
			foreach ( $settings['gallery'] as $key => $image ) {
				$fullURL	= $image['url'];
				$imageID	= $image['id'];
				$img		= wp_get_attachment_image_src( $imageID, 'large');
				if(isset($img[0])){
					$imgURL = $img[0];
				}else if($fullURL != ''){
					$imgURL = $fullURL;
				}
				list($width, $height) = getimagesize($imgURL);
				$imgHTML	= '<img src="'.$imgURL.'" width="'.$width.'" height="'.$height.'" alt="">';
				$html 		.= '<li class="mas__in"><div class="item '.$l__child.'" data-src="'.$fullURL.'">'.$imgHTML.'</div></li>';
			}

			$html 			.= '</ul></div>'.$fnC_End.'</div>';
			
		}else if($layout == 'mosaic'){
			$html			.= $fnC_Start.'<div class="fn__cs_gallery_mosaic" data-hgap="20" data-vgap="20" data-ratio="1"><ul class="listt '.$l__parent.'">';
			foreach ( $settings['gallery'] as $key => $image ) {
				$fullURL	= $image['url'];
				$imageID	= $image['id'];
				$img		= wp_get_attachment_image_src( $imageID, 'large');
				if(isset($img[0])){
					$imgURL = $img[0];
				}else if($fullURL != ''){
					$imgURL = $fullURL;
				}
				list($width, $height) = getimagesize($imgURL);
				$imgHTML	= '<img src="'.$imgURL.'" width="'.$width.'" height="'.$height.'" alt="">';
				$html 		.= '<li><div class="img_holder" '.$l__child.' data-src="'.$fullURL.'"><div class="item_in">'.$imgHTML.'</div></div></li>';
			}

			$html 			.= '</ul></div>'.$fnC_End;
			
		}else if($layout == 'slider'){
			$array = $settings['gallery'];
			if (count($array) % 2 !== 0) {
				array_pop($array);
			}

			$html			.= '<div class="fn__cs_gallery_slider">'.$fnC_Start.'<div class="inner '.$l__parent.'">';

				$html			.= '<div class="swiper-container">';
					$html			.= '<div class="swiper-wrapper">';
						foreach ( $array as $key => $image ) {
							$fullURL	= $image['url'];
							$imageID	= $image['id'];
							$img		= wp_get_attachment_image_src( $imageID, 'large');
							if(isset($img[0])){
								$imgURL = $img[0];
							}else if($fullURL != ''){
								$imgURL = $fullURL;
							}
							list($width, $height) = getimagesize($imgURL);
							$imgHTML	= '<img src="'.$imgURL.'" width="'.$width.'" height="'.$height.'" alt="">';
							$myKey 		= $key % 2;
							if($myKey == 0){
								$html .= '<div class="swiper-slide"><div class="item_wrapper">';
							}
							$html .= '<div class="item '.$l__child.'" data-src="'.$fullURL.'">'.$imgHTML.'</div>';
							if($myKey == 1){
								$html .= '</div></div>';
							}
						}
					$html 			.= '</div>';
				$html			.= '</div>';

			$html 			.= $fnC_End.'</div></div>';
		}else if($layout == 'grid'){
			$cols			= $settings['cols'];
			$html			.= '<div class="fn__cs_gallery_grid" data-cols="'.$cols.'">'.$fnC_Start.'<div class="inner"><ul class="'.$l__parent.'">';
			foreach ( $settings['gallery'] as $key => $image ) {
				$fullURL	= $image['url'];
				$imageID	= attachment_url_to_postid( $fullURL );
				$img		= wp_get_attachment_image_src( $imageID, 'large');
				if(isset($img[0])){
					$imgURL = $img[0];
				}else if($fullURL != ''){
					$imgURL = $fullURL;
				}
				$html 		.= '<li><div class="item '.$l__child.'" data-src="'.$fullURL.'"><img src="'.$imgURL.'" alt=""></div></li>';
			}

			$html 			.= '</ul></div>'.$fnC_End.'</div>';
			
		}else if($layout == 'woto'){
			$woto_previous		= '<a href="#" class="prev">'.mow_fn_svg('right-arr').'</a>';
			$woto_next			= '<a href="#" class="next">'.mow_fn_svg('right-arr').'</a>';

			$woto_title 		= '<div class="woto_title_wrapper"><h1 class="woto_title"></h1></div>';
			$woto_control		= '';
			$thumbArea			= '<div class="woto_thmb_viewport"><div class="woto_thmb_wrapper"><ul class="woto_thmb_list woto_thumbs"></ul></div></div>';
			$data_autoplay 		= 'autoplay';
			$slideInterval 		= 4000;
			$woto_bbb 			= '<div class="woto_gallery_slider" data-thumbs-btn-title="Thumbs"></div>';
			$woto_aaa	  		= $woto_title.$woto_control.$woto_bbb;
			$html				.= '<div class="woto_gallery_all_wrapper">';
			$html				.= $thumbArea;
			$html				.= $woto_aaa;
			$html			 	.= '<div class="woto_gallery_trigger personal_preloader"></div><div class="woto_gallery_wrapper fadeOnLoad">';
			$slides				= '<ul class="no_fit woto_gallery_container '.$data_autoplay.' woto_slider fade video_cover controls_on" data-video="0" data-interval="'.$slideInterval.'" data-autoplay="'.$data_autoplay.'">';
			
			$gallery = $settings['gallery'];
			if ( $gallery ) {
				foreach ( $gallery as $key => $item ) {
					$key++;
					if($item['url'] != ''){
						$slides .= '<li 
						class="woto_slide slide_image block2preload woto_slide'.$key.'" 
						data-count="'.$key.'" 
						data-src="'.$item['url'].'" 
						data-thumb-src="'.$item['url'].'"
						data-bg-img="'.$item['url'].'" 
						data-type="image">
					</li>';
					}
				}
			}
			$slides .= '</ul>';
			$html .= $slides;
			$html .= '</div>';
			$html .= '</div>';
		}
		
		
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
