<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Search extends Widget_Base {

	public function get_name() {
		return 'frel-search';
	}

	public function get_title() {
		return __( 'Search', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-search frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'list_title',
			[
				'label' => __( 'List Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);


		$this->add_control(
			'custom_list',
			[
				'label' => __( 'List', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}'
			]
		);

		$this->add_control(
			'search_placeholder',
			[
				'label' => __( 'Placeholder Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Search Here...', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);

		$this->add_control(
			'search_submit',
			[
				'label' => __( 'Submit Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Search', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);

		$this->add_control(
			'recommended_categories',
			[
				'label' 		=> __( 'Recommended Categories', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'enabled',
				'options' 		=> [
					'enabled'  			=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disabled'  		=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'recommended_label',
			[
				'label' => __( 'Recommended Label', MOW_TEXT_DOMAIN ),
				'default' => __( 'Popular Searches:', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'recommended_categories' => 'enabled',
				]
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' 		=> __( 'Categories Order', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'popular',
				'options' 		=> [
					'popular'  			=> __( 'Popular', MOW_TEXT_DOMAIN ),
					'by_name'  			=> __( 'By Name', MOW_TEXT_DOMAIN ),
					'random'  			=> __( 'Random', MOW_TEXT_DOMAIN ),
					'custom'  			=> __( 'Custom by IDs', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'recommended_categories' => 'enabled',
				]
			]
		);
		
		
		$this->add_control(
			'ids',
			[
				'label' => __( 'Categories IDs', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'condition' => [
					'recommended_categories' => 'enabled',
					'orderby' => 'custom',
				]
			]
		);

		$this->add_control(
			'custom_color',
			[
				'label' 		=> __( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'disabled',
				'options' 		=> [
					'enabled'  			=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disabled'  		=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'bg_color',
			[
				'label' => esc_html__( 'Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} [data-color="enabled"] .searchbox, {{WRAPPER}} [data-color="enabled"] .marquee .item_sep, {{WRAPPER}} [data-color="enabled"] .marquee .item_sep:before, {{WRAPPER}} [data-color="enabled"] .marquee .item_sep:after' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} [data-color="enabled"] .marquee .item, {{WRAPPER}} [data-color="enabled"] .search input' => 'color: {{VALUE}}',
				],
				'condition' => [
					'custom_color' => 'enabled',
				]
			]
		);
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} [data-color="enabled"] .input input, {{WRAPPER}} [data-color="enabled"] .label, {{WRAPPER}} [data-color="enabled"] .cats a' => 'color: {{VALUE}}',
					'{{WRAPPER}} [data-color="enabled"] .cats a' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} [data-color="enabled"] .main_form' => 'border-bottom-color: {{VALUE}}',
					'{{WRAPPER}} [data-color="enabled"] .search input' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'custom_color' => 'enabled',
				]
			]
		);
		
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$custom_list		= $settings['custom_list'];

		echo '<style>[data-color="enabled"] .input input::-webkit-input-placeholder {color:'.$settings['text_color'].';}[data-color="enabled"] .input input::-moz-placeholder {color:'.$settings['text_color'].';}[data-color="enabled"] .input input::-ms-placeholder {color:'.$settings['text_color'].';}[data-color="enabled"] .input input::placeholder {color:'.$settings['text_color'].';}</style>';
		$top_titles = '';
		if(!empty($custom_list)){
			foreach($custom_list as $top_title){
				$top_titles .= '<div class="item">'.$top_title['list_title'].'<div class="item_sep"></div></div>';
			}
		}
		if($top_titles != ''){
			$top_titles = '<div class="top_titles"><div class="marquee">'.$top_titles.'</div></div>';
		}

		$html .= '<div class="fn_cs_searchbox" data-color="'.$settings['custom_color'].'">';
		$html .= $top_titles;
		$html .= '<div class="searchbox"><div class="container"><div class="searchform">';
		$html .= '<form class="main_form" action="'.esc_url(home_url('/')).'" method="get" >
					<div class="input">
						<input type="text" placeholder="'.esc_attr($settings['search_placeholder']).'" name="s" autocomplete="off">
					</div>
					<div class="search">
						<input type="submit" class="pe-7s-search" value="'.esc_attr($settings['search_submit']).'">
					</div>
				</form>';
		if($settings['recommended_categories'] == 'enabled'){
			$search_rc_type = $settings['orderby'];
			$search_rc_list = '';
			if ( $search_rc_type == 'popular' ) {
				$categories = get_categories( array(
					'orderby'	=> 'count',
					'order'		=> 'DESC',
					'hide_empty'=> true,
					'number'	=> 4
				) );
			}else if ( $search_rc_type == 'by_name' ) {
				$categories = get_categories( array(
					'orderby'	=> 'name',
					'order'		=> 'ASC',
					'hide_empty'=> true,
					'number'	=> 4
				) );
			}else if ( $search_rc_type == 'random' ) {
				$categories = get_categories(array( 'hide_empty'=> true ));
				shuffle( $categories );
				$categories = array_slice( $categories, 0, 4);
			}else if ( $search_rc_type == 'custom' ) {
				if($settings['ids'] != ''){
					$search_rc_ids = $settings['ids'];
					$search_rc_ids = preg_replace('/[^0-9,]+/', '', $search_rc_ids);
					$arr = explode (",", $search_rc_ids);
					$custom = array_filter($arr, 'strlen');
				}
				if(isset($custom) && !empty($custom)){
					$categories = get_categories( array(
						'include' => $custom,
						'hide_empty'=> true,
						'orderby' => 'include',
					) );
				}
			}

			if(isset($categories) && !empty($categories)){
				foreach ( $categories as $category ) {
					$search_rc_list .= '<a href="' . esc_url( get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a>';
				}
			}
			if($search_rc_list != ''){
				$html .= '<div class="popular_cats">';
				$html .= '<div class="label">'.$settings['recommended_label'].'</div>';
				$html .= '<div class="cats">'.$search_rc_list.'</div>';
				$html .= '</div>';
			}
		}
		

		$html .= '</div></div></div>';
		$html .= '</div>';

		
		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
