<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Single_Video extends Widget_Base {

	public function get_name() {
		return 'frel-single-video';
	}

	public function get_title() {
		return __( 'Single Video', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-video-camera frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$this->add_control(
			'video_url',
			[
				'label' => __( 'Video URL (Youtube)', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$this->add_control(
			'fallback',
			[
				'label' => esc_html__( 'Fallback Image', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$video_url			= $settings['video_url'];
		$fallback			= $settings['fallback']['url'];

		if($fallback != ''){
			$fallback = 'coverImage: \''.$fallback.'\', ';
		}

		$html .= '<div class="fn_cs_single_video">';
		$video_type 		= mow_fn_detect_video($video_url);
		if($video_type == 'local'){
			$html .= '<div class="video_local"><video class="fcsvl_video video" autoplay controls playsinline><source src="'.$video_url.'" type="video/mp4"></video></div>';
		}else if($video_type == 'youtube'){
			$html .= '<div class="video_youtube"><div class="fcsvy_video video" data-property="{videoURL:\''.$video_url.'\', containment:\'self\', autoPlay:false, loop:false, addRaster: false, mute:false, '.$fallback.'showControls:false, stopMovieOnBlur:false, opacity:1, ratio: \'auto\', showYTLogo: false, anchor: \'center,center\'}"></div><span class="icon fn__link"><span class="play"></span><span class="pause"></span></span></div>';
		}

		$html .= '<div class="title_holder">'.mow_fn_svg('curlyarrow').'<div class="title_wrap"><div class="title"><span>'.esc_html($settings['title']).'</span></div></div></div>';
		$html .= '</div>';
		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
