<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Team_Members extends Widget_Base {

	public function get_name() {
		return 'frel-team-members';
	}

	public function get_title() {
		return __( 'Team Members', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-person frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'image',
			[
				'label' => esc_html__( 'Image', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'name',
			[
				'label' => __( 'Name', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'occ',
			[
				'label' => __( 'Occupation', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'desc',
			[
				'label' => __( 'Description', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'facebook_url',
			[
				'label' => __( 'Facebook URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'twitter_url',
			[
				'label' => __( 'Twitter URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'pinterest_url',
			[
				'label' => __( 'Pinterest URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'linkedin_url',
			[
				'label' => __( 'Linkedin URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'behance_url',
			[
				'label' => __( 'Behance URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'vimeo_url',
			[
				'label' => __( 'Vimeo URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'google_url',
			[
				'label' => __( 'Google URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'youtube_url',
			[
				'label' => __( 'Youtube URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'instagram_url',
			[
				'label' => __( 'Instagram URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'github_url',
			[
				'label' => __( 'Github URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'flickr_url',
			[
				'label' => __( 'Flickr URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'dribbble_url',
			[
				'label' => __( 'Dribbble URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'dropbox_url',
			[
				'label' => __( 'Dropbox URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'paypal_url',
			[
				'label' => __( 'Paypal URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'picasa_url',
			[
				'label' => __( 'Picasa URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'soundcloud_url',
			[
				'label' => __( 'Soundcloud URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'whatsapp_url',
			[
				'label' => __( 'Whatsapp URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'skype_url',
			[
				'label' => __( 'Skype URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'slack_url',
			[
				'label' => __( 'Slack URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'wechat_url',
			[
				'label' => __( 'Wechat URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'icq_url',
			[
				'label' => __( 'ICQ URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'rocketchat_url',
			[
				'label' => __( 'Rocketchat URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'telegram_url',
			[
				'label' => __( 'Telegram URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'tiktok_url',
			[
				'label' => __( 'Tiktok URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'vkontakte_url',
			[
				'label' => __( 'Vkontakte URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$this->add_control(
			'members',
			[
				'label' => __( 'Team Members', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ name }}}',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Image_Size::get_type(),
			[
				'name' => 'thumbnail', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `thumbnail_size` and `thumbnail_custom_dimension`.
				'exclude' => [ 'custom' ],
				'include' => [],
				'default' => 'large',
			]
		);
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$members			= $settings['members'];

		$allSocial = array(
			'facebook',
			'twitter',
			'pinterest',
			'linkedin',
			'behance',
			'vimeo',
			'google',
			'youtube',
			'instagram',
			'github',
			'flickr',
			'dribbble',
			'dropbox',
			'paypal',
			'picasa',
			'soundcloud',
			'whatsapp',
			'skype',
			'slack',
			'wechat',
			'icq',
			'rocketchat',
			'telegram',
			'tiktok',
			'vkontakte',
		);		

		$list = '';
		if(!empty($members)){
			foreach($members as $member){
				$name = $member['name'];
				$image = $member['image']['url'];
				$occ = $member['occ'];
				$desc = $member['desc'];
				if($image != ''){
					$image = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $member, 'thumbnail', 'image' );
					$image = '<div class="img_holder">'.$image.'</div>';
				}
				if($name != ''){
					$name = '<h3 class="name">'.$name.'</h3>';
				}
				if($occ != ''){
					$occ = '<h4 class="occ">'.$occ.'</h4>';
				}
				$social = $socialList = '';
				foreach($allSocial as $key){
					if($member[$key.'_url'] != ''){
						$text = $key;
						if($key == 'twitter'){
							$text = esc_html__('X Network', 'mow');
						}	
						$socialList .= '<li><a href="'.esc_url($member[$key.'_url']).'" target="_blank" title="'.esc_attr($text).'">'.mow_fn_svg($key).'</a></li>';
					}
				}
				if($socialList != ''){
					$social = '<div class="mow_fn_share"><div class="share_wrapper"><ul>'.$socialList.'</ul></div></div>';
				}
				
				$info = '<div class="member_info">'.$name.$occ.$social.'</div>';
				$list .= '<li class="member_item"><div class="item">';
				$list .= '<div class="member_top">'.$image.$info.'</div>';
				$list .= '<div class="member_bottom"><p>'.$desc.'</p></div>';
				$list .= '</div></li>';
			}
		}
		$html .= '<div class="fn_cs_team_members"><ul class="member_list">'.$list.'</ul></div>';
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
