<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Youtube_List extends Widget_Base {

	public function get_name() {
		return 'frel-youtube-list';
	}

	public function get_title() {
		return __( 'Youtube/Local Video List', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-video-playlist frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'video',
            'youtube',
            'ytplayer',
            'play',
            'trailers',
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'title',
			[
				'label' => __( 'Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);

		$repeater->add_control(
			'fallback',
			[
				'label' => esc_html__( 'Thumbnail Image', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);


		$repeater->add_control(
			'url',
			[
				'label' => __( 'Video URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true
			]
		);


		$this->add_control(
			'list',
			[
				'label' => __( 'List', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
			'active_color',
			[
				'label' => esc_html__( 'Active Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn_cs_youtube_list .list_part li.active .img' => 'border-color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_youtube_list .count_holder .play:after' => 'border-left-color: {{VALUE}}',
				],
			]
		);
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$list				= $settings['list'];
		$ytplayer = '';
		$video_list = '';
		$iframes = '';
		if(!empty($list)){
			foreach($list as $key => $item){
				$active = '';
				$video_url = $item['url'];
				if($key == 0){
					$active = 'active';
				}
				$video_type = mow_fn_detect_video($video_url);
				if($video_type == 'local'){
					$iframes .= '<video controls playsinline><source src="'.$video_url.'" type="video/mp4"></video>';
				}else if($video_type == 'youtube'){
					$iframes .= '<iframe width="100%" height="565" src="'.mow_fn_getYoutubeEmbedUrl($video_url).'" frameborder="0" allowfullscreen></iframe>';
				}
				$count = '<span class="count_holder"><span class="count">'.($key+1).'</span><span class="play"></span></span>';
				$image = '<div class="img"><img loading="lazy" decoding="async" src="'.$item['fallback']['url'].'" alt=""></div>';
				$title = '<h3 class="title"><span>'.$item['title'].'</span></h3>';
				$item_wrap = '<div class="item">'.$count.$image.$title.'</div>';
				$video_list .= '<li class="fn__link '.$active.'" data-url="'.$item['url'].'">'.$item_wrap.'</li>';
			}
		}
		$html .= '<div class="fn_cs_youtube_list"><div class="video_part">'.$ytplayer.$iframes.'</div><div class="list_part"><div class="list_in"><ul>'.$video_list.'</ul></div></div></div>';
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
