<?php
/*
	Template Name: Coming Soon Page
*/

get_header();

global $post;
$mow_fn_option 		= mow_fn_theme_option();
if(function_exists('rwmb_meta')){
	$date 			= rwmb_meta( 'mow_fn_coming_time' );
	$rwmb_title 	= rwmb_meta( 'mow_fn_coming_title' );
	$rwmb_desc 		= rwmb_meta( 'mow_fn_coming_desc' );
}

if(isset($date)){
	$date 			= date('F j, Y H:i:s', strtotime($date));
}else{
	$date			= '';
}
if(!isset($rwmb_title) || $rwmb_title === ''){
	$rwmb_title = esc_html__('Building Tomorrow, Today','mow');
}
if(!isset($rwmb_desc) || $rwmb_desc === ''){
	$rwmb_desc = esc_html__('We are crafting a new vision that blends innovation, quality, and design. Stay tuned for the big reveal. Your dream space is about to become a reality. Countdown with us!','mow');
}
$default_logo = mow_fn_getLogo();

// Core Web Vitals 
$image_width1 = $image_height1 = 'auto';
if ($default_logo[0][0]) {
	$image_path1 = str_replace(site_url(), ABSPATH, $default_logo[0][0]); // Convert URL to absolute path
	if (file_exists($image_path1)) {
		list($image_width1, $image_height1) = getimagesize($image_path1);
	}
}
$image_width2 = $image_height2 = 'auto';
if ($default_logo[1][0]) {
	$image_path2 = str_replace(site_url(), ABSPATH, $default_logo[1][0]); // Convert URL to absolute path
	if (file_exists($image_path2)) {
		list($image_width2, $image_height2) = getimagesize($image_path2);
	}
}

$logo = '<a href="'.esc_url(home_url('/')).'" aria-label="'.esc_attr__('Go to homepage', 'mow').'">';
	$logo .= '<img loading="lazy" decoding="async" width="'.$image_width1.'" height="'.$image_height1.'" class="dark_logo" src="'.esc_url($default_logo[0][0]).'" alt="'.esc_attr__('logo', 'mow').'">';
	$logo .= '<img loading="lazy" decoding="async" width="'.$image_width2.'" height="'.$image_height2.'" class="light_logo" src="'.esc_url($default_logo[1][0]).'" alt="'.esc_attr__('logo', 'mow').'">';
$logo .= '</a>';


// Check if page is password protected	
if(post_password_required($post)){
	mow_fn_protectedpage();
}
else
{
$switch_theme_mode = 'enable';
if(isset($mow_fn_option['switch_theme_mode'])){
	$switch_theme_mode = $mow_fn_option['switch_theme_mode'];
}
?>
	
	<div class="mow_fn_coming_soon">
		<div class="container">
			
			<div class="soon_countdown">

				<div class="fn__header_s">
					<div class="ht_left_item fn__logo">
						<?php echo wp_kses($logo, 'post'); ?>
					</div>
					<?php if($switch_theme_mode == 'enable'){ ?>
					<div class="hs_left_item fn__skin">
						<a href="#" class="light" aria-label="<?php esc_attr_e('Switch to light mode', 'mow'); ?>"><span class="text"><?php esc_html_e('Light', 'mow'); ?></span><?php mow_fn_svg('svg__sun','', true); ?></a>
						<a href="#" class="dark" aria-label="<?php esc_attr_e('Switch to dark mode', 'mow'); ?>"><span class="text"><?php esc_html_e('Dark', 'mow'); ?></span><?php mow_fn_svg('svg__moon','', true); ?></a>
					</div>
					<?php } ?>
				</div>
				<!-- 
					There is two types of countdown: due_date (Due Date), ever (Evergreen timer)
						1. 	data-type="due_date"
							In this case you have to change value of data-date. For example:
							data-date="October 13, 2022 12:30:00"
							It will mean that mint will finished at this time

						2. 	data-type="ever"
							In this case you have to change values of data-days, data-hours, data-minutes and data-seconds. For example:
							data-days="34"
							data-hours="10"
							data-minutes="20"
							data-seconds="0"
							It will mean that the time expires after this time, but when the page is refreshed, the value will return again. It means, it won't end.
					Add boxed class to get #1 type of countdown
				-->
				<div class="fn__countdown__boxed" data-type="due_date" data-date="<?php echo esc_attr($date);?>">
					<ul>
						<li class="days">
							<div class="item">
								<div class="count">
									<h3 class="fn__title">00</h3>
								</div>
								<span><?php esc_html_e('&#47; Days &#47;', 'mow'); ?></span>
							</div>
						</li>
						<li class="hours">
							<div class="item">
								<div class="count">
									<h3 class="fn__title">00</h3>
								</div>
								<span><?php esc_html_e('&#47; Hours &#47;', 'mow'); ?></span>
							</div>
						</li>
						<li class="minutes">
							<div class="item">
								<div class="count">
									<h3 class="fn__title">00</h3>
								</div>
								<span><?php esc_html_e('&#47; Minutes &#47;', 'mow'); ?></span>
							</div>
						</li><li class="seconds">
							<div class="item">
								<div class="count">
									<h3 class="fn__title">00</h3>
								</div>
								<span><?php esc_html_e('&#47; Seconds &#47;', 'mow'); ?></span>
							</div>
						</li>
					</ul>
					</div>
			</div>
			<div class="soon_title">
				<h3><?php echo esc_html($rwmb_title); ?></h3>
				<p><?php echo esc_html($rwmb_desc); ?></p>
			</div>
			
		</div>			
	</div>
<?php } ?>

<?php get_footer(); ?>  