<?php
/*
 * Description: Allows users to upload and select unlimited custom fonts.
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Add Mow Custom Fonts menu
function mow_add_custom_fonts_submenu() {
    add_submenu_page(
        'mow-core',           // Parent slug (Mow Core menu)
        esc_html__('Custom Fonts', 'mow'),   // Page title
        esc_html__('Custom Fonts', 'mow'),   // Menu title
        'manage_options',     // Capability
        'mow-custom-fonts',   // Menu slug
        'mow_custom_fonts_page' // Callback function
    );
}
add_action('admin_menu', 'mow_add_custom_fonts_submenu');

// Display Mow Custom Fonts Page
function mow_custom_fonts_page() {
    $fonts = get_option('mow_custom_fonts', []);
    ?>
    <div class="wrap">
        <h1><?php esc_html_e('Custom Fonts', 'mow'); ?></h1>
        <p>
            <?php 
            printf(
                esc_html__('Upload .woff format only. You can convert your font files from any format into .woff format using %s.', 'mow'),
                '<a href="' . esc_url('https://cloudconvert.com/') . '" target="_blank">Cloudconvert</a>'
            ); 
            ?>
        </p>

        <form method="post" action="options.php">
            <?php settings_fields('mow_custom_fonts_group'); ?>
            <table class="form-table" id="mow-custom-fonts-table">
                <thead>
                    <tr>
                    <th><?php esc_html_e('Font URL', 'mow'); ?></th>
                    <th><?php esc_html_e('Font Name', 'mow'); ?></th>
                    <th></th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($fonts)) : ?>
                        <?php foreach ($fonts as $index => $font) : ?>
                            <tr>
                                <td>
                                    <input type="text" class="mow-font-url" name="mow_custom_fonts[<?php echo $index; ?>][url]" value="<?php echo esc_attr($font['url']); ?>" placeholder="<?php esc_html_e('Font Url', 'mow'); ?>" />
                                    <button type="button" class="button mow-upload-font"><?php esc_html_e('Upload', 'mow'); ?></button>
                                </td>
                                <td><input type="text" name="mow_custom_fonts[<?php echo $index; ?>][name]" value="<?php echo esc_attr($font['name']); ?>" placeholder="<?php esc_html_e('Font Name', 'mow'); ?>" /></td>
                                <td><button type="button" class="button remove-font"><?php esc_html_e('Remove', 'mow'); ?></button></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
            <p><button type="button" class="button" id="add-font"><?php esc_html_e('Add Font', 'mow'); ?></button></p>
            <?php submit_button(); ?>
        </form>
    </div>
    <script>
        jQuery(document).ready(function($) {
            $('#add-font').click(function() {
                let index = $('#mow-custom-fonts-table tbody tr').length;
                let newRow = `<tr>
                    <td>
                        <input type="text" class="mow-font-url" name="mow_custom_fonts[${index}][url]" placeholder="Font URL" />
                        <button type="button" class="button mow-upload-font">Upload</button>
                    </td>
                    <td><input type="text" name="mow_custom_fonts[${index}][name]" placeholder="Font Name" /></td>
                    <td><button type="button" class="button remove-font">Remove</button></td>
                </tr>`;
                $('#mow-custom-fonts-table tbody').append(newRow);
                mmpop();
            });
            
            $(document).on('click', '.remove-font', function() {
                $(this).closest('tr').remove();
            });

            mmpop();

            function mmpop(){
                $('.mow-upload-font').click(function(e) {
                    e.preventDefault();
                    
                    var button = $(this);
                    var inputField = button.siblings('.mow-font-url');

                    var customUploader = wp.media({
                        multiple: false
                    }).on('select', function() {
                        var attachment = customUploader.state().get('selection').first().toJSON();
                        inputField.val(attachment.url);
                    }).open();
                });
            }

            

        });

       

    </script>
    <?php
}

// Register setting
function mow_register_custom_fonts_setting() {
    register_setting('mow_custom_fonts_group', 'mow_custom_fonts');
}
add_action('admin_init', 'mow_register_custom_fonts_setting');


