/*
 * Copyright (c) 2023 frenify
 * Author: Frenify
 * This file is made for CURRENT Theme
*/

(function($){
	"use strict";
	
	var FrenifyCore = {
			
		init: function(){
			this.magnific();
			this.bg_images();
			this.tooltip();
			this.activateTheme();
			this.revokePurchasecode();
		},
		
		revokePurchasecode: function(){

			var self = this;
			var parentHolder = $('.frenify__verification');
			$('.frenify__revoke a.fn__revoke').off().on('click', function(){
				
				const apiURL 		= 'https://frenify.com/api/verification/';
				var currentTheme 	= mowData.themeName;
				var currentDomain 	= window.location.href;
				var parento			= $(this).parents('.frenify__revoke');
				var loader			= parento.find('.fn__loading');
				var notice			= parento.find('.fn__notice');

				
				loader.addClass('is_active');
				parentHolder.addClass('is_active');
				// Make an AJAX POST request to the API endpoint
				$.ajax({
					url: apiURL,
					type: 'POST',
					contentType: 'application/json',
					data: JSON.stringify({ theme_name: currentTheme, domain_name: currentDomain, action:'revokePurchase' }),
					success: function(response) {
						// Handle the response from the server
						
						parentHolder.removeClass('is_active');
						if(response.code == 1){
							self.updateThemeStatus('deactivate','');
							parentHolder.attr('data-status','inactive');
							notice = $('.frenify__verification_form .fn__notice');
							notice.addClass('is_active').addClass('success').html(response.message);
							setTimeout(function(){
								notice.removeClass('success').addClass('refresh').html(parentHolder.find('.refresh_hidden').html());
								setTimeout(function(){
									notice.find('.sec').text(2);
								},1000);
								setTimeout(function(){
									notice.find('.sec').text(1);
								},2000);
								setTimeout(function(){
									notice.find('.sec').text(0);
									location.reload();
								},3000);
							}, 3000);
						}
						else{
							notice.addClass('is_active').html(response.message);
							setTimeout(function(){
								notice.removeClass('is_active success');
							}, 5000);
						}
						loader.removeClass('is_active');

						
					},
					error: function(error) {
						// Handle errors
						console.error(error);
						notice.addClass('is_active').html('Unexpected Error. Contact with theme developer');
						loader.removeClass('is_active');
						parentHolder.removeClass('is_active').find('.fn__purchase_code').prop('disabled', false);
					}
					
				});

				return false;

			});
		},
		activateTheme: function(){

			var self = this;
			var parentHolder = $('.frenify__verification');

			$('.frenify__verification_form a.fn__verify').off().on('click', function(){
				
				const apiURL 		= 'https://frenify.com/api/verification/';
				var currentTheme 	= mowData.themeName;
				var currentDomain 	= window.location.href;
				var parento			= $(this).parents('.frenify__verification_form');
				var input			= parento.find('.fn__purchase_code');
				var purchaseCode 	= input.val();
				var loader			= parento.find('.fn__loading');
				var notice			= parento.find('.fn__notice');

				if(purchaseCode === ''){
					
					notice.addClass('is_active').html('You haven\'t entered anything');

					setTimeout(function(){
						notice.removeClass('is_active');
					}, 5000);

					return false;
				
				}
				
				parentHolder.addClass('is_active').find('.fn__purchase_code').prop('disabled', true);
				loader.addClass('is_active');
				// Make an AJAX POST request to the API endpoint
				$.ajax({
					url: apiURL,
					type: 'POST',
					contentType: 'application/json',
					data: JSON.stringify({ purchase_code: purchaseCode, theme_name: currentTheme, domain_name: currentDomain, action:'verifyPurchase' }),
					success: function(response) {
						parentHolder.removeClass('is_active').find('.fn__purchase_code').prop('disabled', false);
						// Handle the response from the server
						if(response.code === 1){
							self.updateThemeStatus('activate',purchaseCode);
							parentHolder.attr('data-status','active');
							notice = $('.frenify__revoke .fn__notice');
							notice.addClass('is_active').html(response.message);
							setTimeout(function(){
								notice.removeClass('success').addClass('refresh').html(parentHolder.find('.refresh_hidden').html());
								setTimeout(function(){
									notice.find('.sec').text(2);
								},1000);
								setTimeout(function(){
									notice.find('.sec').text(1);
								},2000);
								setTimeout(function(){
									notice.find('.sec').text(0);
									location.reload();
								},3000);
							}, 3000);
						}
						else{
							notice.addClass('is_active').html(response.message);
							setTimeout(function(){
								notice.removeClass('is_active');
							}, 5000);
						}
						loader.removeClass('is_active');

						
					},
					error: function(error) {
						// Handle errors
						console.error(error);
						notice.addClass('is_active').html('Unexpected Error. Contact with theme developer');
						loader.removeClass('is_active');
						parentHolder.removeClass('is_active').find('.fn__purchase_code').prop('disabled', false);
					}
					
				});

				return false;

			});
		},


		updateThemeStatus: function($task,purchaseCode){

			$.ajax({
				url: mowData.ajaxurl, // WordPress AJAX URL
				type: 'post',
				data: {
					action: 'update_theme_action',
					task: $task,
					code: purchaseCode,
				},
				success: function(response) {
					
					//console.log('Task: '+ $task);
				},
				error: function(jqXHR, textStatus, errorThrown) {
					console.log('AJAX Error:', textStatus, errorThrown);
				}
			});
			
			return false;
		},
		
		tooltip: function(){
			var img = $('.frenify__welcome_header .img_box');
			var tooltip = $('.fn__tooltip');
			if(img.offset().left + img.outerWidth() + tooltip.outerWidth(true,true) > $(window).width()){
				tooltip.addClass('reversed');
			}else{
				tooltip.removeClass('reversed');
			}
		},

		magnific: function(){
			$('.popup-youtube, .popup-vimeo').each(function() { // the containers for all your galleries
				$(this).magnificPopup({
					disableOn: 700,
					type: 'iframe',
					mainClass: 'mfp-fade',
					removalDelay: 160,
					preloader: false,
					fixedContentPos: false
				});
			});
		},
		
		
		bg_images: function(){
			var data			= $('*[data-bg-img]');
			data.each(function(){
				var element			= $(this);
				var url				= element.data('bg-img');
				element.css({backgroundImage: 'url('+url+')'});
			});
		},
	};
	
	$(document).ready(function(){
		// initialization
		FrenifyCore.init();

	});
	
	$(window).on('resize', function(){
		// initialization
		FrenifyCore.tooltip();

	});
	
})(jQuery);
