<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class Mow_Settings {

	public function __construct() 
	{
		add_action('admin_menu', array($this, 'admin_menu'), 5);
		add_action('wp_ajax_update_theme_action', array($this, 'update_theme_status'));
		add_action('wp_ajax_nopriv_update_theme_action', array($this, 'update_theme_status')); 
	}
	
	public function admin_menu()
	{
		 // Add menu item for settings page
		$page_title 	= esc_html__('Mow', MOW_TEXT_DOMAIN);
		$menu_title 	= esc_html__('Mow', MOW_TEXT_DOMAIN);
		$capability 	= 'manage_options';
		$menu_slug 		= 'mow-core';
		$callback 		= [$this, "welcome_page"];
		$icon_url 		= 'dashicons-flag';
		$position 		= 90;
		$menu			= add_menu_page($page_title, $menu_title, $capability, $menu_slug, $callback, $icon_url, $position);
		
		add_action( 'admin_print_styles-' . $menu, array($this,'admin_css') );
		add_action( 'admin_print_scripts-' . $menu, array($this,'admin_js') );
	}
	
	public static function welcome_page(){
		include_once ( plugin_dir_path( __FILE__ ) . '/welcome.php');
	}
	public function admin_css() {
		wp_enqueue_style('magnific-popup', MOW_PLUGIN_URL . 'inc/settings/assets/css/magnific-popup.css', array(), MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, 'all');
		wp_enqueue_style('frenify-welcome-css', MOW_PLUGIN_URL . 'inc/settings/assets/css/style.css', array(), MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, 'all');
	}
	public function admin_js() {
		wp_enqueue_script('magnific-popup', MOW_PLUGIN_URL . 'inc/settings/assets/js/magnific-popup.js', array('jquery'), MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, FALSE);
		wp_enqueue_script('frenify-welcome-js', MOW_PLUGIN_URL . 'inc/settings/assets/js/init.js', array('jquery'), MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, FALSE);
		
		wp_localize_script(
			'frenify-welcome-js',
			'mowData', 
			array(
				'themeName' => 'Mow',
				'ajaxurl'   => esc_url(admin_url('admin-ajax.php')),
			)
		);
	}
	
	public function update_theme_status(){

		if(isset($_POST['task']) && isset($_POST['code']) && wp_doing_ajax())
		{
			$task = $_POST['task'];
			$code = $_POST['code'];
			

			if ($task === 'activate') {
				update_option('mow_theme_status', 'active');
				update_option('mow_theme_purchasecode', $code);
			} elseif ($task === 'deactivate') {
				update_option('mow_theme_status', 'inactive');
				update_option('mow_theme_purchasecode', '');
			}
		}
	}
	
}
new Mow_Settings();