<?php

/**
 * Plugin Name: Custom Categories
 * Description: A widget that show Custom Categories
 * Version: 1.0
 * Author: Frenify
 * Author URI: http://themeforest.net/user/frenify
 *
 */


/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Mow_Custom_Categories extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		parent::__construct(
			'Mow_Custom_Categories', // Base ID
			esc_html__( 'Frenify Custom Categories', MOW_TEXT_DOMAIN ), // Name
			array( 'description' => esc_html__( 'Custom Categories', MOW_TEXT_DOMAIN ), ) // Args
		);
		
		add_action( 'widgets_init', function() {
            register_widget( 'Mow_Custom_Categories' );
        });
	}
	

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		global $post;
		
		$title		= '';
		$ids		= '';
				
		
		/* Our variables from the widget settings. */
		if ( !empty( $instance[ 'title' ] ) ) { 
			$title 	= $instance[ 'title' ];
		}
		$title 		= apply_filters(esc_html__('Categories', MOW_TEXT_DOMAIN), $title );
		
		if ( !empty( $instance[ 'ids' ] ) ) {$ids = $instance[ 'ids' ];}
		
		
		
		/* Before widget (defined by themes). */
		echo wp_kses_post($before_widget);
		if ( $title ) {
			echo wp_kses_post($before_title . $title . $after_title); 
		}
		
		$list = '';
		$ids = preg_replace('/[^0-9,]+/', '', $ids);
		$arr = explode (",", $ids);
		$arr = array_filter($arr, 'strlen');
		$args = array(
			'include' => $arr
		);
		$categories = get_categories($args);
		if($categories){
			$list .= '<ul>';
			foreach( $categories as $key => $term ){
				$name        	= $term->name;
				$term_count		= $term->count;
				$cat_link    	= get_term_link( $term->slug, 'category' );
				$category_image_id 		= get_term_meta( $term->term_id, 'category-image-id', true );
				$image = '';
				if ( $category_image_id ) {
					// Get the image URL based on the image ID
					$category_image_url = wp_get_attachment_url( $category_image_id );
					$imageData 			= wp_get_attachment_image_src(attachment_url_to_postid($category_image_url), 'medium');
					if($imageData){
						$image = '<img loading="lazy" src="'.esc_url($imageData[0]).'" alt="'.esc_html( $name ).'">';
					}
				}

				$list .= '<li><a class="cat-item" href="'.$cat_link.'"><span class="cat-title">'.$name.'</span><span class="cat-image">'.$image.'</span><span class="count">'.$term_count.'</span></a></li>';
			}
			$list .= '</ul>';
		}
		?>
           	<div class="mow_fn_ccategories">
				<?php echo wp_kses_post($list); ?>
            </div>
            
		<?php 
		/* After widget (defined by themes). */
		echo wp_kses_post($after_widget);
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = array();
 
        $instance['title'] 	= ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['ids'] 	= ( !empty( $new_instance['ids'] ) ) ? strip_tags( $new_instance['ids'] ) : '';
 
        return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		/* Set up some default widget settings. */
		$title 	= ! empty( $instance['title'] ) ? $instance['title'] : '';
		$ids 	= ! empty( $instance['ids'] ) ? $instance['ids'] : '';
		
		?>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" class="mow_fn_width100">
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'ids' )); ?>"><?php esc_html_e('Categories IDs', MOW_TEXT_DOMAIN); ?></label>
			<input type="text" id="<?php echo esc_attr($this->get_field_id( 'ids' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'ids' )); ?>" value="<?php echo esc_attr($ids); ?>" class="mow_fn_width100">
		</p>

	<?php
	}
}

$my_widget = new Mow_Custom_Categories();