<?php

/**
 * Plugin Name: Top Articles
 * Description: A widget that show top news by comments
 * Version: 1.0
 * Author: Frenify
 * Author URI: http://themeforest.net/user/frenify
 *
 */


/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Mow_Top_Artilces extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		parent::__construct(
			'mow_top_articles', // Base ID
			esc_html__( 'Frenify Posts', MOW_TEXT_DOMAIN ), // Name
			array( 'description' => esc_html__( 'Get Posts', MOW_TEXT_DOMAIN ), ) // Args
		);
		
		add_action( 'widgets_init', function() {
            register_widget( 'Mow_Top_Artilces' );
        });
	}
	

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		global $post;
		
		$title		= '';
		$count		= 4;
		$layout		= 'alpha';
		$type		= 'most_viewed'; // most_viewed, most_commented, random, custom
		$recent		= 'disabled';
		$recent_text= '';
		$custom		= '';
				
		
		/* Our variables from the widget settings. */
		if ( !empty( $instance[ 'title' ] ) ) { 
			$title 	= $instance[ 'title' ];
		}
		$title 		= apply_filters(esc_html__('Articles', MOW_TEXT_DOMAIN), $title );
		
		if ( !empty( $instance[ 'count' ] ) ) {$count = $instance[ 'count' ];}
		if ( !empty( $instance[ 'layout' ] ) ) {$layout = $instance[ 'layout' ];}
		if ( !empty( $instance[ 'recent' ] ) ) {$recent = $instance[ 'recent' ];}
		if ( !empty( $instance[ 'custom' ] ) ) {$custom = $instance[ 'custom' ];}
		if ( !empty( $instance[ 'type' ] ) ) {$type = $instance[ 'type' ];}
		if ( !empty( $instance[ 'recent_text' ] ) ) {$recent_text = $instance[ 'recent_text' ];}
		
		$count = (int)$count;
		if($count < 1){$count = 1;}
		
		echo wp_kses_post($before_widget);
		
		if($recent == 'enabled'){
			$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$title.'</a><a href="#" data-class="second_item">'.$recent_text.'</a></div>';
		}else if($title != ''){
			$widget_title_holder = '<div class="wid-title"><span class="text"><span>'.$title.'</span></span></div>';
		}else{
			$widget_title_holder = '';
		}
		
		if($type == 'random'){
			$query_args = array(	
				'post_type' 			=> 'post',
				'post_status' 			=> 'publish',
				'ignore_sticky_posts' 	=> true,
				'posts_per_page' 		=> $count,
				'orderby' 				=> 'rand',
			);
		}else if($type == 'custom'){
			$custom = preg_replace('/[^0-9,]+/', '', $custom);
			$query_args = array(
				'post_type'             => 'post',
				'post_status'           => 'publish',
				'post__in'              => array_filter(explode (",", $custom), 'strlen'),
				'orderby'               => 'post__in',
				'ignore_sticky_posts'   => true,
				'posts_per_page'        => $count,
			);
		}else if($type == 'most_viewed'){
			$query_args = array(
				'post_type'             => 'post',
				'order'                 => 'DESC',
				'orderby'               => 'meta_value_num',
				'meta_key'              => 'frenify_post_views_count',
				'post_status'           => 'publish',
				'posts_per_page' 		=> $count,
				'ignore_sticky_posts'   => true,
				'date_query'            => array(
					array(
						'after' => '365 days ago', // Only include posts from the last x days
					),
				),
				'meta_query'            => array(
					array(
						'key'       => 'frenify_post_views_count',
						'value'     => 0,
						'compare'   => '>',
						'type'      => 'NUMERIC'
					)
				)
			);
		}else if($type == 'most_commented'){
			$query_args = array(
				'post_type'             => 'post',
				'post_status'           => 'publish',
				'ignore_sticky_posts'   => true,
				'posts_per_page'        => $count,
				'orderby'               => 'comment_count',
				'order'                 => 'DESC',
			);
		}


		$cache_key = 'frenify_popular_posts_last_x_days_' . $count;
		$loop = get_transient($cache_key);

		if (false === $loop) {
			$loop = new \WP_Query( $query_args );
			set_transient($cache_key, $loop, 0.1 * HOUR_IN_SECONDS); // Cache for 24 hours
		}
		

		$list = '';
		if($layout == 'alpha'){
			$list .= '<div class="fn__widget_posts_alpha">';
			$list .= $widget_title_holder;
			$list .= '<div class="fn__widget_filter_content">';

			// first list
			$list .= '<ul class="first_item alpha_items active">';
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_meta = mow_fn_metas(array('post_id' => $post_id));
				$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';

				if($post_image != ''){
					$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><img loading="lazy" decoding="async" src="'.$post_image.'" alt=""></a></div></div>';
				}else{
					$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
				}

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

				$list .= '<li class="alpha_item"><div class="alpha__item">'.$image_holder.$title_holder.'</div></li>';
				wp_reset_postdata();
			}
			$list .= '</ul>';

			// second list
			if($recent == 'enabled'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $count,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$list .= '<ul class="second_item alpha_items">';
				foreach ( $loop->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_meta = mow_fn_metas(array('post_id' => $post_id));
					$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
	
					if($post_image != ''){
						$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><img loading="lazy" decoding="async" src="'.$post_image.'" alt=""></a></div></div>';
					}else{
						$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
					}
	
					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';
	
					$list .= '<li class="alpha_item"><div class="alpha__item">'.$image_holder.$title_holder.'</div></li>';
					wp_reset_postdata();
				}
				$list .= '</ul>';
			}

			$list .= '</div>';

			$list .= '</div>';
		}else if($layout == 'beta'){
			$list .= '<div class="fn__widget_posts_beta">';
			$list .= $widget_title_holder;
			$list .= '<div class="fn__widget_filter_content">';

			// first list
			$list .= '<ul class="first_item beta_items active">';
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_meta = mow_fn_metas(array('post_id' => $post_id));
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';

				$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
				$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

				$list .= '<li class="beta_item"><div class="beta__item">'.$count_holder.$title_holder.'</div></li>';
				wp_reset_postdata();
			}
			$list .= '</ul>';

			// second list
			if($recent == 'enabled'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $count,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$list .= '<ul class="second_item beta_items">';
				foreach ( $loop->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_meta = mow_fn_metas(array('post_id' => $post_id));
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';

					$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
					$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

					$list .= '<li class="beta_item"><div class="beta__item">'.$count_holder.$title_holder.'</div></li>';
					wp_reset_postdata();
				}
				$list .= '</ul>';
			}

			$list .= '</div>';

			$list .= '</div>';
		}else if($layout == 'gamma'){
			$list .= '<div class="fn__widget_posts_gamma">';
			$list .= $widget_title_holder;
			$list .= '<div class="fn__widget_filter_content">';

			// first list
			$list .= '<ul class="first_item gamma_items active">';
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_meta = mow_fn_metas(array('post_id' => $post_id));
				$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';

				$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
				$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

				if($post_image != ''){
					$image_holder = '<div class="img_holder"><div class="item_img">'.$count_holder.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><img loading="lazy" decoding="async" src="'.$post_image.'" alt=""></a></div></div>';
				}else{
					$image_holder = '<div class="img_holder"><div class="item_space">'.$count_holder.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
				}

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

				$list .= '<li class="gamma_item"><div class="gamma__item">'.$image_holder.$title_holder.'</div></li>';
				wp_reset_postdata();
			}
			$list .= '</ul>';

			// second list
			if($recent == 'enabled'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $count,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$list .= '<ul class="second_item gamma_items">';
				foreach ( $loop->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_meta = mow_fn_metas(array('post_id' => $post_id));
					$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
					
					$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
					$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

					if($post_image != ''){
						$image_holder = '<div class="img_holder"><div class="item_img">'.$count_holder.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><img loading="lazy" decoding="async" src="'.$post_image.'" alt=""></a></div></div>';
					}else{
						$image_holder = '<div class="img_holder"><div class="item_space">'.$count_holder.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
					}
	
					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';
	
					$list .= '<li class="gamma_item"><div class="gamma__item">'.$image_holder.$title_holder.'</div></li>';
					wp_reset_postdata();
				}
				$list .= '</ul>';
			}

			$list .= '</div>';

			$list .= '</div>';
		}
		
		echo $list; ?>
            
		<?php 
		/* After widget (defined by themes). */
		echo wp_kses_post($after_widget);
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = array();
 
        $instance['title'] 			= ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['count'] 			= ( !empty( $new_instance['count'] ) ) ? strip_tags( $new_instance['count'] ) : '';
        $instance['layout'] 		= ( !empty( $new_instance['layout'] ) ) ? strip_tags( $new_instance['layout'] ) : '';
        $instance['type'] 			= ( !empty( $new_instance['type'] ) ) ? strip_tags( $new_instance['type'] ) : '';
        $instance['recent'] 		= ( !empty( $new_instance['recent'] ) ) ? strip_tags( $new_instance['recent'] ) : '';
        $instance['recent_text'] 	= ( !empty( $new_instance['recent_text'] ) ) ? strip_tags( $new_instance['recent_text'] ) : '';
        $instance['custom'] 		= ( !empty( $new_instance['custom'] ) ) ? strip_tags( $new_instance['custom'] ) : '';
		
        return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {
		/* Set up some default widget settings. */
		$title 			= ! empty( $instance['title'] ) ? $instance['title'] : '';
		$count 			= ! empty( $instance['count'] ) ? $instance['count'] : 4;
		$layout 		= ! empty( $instance['layout'] ) ? $instance['layout'] : 'alpha';
		$type 			= ! empty( $instance['type'] ) ? $instance['type'] : 'most_viewed';
		$recent 		= ! empty( $instance['recent'] ) ? $instance['recent'] : 'disabled';
		$recent_text 	= ! empty( $instance['recent_text'] ) ? $instance['recent_text'] : '';
		$custom 		= ! empty( $instance['custom'] ) ? $instance['custom'] : '';
		
		$alphaSelect = $betaSelect = $gammaSelect = $deltaSelect = '';
		if($layout == 'alpha'){$alphaSelect = 'selected';}
		else if($layout == 'beta'){$betaSelect = 'selected';}
		else if($layout == 'gamma'){$gammaSelect = 'selected';}
		else if($layout == 'delta'){$deltaSelect = 'selected';}
		
		$type_1_select = $type_2_select = $type_3_select = $type_4_select = '';
		if($type == 'most_viewed'){$type_1_select = 'selected';}
		else if($type == 'most_commented'){$type_2_select = 'selected';}
		else if($type == 'random'){$type_3_select = 'selected';}
		else if($type == 'custom'){$type_4_select = 'selected';}
		
		$recent_1_select = $recent_2_select = '';
		if($recent == 'enabled'){$recent_1_select = 'selected';}
		else if($recent == 'disabled'){$recent_2_select = 'selected';}
		?>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'layout' )); ?>"><?php esc_html_e('Layout', MOW_TEXT_DOMAIN); ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'layout' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'layout' )); ?>">
				<option <?php echo esc_attr($alphaSelect);?> value="alpha"><?php esc_html_e('Alpha', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($betaSelect);?> value="beta"><?php esc_html_e('Beta', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($gammaSelect);?> value="gamma"><?php esc_html_e('Gamma', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($deltaSelect);?> value="delta"><?php esc_html_e('Delta', MOW_TEXT_DOMAIN); ?></option>
			</select>
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'type' )); ?>"><?php esc_html_e('Type', MOW_TEXT_DOMAIN); ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'type' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'type' )); ?>">
				<option <?php echo esc_attr($type_1_select);?> value="most_viewed"><?php esc_html_e('Most Viewed', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($type_2_select);?> value="most_commented"><?php esc_html_e('Most Commented', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($type_3_select);?> value="random"><?php esc_html_e('Random', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($type_4_select);?> value="custom"><?php esc_html_e('Custom', MOW_TEXT_DOMAIN); ?></option>
			</select>
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'recent' )); ?>"><?php esc_html_e('Recent', MOW_TEXT_DOMAIN); ?></label>
			<select name="<?php echo esc_attr($this->get_field_name( 'recent' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'recent' )); ?>">
				<option <?php echo esc_attr($recent_1_select);?> value="enabled"><?php esc_html_e('Enabled', MOW_TEXT_DOMAIN); ?></option>
				<option <?php echo esc_attr($recent_2_select);?> value="disabled"><?php esc_html_e('Disabled', MOW_TEXT_DOMAIN); ?></option>
			</select>
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" class="mow_fn_width100">
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'recent_text' )); ?>"><?php esc_html_e('Recent Text:', MOW_TEXT_DOMAIN); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id( 'recent_text' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'recent_text' )); ?>" value="<?php echo esc_attr($recent_text); ?>" class="mow_fn_width100">
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'count' )); ?>"><?php esc_html_e('Post Count:', MOW_TEXT_DOMAIN); ?></label>
			<input min="1" type="number" id="<?php echo esc_attr($this->get_field_id( 'count' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'count' )); ?>" value="<?php echo esc_attr($count); ?>" class="mow_fn_width100">
		</p>
		<p class="mow_fn_social_paragraph">
			<label for="<?php echo esc_attr($this->get_field_id( 'custom' )); ?>"><?php esc_html_e('Custom Posts IDs', MOW_TEXT_DOMAIN); ?></label>
			<input type="text" id="<?php echo esc_attr($this->get_field_id( 'custom' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'custom' )); ?>" value="<?php echo esc_attr($custom); ?>" class="mow_fn_width100">
		</p>

	<?php
	}
}

$my_widget = new Mow_Top_Artilces();