<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */
    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

	Redux::disable_demo();

	// Custom Fonts
	function get_custom_fonts() {
		// Get custom fonts
		$custom_fonts = get_option('mow_custom_fonts', []);
		$fonts = [];
	
		if (!empty($custom_fonts)) {
			foreach ($custom_fonts as $font) {
				if (!empty($font['name']) && !empty($font['url'])) {
					$fonts[$font['name']] = [
						'family' => $font['name'],
						'variants' => ['400', '700'], // Default variants
						'subsets' => ['latin'], // Default subset
						'url' => $font['url'] // URL to the uploaded font file
					];
				}
			}
		}
	
		// Add standard fonts
		$standard_fonts = [
			'Arial, Helvetica, sans-serif'         => ['family' => 'Arial, Helvetica, sans-serif'],
			"'Arial Black', Gadget, sans-serif"   => ['family' => "'Arial Black', Gadget, sans-serif"],
			"'Bookman Old Style', serif"          => ['family' => "'Bookman Old Style', serif"],
			"'Comic Sans MS', cursive"            => ['family' => "'Comic Sans MS', cursive"],
			"'Courier New', Courier, monospace"   => ['family' => "'Courier New', Courier, monospace"],
			"'Georgia', serif"                    => ['family' => "'Georgia', serif"],
			"'Impact', Charcoal, sans-serif"      => ['family' => "'Impact', Charcoal, sans-serif"],
			"'Lucida Console', Monaco, monospace" => ['family' => "'Lucida Console', Monaco, monospace"],
			"'Tahoma', Geneva, sans-serif"        => ['family' => "'Tahoma', Geneva, sans-serif"],
			"'Times New Roman', Times, serif"     => ['family' => "'Times New Roman', Times, serif"],
			"'Trebuchet MS', Helvetica, sans-serif" => ['family' => "'Trebuchet MS', Helvetica, sans-serif"],
			"'Verdana', Geneva, sans-serif"       => ['family' => "'Verdana', Geneva, sans-serif"],
		];
	
		// Merge custom fonts and standard fonts
		return array_merge($fonts, $standard_fonts);
	}
	

    // This is your option name where all the Redux data is stored.
    $opt_name = "mow_fn_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ) . ' / Version: ' . $theme->get( 'Version' ),
        // Name that appears at the top of your panel
        'display_version'      => 'The theme is developed by <a href="https://frenify.com/" target="_blank">Frenify Team</a>',
        // Version that appears at the top of your panel
        'menu_type'            => 'submenu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Theme Options', 'redux-framework-demo' ),
        'page_title'           => __( 'Theme Options', 'redux-framework-demo' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => 'mow_fn_option',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'mow-core',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '_frenify_options',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );
    
    Redux::setArgs( $opt_name, $args );


    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        )
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo' );
    Redux::set_help_sidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */
	$adminURL = '<a href="'.admin_url('options-permalink.php').'">'.esc_html__('Here', 'redux-framework-demo').'</a>';	 
	$permalink_description = __('After changing this, go to following link and click save. '.$adminURL.'', 'redux-framework-demo');

	$langURL = '<a target="_blank" href="https://wpml.org/">'.esc_html__('WPML Multilingual CMS', 'redux-framework-demo').'</a>';	 
	$lang_desc = __('Please, install and set up following plugin: '.$langURL.'', 'redux-framework-demo');
    // -> START Basic Fields



	
Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'General', 'redux-framework-demo' ),
	'id'    => 'general',
	'icon'  => 'el el-globe',
	'fields' 	=> array(
		array(
			'id' 		=> 'switch_theme_mode',
			'type' 		=> 'button_set',
			'title' 	=> __('Light/Dark Button', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'enable'
		),
		array(
			'id' 		=> 'default_theme_mode',
			'type' 		=> 'button_set',
			'title' 	=> __('Default Theme Mode', 'redux-framework-demo'),
			'options' 	=> array(
							'light'  		=> esc_html__('Light', 'redux-framework-demo'), 
							'dark' 			=> esc_html__('Dark', 'redux-framework-demo')), 
			'default' 	=> 'light'
		),
		array(
			'id' 		=> 'author_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Post Author', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'enable'
		),
		array(
			'id' 		=> 'time_format',
			'type' 		=> 'button_set',
			'title' 	=> __('Time Format', 'redux-framework-demo'),
			'options' 	=> array(
							'default'  			=> esc_html__('Default', 'redux-framework-demo'), 
							'difference' 		=> esc_html__('Time Difference', 'redux-framework-demo')), 
			'default' 	=> 'difference'
		),
		
		// array(
		// 	'id' 		=> 'site_direction',
		// 	'type' 		=> 'button_set',
		// 	'title' 	=> __('Site Direction', 'redux-framework-demo'),
		// 	'options' 	=> array(
		// 					'ltr'  		=> esc_html__('LTR (left to right)', 'redux-framework-demo'), 
		// 					'rtl' 		=> esc_html__('RTL (right to left)', 'redux-framework-demo')), 
		// 	'default' 	=> 'ltr'
		// ),

		array(
			'id' 		=> 'mcursor_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Magic Cursor', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'magic_cursor',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
			"multi" 	=> true,
			'options' 	=> array(
							'default'  		=> esc_html__('Default', 'redux-framework-demo'), 
							'link' 			=> esc_html__('Link Hover', 'redux-framework-demo'),
							'slider' 		=> esc_html__('Slider (Swiper)', 'redux-framework-demo'),
			),
		),
		array(
			'id'		=> 'mcursor_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Cursor Color For Light BG', 'redux-framework-demo'),
			'default'   => '#000000',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'mcursor_color_dark',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Cursor Color For Dark BG', 'redux-framework-demo'),
			'default'   => '#ffffff',
			'validate' 	=> 'color',
		),

		array(
			'id' 		=> 'mcursor_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),
		
		array(
			'id'		=> 'woo_per_page',
			'type' 		=> 'slider',
			'default' 	=> 6,
			'min' 		=> 0,
			'max' 		=> 999,
			'title' 	=> esc_html__('WooCommerce Per Page (shop page)', 'redux-framework-demo'),
		),
		
		array(
			'id'		=> 'redirect_page_time',
			'type' 		=> 'slider',
			'default' 	=> 10,
			'min' 		=> 1,
			'max' 		=> 100,
			'title' 	=> esc_html__('Redirect Page Timer (in seconds)', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'redirect_footer_text',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Redirect Page Text', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable'   		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			),
			'default' 	=> 'enable',
		),
		array(
			'id'		=> 'breadcrumbs_toggle',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Breadcrumbs', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> true,
		),
	)

));
Redux::setSection( $opt_name, array(
		'title' => esc_html__( 'Main Colors', 'redux-framework-demo' ),
		'id'    => 'main_color',
		'icon'  => 'el el-brush ',
		'fields' 	=> array(

		array(
			'id' 		=> 'light_colors_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Light Mode Colors', 'redux-framework-demo'),
			'indent' 	=> true,
		),
		array(
			'id'		=> 'main_color_1',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Main Color #1', 'redux-framework-demo'),
			'default' 	=> '#6428ec',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'body_bg_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Body Background', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Whole website background color', 'redux-framework-demo'),
			'default' 	=> '#fff',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'ebc_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Extra Background', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Used for some sections', 'redux-framework-demo'),
			'default' 	=> '#f5f5f5',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'aebc_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Active Extra Background', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Used for some sections', 'redux-framework-demo'),
			'default' 	=> '#e5e5e5',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'body_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Text Color', 'redux-framework-demo'),
			'default' 	=> '#777777',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'heading_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Heading Regular Color', 'redux-framework-demo'),
			'default' 	=> '#080808',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'heading_hover_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Heading Hover Color', 'redux-framework-demo'),
			'default' 	=> '#6428ec',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'border_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Border Color', 'redux-framework-demo'),
			'default' 	=> '#cccccc',
			'validate' 	=> 'color',
		),
		array(
			'id' 		=> 'light_colors_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'dark_colors_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Dark Mode Colors', 'redux-framework-demo'),
			'indent' 	=> true,
		),
		array(
			'id'		=> 'dark_main_color_1',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Main Color #1', 'redux-framework-demo'),
			'default' 	=> '#6428ec',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_body_bg_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Body Background', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Whole website background color', 'redux-framework-demo'),
			'default' 	=> '#121212',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_ebc_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Extra Background', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Used for some sections', 'redux-framework-demo'),
			'default' 	=> '#1d1d1d',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_aebc_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Active Extra Background', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Used for some sections', 'redux-framework-demo'),
			'default' 	=> '#222222',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_body_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Text Color', 'redux-framework-demo'),
			'default' 	=> '#777777',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_heading_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Heading Regular Color', 'redux-framework-demo'),
			'default' 	=> '#ccc',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_heading_hover_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Heading Hover Color', 'redux-framework-demo'),
			'default' 	=> '#6428ec',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'dark_border_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Border Color', 'redux-framework-demo'),
			'default' 	=> '#333333',
			'validate' 	=> 'color',
		),

		array(
			'id' 		=> 'dark_colors_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'other_colors_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Other Colors', 'redux-framework-demo'),
			'indent' 	=> true,
		),
		array(
			'id'		=> 'sticky_post_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Sticky Post Background Color', 'redux-framework-demo'),
			'default' 	=> '#ffeeaf',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'rating_bg_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Rating Background Color', 'redux-framework-demo'),
			'default' 	=> '#fdd23c',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'rating_text_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Rating Text Color', 'redux-framework-demo'),
			'default' 	=> '#000000',
			'validate' 	=> 'color',
		),
		array(
			'id'		=> 'contrast_text_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Contrast Text Color', 'redux-framework-demo'),
			'default' 	=> '#ffffff',
			'validate' 	=> 'color',
		),

		array(
			'id' 		=> 'other_colors_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),
	)
));

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Logo', 'redux-framework-demo' ),
	'id'    => 'logo',
	'icon'  => 'el el-puzzle',
	'fields' 	=> array(

		array(
			'id'			=> 'desktop_logo',
			'type' 			=> 'media',
			'url'       	=> true,
			'title' 		=> esc_html__('Dark Logo', 'redux-framework-demo'),
			'subtitle' 		=> esc_html__('Logo for light background', 'redux-framework-demo'),
		),

		array(
			'id'			=> 'light_logo',
			'type' 			=> 'media',
			'url'      	 	=> true,
			'title' 		=> esc_html__('Light Logo', 'redux-framework-demo'),
			'subtitle' 		=> esc_html__('Logo for dark background', 'redux-framework-demo'),
		),

		array(
			'id'			=> 'mobile_logo',
			'type' 			=> 'media',
			'url'      	 	=> true,
			'title' 		=> esc_html__('Mobile Logo', 'redux-framework-demo'),
			'subtitle' 		=> esc_html__('Logo for mobile devices', 'redux-framework-demo'),
		),

		array(
			'id'		=> 'logo_w',
			'type' 		=> 'slider',
			'default' 	=> 220,
			'min' 		=> 1,
			'max' 		=> 900,
			'title' 	=> esc_html__('Max Logo Width', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Set the maximum width for the logo', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'logo_h',
			'type' 		=> 'slider',
			'default' 	=> 80,
			'min' 		=> 1,
			'max' 		=> 900,
			'title' 	=> esc_html__('Max Logo Height', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Set the maximum height for the logo', 'redux-framework-demo'),
		),
	)
));

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Floating Bar', 'redux-framework-demo' ),
	'id'    => 'fixed_bar',
	'icon'  => 'el el-laptop',
	'fields' 	=> array(

		array(
			'id' 		=> 'woo_btn_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Cart Button', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'woo_btn_switcher',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      		=> esc_html__( 'Enable when WooCommerce is running', 'redux-framework-demo' ),
				'disable'   		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			),
			'default' 	=> 'enable',
		),

		array(
			'id' 		=> 'woo_btn_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'hot_btn_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Hot Page Button', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'hot_btn_switcher',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      		=> esc_html__( 'Activate if hot page is created', 'redux-framework-demo' ),
				'disable'   		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			),
			'default' 	=> 'enable',
		),

		array(
			'id' 		=> 'hot_btn_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'register_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Account Button', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'register',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Condition', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      		=> esc_html__( 'Enable Both', 'redux-framework-demo' ),
				'sign_in'   		=> esc_html__( 'Sign-In Only', 'redux-framework-demo' ),
				'disable'   		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			),
			'default' 	=> 'enable',
		),

		array(
			'id'		=> 'register_after',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Archive Page Button After Signing In', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'   			=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable'   		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			),
			'default' 	=> 'enable',
		),

		array(
			'id' 		=> 'register_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'fixed_posts_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Fixed Posts/Categories', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'fixed_posts_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> false,
		),

		array(
			'id'		=> 'fixed_posts_title_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Title Switcher', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> true,
			'required' 	=> array(
				array('fixed_posts_switcher','=', true),
			),
		),
		
		array(
			'id'       	=> 'fixed_posts_title',
			'type'     	=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Popular Now', 'redux-framework-demo'),
			'required' 	=> array(
				array('fixed_posts_title_switcher','=', true),
				array('fixed_posts_switcher','=', true),
			),
		),

		array(
			'id' 		=> 'fixed_posts_content',
			'type' 		=> 'button_set',
			'title' 	=> __('Content Type', 'redux-framework-demo'),
			'options' 	=> array(
				'post'      		=> esc_html__( 'Posts', 'redux-framework-demo' ),
				'category'      	=> esc_html__( 'Categories', 'redux-framework-demo' ),
			), 
			'default' 	=> 'post',
			'required' 	=> array(
				array('fixed_posts_switcher','=', true),
			),
		),

		array(
			'id' 		=> 'fixed_posts_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Posts Type', 'redux-framework-demo'),
			'options' 	=> array(
				'most_viewed'      	=> esc_html__( 'Most Viewed Posts', 'redux-framework-demo' ),
				'most_commented'   	=> esc_html__( 'Most Commented Posts', 'redux-framework-demo' ),
				'random'   			=> esc_html__( 'Random Posts', 'redux-framework-demo' ),
				'custom'   			=> esc_html__( 'Custom Posts by IDs', 'redux-framework-demo' ),
			)
			, 
			'default' 	=> 'most_viewed',
			'required' 	=> array(
				array('fixed_posts_switcher','=', true),
				array('fixed_posts_content','=', 'post'),
			),
		),

		array(
			'id'       	=> 'fixed_posts_ids',
			'type'     	=> 'text',
			'title' 	=> esc_html__('Fixed Posts IDs', 'redux-framework-demo'),
			'required' 	=> array(
				array('fixed_posts_type','=','custom'),
				array('fixed_posts_switcher','=', true),
				array('fixed_posts_content','=', 'post'),
			),
		),

		array(
			'id' 		=> 'fixed_category_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Categories Type', 'redux-framework-demo'),
			'options' 	=> array(
				'popular'      		=> esc_html__( 'Most Popular Categories', 'redux-framework-demo' ),
				'random'   			=> esc_html__( 'Random Categories', 'redux-framework-demo' ),
				'custom'   			=> esc_html__( 'Custom Categories by IDs', 'redux-framework-demo' ),
			)
			, 
			'default' 	=> 'popular',
			'required' 	=> array(
				array('fixed_posts_switcher','=', true),
				array('fixed_posts_content','=', 'category'),
			),
		),

		array(
			'id'       	=> 'fixed_category_ids',
			'type'     	=> 'text',
			'title' 	=> esc_html__('Fixed Categories IDs', 'redux-framework-demo'),
			'required' 	=> array(
				array('fixed_category_type','=','custom'),
				array('fixed_posts_switcher','=', true),
				array('fixed_posts_content','=', 'category'),
			),
		),

		array(
			'id' 		=> 'fixed_posts_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),
		

		array(
			'id' 		=> 'totop_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Totop Button', 'redux-framework-demo'),
			'indent' 	=> true,
		),
		
		
		array(
			'id'		=> 'totop_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('For Desktop', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> true,
		),

		array(
			'id' 		=> 'totop_mobile',
			'type' 		=> 'switch',
			'title' 	=> __('For Mobile', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> false,
		),
		
		array(
			'id'       	=> 'totop_text',
			'type'     	=> 'text',
			'title' 	=> esc_html__('Text', 'redux-framework-demo'),
			'default' 	=> esc_html__('Scroll to Top', 'redux-framework-demo'),
		),

		array(
			'id' 		=> 'totop_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),


		array(
			'id' 		=> 'search_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Search', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'search_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Switcher', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> true,
		),

		array(
			'id'		=> 'search_rc_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Recommended Categories', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> true,
			'required' 	=> array(
				array('search_switcher','=', true),
			),
		),
		
		array(
			'id'       	=> 'search_rc_label',
			'type'     	=> 'text',
			'title' 	=> esc_html__('Recommended Label', 'redux-framework-demo'),
			'default' 	=> esc_html__('Popular Searches:', 'redux-framework-demo'),
			'required' 	=> array(
				array('search_rc_switcher','=', true),
				array('search_switcher','=', true),
			),
		),

		array(
			'id' 		=> 'search_rc_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Categories Order', 'redux-framework-demo'),
			'options' 	=> array(
				'popular'      	=> esc_html__( 'Popular', 'redux-framework-demo' ),
				'by_name'   	=> esc_html__( 'By Name', 'redux-framework-demo' ),
				'random'   		=> esc_html__( 'Random', 'redux-framework-demo' ),
				'custom'   		=> esc_html__( 'Custom by IDs', 'redux-framework-demo' ),
			)
			, 
			'default' 	=> 'popular',
			'required' 	=> array(
				array('search_rc_switcher','=', true),
				array('search_switcher','=', true),
			),
		),

		array(
			'id'       	=> 'search_rc_ids',
			'type'     	=> 'text',
			'title' 	=> esc_html__('Categories IDs', 'redux-framework-demo'),
			'required' 	=> array(
				array('search_rc_switcher','=', true),
				array('search_switcher','=', true),
				array('search_rc_type','=', 'custom'),
			),
		),


		array(
			'id' 		=> 'search_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'add_new_post_fe_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Front-End Post Submission', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'		=> 'new_post_fe_switcher',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Submission', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      	=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable'      	=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable',
		),

		array(
			'id'		=> 'new_post_fe__link',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Adding a Link Post', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      	=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable'      	=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable',
		),

		array(
			'id'		=> 'new_post_fe__post',
			'type' 		=> 'button_set',
			'title' 	=> esc_html__('Adding a Standard Post', 'redux-framework-demo'),
			'options' 	=> array(
				'enable'      	=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable'      	=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable',
		),

		array(
			'id' 		=> 'add_new_post_fe_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),
	)
));

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Header', 'redux-framework-demo' ),
	'id'    => 'desktop_navigation',
	'icon'  => 'el el-laptop',
	'fields' 	=> array(

		
		array(
			'id' 		=> 'header_layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Header Layout', 'redux-framework-demo'),
			'options' 	=> array(
							'o_line'  	=> esc_html__('One Line', 'redux-framework-demo'), 
							'm_logo' 	=> esc_html__('Middle Logo', 'redux-framework-demo')), 
			'default' 	=> 'o_line'
		),
		array(
			'id' 		=> 'mlogo_layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Middle Logo Layout', 'redux-framework-demo'),
			'options' 	=> array(
							'full_border'  		=> esc_html__('Full Border', 'redux-framework-demo'), 
							'contained_border' 	=> esc_html__('Contained Border', 'redux-framework-demo'),
							'overlay_bg' 		=> esc_html__('Overlay Background', 'redux-framework-demo')), 
			'default' 	=> 'full_border',
			'required' 	=> array(
				array('header_layout','=', 'm_logo'),
			),
		),

		array(
			'id' 		=> 'header_width',
			'type' 		=> 'button_set',
			'title' 	=> __('Header Width', 'redux-framework-demo'),
			'options' 	=> array(
							'full'  	=> esc_html__('Full', 'redux-framework-demo'), 
							'boxed' 	=> esc_html__('Boxed', 'redux-framework-demo')), 
			'default' 	=> 'full'
		),

		array(
			'id'		=> 'o_line_nav_item_height',
			'type' 		=> 'slider',
			'default' 	=> 147,
			'min' 		=> 1,
			'max' 		=> 300,
			'title' 	=> esc_html__('Navigation Height (links)', 'redux-framework-demo'),
			'required' 	=> array(
				array('header_layout','=', 'o_line'),
			),
		),

		array(
			'id'		=> 'm_logo_nav_item_height',
			'type' 		=> 'slider',
			'default' 	=> 40,
			'min' 		=> 1,
			'max' 		=> 300,
			'title' 	=> esc_html__('Navigation Height (links)', 'redux-framework-demo'),
			'required' 	=> array(
				array('header_layout','=', 'm_logo'),
			),
		),

		array(
			'id'		=> 'mlogo_nav_bg',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Navigation Background', 'redux-framework-demo'),
			'default' 	=> '#080808',
			'validate' 	=> 'color',
			'required' 	=> array(
				array('mlogo_layout','=', 'overlay_bg'),
				array('header_layout','=', 'm_logo'),
			),
		),

		array(
			'id'		=> 'mlogo_nav_color',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Navigation Link Color', 'redux-framework-demo'),
			'default' 	=> '#ffffff',
			'validate' 	=> 'color',
			'required' 	=> array(
				array('mlogo_layout','=', 'overlay_bg'),
				array('header_layout','=', 'm_logo'),
			),
		),

		array(
			'id' 		=> 'sticky_header_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Sticky Header Behavior', 'redux-framework-demo'),
			'options' 	=> array(
							'always_on'  		=> esc_html__('Always On', 'redux-framework-demo'), 
							'on_scroll_top'  	=> esc_html__('Enable on Scroll Up', 'redux-framework-demo'), 
							'disable' 			=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'always_on'
		),

		array(
			'id' 		=> 'nav_eb_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Extra Button', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id' 		=> 'nav_eb_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'disable'
		),

		array(
			'id'		=> 'nav_eb_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> __('Buy Now', 'redux-framework-demo'),
		),

		array(
			'id'		=> 'nav_eb_img',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Image', 'redux-framework-demo'),
		),

		array(
			'id'		=> 'nav_eb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Link', 'redux-framework-demo'),
		),

		array(
			'id' 		=> 'nav_eb_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'mobnav_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Mobile Navigation Settings', 'redux-framework-demo'),
			'indent' 	=> true,
		),
		
		array(
			'id'		=> 'sticky_mobile_nav',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Sticky Navigation', 'redux-framework-demo'),
			'on'		=> esc_html__('Enabled', 'redux-framework-demo'),
			'off'		=> esc_html__('Disabled', 'redux-framework-demo'),
			'default' 	=> false,
		),
		
		array(
			'id'		=> 'suffix_mobile_nav',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Menu Items Suffix (//)', 'redux-framework-demo'),
			'on'		=> esc_html__('Enabled', 'redux-framework-demo'),
			'off'		=> esc_html__('Disabled', 'redux-framework-demo'),
			'default' 	=> true,
		),
		
		array(
			'id'		=> 'mobnav_bg',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Navigation Background Color', 'redux-framework-demo'),
			'default'   => '#000000',
			'validate' 	=> 'color',
		),
		
		array(
			'id'		=> 'mobnav_text',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Menu Items Text Color', 'redux-framework-demo'),
			'default'   => '#eeeeee',
			'validate' 	=> 'color',
		),
		
		array(
			'id'		=> 'mobnav_line',
			'type' 		=> 'color',
			'transparent' => false,
			'title' 	=> esc_html__('Divider Line Color', 'redux-framework-demo'),
			'default'   => '#222222',
			'validate' 	=> 'color',
		),
		
		array(
			'id' 		=> 'mobnav_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),
		

	)
));


Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Typography', 'redux-framework-demo' ),
	'id'    => 'typography',
	'icon'  => 'el el-font',
	'fields' 	=> array(
		array(
			'id'		=> 'body_font',
			'type' 		=> 'typography',
			'title' 	=> esc_html__('Body Font', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Specify the body font properties.', 'redux-framework-demo'),
			'google' 	=> true,
			'fonts'     => get_custom_fonts(),
			'preview'	=> false,
			'line-height'=>false,
			'color' => false,
			'text-align' => false,
			'default' 	=> array(
				'font-size' 	=> '18px',
				'font-family' 	=> 'Work Sans',
				'font-weight' 	=> '400',
			),
			'output'      => array('body'),
		),
		array(
			'id'		=> 'nav_font',
			'type' 		=> 'typography',
			'title' 	=> esc_html__('Desktop Navigation Font', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Specify the navigation font properties.', 'redux-framework-demo'),
			'google' 	=> true,
			'fonts'     => get_custom_fonts(),
			'preview'	=> false,
			'line-height'=>false,
			'color' 	=> false,
			'font-weight' => false,
			'text-align' => false,
			'default' 	=> array(
				'font-size' 	=> '20px',
				'font-family' 	=> 'Heebo',
			),
			'output'      => array('.mow_fn_main_nav > li > a'),
		),

		array(
			'id'		=> 'input_font',
			'type' 		=> 'typography',
			'title' 	=> esc_html__('Input Font', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Specify the Input font properties.', 'redux-framework-demo'),
			'google' 	=> true,
			'fonts'     => get_custom_fonts(),
			'preview'	=> false,
			'line-height'=>false,
			'color' 	=> false,
			'text-align' => false,
			'default' 	=> array(
				'font-size' 	=> '16px',
				'font-family' 	=> 'Heebo',
				'font-weight' 	=> '400',
			),
			'output'      => array('input'),
		),
		array(
			'id'		=> 'blockquote_font',
			'type' 		=> 'typography',
			'title' 	=> esc_html__('Blockquote Font', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Specify the blockquote font properties.', 'redux-framework-demo'),
			'google' 	=> true,
			'fonts'     => get_custom_fonts(),
			'preview'	=> false,
			'line-height'=>false,
			'color' 	=> false,
			'text-align' => false,
			'default' 	=> array(
				'font-size' 	=> '24px',
				'font-family' 	=> 'Lora',
				'font-weight' 	=> '400',
			),
			'output'      => array('blockquote'),
		),
		array(
			'id'		=> 'heading_font',
			'type' 		=> 'typography',
			'title' 	=> esc_html__('Heading Font', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Specify the heading font properties.', 'redux-framework-demo'),
			'google' 	=> true,
			'fonts'     => get_custom_fonts(),
			'preview'	=> false,
			'line-height'=>false,
			'color' 	=> false,
			'font-size' => false,
			'text-align' => false,
			'default' 	=> array(
				'font-family' 	=> 'Heebo',
				'font-weight' 	=> '400',
			),
			'output'      => array('h1,h2,h3,h4,h5,h6'),
		),

		array(
			'id'		=> 'heading_font_weight',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Apply Font Weight for all headings', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> false,
		),
	
		// array(
		// 	'id'        => 'h1_size',
		// 	'type'      => 'slider',
		// 	'title'     => esc_html__('h1 size', 'redux-framework-demo'),
		// 	"default"   => 45,
		// 	"min"       => 1,
		// 	"step"      => 1,
		// 	"max"       => 300,
		// 	'display_value' => 'text'
		// ),
	
		// array(
		// 	'id'        => 'h2_size',
		// 	'type'      => 'slider',
		// 	'title'     => esc_html__('h2 size', 'redux-framework-demo'),
		// 	"default"   => 36,
		// 	"min"       => 1,
		// 	"step"      => 1,
		// 	"max"       => 300,
		// 	'display_value' => 'text'
		// ),
	
		// array(
		// 	'id'        => 'h3_size',
		// 	'type'      => 'slider',
		// 	'title'     => esc_html__('h3 size', 'redux-framework-demo'),
		// 	"default"   => 30,
		// 	"min"       => 1,
		// 	"step"      => 1,
		// 	"max"       => 300,
		// 	'display_value' => 'text'
		// ),
	
		// array(
		// 	'id'        => 'h4_size',
		// 	'type'      => 'slider',
		// 	'title'     => esc_html__('h4 size', 'redux-framework-demo'),
		// 	"default"   => 24,
		// 	"min"       => 1,
		// 	"step"      => 1,
		// 	"max"       => 300,
		// 	'display_value' => 'text'
		// ),
	
		// array(
		// 	'id'        => 'h5_size',
		// 	'type'      => 'slider',
		// 	'title'     => esc_html__('h5 size', 'redux-framework-demo'),
		// 	"default"   => 20,
		// 	"min"       => 1,
		// 	"step"      => 1,
		// 	"max"       => 300,
		// 	'display_value' => 'text'
		// ),
	
		// array(
		// 	'id'        => 'h6_size',
		// 	'type'      => 'slider',
		// 	'title'     => esc_html__('h6 size', 'redux-framework-demo'),
		// 	"default"   => 16,
		// 	"min"       => 1,
		// 	"step"      => 1,
		// 	"max"       => 300,
		// 	'display_value' => 'text'
		// ),
	)
));

Redux::setSection( $opt_name, array(
	'title' 	=> esc_html__( 'Social List', 'redux-framework-demo' ),
	'id'    	=> 'social-list',
	'icon'  	=> 'el el-facebook',
	'fields' 	=> array(
		array(
			'id'		=> 'fixed_social_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Fixed Social List', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> false,
		),
		array(
			'id'		=> 'fixed_social_title_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Fixed Social Title Switcher', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> true,
			'required' 	=> array(
				array('fixed_social_switcher','=', true),
			),
		),
		array(
			'id'        => 'fixed_social_title',
			'type'      => 'text',
			'title'     => esc_html__('Fixed Social Title', 'redux-framework-demo'),
			'default'   => esc_html__('Follow', 'redux-framework-demo'),
			'required' 	=> array(
				array('fixed_social_switcher','=', true),
				array('fixed_social_title_switcher','=', true),
			),
		),
		array(
			'id'		=> 'footer_social_switcher',
			'type' 		=> 'switch',
			'title' 	=> esc_html__('Footer Social List', 'redux-framework-demo'),
			'on'		=> esc_html__('Enable', 'redux-framework-demo'),
			'off'		=> esc_html__('Disable', 'redux-framework-demo'),
			'default' 	=> false,
		),
		array(
			'id'       => 'social_position',
			'type'     => 'sortable',
			'title'    => __('Visibility and Order', 'redux-framework-demo'),
			'subtitle' => __('Configure the settings for each social platform', 'redux-framework-demo'),
			'mode'     => 'checkbox',
			'options'  => array(
				'facebook'      => __('Facebook', 'redux-framework-demo'),
				'twitter'       => __('Twitter', 'redux-framework-demo'),
				'pinterest'     => __('Pinterest', 'redux-framework-demo'),
				'linkedin'      => __('Linkedin', 'redux-framework-demo'),
				'behance'       => __('Behance', 'redux-framework-demo'),
				'vimeo'         => __('Vimeo', 'redux-framework-demo'),
				'google'        => __('Google', 'redux-framework-demo'),
				'youtube'       => __('Youtube', 'redux-framework-demo'),
				'instagram'     => __('Instagram', 'redux-framework-demo'),
				'github'        => __('Github', 'redux-framework-demo'),
				'flickr'        => __('Flickr', 'redux-framework-demo'),
				'dribbble'      => __('Dribbble', 'redux-framework-demo'),
				'dropbox'       => __('Dropbox', 'redux-framework-demo'),
				'paypal'        => __('Paypal', 'redux-framework-demo'),
				'picasa'        => __('Picasa', 'redux-framework-demo'),
				'soundcloud'    => __('SoundCloud', 'redux-framework-demo'),
				'whatsapp'      => __('Whatsapp', 'redux-framework-demo'),
				'skype'         => __('Skype', 'redux-framework-demo'),
				'slack'         => __('Slack', 'redux-framework-demo'),
				'wechat'        => __('WeChat', 'redux-framework-demo'),
				'icq'           => __('ICQ', 'redux-framework-demo'),
				'rocketchat'    => __('RocketChat', 'redux-framework-demo'),
				'telegram'      => __('Telegram', 'redux-framework-demo'),
				'tiktok'     	=> __('Tiktok', 'redux-framework-demo'),
				'vkontakte'		=> __('Vkontakte', 'redux-framework-demo'),
				'bluesky'		=> __('Bluesky', 'redux-framework-demo'),
				'threads'		=> __('Threads', 'redux-framework-demo'),
				'strava'		=> __('Strava', 'redux-framework-demo'),
			),
			// For checkbox mode
			'default' => array(
				'facebook' => true,
				'twitter' => true,
				'pinterest' => true,
				'linkedin' => true,
				'behance' => true,
				'vimeo' => true,
				'google' => true,
				'youtube' => true,
				'instagram' => true,
				'github' => true,
				'flickr' => true,
				'dribbble' => true,
				'dropbox' => true,
				'paypal' => true,
				'picasa' => true,
				'soundcloud' => true,
				'whatsapp' => true,
				'skype' => true,
				'slack' => true,
				'wechat' => true,
				'icq' => true,
				'rocketchat' => true,
				'telegram' => true,
				'tiktok' => true,
				'vkontakte' => true,
				'bluesky' => true,
				'threads' => true,
				'strava' => true,
			),
		),
	
		array(
			'id' 		=> 'social_links_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Social Network URLs', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		// URL fields for each social platform
		array(
			'id'        => 'facebook_url',
			'type'      => 'text',
			'title'     => esc_html__('Facebook URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'twitter_url',
			'type'      => 'text',
			'title'     => esc_html__('Twitter URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'pinterest_url',
			'type'      => 'text',
			'title'     => esc_html__('Pinterest URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'linkedin_url',
			'type'      => 'text',
			'title'     => esc_html__('Linkedin URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'behance_url',
			'type'      => 'text',
			'title'     => esc_html__('Behance URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'vimeo_url',
			'type'      => 'text',
			'title'     => esc_html__('Vimeo URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'google_url',
			'type'      => 'text',
			'title'     => esc_html__('Google URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'youtube_url',
			'type'      => 'text',
			'title'     => esc_html__('Youtube URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'instagram_url',
			'type'      => 'text',
			'title'     => esc_html__('Instagram URL', 'redux-framework-demo'),
		),
		array(
			'id'        => 'github_url',
			'type'      => 'text',
			'title'     => esc_html__('Github URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'flickr_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Flickr URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'dribbble_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Dribbble URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'dropbox_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Dropbox URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'paypal_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Paypal URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'picasa_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Picasa URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'soundcloud_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Soundcloud URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'whatsapp_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Whatsapp URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'skype_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Skype URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'slack_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Slack URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'wechat_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Wechat URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'icq_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('ICQ URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'rocketchat_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Rocketchat URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'telegram_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Telegram URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'tiktok_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Tiktok URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'vkontakte_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Vkontakte URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'bluesky_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Bluesky URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'threads_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Threads URL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'strava_url',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Strava URL', 'redux-framework-demo'),
		),
	
		array(
			'id' 		=> 'social_links_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

	)

));

Redux::setSection( $opt_name, array(
	'title' 	=> esc_html__( 'Viral', 'redux-framework-demo' ),
	'id'    	=> 'reactions',
	'icon'  	=> 'el el-smiley',
	'fields' 	=> array(

		array(
			'id' 		=> 'pageviews_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Page Views', 'redux-framework-demo'),
			'indent' 	=> true,
		),
		array(
			'id' 		=> 'post_views_fake',
			'type' 		=> 'button_set',
			'title' 	=> __('Fake views', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable'
		),
		array(
			'id'       => 'post_views_fake_count',
			'type'     => 'text',
			'validate' => 'numeric',
			'title'    => __('Fake views count', 'redux-framework-demo'),
			'required' => array(
				array('post_views_fake','=','enable'),
			),
		),
		array(
			'id' 		=> 'post_views_interval',
			'type' 		=> 'button_set',
			'title' 	=> __('Visit Tracking Interval', 'redux-framework-demo'),
			'desc' 		=> __('Please be careful when setting this option. If you select "1 day" and a user visits a post, their subsequent pageviews for that post will not be counted again within that day. Even if you later change the interval to "5 minutes" or something shorter, their views will still be restricted by the previously selected "1 day" interval. New views will only be counted after the day has passed', 'redux-framework-demo'),
			'options' 	=> array(
					0 			=> esc_html__( 'No Interval', 'redux-framework-demo' ),
					300 		=> esc_html__( '5 minutes', 'redux-framework-demo' ),
					900 		=> esc_html__( '15 minutes', 'redux-framework-demo' ),
					1800 		=> esc_html__( '30 minutes', 'redux-framework-demo' ),
					3600 		=> esc_html__( '1 hour', 'redux-framework-demo' ),
					7200 		=> esc_html__( '2 hours', 'redux-framework-demo' ),
					86400		=> esc_html__( '1 day', 'redux-framework-demo' ),
			), 
			'default' 	=> 0
		),
		array(
			'id' 		=> 'post_views_in_single',
			'type' 		=> 'button_set',
			'title' 	=> __('Display options', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'enable'
		),
		
		array(
			'id' 		=> 'pageviews_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),
		array(
			'id' 		=> 'vote_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Votes Switcher', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable'
		),
		array(
			'id' 		=> 'reaction_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Reaction Switcher', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable'
		),
		array(
			'id'       => 'reactions_default',
			'type'     => 'sortable',
			'title'    => __('Reactions', 'redux-framework-demo'),
			'subtitle' => __('Define and reorder these however you want.', 'redux-framework-demo'),
			'mode'     => 'checkbox',
			'options'  => array(
				'in_love'     		=> __('In Love', 'redux-framework-demo'),
				'happy'     		=> __('Happy', 'redux-framework-demo'),
				'not_sure'     		=> __('Not Sure', 'redux-framework-demo'),
				'omg'     			=> __('OMG', 'redux-framework-demo'),
				'angry'     		=> __('Angry', 'redux-framework-demo'),
				'sad'     			=> __('Sad', 'redux-framework-demo'),
				'lol'     			=> __('Lol', 'redux-framework-demo'),
				'cry'     			=> __('Cry', 'redux-framework-demo'),
				'silly'     		=> __('Silly', 'redux-framework-demo'),
				'crazy'     		=> __('Crazy', 'redux-framework-demo'),
			),
			// For checkbox mode
			'default' => array(
				'in_love' 	=> true,
				'happy' 	=> true,
				'not_sure' 	=> true,
				'omg' 		=> true,
				'angry' 	=> true,
				'sad' 		=> true,
				'lol' 		=> true,
				'cry' 		=> true,
				'silly' 	=> true,
				'crazy' 	=> true,
			),
		),
		array(
			'id'		=> 'reaction_in_love_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('In Love Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: In Love', 'redux-framework-demo'),
			'default' 	=> esc_html__('In Love', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_happy_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Happy Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Happy', 'redux-framework-demo'),
			'default' 	=> esc_html__('Happy', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_not_sure_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Not Sure Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Not Sure', 'redux-framework-demo'),
			'default' 	=> esc_html__('Not Sure', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_omg_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('OMG Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: OMG', 'redux-framework-demo'),
			'default' 	=> esc_html__('OMG', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_angry_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Angry Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Angry', 'redux-framework-demo'),
			'default' 	=> esc_html__('Angry', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_sad_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Sad Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Sad', 'redux-framework-demo'),
			'default' 	=> esc_html__('Sad', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_lol_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('LOL Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: LOL', 'redux-framework-demo'),
			'default' 	=> esc_html__('LOL', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_cry_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Cry Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Cry', 'redux-framework-demo'),
			'default' 	=> esc_html__('Cry', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_silly_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Silly Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Silly', 'redux-framework-demo'),
			'default' 	=> esc_html__('Silly', 'redux-framework-demo'),
		),
		array(
			'id'		=> 'reaction_crazy_text',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Crazy Text', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default Value: Crazy', 'redux-framework-demo'),
			'default' 	=> esc_html__('Crazy', 'redux-framework-demo'),
		),
	
		array(
			'id'          => 'reactions_custom',
			'type'        => 'slides',
			'title'       => esc_html__('Custom Reactions', 'redux-framework-demo'),
			'subtitle'    => esc_html__('Add/Reorder your custom reactions here', 'redux-framework-demo'),
			'placeholder' => array(
				'title' 		=> __( 'Reaction Title' , 'redux-framework-demo' ),
				'description' 	=> __( 'Upload your reaction icon (png).' , 'redux-framework-demo' ),
				'url' 			=> __( 'Reaction ID. Use only english lowercase/uppercase characters (a-z, A-Z) and symbol _. For example: reaction_hot.' , 'redux-framework-demo' )
			),
			'show' => array(
				'title' => true,
				'description' => false,
				'url' => true
			)
		),
	)
));

Redux::setSection( $opt_name, array(
	'title' 	=> esc_html__( 'Blog Single (wp post)', 'redux-framework-demo' ),
	'id'    	=> 'blogsingle',
	'icon'  	=> 'el el-file',
	'fields' 	=> array(
	
		array(
			'id' 		=> 'single_layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Single Layout', 'redux-framework-demo'),
			'options' 	=> array(
				'standard' 			=> esc_html__( 'Standard', 'redux-framework-demo' ),
				'featured' 			=> esc_html__( 'Featured', 'redux-framework-demo' ),
				'spotlight' 		=> esc_html__( 'Spotlight Headline', 'redux-framework-demo' ),
				'overlay_title' 	=> esc_html__( 'Overlay Title', 'redux-framework-demo' ),
				'large_image' 		=> esc_html__( 'Large Image', 'redux-framework-demo' ),
				'overlay_content' 	=> esc_html__( 'Overlay Content', 'redux-framework-demo' ),
			), 
			'default' 	=> 'standard'
		),
	
		// array(
		// 	'id' 		=> 'single_sticky_title',
		// 	'type' 		=> 'button_set',
		// 	'title' 	=> __('Post Title Sticky in Single Post', 'redux-framework-demo'),
		// 	'options' 	=> array(
		// 		'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
		// 		'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
		// 	), 
		// 	'default' 	=> 'enable'
		// ),
	
		array(
			'id' 		=> 'single_prevnext__layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Previous/Next Layout', 'redux-framework-demo'),
			'options' 	=> array(
				'classic' 		=> esc_html__( 'Classic', 'redux-framework-demo' ),
				'none' 			=> esc_html__( 'None', 'redux-framework-demo' ),
			), 
			'default' 	=> 'classic'
		),
	
		
	
		array(
			'id' 		=> 'single_related_posts',
			'type' 		=> 'button_set',
			'title' 	=> __('Related Posts', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'enable'
		),
	
		array(
			'id' 		=> 'single_author_information',
			'type' 		=> 'button_set',
			'title' 	=> __('Author Information in Single Page', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'enable'
		),
	
		array(
			'id' 		=> 'single_auto_loading_post',
			'type' 		=> 'button_set',
			'title' 	=> __('Autoloading Post', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'enable'
		),

		array(
			'id' 		=> 'single_subscribe_block',
			'type' 		=> 'button_set',
			'title' 	=> __('Subscribe Block', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 		=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable'
		),
		array(
			'id'       		=> 'single_subscribe_block_form',
			'type'     		=> 'textarea',
			'title' 		=> esc_html__('Subscribe Shortcode', 'redux-framework-demo'),
			'required' 		=> array(
				array('single_subscribe_block','=','enable'),
			),
		),

		array(
			'id'       => 'post_single_excerpt',
			'type'     => 'button_set',
			'title'    => __('Display excerpt in single posts', 'redux-framework-demo'),
			'subtitle'  => __('Applies to all post formats except the link format', 'redux-framework-demo'),
			'options'  => array(
				'enable'    	=> esc_html__('Enable', 'redux-framework-demo'),
				'disable'    	=> esc_html__('Disable', 'redux-framework-demo'),
			),
			'default'  => 'disable',
		),	

		array(
			'id'       => 'single_link_info',
			'type'     => 'button_set',
			'title'    => __('Post Format Link: Display Options', 'redux-framework-demo'),
			'options'  => array(
				'link'    => esc_html__('Show Only Link', 'redux-framework-demo'),
				'excerpt' => esc_html__('Show Link & Excerpt', 'redux-framework-demo'),
				'content' => esc_html__('Show Link & Full Content', 'redux-framework-demo'),
			),
			'default'  => 'link',
		),	

		array(
			'id'       => 'caption_show',
			'type'     => 'button_set',
			'title'    => __('Image Caption Display', 'redux-framework-demo'),
			'options'  => array(
				'none'        => esc_html__('Do not display', 'redux-framework-demo'),
				'caption'     => esc_html__('Caption', 'redux-framework-demo'),
				'description' => esc_html__('Description', 'redux-framework-demo'),
			),
			'default'  => 'none',
		),

		array(
			'id'        => 'single_post_lightbox',
			'type'      => 'button_set',
			'title'     => __('Image Lightbox', 'redux-framework-demo'),
			'options'   => array(
				'enable'        => esc_html__('Enable', 'redux-framework-demo'),
				'disable'       => esc_html__('Disable', 'redux-framework-demo'),
			), 
			'default'   => 'enable',
		),

		array(
			'id'        => 'single_post_sidebar_from',
			'type'      => 'button_set',
			'title'     => __('Sidebar Source for Single Post', 'redux-framework-demo'),
			'options'   => array(
				'global'        => esc_html__('Global Setting', 'redux-framework-demo'),
				'local'         => esc_html__('Local Setting', 'redux-framework-demo'),
			), 
			'default'   => 'local',
		),
		
		array(
			'id'        => 'single_post_sidebar',
			'type'      => 'button_set',
			'title'     => __('Single Post Sidebar Position', 'redux-framework-demo'),
			'options'   => array(
				'wsl'           => esc_html__('Left Sidebar', 'redux-framework-demo'),
				'wsr'           => esc_html__('Right Sidebar', 'redux-framework-demo'),
				'full'          => esc_html__('No Sidebar', 'redux-framework-demo'),
			), 
			'default'   => 'wsr',
			'required'  => array(
				array('single_post_sidebar_from', '=', 'global'),
			),
		),
		

		array(
			'id' 		=> 'sticky_sidebar',
			'type' 		=> 'button_set',
			'title' 	=> __('Sticky Sidebar', 'redux-framework-demo'),
			'options' 	=> array(
				'enable' 			=> esc_html__( 'Enable', 'redux-framework-demo' ),
				'disable' 			=> esc_html__( 'Disable', 'redux-framework-demo' ),
			), 
			'default' 	=> 'enable'
		),
		
	)
));



Redux::setSection( $opt_name, array(
	'title' 	=> esc_html__( 'Blog', 'redux-framework-demo' ),
	'id'    	=> 'blogpage',
	'icon'  	=> 'el el-list-alt',
	'fields' 	=> array(


		
		array(
			'id'        => 'rating_system',
			'type'      => 'slider',
			'title'     => esc_html__('Rating System', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('Default: 10-point system', 'redux-framework-demo'),
			"default"   => 10,
			"min"       => 1,
			"step"      => 1,
			"max"       => 100,
			'display_value' => 'text'
		),

		
		
		array(
			'id'		=> 'blog_single_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Index Page Title', 'redux-framework-demo'),
			'subtitle' 	=> esc_html__('If for homepage is selected Latest Posts', 'redux-framework-demo'),
			'default'	=> esc_html__('Latest Articles', 'redux-framework-demo'),
		),
		
		array(
			'id' 		=> 'blog_layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Archive Layout', 'redux-framework-demo'),
			'options' 	=> array(
				'classic' 			=> esc_html__( 'Classic', 'redux-framework-demo' ),
				'masonry' 			=> esc_html__( 'Masonry', 'redux-framework-demo' ),
				'list' 				=> esc_html__( 'List', 'redux-framework-demo' ),
				'mixed' 			=> esc_html__( 'Mixed', 'redux-framework-demo' ),
				'simple_text' 		=> esc_html__( 'Simple text', 'redux-framework-demo' ),
				'small_list' 		=> esc_html__( 'Small List #1', 'redux-framework-demo' ),
				'small_list_2' 		=> esc_html__( 'Small List #2', 'redux-framework-demo' ),
							), 
			'default' 	=> 'list'
		),

		array(
			'id'       => 'video_autoplay',
			'type'     => 'switch', 
			'title'    => esc_html__('Videos autoplay in blog list', 'redux-framework-demo'),
			'default'  => true,
		),

		array(
			'id'       => 'report_post',
			'type'     => 'switch', 
			'title'    => esc_html__('Report Posts', 'redux-framework-demo'),
			'default'  => false,
		),
		array(
			'id'		=> 'report_post_email',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Report Email', 'redux-framework-demo'),
		),
	)
));



Redux::setSection( $opt_name, array(
	'title' 	=> esc_html__( 'Relink Page', 'redux-framework-demo' ),
	'id'    	=> 'relinkpage',
	'icon'  	=> 'el el-list-alt',
	'fields' 	=> array(

		array(
			'id' 		=> 'relink_pending_posts_visibility',
			'type' 		=> 'button_set',
			'title'    => __('Pending Posts in Admin Bar', 'redux-framework-demo'),
			'subtitle' => __('Toggle the visibility of pending posts in the WordPress admin bar.', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'enable'
		),

		array(
			'id' 		=> 'relink_posts_layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Posts Layout', 'redux-framework-demo'),
			'options' 	=> array(
				'small_list' 		=> esc_html__( 'Small List #1', 'redux-framework-demo' ),
				'small_list_2' 		=> esc_html__( 'Small List #2', 'redux-framework-demo' ),
			), 
			'default' 	=> 'small_list_2',
		),

		array(
			'id' 		=> 'relink_vote_layout',
			'type' 		=> 'button_set',
			'title' 	=> __('Vote Layout', 'redux-framework-demo'),
			'options' 	=> array(
				'vclassic' 		=> esc_html__( 'Classic', 'redux-framework-demo' ),
				'vmodern' 		=> esc_html__( 'Modern', 'redux-framework-demo' ),
			), 
			'default' 	=> 'vclassic',
		),
		array(
			'id' 		=> 'blog_filter_section_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Filter', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id'       => 'blog_filter_popular_switcher',
			'type'     => 'switch', 
			'title'    => esc_html__('Popular Posts', 'redux-framework-demo'),
			'default'  => true,
		),

		array(
			'id'       => 'blog_filter_trending_switcher',
			'type'     => 'switch', 
			'title'    => esc_html__('Trending Posts', 'redux-framework-demo'),
			'default'  => true,
		),

		array(
			'id'       => 'blog_filter_hot_switcher',
			'type'     => 'switch', 
			'title'    => esc_html__('Hot Posts', 'redux-framework-demo'),
			'default'  => true,
		),

		array(
			'id'       => 'blog_filter_editor_switcher',
			'type'     => 'switch', 
			'title'    => esc_html__('Editor Picks', 'redux-framework-demo'),
			'default'  => false,
		),

		array(
			'id' 		=> 'trending_period_count',
			'type' 		=> 'slider',
			'title' 	=> __('Trending Period Count', 'redux-framework-demo'),
			'min'  		=> 1,
			'max'  		=> 999,
			'step' 		=> 1,
			'default' 	=> 1,
			'required' 	=> array(
				array('blog_filter_trending_switcher','=', true),
			),
		),
	
		array(
			'id' 		=> 'trending_period_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Trending Period Type', 'redux-framework-demo'),
			'options' 	=> array(
				'day' 		=> esc_html__( 'Days', 'redux-framework-demo' ),
				'week' 		=> esc_html__( 'Weeks', 'redux-framework-demo' ),
				'month' 	=> esc_html__( 'Months', 'redux-framework-demo' ),
				'year' 		=> esc_html__( 'Years', 'redux-framework-demo' ),
							), 
			'default' 	=> 'month',
			'required' 	=> array(
				array('blog_filter_trending_switcher','=', true),
			),
		),

		array(
			'id' 		=> 'hot_period_count',
			'type' 		=> 'slider',
			'title' 	=> __('Hot Period Count', 'redux-framework-demo'),
			'min'  		=> 1,
			'max'  		=> 999,
			'step' 		=> 1,
			'default' 	=> 3,
			'required' 	=> array(
				array('blog_filter_hot_switcher','=', true),
			),
		),
	
		array(
			'id' 		=> 'hot_period_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Hot Period Type', 'redux-framework-demo'),
			'options' 	=> array(
				'day' 		=> esc_html__( 'Days', 'redux-framework-demo' ),
				'week' 		=> esc_html__( 'Weeks', 'redux-framework-demo' ),
				'month' 	=> esc_html__( 'Months', 'redux-framework-demo' ),
				'year' 		=> esc_html__( 'Years', 'redux-framework-demo' ),
							), 
			'default' 	=> 'day',
			'required' 	=> array(
				array('blog_filter_hot_switcher','=', true),
			),
		),

		array(
			'id'       		=> 'editors_pick_posts__id',
			'type'     		=> 'textarea',
			'title'			=> esc_html__('Editors Pick. Enter Posts IDs', 'redux-framework-demo'),
			'subtitle'		=> esc_html__('Please list your posts by ID. For example: 3,4,10. It means that you have selected posts with these IDs.', 'redux-framework-demo'),
			'required' 	=> array(
				array('blog_filter_editor_switcher','=', true),
			),
		),

		array(
			'id'      => 'blog_filter_seconday',
			'type'    => 'sorter',
			'title'   => esc_html__('Structure of the secondary filter', 'redux-framework-demo'),
			'options' => array(
				'enabled'  => array(
					'views'     		=> esc_html__('Views', 'redux-framework-demo'),
					'points' 			=> esc_html__('Points', 'redux-framework-demo'),
					'total_votes' 		=> esc_html__('Total Votes', 'redux-framework-demo'),
					'upvotes' 			=> esc_html__('Upvotes', 'redux-framework-demo'),
					'downvotes' 		=> esc_html__('Downvotes', 'redux-framework-demo'),
					'comments' 			=> esc_html__('Comments', 'redux-framework-demo'),
				),
				'disabled' => array(
					'rating' 			=> esc_html__('Rating', 'redux-framework-demo'),
				),
			),
		),

		array(
			'id' 		=> 'blog_filter_section_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id'        => 'share_count_dependency_on_pageviews',
			'type'      => 'slider',
			'title'     => __('Share Frequency Based on Views (%)', 'redux-framework-demo'),
			'subtitle'  => __('Set the percentage to determine how often your content is shared based on page views. The share count will dynamically adjust according to the specified percentage of total views, contributing to the overall sharing calculation.', 'redux-framework-demo'),
			'min'       => 0,
			'max'       => 100,
			'step'      => 1,
			'default'   => 2,
		),
		
		array(
			'id'        => 'share_count_dependency_on_points',
			'type'      => 'slider',
			'title'     => __('Share Frequency Based on Points (%)', 'redux-framework-demo'),
			'subtitle'  => __('Set the percentage to define how often your content is shared based on points. The number of shares will dynamically adjust according to the specified percentage of points, contributing to the total share count when combined with the page view percentage.', 'redux-framework-demo'),
			'min'       => 0,
			'max'       => 100,
			'step'      => 1,
			'default'   => 1,
		),
		
	)

));

Redux::setSection( $opt_name, array(
	'title' 	=> __( 'Footer', 'redux-framework-demo' ),
	'id'    	=> 'footer',
	'icon'  	=> 'el el-road',
	'fields' 	=> array(
	
		
	
		array(
			'id'		=> 'footer__copyright',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Copyright Text', 'redux-framework-demo'),
			'default'	=> 'Copyright © [current_year] MOW. All rights reserved.',
		),
		
		array(
			'id' 		=> 'footer_w_col_count',
			'type' 		=> 'button_set',
			'title' 	=> __('Widgets Area', 'redux-framework-demo'),
			'options' 	=> array(
				'disable' 		=> esc_html__( 'Disable', 'redux-framework-demo' ),
				'1' 			=> esc_html__( '1 Col', 'redux-framework-demo' ),
				'2' 			=> esc_html__( '2 Cols', 'redux-framework-demo' ),
				'3' 			=> esc_html__( '3 Cols', 'redux-framework-demo' ),
				'4' 			=> esc_html__( '4 Cols', 'redux-framework-demo' ),
			), 
			'default' 	=> 'disable'
		),


		
		
	)
));


Redux::setSection( $opt_name, array(
	'title' => __( 'Share Options', 'redux-framework-demo' ),
	'id'    => 'sharebox',
	'icon'  => 'el el-share-alt',
	'fields' 	=> array(  
		array(
			'id' 		=> 'open_graph_meta',
			'type' 		=> 'button_set',
			'title' 	=> __('Open Graph Meta', 'redux-framework-demo'),
			'subtitle' 	=> __('Open Graph Meta refers to the metadata tags that use the Open Graph Protocol to enhance how your content appears on social media platforms. Adding these tags to your website boosts its shareability and ensures a professional and appealing presence online. Let me know if you would like help adding Open Graph tags to your site!', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'disable'
		),
		array(
			'id' 		=> 'share_facebook',
			'type' 		=> 'button_set',
			'title' 	=> __('Facebook', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'enable'
		),
		array(
			'id' 		=> 'share_twitter',
			'type' 		=> 'button_set',
			'title' 	=> __('Twitter', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'enable'
		),
		array(
			'id' 		=> 'share_pinterest',
			'type' 		=> 'button_set',
			'title' 	=> __('Pinterest', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'enable'
		),
		array(
			'id' 		=> 'share_linkedin',
			'type' 		=> 'button_set',
			'title' 	=> __('Linkedin', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),
		array(
			'id' 		=> 'share_whatsapp',
			'type' 		=> 'button_set',
			'title' 	=> __('Whatsapp', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')), 
			'default' 	=> 'disable'
		),
		array(
			'id' 		=> 'share_email',
			'type' 		=> 'button_set',
			'title' 	=> __('Email', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),
		array(
			'id' 		=> 'share_vk',
			'type' 		=> 'button_set',
			'title' 	=> __('Vkontakte', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'enable'
		),
		array(
			'id' 		=> 'share_text_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Share Text Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'enable'
		),
	)
));
  

$section = array(
	'title' => esc_html__( 'Advertising', 'redux-framework-demo' ),
	'id'    => 'advertising',
	'icon'  => 'el el-bullhorn',
);
Redux::setSection($opt_name, $section);

// #1 subsection
$section = array(
	'title' 	=> esc_html__( 'Off-Canvas', 'redux-framework-demo' ),
    'id'         => 'ads_off_canvas',
    'subsection' => true,
    'desc'       => '',
    'fields'     => array(
	
		array(
			'id' 		=> 'ads_off_canvas_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),

		array(
			'id' 		=> 'ads_off_canvas_title_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Title Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable',
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
			),
		),

		array(
			'id'		=> 'ads_off_canvas_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Advertisement', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
				array('ads_off_canvas_title_switcher','=','enable'),
			),
		),

		array(
			'id'             => 'ads_off_canvas_spacing',
			'type'           => 'spacing',
			'output'         => array('.mow_fn_banner__off_canvas'),
			'mode'           => 'padding',
			'units'          => array('px'),
			'units_extended' => 'false',
			'title'          => esc_html__('Padding Option', 'redux-framework-demo'),
			'default'            => array(
				'margin-top'     => '0px', 
				'margin-right'   => '0px', 
				'margin-bottom'  => '0px', 
				'margin-left'    => '0px',
				'units'          => 'px', 
			),
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
			),
		),
		
		array(
			'id' 		=> 'ads_off_canvas_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Ads type', 'redux-framework-demo'),
			'options' 	=> array(
							'custom_banner'  	=> esc_html__('Custom Banner', 'redux-framework-demo'), 
							'google_ads'		=> esc_html__('Google Ads', 'redux-framework-demo')
			),
			'default' 	=> 'custom_banner',
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=> 'ads_off_canvas_ga_area',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Google Ads Area', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
				array('ads_off_canvas_type','=','google_ads'),
			),
		),
	
		array(
			'id'		=> 'ads_off_canvas_cb_image',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Upload your banner', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
				array('ads_off_canvas_type','=','custom_banner'),
			),
		),
	
		array(
			'id'		=> 'ads_off_canvas_cb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Banner Link URL', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
				array('ads_off_canvas_type','=','custom_banner'),
			),
		),
	
		array(
			'id' 		=> 'ads_off_canvas_cb_target',
			'type' 		=> 'button_set',
			'title' 	=> __('Banner Link Target', 'redux-framework-demo'),
			'options' 	=> array(
							'_blank'  	=> esc_html__('Open in new tab', 'redux-framework-demo'), 
							'_self'		=> esc_html__('Open in the same page', 'redux-framework-demo')
			),
			'default' 	=> '_blank',
			'required' 	=> array(
				array('ads_off_canvas_switcher','=','enable'),
				array('ads_off_canvas_type','=','custom_banner'),
			),
		),
	
	)
);
Redux::setSection($opt_name, $section);


// #2 subsection
$section = array(
	'title' 	=> esc_html__( 'Header Below', 'redux-framework-demo' ),
    'id'         => 'ads_header_below',
    'subsection' => true,
    'desc'       => '',
    'fields'     => array(
	
		array(
			'id' 		=> 'ads_header_below_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),

		array(
			'id' 		=> 'ads_header_below_title_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Title Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable',
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
			),
		),

		array(
			'id'		=> 'ads_header_below_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Advertisement', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
				array('ads_header_below_title_switcher','=','enable'),
			),
		),
		
		array(
			'id' 		=> 'ads_header_below_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Ads type', 'redux-framework-demo'),
			'options' 	=> array(
							'custom_banner'  	=> esc_html__('Custom Banner', 'redux-framework-demo'), 
							'google_ads'		=> esc_html__('Google Ads', 'redux-framework-demo')
			),
			'default' 	=> 'custom_banner',
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=> 'ads_header_below_ga_area',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Google Ads Area', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
				array('ads_header_below_type','=','google_ads'),
			),
		),
	
		array(
			'id'		=> 'ads_header_below_cb_image',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Upload your banner', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
				array('ads_header_below_type','=','custom_banner'),
			),
		),
	
		array(
			'id'		=> 'ads_header_below_cb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Banner Link URL', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
				array('ads_header_below_type','=','custom_banner'),
			),
		),
	
		array(
			'id' 		=> 'ads_header_below_cb_target',
			'type' 		=> 'button_set',
			'title' 	=> __('Banner Link Target', 'redux-framework-demo'),
			'options' 	=> array(
							'_blank'  	=> esc_html__('Open in new tab', 'redux-framework-demo'), 
							'_self'		=> esc_html__('Open in the same page', 'redux-framework-demo')
			),
			'default' 	=> '_blank',
			'required' 	=> array(
				array('ads_header_below_switcher','=','enable'),
				array('ads_header_below_type','=','custom_banner'),
			),
		),
	
	)
);
Redux::setSection($opt_name, $section);

// #3 subsection
$section = array(
	'title' 	=> esc_html__( 'Footer Above', 'redux-framework-demo' ),
    'id'         => 'ads_footer_above',
    'subsection' => true,
    'desc'       => '',
    'fields'     => array(
	
		array(
			'id' 		=> 'ads_footer_above_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),

		array(
			'id' 		=> 'ads_footer_above_title_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Title Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable',
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
			),
		),

		array(
			'id'		=> 'ads_footer_above_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Advertisement', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
				array('ads_footer_above_title_switcher','=','enable'),
			),
		),
		
		array(
			'id' 		=> 'ads_footer_above_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Ads type', 'redux-framework-demo'),
			'options' 	=> array(
							'custom_banner'  	=> esc_html__('Custom Banner', 'redux-framework-demo'), 
							'google_ads'		=> esc_html__('Google Ads', 'redux-framework-demo')
			),
			'default' 	=> 'custom_banner',
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=> 'ads_footer_above_ga_area',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Google Ads Area', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
				array('ads_footer_above_type','=','google_ads'),
			),
		),
	
		array(
			'id'		=> 'ads_footer_above_cb_image',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Upload your banner', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
				array('ads_footer_above_type','=','custom_banner'),
			),
		),
	
		array(
			'id'		=> 'ads_footer_above_cb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Banner Link URL', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
				array('ads_footer_above_type','=','custom_banner'),
			),
		),
	
		array(
			'id' 		=> 'ads_footer_above_cb_target',
			'type' 		=> 'button_set',
			'title' 	=> __('Banner Link Target', 'redux-framework-demo'),
			'options' 	=> array(
							'_blank'  	=> esc_html__('Open in new tab', 'redux-framework-demo'), 
							'_self'		=> esc_html__('Open in the same page', 'redux-framework-demo')
			),
			'default' 	=> '_blank',
			'required' 	=> array(
				array('ads_footer_above_switcher','=','enable'),
				array('ads_footer_above_type','=','custom_banner'),
			),
		),
	
	)
);
Redux::setSection($opt_name, $section);

// #4 subsection
$section = array(
	'title' 	=> esc_html__( 'List Posts Between', 'redux-framework-demo' ),
    'id'         => 'ads_listpost_btwn',
    'subsection' => true,
    'desc'       => '',
    'fields'     => array(
	
		array(
			'id' 		=> 'ads_listpost_btwn_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),

		array(
			'id' 		=> 'ads_listpost_btwn_title_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Title Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable',
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
			),
		),

		array(
			'id'		=> 'ads_listpost_btwn_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Advertisement', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
				array('ads_listpost_btwn_title_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=>'ads_listpost_btwn_position',
			'type' 		=> 'multi_text',
			'title' 	=> esc_html__('Banner Positions', 'your-textdomain-here'),
			'validate' 	=> array( 'numeric' ),
		),
		
		array(
			'id' 		=> 'ads_listpost_btwn_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Ads type', 'redux-framework-demo'),
			'options' 	=> array(
							'custom_banner'  	=> esc_html__('Custom Banner', 'redux-framework-demo'), 
							'google_ads'		=> esc_html__('Google Ads', 'redux-framework-demo')
			),
			'default' 	=> 'custom_banner',
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=> 'ads_listpost_btwn_ga_area',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Google Ads Area', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
				array('ads_listpost_btwn_type','=','google_ads'),
			),
		),
	
		array(
			'id'		=> 'ads_listpost_btwn_cb_image',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Upload your banner', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
				array('ads_listpost_btwn_type','=','custom_banner'),
			),
		),
	
		array(
			'id'		=> 'ads_listpost_btwn_cb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Banner Link URL', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
				array('ads_listpost_btwn_type','=','custom_banner'),
			),
		),
	
		array(
			'id' 		=> 'ads_listpost_btwn_cb_target',
			'type' 		=> 'button_set',
			'title' 	=> __('Banner Link Target', 'redux-framework-demo'),
			'options' 	=> array(
							'_blank'  	=> esc_html__('Open in new tab', 'redux-framework-demo'), 
							'_self'		=> esc_html__('Open in the same page', 'redux-framework-demo')
			),
			'default' 	=> '_blank',
			'required' 	=> array(
				array('ads_listpost_btwn_switcher','=','enable'),
				array('ads_listpost_btwn_type','=','custom_banner'),
			),
		),
	
	)
);
Redux::setSection($opt_name, $section);

// #5 subsection
$section = array(
	'title' 	=> esc_html__( 'Single Post: Inside Content', 'redux-framework-demo' ),
    'id'         => 'ads_singlepost_in',
    'subsection' => true,
    'desc'       => '',
    'fields'     => array(
	
		array(
			'id' 		=> 'ads_singlepost_in_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),

		array(
			'id' 		=> 'ads_singlepost_in_title_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Title Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable',
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
			),
		),

		array(
			'id'		=> 'ads_singlepost_in_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Advertisement', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
				array('ads_singlepost_in_title_switcher','=','enable'),
			),
		),
		
		array(
			'id' 		=> 'ads_singlepost_in_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Ads type', 'redux-framework-demo'),
			'options' 	=> array(
							'custom_banner'  	=> esc_html__('Custom Banner', 'redux-framework-demo'), 
							'google_ads'		=> esc_html__('Google Ads', 'redux-framework-demo')
			),
			'default' 	=> 'custom_banner',
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=> 'ads_singlepost_in_ga_area',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Google Ads Area', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
				array('ads_singlepost_in_type','=','google_ads'),
			),
		),
	
		array(
			'id'		=> 'ads_singlepost_in_cb_image',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Upload your banner', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
				array('ads_singlepost_in_type','=','custom_banner'),
			),
		),
	
		array(
			'id'		=> 'ads_singlepost_in_cb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Banner Link URL', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
				array('ads_singlepost_in_type','=','custom_banner'),
			),
		),
	
		array(
			'id' 		=> 'ads_singlepost_in_cb_target',
			'type' 		=> 'button_set',
			'title' 	=> __('Banner Link Target', 'redux-framework-demo'),
			'options' 	=> array(
							'_blank'  	=> esc_html__('Open in new tab', 'redux-framework-demo'), 
							'_self'		=> esc_html__('Open in the same page', 'redux-framework-demo')
			),
			'default' 	=> '_blank',
			'required' 	=> array(
				array('ads_singlepost_in_switcher','=','enable'),
				array('ads_singlepost_in_type','=','custom_banner'),
			),
		),
	
	)
);
Redux::setSection($opt_name, $section);

// #6 subsection
$section = array(
	'title' 	=> esc_html__( 'Single Post: After Content', 'redux-framework-demo' ),
    'id'         => 'ads_singlepost_after',
    'subsection' => true,
    'desc'       => '',
    'fields'     => array(
	
		array(
			'id' 		=> 'ads_singlepost_after_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable'
		),

		array(
			'id' 		=> 'ads_singlepost_after_title_switcher',
			'type' 		=> 'button_set',
			'title' 	=> __('Title Switcher', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'disable',
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
			),
		),

		array(
			'id'		=> 'ads_singlepost_after_title',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Title', 'redux-framework-demo'),
			'default' 	=> esc_html__('Advertisement', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
				array('ads_singlepost_after_title_switcher','=','enable'),
			),
		),
		
		array(
			'id' 		=> 'ads_singlepost_after_type',
			'type' 		=> 'button_set',
			'title' 	=> __('Ads type', 'redux-framework-demo'),
			'options' 	=> array(
							'custom_banner'  	=> esc_html__('Custom Banner', 'redux-framework-demo'), 
							'google_ads'		=> esc_html__('Google Ads', 'redux-framework-demo')
			),
			'default' 	=> 'custom_banner',
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
			),
		),
	
		array(
			'id'		=> 'ads_singlepost_after_ga_area',
			'type' 		=> 'textarea',
			'title' 	=> esc_html__('Google Ads Area', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
				array('ads_singlepost_after_type','=','google_ads'),
			),
		),
	
		array(
			'id'		=> 'ads_singlepost_after_cb_image',
			'type' 		=> 'media',
			'url'       => true,
			'title' 	=> esc_html__('Upload your banner', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
				array('ads_singlepost_after_type','=','custom_banner'),
			),
		),
	
		array(
			'id'		=> 'ads_singlepost_after_cb_link',
			'type' 		=> 'text',
			'title' 	=> esc_html__('Banner Link URL', 'redux-framework-demo'),
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
				array('ads_singlepost_after_type','=','custom_banner'),
			),
		),
	
		array(
			'id' 		=> 'ads_singlepost_after_cb_target',
			'type' 		=> 'button_set',
			'title' 	=> __('Banner Link Target', 'redux-framework-demo'),
			'options' 	=> array(
							'_blank'  	=> esc_html__('Open in new tab', 'redux-framework-demo'), 
							'_self'		=> esc_html__('Open in the same page', 'redux-framework-demo')
			),
			'default' 	=> '_blank',
			'required' 	=> array(
				array('ads_singlepost_after_switcher','=','enable'),
				array('ads_singlepost_after_type','=','custom_banner'),
			),
		),
	
	)
);
Redux::setSection($opt_name, $section);

	
Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Custom CSS', 'redux-framework-demo' ),
	'id'    => 'css',
	'icon'  => 'el el-css',
	'fields' 	=> array(
		array(
			'id'       => 'custom_css',
			'type'     => 'ace_editor',
			'title'    => __('Custom CSS', 'redux-framework-demo'),
			'subtitle' => __('Paste your CSS code here.', 'redux-framework-demo'),
			'mode'     => 'css',
			'theme'    => 'monokai',
		),
	)
)); 
	

$seo_tags = array(	'span' 	=> 'span', 
					'p' 	=> 'p',		
					'h1' 	=> 'H1',		
					'h2' 	=> 'H2',		
					'h3' 	=> 'H3',		
					'h4' 	=> 'H4',		
					'h5' 	=> 'H5',		
					'h6' 	=> 'H6');


Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'SEO', 'redux-framework-demo' ),
	'id'    => 'seo',
	'icon'  => 'el el-signal',
	'fields' 	=> array(

		array(
			'id' 		=> 'meta_description_section_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Meta Description Settings', 'redux-framework-demo'),
			'indent' 	=> true,
		),

		array(
			'id' 		=> 'meta_description',
			'type' 		=> 'button_set',
			'title' 	=> __('Enable Meta Description', 'redux-framework-demo'),
			'options' 	=> array(
							'enable'  		=> esc_html__('Enable', 'redux-framework-demo'), 
							'disable' 		=> esc_html__('Disable', 'redux-framework-demo')),
			'default' 	=> 'enable'
		),

		array(
			'id'       		=> 'meta_description_text',
			'type'     		=> 'textarea',
			'title' 		=> esc_html__('Custom Meta Description Text', 'redux-framework-demo'),
			'default' 		=> esc_html__('Mow is a versatile WordPress theme for blogs and magazines, offering stylish design, fast performance, and powerful features for creators worldwide.', 'redux-framework-demo'),
			'required' 		=> array(
				array('meta_description','=','enable'),
			),
		),

		array(
			'id'		=> 'meta_description_limit',
			'type' 		=> 'slider',
			'default' 	=> 160,
			'min' 		=> 1,
			'max' 		=> 999,
			'title' 	=> esc_html__('Character Limit', 'redux-framework-demo'),
		),

		array(
			'id' 		=> 'meta_description_section_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

		array(
			'id' 		=> 'seo_page_section_start',
			'type' 		=> 'section',
			'title' 	=> esc_html__('Pages HTML Tags', 'redux-framework-demo'),
			'indent' 	=> true,
		),

			array(
				'id'		=> 'seo_page_title',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Page Title', 'redux-framework-demo'),
				'default' 	=> 'h1',
				'options' 	=> $seo_tags
			),

			array(
				'id'		=> 'seo_blog_list_title',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('Blog List Title', 'redux-framework-demo'),
				'default' 	=> 'h2',
				'options' 	=> $seo_tags
			),
			array(
				'id'		=> 'seo_404_not_found',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('404 Page: Not Found Text', 'redux-framework-demo'),
				'default' 	=> 'h3',
				'options' 	=> $seo_tags
			),

			array(
				'id'		=> 'seo_404_desc',
				'type' 		=> 'button_set',
				'title' 	=> esc_html__('404 Page: Description', 'redux-framework-demo'),
				'default' 	=> 'p',
				'options' 	=> $seo_tags
			),

		array(
			'id' 		=> 'seo_page_section_end',
			'type' 		=> 'section',
			'indent' 	=> false,
		),

	)
));
