<?php

namespace Frel;

// Exit if accessed directly. 
if ( ! defined( 'ABSPATH' ) ) { exit; }


// Main Plugin Class
class Frel_Plugin
{
	
	
    // Constructor
    public function __construct()
    {
        $this->add_actions();
		
    }
    
    
	// Add Actions
    private function add_actions()
    {
		
		
		// Add New Elementor Categories
        add_action( 'elementor/init', array( $this, 'add_elementor_category' ), 999 );
        // Register Widget Scripts
        add_action( 'elementor/frontend/after_enqueue_scripts', array( $this, 'register_widget_scripts' ) );
        // Register Widget Styles
        add_action( 'elementor/frontend/after_enqueue_styles', array( $this, 'register_widget_styles' ) );
        // Register New Widgets
        add_action( 'elementor/widgets/register', array( $this, 'register_widgets' ), 10 );
		
        add_action( 'elementor/editor/before_enqueue_scripts', function() {
          wp_enqueue_style( 'frel_elementor_css', MOW_PLUGIN_URL . 'assets/css/elementor.css', false, MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, 'all' );
        });
		
		
    }
	
	
	
    // Add New Categories to Elementor
    public function add_elementor_category()
    {
        \Elementor\Plugin::instance()->elements_manager->add_category( 'frel-elements', array(
            'title' => __( 'Frenify Elements', MOW_TEXT_DOMAIN ),
        ), 1 );
    }
    
    // Register Widget Scripts
    public function register_widget_scripts()
    {
		
		wp_enqueue_script( 'justified', plugins_url( 'assets/js/justified.js', __FILE__ ), array( 'jquery' ), MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, TRUE );
		wp_enqueue_script( 'frel_init', MOW_PLUGIN_URL . 'assets/js/init.js', array( 'jquery' ), MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, TRUE );
		
		wp_localize_script(
			'frel_init',
			'MowCoreAjaxObject',
			array( 
				'ajax_url' 			=> admin_url( 'admin-ajax.php' ),
				'siteurl'			=> home_url(),
				'nonce'				=> wp_create_nonce('mow-secure'),
			)
		);
		
    }
	
    // Register Widget Styles
    public function register_widget_styles()
    {
      wp_enqueue_style( 'justified', plugins_url( 'assets/css/justified.css', __FILE__ ), false, MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, 'all' );
      wp_enqueue_style( 'frel_style', MOW_PLUGIN_URL . 'assets/css/style.css', false, MOW_PLUGIN_VERSION.MOW_PLUGIN_SUBVER, 'all' );
    }
    
	
    // Register New Widgets
    public function register_widgets()
    {
        $this->include_widgets();
		$this->include_widget_outputs();
    }
	
	
    // Include Widgets
    private function include_widgets()
    {
		foreach(glob(plugin_dir_path( __FILE__ ) . '/widgets/*.php' ) as $file ){
			$this->include_widget( $file );
		}
		
    }
	
	
	// Include and Load Widget
    private function include_widget($file)
    {
		
		$base  = basename( str_replace( '.php', '', $file ) );
		$class = ucwords( str_replace( '-', ' ', $base ) );
		$class = str_replace( ' ', '_', $class );
		$class = sprintf( 'Frel\Widgets\%s', $class );
		
		require_once $file; // include widget php file
		
		if ( class_exists( $class ) ) {
			\Elementor\Plugin::instance()->widgets_manager->register( new $class ); // load widget class
		}
		
    }
	
	
	// call to widget outputs
	private function include_widget_outputs()
    {
		foreach(glob(plugin_dir_path( __FILE__ ) . '/widgets/output/*.php' ) as $file ){
			require_once $file;
		}
    }
	
	

}