<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Ad extends Widget_Base {

	public function get_name() {
		return 'frel-ad';
	}

	public function get_title() {
		return __( 'Ad.', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-speakerphone frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'ads',
            'advertisement',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'show_bg',
			[
				'label' => esc_html__( 'Background Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_container',
			[
				'label' => esc_html__( 'Container Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label' => esc_html__( 'Title Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'show_title' => 'yes',
				]
			]
		);

		$this->add_control(
			'type',
			[
				'label' 		=> __( 'Type', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'image',
				'options' 		=> [
					'image'		=> __( 'Image', MOW_TEXT_DOMAIN ),
					'code'  	=> __( 'Code', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'type_image',
			[
				'label' => esc_html__( 'Choose Image', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image',
				]
			]
		);
		
		$this->add_control(
			'type_image_url',
			[
				'label' => __( 'URL', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'type' => 'image',
				]
			]
		);
		
		$this->add_control(
			'type_code',
			[
				'label' => __( 'Code', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'condition' => [
					'type' => 'code',
				]
			]
		);
		
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$container_start = $container_end = $title = $content = '';
		if($settings['show_container'] == 'yes'){
			$container_start = '<div class="container">';
			$container_end = '</div>';
		}
		if($settings['show_title'] == 'yes'){
			$title = '<h3 class="ad_title">'.$settings['title'].'</h3>';
		}
		if($settings['type'] == 'image'){


			$image_width = $image_height = 'auto';
			if ($settings['type_image']['url']) {
				$image_path = str_replace(site_url(), ABSPATH, $settings['type_image']['url']); // Convert URL to absolute path
				if (file_exists($image_path)) {
					list($image_width, $image_height) = getimagesize($image_path);
				}
			}

			$content = '<div class="ad_content"><a href="'.$settings['type_image_url'].'" rel="nofollow" target="_blank" aria-label="/"><img loading="lazy" src="'.$settings['type_image']['url'].'" width="' . $image_width . '" height="' . $image_height . '" alt=""></a></div>';
		}else{
			$content = '<div class="ad_content">'.$settings['type_code'].'</div>';
		}
		$ad = '<div class="fn_cs_ad_in" data-bg="'.$settings['show_bg'].'">'.$title.$content.'</div>';
		$html .= '<div class="fn_cs_ad">'.$container_start.$ad.$container_end.'</div>';

		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
