<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Posts extends Widget_Base {

	public function get_name() {
		return 'frel-posts';
	}

	public function get_title() {
		return __( 'Posts', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-post-list frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            'posts',
            'post',
            'custom posts',
            'custom post',
            'blog posts',
            'blog post',
            'portfolio posts',
            'portfolio post',
            'portfolio single',
            'projects',
            'project',
            'project posts',
            'project post',
            'project single',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		$timeOptions = array();
		$timeIntervalMinute = 10;
		$timeAllMinutes = 1440;
		$timeIntervalCount = $timeAllMinutes / $timeIntervalMinute;
		for($i = 0; $i < $timeIntervalCount; $i++){
			$minutes = $i * $timeIntervalMinute;
			$ii = $minutes % 60;
			$hh = intdiv($minutes , 60);
			if($hh < 10){$hh = '0'.$hh;}
			if($ii < 10){$ii = '0'.$ii;}
			$timeOptions[$minutes] = $hh .':'. $ii;
		}
		$timeOptions[$timeAllMinutes-1] = '23:59';
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' 		=> __( 'Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'alpha',
				'options' 		=> [
					'alpha'  			=> __( 'Alpha', MOW_TEXT_DOMAIN ),
					'beta'  			=> __( 'Beta', MOW_TEXT_DOMAIN ),
					'gamma'  			=> __( 'Gamma', MOW_TEXT_DOMAIN ),
					'delta'  			=> __( 'Delta', MOW_TEXT_DOMAIN ),
					'epsilon'  			=> __( 'Epsilon', MOW_TEXT_DOMAIN ),
					'zeta'  			=> __( 'Zeta', MOW_TEXT_DOMAIN ),
					'interactive'		=> __( 'Interactive #1', MOW_TEXT_DOMAIN ),
					'fslider'			=> __( 'Full Slider', MOW_TEXT_DOMAIN ),
					'cslider'			=> __( 'Circle Slider', MOW_TEXT_DOMAIN ),
					'gcarousel'			=> __( 'Grid Carousel', MOW_TEXT_DOMAIN ),
					'fcarousel'			=> __( 'Full Carousel', MOW_TEXT_DOMAIN ),
					'mcarousel'			=> __( 'Modern Slider', MOW_TEXT_DOMAIN ),
					'yota_1'			=> __( 'Yota 1', MOW_TEXT_DOMAIN ),
					'yota_2'			=> __( 'Yota 2', MOW_TEXT_DOMAIN ),
					'date_1'			=> __( 'Date Highlight', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'fslider_type',
			[
				'label' 		=> __( 'Slider Type', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'classic',
				'options' 		=> [
					'classic'  		=> __( 'Classic', MOW_TEXT_DOMAIN ),
					'centered'  	=> __( 'Centered', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'fslider',
				]
			]
		);

		$this->add_control(
			'meta_switcher',
			[
				'label' => esc_html__( 'Meta Data', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'meta_display',
			[
				'label' => __( 'Meta Display', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => [
					'date'  => esc_html__( 'Date', MOW_TEXT_DOMAIN ),
					'category' => esc_html__( 'Category', MOW_TEXT_DOMAIN ),
				],
				'default' => [ 'date', 'category' ],
				'condition' => [
					'meta_switcher' 	=> 'yes',
				]
			]
		);


		$this->add_control(
			'excerpt_switcher',
			[
				'label' => esc_html__( 'Excerpt', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'read_more_switcher',
			[
				'label' => esc_html__( 'Read More', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'read_more_text',
			[
				'label' => __( 'Read More Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Read More', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'read_more_switcher' => 'yes',
				]
			]
		);

		$this->add_control(
			'posts_recent_filter_switcher',
			[
				'label' => esc_html__( 'Posts Recent Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'posts_filter_left_text',
			[
				'label' => __( 'Filter Left Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Popular', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'posts_recent_filter_switcher' => 'yes',
				]
			]
		);

		$this->add_control(
			'posts_filter_right_text',
			[
				'label' => __( 'Filter Right Text', MOW_TEXT_DOMAIN ),
				'default' => __( 'Recent', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'posts_recent_filter_switcher' => 'yes',
				]
			]
		);
		
		
		$this->end_controls_section();
		
		
		$this->start_controls_section(
			'section_query',
			[
				'label' => __( 'Query', MOW_TEXT_DOMAIN ),
			]
		);
		
		$this->add_control(
			'blog_post_number',
			[
				'label' => __( 'Post Number', MOW_TEXT_DOMAIN ),
				'description' 	=> __( '-1 to get all posts', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 6,
				],
				'range' => [
					'px' => [
						'min' => -1,
						'max' => 9999,
						'step' => 1,
					]
				],
			]
		);
		
		$this->add_control(
            'blog_post_offset',
            [
                'label' 	=> esc_html__( 'Post Offset', MOW_TEXT_DOMAIN ),
                'type' 		=> Controls_Manager::NUMBER,
                'default' 	=> 0,
				'min'		=> 0,
            ]
        );
		
		$this->add_control(
			'bpo_formats',
			[
				'label' => esc_html__( 'Formats Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_formats__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'bpo_formats_options',
			[
				'label' 		=> __( 'Post Formats', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT2,
				'multiple'	 	=> true,
				'options' 		=> [
					'all'  						=> __( 'All', MOW_TEXT_DOMAIN ),
					'post-format-video'  		=> __( 'Video', MOW_TEXT_DOMAIN ),
					'post-format-audio'  		=> __( 'Audio', MOW_TEXT_DOMAIN ),
					'post-format-gallery'  		=> __( 'Gallery', MOW_TEXT_DOMAIN ),
					'post-format-image'  		=> __( 'Image', MOW_TEXT_DOMAIN ),
					'post-format-link'  		=> __( 'Link', MOW_TEXT_DOMAIN ),
					'post-format-quote'  		=> __( 'Quote', MOW_TEXT_DOMAIN ),
					'post-format-status'  		=> __( 'Status', MOW_TEXT_DOMAIN ),
					'post-format-standard'  	=> __( 'Standard', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'bpo_formats__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'bpo_posts',
			[
				'label' => esc_html__( 'Post Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_posts__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		
		$this->add_control(
			'blog_post_include__id',
			[
					'label'	 	=> __( 'Include Posts', MOW_TEXT_DOMAIN ),
					'description'	 => __( 'Please list your posts by ID. For example: 3,4,10. It means that you have selected posts with these IDs.', MOW_TEXT_DOMAIN ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'condition' => [
					'bpo_posts__switcher' => 'yes',
				]
			]
		);
		$this->add_control(
			'blog_post_exclude__id',
			[
					'label'	 	=> __( 'Exclude Posts', MOW_TEXT_DOMAIN ),
					'description'	 => __( 'Please list your posts by ID. For example: 3,4,10. It means that you have selected posts with these IDs.', MOW_TEXT_DOMAIN ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'condition' => [
					'bpo_posts__switcher' => 'yes',
				]
			]
		);
		
		
		
		$this->add_control(
			'bpo_categories',
			[
				'label' => esc_html__( 'Category Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_categories__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
			'blog_post_in_categories__id',
			[
					'label'	 	=> __( 'Include Categories', MOW_TEXT_DOMAIN ),
					'description'	 => __( 'Please list your categories by ID. For example: 3,4,10. It means that you have selected categories with these IDs.', MOW_TEXT_DOMAIN ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'condition' => [
					'bpo_categories__switcher' => 'yes',
				]
			]
		);
		$this->add_control(
			'blog_post_ex_categories__id',
			[
					'label'	 	=> __( 'Exclude Categories', MOW_TEXT_DOMAIN ),
					'description'	 => __( 'Please list your categories by ID. For example: 3,4,10. It means that you have selected categories with these IDs.', MOW_TEXT_DOMAIN ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'condition' => [
					'bpo_categories__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'bpo_authors',
			[
				'label' => esc_html__( 'Author Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_author__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
			'blog_post_in_author',
			[
			 	'label'	 		=> __( 'Include Author', MOW_TEXT_DOMAIN ),
			 	'description'	=> __( 'Select author(s) to include', MOW_TEXT_DOMAIN ),
			 	'type' 			=> Controls_Manager::SELECT2,
			 	'multiple'	 	=> true,
			 	'label_block'	=> true,
				'options' 		=> Frel_Helper::getAllAuthors(),
				'condition' => [
					'bpo_author__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'blog_post_ex_author',
			[
			 	'label'	 		=> __( 'Exclude Author', MOW_TEXT_DOMAIN ),
			 	'description'	=> __( 'Select author(s) to exclude', MOW_TEXT_DOMAIN ),
			 	'type' 			=> Controls_Manager::SELECT2,
			 	'multiple'	 	=> true,
			 	'label_block'	=> true,
				'options' 		=> Frel_Helper::getAllAuthors(),
				'condition' => [
					'bpo_author__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'bpo_tags',
			[
				'label' => esc_html__( 'Tag Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_tag__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
			'blog_post_in_tag__id',
			[
					'label'	 	=> __( 'Include Tags', MOW_TEXT_DOMAIN ),
					'description'	 => __( 'Please list your tags by ID. For example: 3,4,10. It means that you have selected tags with these IDs.', MOW_TEXT_DOMAIN ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'condition' => [
					'bpo_tag__switcher' => 'yes',
				]
			]
		);
		$this->add_control(
			'blog_post_ex_tag__id',
			[
					'label'	 	=> __( 'Exclude Tags', MOW_TEXT_DOMAIN ),
					'description'	 => __( 'Please list your tags by ID. For example: 3,4,10. It means that you have selected tags with these IDs.', MOW_TEXT_DOMAIN ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'condition' => [
					'bpo_tag__switcher' => 'yes',
				]
			]
		);
		
		
		$this->add_control(
			'bpo_search',
			[
				'label' => esc_html__( 'Search Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_search__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
			'blog_post_search',
			[
				'label' => esc_html__( 'Keyword search', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'bpo_search__switcher' => 'yes',
				]
			]
		);
		
		
		$this->add_control(
			'bpo_comment',
			[
				'label' => esc_html__( 'Comment Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_comment__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
			'blog_post_comment_count',
			[
				'label' => esc_html__( 'Comment Count', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'step' => 1,
				'default' => 0,
				'condition' => [
					'bpo_comment__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'blog_post_comment_compare',
			[
				'label' => esc_html__( 'Comment Compare', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '>=',
				'options' => [
					'='  => '=',
					'!='  => '!=',
					'>'  => '>',
					'>='  => '>=',
					'<'  => '<',
					'<='  => '<=',
				],
				'condition' => [
					'bpo_comment__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'bpo_order',
			[
				'label' => esc_html__( 'Order Parameters', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_order__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$this->add_control(
            'blog_post_order',
            [
                'label' => esc_html__( 'Post Order', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'asc' 	=> esc_html__( 'Ascending', MOW_TEXT_DOMAIN ),
                    'desc' 	=> esc_html__( 'Descending', MOW_TEXT_DOMAIN )
                ],
                'default' => 'desc',
				'condition' => [
					'bpo_order__switcher' => 'yes',
				]

            ]
        );
		
		$this->add_control(
            'blog_post_orderby',
            [
                'label' => esc_html__( 'Post Orderby', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'select' 			=> esc_html__( 'Select Option', MOW_TEXT_DOMAIN ),
                    'ID' 				=> esc_html__( 'Order by post id', MOW_TEXT_DOMAIN ),
                    'popular' 			=> esc_html__( 'Order by page views / popularity', MOW_TEXT_DOMAIN ),
                    'rating' 			=> esc_html__( 'Order by rating', MOW_TEXT_DOMAIN ),
                    'total_votes'		=> esc_html__( 'Order by total votes', MOW_TEXT_DOMAIN ),
                    'vote_diff'			=> esc_html__( 'Order by vote difference', MOW_TEXT_DOMAIN ),
                    'vote_up'     		=> esc_html__( 'Order by upvotes', MOW_TEXT_DOMAIN ),
					'vote_down' 	  	=> esc_html__( 'Order by downvotes', MOW_TEXT_DOMAIN ),
                    'author' 			=> esc_html__( 'Order by author', MOW_TEXT_DOMAIN ),
                    'title' 			=> esc_html__( 'Order by title', MOW_TEXT_DOMAIN ),
                    'name' 				=> esc_html__( 'Order by post name', MOW_TEXT_DOMAIN ),
                    'date' 				=> esc_html__( 'Order by date', MOW_TEXT_DOMAIN ),
                    'modified' 			=> esc_html__( 'Order by last modified date', MOW_TEXT_DOMAIN ),
                    'rand' 				=> esc_html__( 'Random order', MOW_TEXT_DOMAIN ),
                    'comment_count' 	=> esc_html__( 'Order by number of comments', MOW_TEXT_DOMAIN ),
                    'menu_order' 		=> esc_html__( 'Order by Page Order', MOW_TEXT_DOMAIN ),
				],
                'default' => 'select',
				'condition' => [
					'bpo_order__switcher' => 'yes',
				]

            ]
        );
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'date_filter_section',
			[
				'label' => __( 'Date/Time Query', MOW_TEXT_DOMAIN ),
			]
		);
		
		
		$this->add_control(
			'bpo_date_query',
			[
				'label' => esc_html__( 'Date Query', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		
		$this->add_control(
			'bpo_date__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
            'bpod_type',
            [
                'label' => esc_html__( 'Filter Type', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' 					=> esc_html__( 'Select', MOW_TEXT_DOMAIN ),
                    'range' 			=> esc_html__( 'Range', MOW_TEXT_DOMAIN ),
                    'period' 			=> esc_html__( 'Period', MOW_TEXT_DOMAIN ),
                    'last' 				=> esc_html__( 'Last', MOW_TEXT_DOMAIN ),
                    'before' 			=> esc_html__( 'Before', MOW_TEXT_DOMAIN ),
                    'after' 			=> esc_html__( 'After', MOW_TEXT_DOMAIN ),
                    'date' 				=> esc_html__( 'Date', MOW_TEXT_DOMAIN ),
                    'year' 				=> esc_html__( 'Year', MOW_TEXT_DOMAIN ),
                    'month' 			=> esc_html__( 'Month', MOW_TEXT_DOMAIN ),
                    'day' 				=> esc_html__( 'Day', MOW_TEXT_DOMAIN ),
                    'week' 				=> esc_html__( 'Week', MOW_TEXT_DOMAIN ),
                    'week_days' 		=> esc_html__( 'Days of the week', MOW_TEXT_DOMAIN ),
                ],
                'default' => '',
            ]
        );
		
		/* Range */
		$repeater->add_control(
            'bpod_range',
            [
                'label' => esc_html__( 'Range', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'today' 		=> esc_html__( 'Today', MOW_TEXT_DOMAIN ),
                    'yesterday' 	=> esc_html__( 'Yesterday', MOW_TEXT_DOMAIN ),
                    'this_week' 	=> esc_html__( 'This Week', MOW_TEXT_DOMAIN ),
                    'last_week' 	=> esc_html__( 'Last Week', MOW_TEXT_DOMAIN ),
                    'this_month' 	=> esc_html__( 'This Month', MOW_TEXT_DOMAIN ),
                    'last_month' 	=> esc_html__( 'Last Month', MOW_TEXT_DOMAIN ),
                    'this_year' 	=> esc_html__( 'This Year', MOW_TEXT_DOMAIN ),
                    'last_year' 	=> esc_html__( 'Last Year', MOW_TEXT_DOMAIN ),
                    'last_7d' 		=> esc_html__( 'Last 7 Days', MOW_TEXT_DOMAIN ),
                    'last_30d' 		=> esc_html__( 'Last 30 Days', MOW_TEXT_DOMAIN ),
                    'last_60d' 		=> esc_html__( 'Last 60 Days', MOW_TEXT_DOMAIN ),
                    'last_90d' 		=> esc_html__( 'Last 90 Days', MOW_TEXT_DOMAIN ),
                    'last_365d' 	=> esc_html__( 'Last 365 Days', MOW_TEXT_DOMAIN ),
                ],
                'default' => 'this_month',
				'label_block'	=> true,
				'condition' => [
					'bpod_type' => 'range',
				]
            ]
        );
		
		/* Period */
		$repeater->add_control(
			'bpod_from',
			[
				'label' => esc_html__( 'From', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
				'picker_options' => [
					'enableTime' => false
				],
				'condition' => [
					'bpod_type' => 'period',
				]
			]
		);
		$repeater->add_control(
			'bpod_to',
			[
				'label' => esc_html__( 'To', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
				'picker_options' => [
					'enableTime' => false
				],
				'condition' => [
					'bpod_type' => 'period',
				]
			]
		);
		
		/* Last */
		$repeater->add_control(
            'bpod_last_count',
            [
                'label' 	=> esc_html__( 'Count', MOW_TEXT_DOMAIN ),
                'type' 		=> Controls_Manager::NUMBER,
                'default' 	=> 1,
				'min'		=> 1,
				'condition' => [
					'bpod_type' => 'last',
				]
            ]
        );
		
		$repeater->add_control(
            'bpod_last_type',
            [
                'label' => esc_html__( 'Type', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'days' 			=> esc_html__( 'Days', MOW_TEXT_DOMAIN ),
                    'weeks' 		=> esc_html__( 'Weeks', MOW_TEXT_DOMAIN ),
                    'months' 		=> esc_html__( 'Months', MOW_TEXT_DOMAIN ),
                    'years' 		=> esc_html__( 'Years', MOW_TEXT_DOMAIN ),
                ],
                'default' 		=> 'days',
				'label_block'	=> true,
				'condition' => [
					'bpod_type' => 'last',
				]
            ]
        );
		
		/* Before */
		$repeater->add_control(
			'bpod_before',
			[
				'label' => esc_html__( 'Select Date', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
				'picker_options' => [
					'enableTime' => false
				],
				'condition' => [
					'bpod_type' => 'before',
				]
			]
		);
		
		/* After */
		$repeater->add_control(
			'bpod_after',
			[
				'label' => esc_html__( 'Select Date', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
				'picker_options' => [
					'enableTime' => false
				],
				'condition' => [
					'bpod_type' => 'after',
				]
			]
		);
		
		/* Date */
		$repeater->add_control(
			'bpod_date',
			[
				'label' => esc_html__( 'Select Date', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
				'picker_options' => [
					'enableTime' => false
				],
				'condition' => [
					'bpod_type' => 'date',
				]
			]
		);
		
		/* Year */
		$repeater->add_control(
			'bpod_year',
			[
				'label' 	=> esc_html__( 'Year', MOW_TEXT_DOMAIN ),
                'type' 		=> Controls_Manager::NUMBER,
                'default' 	=> date( 'Y' ),
				'min'		=> 0,
				'max'		=> 3000,
				'condition' => [
					'bpod_type' => 'year',
				]
			]
		);
		
		/* Month */
		$repeater->add_control(
			'bpod_month',
			[
				'label'			=> esc_html__( 'Month', MOW_TEXT_DOMAIN ),
                'type' 			=> Controls_Manager::SELECT2,
			 	'multiple'	 	=> true,
                'options' => [
                    1 		=> esc_html__( 'January', MOW_TEXT_DOMAIN ),
                    2 		=> esc_html__( 'February', MOW_TEXT_DOMAIN ),
                    3 		=> esc_html__( 'March', MOW_TEXT_DOMAIN ),
                    4 		=> esc_html__( 'April', MOW_TEXT_DOMAIN ),
                    5 		=> esc_html__( 'May', MOW_TEXT_DOMAIN ),
                    6 		=> esc_html__( 'June', MOW_TEXT_DOMAIN ),
                    7 		=> esc_html__( 'July', MOW_TEXT_DOMAIN ),
                    8 		=> esc_html__( 'August', MOW_TEXT_DOMAIN ),
                    9 		=> esc_html__( 'September', MOW_TEXT_DOMAIN ),
                    10 		=> esc_html__( 'October', MOW_TEXT_DOMAIN ),
                    11 		=> esc_html__( 'November', MOW_TEXT_DOMAIN ),
                    12 		=> esc_html__( 'December', MOW_TEXT_DOMAIN ),
                ],
				'condition' => [
					'bpod_type' => 'month',
				]
			]
		);
		
		/* Day */
		$repeater->add_control(
			'bpod_day',
			[
				'label' => esc_html__( 'Day', MOW_TEXT_DOMAIN ),
                'type' 		=> Controls_Manager::NUMBER,
                'default' 	=> date( 'd' ),
				'min'		=> 0,
				'max'		=> 31,
				'condition' => [
					'bpod_type' => 'day',
				]
			]
		);
		
		/* Week */
		$repeater->add_control(
			'bpod_week',
			[
				'label' => esc_html__( 'Week', MOW_TEXT_DOMAIN ),
                'type' 		=> Controls_Manager::NUMBER,
                'default' 	=> date( 'w' ),
				'min'		=> 0,
				'max'		=> 53,
				'condition' => [
					'bpod_type' => 'week',
				]
			]
		);
		
		/* Days of the week */
		$repeater->add_control(
			'bpod_week_days',
			[
				'label'	 		=> esc_html__( 'Days of the week', MOW_TEXT_DOMAIN ),
                'type' 			=> Controls_Manager::SELECT2,
			 	'multiple'	 	=> true,
                'options' => [
                    2 		=> esc_html__( 'Monday', MOW_TEXT_DOMAIN ),
                    3 		=> esc_html__( 'Tuesday', MOW_TEXT_DOMAIN ),
                    4 		=> esc_html__( 'Wednesday', MOW_TEXT_DOMAIN ),
                    5 		=> esc_html__( 'Thursday', MOW_TEXT_DOMAIN ),
                    6 		=> esc_html__( 'Friday', MOW_TEXT_DOMAIN ),
                    7 		=> esc_html__( 'Saturday', MOW_TEXT_DOMAIN ),
                    1 		=> esc_html__( 'Sunday', MOW_TEXT_DOMAIN ),
                ],
				'condition' => [
					'bpod_type' => 'week_days',
				]
			]
		);
		
		
		$this->add_control(
			'bpod_list',
			[
				'label' => __( 'Date Conditions', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ bpod_type }}}',
				'condition' => [
					'bpo_date__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'bpo_time_query',
			[
				'label' => esc_html__( 'Time Query', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'bpo_time__switcher',
			[
				'label' => esc_html__( 'Apply Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		
		$this->add_control(
			'bpot_from',
			[
				'label' => esc_html__( 'From', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => $timeOptions,
				'default' => 480,
				'condition' => [
					'bpo_time__switcher' => 'yes',
				]
			]
		);
		
		$this->add_control(
			'bpot_to',
			[
				'label' => esc_html__( 'To', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => $timeOptions,
				'default' => 1020,
				'condition' => [
					'bpo_time__switcher' => 'yes',
				]
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'hlight_section',
			[
				'label' => __( 'Highlight Text', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'hlight_switcher',
			[
				'label' => esc_html__( 'Highlight Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
		
		
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'hlight_text',
			[
				'label' => esc_html__( 'Text', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);
		
		
		$this->add_control(
			'hlight_list',
			[
				'label' => __( 'Highlight List', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ hlight_text }}}',
				'condition' => [
					'hlight_switcher' => 'yes',
				]
			]
		);

		$this->add_control(
            'hlight_type',
            [
                'label' => esc_html__( 'Type', MOW_TEXT_DOMAIN ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'inline' 		=> esc_html__( 'Inline', MOW_TEXT_DOMAIN ),
                    'separated' 	=> esc_html__( 'Separated', MOW_TEXT_DOMAIN ),
                ],
                'default' 		=> 'inline',
				'label_block'	=> true,
				'condition' => [
					'hlight_switcher' => 'yes',
				]
            ]
        );

		$this->add_control(
			'hlight_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'hlight_switcher' => 'yes',
				]
			]
		);

		$this->add_control(
			'hlight_custom_color_bg',
			[
				'label' => esc_html__( 'Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__w_posts[data-hlight-color="yes"] .fn__hlight_text' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'hlight_switcher' => 'yes',
					'hlight_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'hlight_custom_color_text',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__w_posts[data-hlight-color="yes"] .fn__hlight_text' => 'color: {{VALUE}}',
				],
				'condition' => [
					'hlight_switcher' => 'yes',
					'hlight_custom_color' => 'yes',
				]
			]
		);
		
		$this->end_controls_section();

		
		
		$this->start_controls_section(
			'features_section',
			[
				'label' => __( 'Options', MOW_TEXT_DOMAIN ),
			]
		);

		

		$this->add_control(
			'alpha_border',
			[
				'label' 		=> __( 'Border', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'disabled',
				'options' 		=> [
					'enabled'  		=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disabled'  	=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'alpha',
				]
			]
		);

		

		$this->add_control(
			'alpha_layout',
			[
				'label' 		=> __( 'Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'classic',
				'options' 		=> [
					'classic'  		=> __( 'Classic', MOW_TEXT_DOMAIN ),
					'zigzag'  		=> __( 'Zigzag', MOW_TEXT_DOMAIN ),
					'column'  		=> __( 'Column', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'alpha',
				]
			]
		);

		$this->add_control(
			'alpha_img_pos',
			[
				'label' 		=> __( 'Image Position', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'left',
				'options' 		=> [
					'left'  		=> __( 'Left', MOW_TEXT_DOMAIN ),
					'right'  		=> __( 'Right', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'alpha',
					'alpha_layout!' 	=> 'zigzag',
				]
			]
		);

		$this->add_control(
			'alpha_text_pos',
			[
				'label' 		=> __( 'Text Position', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'left',
				'options' 		=> [
					'left'  		=> __( 'Left', MOW_TEXT_DOMAIN ),
					'center'  		=> __( 'Center', MOW_TEXT_DOMAIN ),
					'right'  		=> __( 'Right', MOW_TEXT_DOMAIN ),
					'to_img'  		=> __( 'To Image', MOW_TEXT_DOMAIN ),
					'against_img'  	=> __( 'Against Image', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'alpha',
				]
			]
		);

		$this->add_control(
			'alpha_border_radius',
			[
				'label' => esc_html__( 'Border Radius', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 5,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_alpha .item_img, {{WRAPPER}} .fn__widget_posts_alpha .item_space' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'layout' => 'alpha',
				]
			]
		);

		$this->add_control(
			'video_autoplay',
			[
				'label' 		=> __( 'Video Autoplay', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'default',
				'options' 		=> [
					'default'  			=> __( 'Default (from theme options)', MOW_TEXT_DOMAIN ),
					'enable'  			=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disable'  			=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'icon_size',
			[
				'label' 		=> __( 'Gallery/Video/Rating Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'd',
				'options' 		=> [
					'd'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					'n'  			=> __( 'Normal', MOW_TEXT_DOMAIN ),
					's'  			=> __( 'Small', MOW_TEXT_DOMAIN ),
					'xs'  			=> __( 'Extra Small', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> ['gcarousel','delta'],
				]
			]
		);

		$this->add_control(
			'gamma_layout',
			[
				'label' 		=> __( 'Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'row',
				'options' 		=> [
					'row'  			=> __( 'Row', MOW_TEXT_DOMAIN ),
					'column'  		=> __( 'Column', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'gamma',
				]
			]
		);

		$this->add_control(
			'gamma_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'gamma',
				]
			]
		);

		$this->add_control(
			'gamma_title_color',
			[
				'label' => esc_html__( 'Title Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_gamma[data-color="yes"] .post_title a' => 'color: {{VALUE}}',
				],
				'condition' => [
					'gamma_custom_color' => 'yes',
					'layout' => 'gamma',
				]
			]
		);

		$this->add_control(
			'gamma_count_bg_color',
			[
				'label' => esc_html__( 'Count Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_gamma[data-color="yes"] .count_holder span' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'gamma_custom_color' => 'yes',
					'layout' => 'gamma',
				]
			]
		);

		$this->add_control(
			'gamma_count_text_color',
			[
				'label' => esc_html__( 'Count Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_gamma[data-color="yes"] .count_holder span' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'gamma',
				]
			]
		);

		
		
		$this->add_control(
			'delta_layout',
			[
				'label' 		=> __( 'Delta Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'row',
				'options' 		=> [
					'column'  		=> __( 'Column', MOW_TEXT_DOMAIN ),
					'col_grid'  	=> __( 'Column Grid', MOW_TEXT_DOMAIN ),
					'row'  			=> __( 'Row', MOW_TEXT_DOMAIN ),
					'row_r'  		=> __( 'Row Reverse', MOW_TEXT_DOMAIN ),
					'inline'  		=> __( 'Inline', MOW_TEXT_DOMAIN ),
					'inline_mini'  	=> __( 'Inline Mini', MOW_TEXT_DOMAIN ),
					'inline_max'  	=> __( 'Inline Max', MOW_TEXT_DOMAIN ),
					'inline_reverse'=> __( 'Inline Reverse ', MOW_TEXT_DOMAIN ),
					'no_image' 		=> __( 'No Image', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'delta',
				]
			]
		);

		$this->add_control(
			'delta_inline_max_img_pos',
			[
				'label' 		=> __( 'Image Position', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'left',
				'options' 		=> [
					'left'  		=> __( 'Left', MOW_TEXT_DOMAIN ),
					'right'  		=> __( 'Right', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'delta',
					'delta_layout' 	=> 'inline_max',
				]
			]
		);

		$this->add_control(
			'delta_inline_max_text_pos',
			[
				'label' 		=> __( 'Text Horizontal Position', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'left',
				'options' 		=> [
					'left'  		=> __( 'Left', MOW_TEXT_DOMAIN ),
					'center'  		=> __( 'Center', MOW_TEXT_DOMAIN ),
					'right'  		=> __( 'Right', MOW_TEXT_DOMAIN ),
					'to_img'  		=> __( 'To Image', MOW_TEXT_DOMAIN ),
					'against_img'  	=> __( 'Against Image', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'delta',
					'delta_layout' 	=> 'inline_max',
				]
			]
		);

		$this->add_control(
			'delta_inline_max_text_vpos',
			[
				'label' 		=> __( 'Text Vertical Position', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'top',
				'options' 		=> [
					'top'  		=> __( 'Top', MOW_TEXT_DOMAIN ),
					'middle'  		=> __( 'Middle', MOW_TEXT_DOMAIN ),
					'bottom'  		=> __( 'Bottom', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'delta',
					'delta_layout' 	=> 'inline_max',
				]
			]
		);
		
		$this->add_control(
			'delta_col_count',
			[
				'label' 		=> __( 'Column Count', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'auto',
				'options' 		=> [
					'col_2'  		=> __( '2 Cols', MOW_TEXT_DOMAIN ),
					'col_3'  		=> __( '3 Cols', MOW_TEXT_DOMAIN ),
					'col_4'  		=> __( '4 Cols', MOW_TEXT_DOMAIN ),
					'auto'  		=> __( 'Auto Cols', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'delta',
					'delta_layout' => 'column',
				]
			]
		);

		$this->add_control(
			'delta_inline_col_count',
			[
				'label' 		=> __( 'Cols', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'col_1',
				'options' 		=> [
					'col_1'  		=> __( '1 Col', MOW_TEXT_DOMAIN ),
					'col_2'  		=> __( '2 Cols', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'delta',
					'delta_layout' => ['inline','inline_mini'],
				]
			]
		);

		$this->add_control(
			'delta_inline_border',
			[
				'label' 		=> __( 'Border', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'disabled',
				'options' 		=> [
					'enabled'  		=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disabled'  	=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'delta',
					'delta_layout' => ['inline','inline_mini'],
				]
			]
		);

		$this->add_control(
			'delta_row_border',
			[
				'label' 		=> __( 'Border', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'disabled',
				'options' 		=> [
					'enabled'  		=> __( 'Enabled', MOW_TEXT_DOMAIN ),
					'disabled'  	=> __( 'Disabled', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'delta',
					'delta_layout' => 'row',
				]
			]
		);

		$this->add_responsive_control(
			'delta_img_ratio',
			[
				'label' => esc_html__( 'Image Ratio', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0.1,
						'max' => 5,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta .item_space,{{WRAPPER}} .fn__widget_posts_delta .item_img img,{{WRAPPER}} .fn__video_post .item_space,{{WRAPPER}} .fn__video_post .blog__image img,{{WRAPPER}} .fn__video_post[data-video="youtube"]' => 'aspect-ratio: {{SIZE}};',
				],
				'condition' => [
					'layout' => 'delta',
				]
			]
		);

		$this->add_control(
			'delta_img_size',
			[
				'label' 		=> __( 'Image Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'large',
				'options' 		=> [
					'thumbnail'		=> __( 'Thumbnail', MOW_TEXT_DOMAIN ),
					'medium'  		=> __( 'Medium', MOW_TEXT_DOMAIN ),
					'large'  		=> __( 'Large', MOW_TEXT_DOMAIN ),
					'full'  		=> __( 'Full', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'delta',
				]
			]
		);

		

		$this->add_control(
			'delta_title_size',
			[
				'label' 		=> __( 'Title Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'm',
				'options' 		=> [
					'm'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					'l'  			=> __( 'Large', MOW_TEXT_DOMAIN ),
					'c'  			=> __( 'Custom', MOW_TEXT_DOMAIN ),
					// 'xl'  			=> __( 'Extra Large', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'delta',
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'delta_title_typography',
				'selector' => '{{WRAPPER}} .fn__widget_posts_delta[data-title-size="c"] .post_title',
				'condition' => [
					'layout' => 'delta',
					'delta_title_size' => 'c',
				]
			]
		);

		$this->add_control(
			'zeta_layout',
			[
				'label' 		=> __( 'Zeta Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'row',
				'options' 		=> [
					'column'  		=> __( 'Column', MOW_TEXT_DOMAIN ),
					'row'  			=> __( 'Row', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'zeta',
				]
			]
		);

		$this->add_control(
			'zeta_title_size',
			[
				'label' 		=> __( 'Title Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'm',
				'options' 		=> [
					'm'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					'l'  			=> __( 'Large', MOW_TEXT_DOMAIN ),
					// 'xl'  			=> __( 'Extra Large', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'zeta',
				]
			]
		);

		$this->add_control(
			'zeta_marker',
			[
				'label' => esc_html__( 'Triangle Marker', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'zeta',
				]
			]
		);

		$this->add_control(
			'zeta_marker_color',
			[
				'label' => esc_html__( 'Marker Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_zeta[data-marker="yes"] .zeta__item:after' => 'border-left-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'zeta',
					'zeta_marker' => 'yes',
				]
			]
		);
		$this->add_control(
			'zeta_marker_top',
			[
				'label' => esc_html__( 'Marker Top Spacing', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_zeta[data-marker="yes"] .zeta__item:after' => 'top: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'layout' => 'zeta',
					'zeta_marker' => 'yes',
				]
			]
		);

		$this->add_control(
			'delta_pagination_filter',
			[
				'label' => esc_html__( 'Pagination Filter', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'No', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => ['delta', 'date_1', 'zeta'],
				]
			]
		);
		$this->add_control(
			'delta_pagination_pp',
			[
				'label' => __( 'Per Page', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 8,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 9999,
						'step' => 1,
					]
				],
				'condition' => [
					'delta_pagination_filter' => 'yes',
					'layout' => ['delta', 'date_1', 'zeta']
				]
			]
		);

		$this->add_control(
			'load_more_text',
			[
				'label' => esc_html__( 'Load More Text', MOW_TEXT_DOMAIN ),
				'default' => esc_html__( 'Load More Articles', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'delta_pagination_filter' => 'yes',
					'layout' => ['delta', 'date_1', 'zeta']
				]
			]
		);

		$this->add_control(
			'epsilon_img_size',
			[
				'label' 		=> __( 'Image Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'large',
				'options' 		=> [
					'thumbnail'		=> __( 'Thumbnail', MOW_TEXT_DOMAIN ),
					'medium'  		=> __( 'Medium', MOW_TEXT_DOMAIN ),
					'large'  		=> __( 'Large', MOW_TEXT_DOMAIN ),
					'full'  		=> __( 'Full', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' 	=> 'epsilon',
				]
			]
		);

		$this->add_control(
			'epsilon_title_size',
			[
				'label' 		=> __( 'Title Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'm',
				'options' 		=> [
					'm'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					'l'  			=> __( 'Large', MOW_TEXT_DOMAIN ),
					// 'xl'  			=> __( 'Extra Large', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'epsilon',
				]
			]
		);
		

		$this->add_responsive_control(
			'epsilon_img_ratio',
			[
				'label' => esc_html__( 'Image Ratio', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0.1,
						'max' => 5,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_epsilon .fn__video_post[data-video="local"] video, {{WRAPPER}} .fn__widget_posts_epsilon .item_space,{{WRAPPER}} .fn__widget_posts_epsilon .item_img img,{{WRAPPER}} .fn__video_post .item_space,{{WRAPPER}} .fn__video_post .blog__image img,{{WRAPPER}} .fn__video_post[data-video="youtube"]' => 'aspect-ratio: {{SIZE}} !important;',
				],
				'condition' => [
					'layout' => 'epsilon',
				]
			]
		);

		
		$this->add_control(
			'fslider_border_radius',
			[
				'label' => esc_html__( 'Border Radius', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_fslider .fslider__item' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'layout' => 'fslider',
				]
			]
		);

		$this->add_control(
			'show_container',
			[
				'label' => esc_html__( 'Container Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => ['delta','fslider'],
				]
			]
		);


		$this->add_control(
			'custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'fcarousel',
				]
			]
		);

		$this->add_control(
			'fcarousel_title_color',
			[
				'label' => esc_html__( 'Title Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_fcarousel .post_title a:not(:hover),{{WRAPPER}} .fn__meta p,{{WRAPPER}} .fn__meta a:not(:hover)' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn__meta .meta_sep,{{WRAPPER}} .fn__meta .meta_sep:after,{{WRAPPER}} .fn__meta .meta_sep:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'fcarousel',
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'fcarousel_title_h_color',
			[
				'label' => esc_html__( 'Title Hover Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_fcarousel .post_title a:hover,{{WRAPPER}} .fn__meta a:hover' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'fcarousel',
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'fcarousel_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_fcarousel .fn__descr' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'fcarousel',
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'alpha_title_size',
			[
				'label' 		=> __( 'Title Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'm',
				'options' 		=> [
					'm'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					'c'  			=> __( 'Custom', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'alpha',
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'alpha_title_typography',
				'selector' => '{{WRAPPER}} .fn__widget_posts_alpha[data-title-size="c"] .post_title',
				'condition' => [
					'layout' => 'alpha',
					'alpha_title_size' => 'c',
				]
			]
		);


		$this->add_control(
			'alpha_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'alpha',
				]
			]
		);

		$this->add_control(
			'alpha_title_color',
			[
				'label' => esc_html__( 'Title Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .post_title a' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'alpha',
					'alpha_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'alpha_meta_color',
			[
				'label' => esc_html__( 'Meta Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .fn__meta p,{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .fn__meta a' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .fn__meta .meta_sep,{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .fn__meta .meta_sep:after,{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .fn__meta .meta_sep:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'alpha',
					'alpha_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'alpha_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"] .fn__descr' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'alpha',
					'alpha_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'alpha_border_color',
			[
				'label' => esc_html__( 'Border Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_alpha[data-color="yes"][data-border="enabled"] li:not(:last-child)' => 'border-bottom-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'alpha',
					'alpha_custom_color' => 'yes',
				]
			]
		);


		$this->add_control(
			'delta_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'delta',
				]
			]
		);

		$this->add_control(
			'delta_title_color',
			[
				'label' => esc_html__( 'Title Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .post_title a' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'delta',
					'delta_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'delta_meta_color',
			[
				'label' => esc_html__( 'Meta Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .fn__meta p,{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .fn__meta a' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .fn__meta .meta_sep,{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .fn__meta .meta_sep:after,{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .fn__meta .meta_sep:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'delta',
					'delta_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'delta_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-color="yes"] .fn__descr' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'delta',
					'delta_custom_color' => 'yes',
				]
			]
		);


		$this->add_control(
			'gcarousel_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);

		$this->add_control(
			'gcarousel_title_color',
			[
				'label' => esc_html__( 'Title Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .post_title a,{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .fn__meta p,{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .fn__meta a' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .fn__meta .meta_sep,{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .fn__meta .meta_sep:after,{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .fn__meta .meta_sep:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'gcarousel',
					'gcarousel_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'gcarousel_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_gcarousel[data-color="yes"] .fn__descr' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'gcarousel',
					'gcarousel_custom_color' => 'yes',
				]
			]
		);


		$this->add_control(
			'cslider_blind_mode',
			[
				'label' => esc_html__( 'Blind Mode', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'cslider',
				]
			]
		);

		$this->add_control(
			'cslider_custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'cslider',
				]
			]
		);

		$this->add_control(
			'cslider_bg_color',
			[
				'label' => esc_html__( 'Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_cslider[data-blind-mode="yes"][data-color="yes"] .circle_holder,{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .title_holder:after' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .fn__widget_posts_cslider .title_holder' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'cslider',
					'cslider_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'cslider_title_color',
			[
				'label' => esc_html__( 'Title Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__meta .meta_item,{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .post_title a,{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__meta p,{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__meta a' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__meta .meta_sep,{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__meta .meta_sep:after,{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__meta .meta_sep:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'cslider',
					'cslider_custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'cslider_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_cslider[data-color="yes"] .fn__descr' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'cslider',
					'cslider_custom_color' => 'yes',
				]
			]
		);

		$this->add_responsive_control(
			'gcarousel_img_ratio',
			[
				'label' => esc_html__( 'Image Ratio', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0.1,
						'max' => 5,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0.75,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_gcarousel .item_img img,{{WRAPPER}} .fn__widget_posts_gcarousel .item_space' => 'aspect-ratio: {{SIZE}};',
				],
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);

		$this->add_control(
			'gcarousel_autoplay_slider',
			[
				'label' 		=> __( 'Autoplay Slider', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'enable',
				'options' 		=> [
					'enable'  		=> __( 'Enable', MOW_TEXT_DOMAIN ),
					'disable'  		=> __( 'Disable', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);

		$this->add_control(
			'gcarousel_perview',
			[
				'label' 		=> __( 'Columns Count', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'col_4',
				'options' 		=> [
					'col_2'  		=> __( '2 Cols', MOW_TEXT_DOMAIN ),
					'col_3'  		=> __( '3 Cols', MOW_TEXT_DOMAIN ),
					'col_4'  		=> __( '4 Cols', MOW_TEXT_DOMAIN ),
					'col_5'  		=> __( '5 Cols', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);
		$this->add_control(
			'gcarousel_navsize',
			[
				'label' 		=> __( 'Navigation Size', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'd',
				'options' 		=> [
					'd'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					's'  			=> __( 'Small', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);

		$this->add_control(
			'gcarousel_title_typog',
			[
				'label' => esc_html__( 'Custom Title Typography', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'gcarousel_title_typography',
				'selector' => '{{WRAPPER}} .fn__widget_posts_gcarousel[data-title-typography="yes"] .post_title',
				'condition' => [
					'layout' => 'gcarousel',
					'gcarousel_title_typog' => 'yes',
				]
			]
		);

		$this->add_control(
			'gcarousel_text_align',
			[
				'label' => esc_html__( 'Alignment', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', MOW_TEXT_DOMAIN ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', MOW_TEXT_DOMAIN ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', MOW_TEXT_DOMAIN ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'left',
				'toggle' => true,
				'condition' => [
					'layout' => 'gcarousel',
				]
			]
		);

		$this->add_control(
			'read_more_custom_color',
			[
				'label' 		=> __( 'Read More Skin', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'default',
				'options' 		=> [
					'default'  			=> __( 'Default', MOW_TEXT_DOMAIN ),
					'light'  			=> __( 'Light', MOW_TEXT_DOMAIN ),
					// 'dark'  			=> __( 'Dark', MOW_TEXT_DOMAIN ),
					'main_color'  		=> __( 'Main Color', MOW_TEXT_DOMAIN ),
					'custom'  			=> __( 'Custom Color', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'read_more_custom_color_bg',
			[
				'label' => esc_html__( 'Read More Background Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__w_posts[data-readmore-color="custom"] .fn__read_more .text' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .fn__w_posts[data-readmore-color="custom"] .fn__read_more .text:before' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'read_more_custom_color' => 'custom',
				]
			]
		);

		$this->add_control(
			'read_more_custom_color_text',
			[
				'label' => esc_html__( 'Read More Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__w_posts[data-readmore-color="custom"] .fn__read_more .text,{{WRAPPER}} .fn__w_posts[data-readmore-color="main_color"] .fn__read_more a:hover .text' => 'color: {{VALUE}}',
				],
				'condition' => [
					'read_more_custom_color' => 'custom',
				]
			]
		);

		$this->add_control(
			'delta_custom_spacing',
			[
				'label' => esc_html__( 'Custom Spacing', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'delta',
				]
			]
		);

		$this->add_control(
			'delta_img_spacing',
			[
				'label' => esc_html__( 'Image Bottom Spacing', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-spacing="yes"] .img_holder' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'delta_custom_spacing' => 'yes',
				]
			]
		);

		$this->add_control(
			'delta_meta_spacing',
			[
				'label' => esc_html__( 'Meta Bottom Spacing', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-spacing="yes"] .fn__meta' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'delta_custom_spacing' => 'yes',
				]
			]
		);

		$this->add_control(
			'delta_title_spacing',
			[
				'label' => esc_html__( 'Title Bottom Spacing', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-spacing="yes"] .post_title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'delta_custom_spacing' => 'yes',
				]
			]
		);

		$this->add_control(
			'delta_desc_spacing',
			[
				'label' => esc_html__( 'Description Bottom Spacing', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .fn__widget_posts_delta[data-spacing="yes"] .fn__descr' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'delta_custom_spacing' => 'yes',
				]
			]
		);
		
		
		$this->end_controls_section();
		
		
	}


	protected function render() {
		$taxonomy			= 'category';
		$settings 			= $this->get_settings();
		$layout				= $settings['layout'];
		
		// Post Number
		$post_number 	= $settings['blog_post_number']['size'];

		$query_args = array(
			'post_type' 			=> "post",
			'post_status' 			=> "publish",
			'ignore_sticky_posts' 	=> true,
		);

		
		global $mow_fn_option;
		// since v1.1.1
		// 13 may 2023
		$seo_bloglist_title = 'h3';
		if(isset($mow_fn_option['seo_bloglist_title'])){
			$seo_bloglist_title = $mow_fn_option['seo_bloglist_title'];
		}


		// Filter Parameters
		$filter_parameters = $settings['bpo_formats__switcher'] == 'yes' && !empty($settings['bpo_formats_options']) && !in_array('all', $settings['bpo_formats_options']);
		if($filter_parameters){
			$query_args['tax_query'] =  array(
				'taxonomy' => 'post_format',
				'field'    => 'slug',
				'terms'    => $settings['bpo_formats_options'],
			);
		}


		// Post Parameters
		$post_filter	= $settings['bpo_posts__switcher'];
		if($post_filter == 'yes'){
			$blog_post_include__id = $settings['blog_post_include__id'];
			$blog_post_include__id = preg_replace('/[^0-9,]+/', '', $blog_post_include__id);
			$arr = explode (",", $blog_post_include__id);
			$arr = array_filter($arr, 'strlen');
			if(!empty($arr)){
				$query_args['post__in'] = $arr;
			}
			
			$blog_post_exclude__id = $settings['blog_post_exclude__id'];
			$blog_post_exclude__id = preg_replace('/[^0-9,]+/', '', $blog_post_exclude__id);
			$arr2 = explode (",", $blog_post_exclude__id);
			$arr2 = array_filter($arr2, 'strlen');
			if(!empty($arr2)){
				$query_args['post__not_in'] = $arr2;
			}
		}

		// Category Paramters
		$category_filter = $settings['bpo_categories__switcher'];
		if($category_filter == 'yes'){
			$blog_post_in_categories__id = $settings['blog_post_in_categories__id'];
			$blog_post_in_categories__id = preg_replace('/[^0-9,]+/', '', $blog_post_in_categories__id);
			$arr3 = explode (",", $blog_post_in_categories__id);
			$arr3 = array_filter($arr3, 'strlen');
			if(!empty($arr3)){
				$cf_include = array();
				foreach($arr3 as $term_id){
					if(isset(get_term( $term_id, $taxonomy )->slug)){
						$cf_include[] = get_term( $term_id, $taxonomy )->slug;
					}
				}
			}
			
			$blog_post_ex_categories__id = $settings['blog_post_ex_categories__id'];
			$blog_post_ex_categories__id = preg_replace('/[^0-9,]+/', '', $blog_post_ex_categories__id);
			$arr4 = explode (",", $blog_post_ex_categories__id);
			$arr4 = array_filter($arr4, 'strlen');
			if(!empty($arr4)){
				$cf_exclude = array();
				foreach($arr4 as $term_id){
					if(isset(get_term( $term_id, $taxonomy )->slug)){
						$cf_exclude[] = get_term( $term_id, $taxonomy )->slug;
					}
				}
			}

			if ( ! empty ( $cf_exclude ) ) {

				if($filter_parameters){
					$query_args['tax_query']['relation'] = 'AND';
					$query_args['tax_query'][] = array(
						array(
							'taxonomy'	=> 'category', 
							'field'	 	=> 'slug',
							'terms'		=> $cf_exclude,
							'operator'	=> 'NOT IN'
						)
					);
				}else{
					$query_args['tax_query'] = array(
						array(
							'taxonomy'	=> 'category', 
							'field'	 	=> 'slug',
							'terms'		=> $cf_exclude,
							'operator'	=> 'NOT IN'
						)
					);
				}

				

				if ( ! empty ( $cf_include ) ) {
					$query_args['tax_query']['relation'] = 'AND';
					$query_args['tax_query'][] = array(
						'taxonomy'	=> 'category',
						'field'		=> 'slug',
						'terms'		=> $cf_include,
						'operator'	=> 'IN'
					);
				}
			} else {
				if ( ! empty ( $cf_include ) ) {
					if($filter_parameters){
						$query_args['tax_query']['relation'] = 'AND';
						$query_args['tax_query'][] = array(
							array(
								'taxonomy' 	=> 'category',
								'field' 	=> 'slug',
								'terms' 	=> $cf_include,
								'operator'	=> 'IN'
							)
						);
					}else{
						$query_args['tax_query'] = array(
							array(
								'taxonomy' 	=> 'category',
								'field' 	=> 'slug',
								'terms' 	=> $cf_include,
								'operator'	=> 'IN'
							)
						);
					}
				}
			}
			
		}

		// Author Parameters
		$author_filter	= $settings['bpo_author__switcher'];
		if($author_filter == 'yes'){
			$query_args['author__in'] = $settings['blog_post_in_author'];
			$query_args['author__not_in'] = $settings['blog_post_ex_author'];
		}

		// Tag Parameters
		$tag_filter	= $settings['bpo_tag__switcher'];
		if($tag_filter == 'yes'){
			$blog_post_in_tag__id = $settings['blog_post_in_tag__id'];
			$blog_post_in_tag__id = preg_replace('/[^0-9,]+/', '', $blog_post_in_tag__id);
			$arr5 = explode (",", $blog_post_in_tag__id);
			$arr5 = array_filter($arr5, 'strlen');
			if(!empty($arr5)){
				$query_args['tag__in'] = $arr5;
			}
			
			$blog_post_ex_tag__id = $settings['blog_post_ex_tag__id'];
			$blog_post_ex_tag__id = preg_replace('/[^0-9,]+/', '', $blog_post_ex_tag__id);
			$arr6 = explode (",", $blog_post_ex_tag__id);
			$arr6 = array_filter($arr6, 'strlen');
			if(!empty($arr6)){
				$query_args['tag__not_in'] = $arr6;
			}
		}

		// Search Parameters
		$search_filter	= $settings['bpo_search__switcher'];
		if($search_filter == 'yes'){
			$sf_text = $settings['blog_post_search'];
			$query_args['s'] = esc_html($sf_text);
		}

		// Comment Parameters
		$comment_filter	= $settings['bpo_comment__switcher'];
		if($comment_filter == 'yes'){
			$cf_count = $settings['blog_post_comment_count'];
			$cf_compare = $settings['blog_post_comment_compare'];
			$query_args['comment_count'] = array('value' => (int)$cf_count, 'compare' => $cf_compare);
		}

		// Order Parameters
		$order_filter = $settings['bpo_order__switcher'];
		if($order_filter == 'yes'){
			$of_order = $settings['blog_post_order'];
			$of_orderby = $settings['blog_post_orderby'];
			if($of_orderby === 'select'){$of_orderby = '';}
			$query_args['order'] = $of_order;
			if($of_orderby == 'popular'){
				$query_args['orderby'] = 'meta_value_num';
				$query_args['meta_key'] = 'frenify_post_views_count';
			}else if($of_orderby =='rating'){
				$query_args['orderby'] = 'meta_value_num';
				$query_args['meta_key'] = '_fers_overall_rating';
			}else if($of_orderby =='total_votes'){
				$query_args['orderby'] = 'meta_value_num';
				$query_args['meta_key'] = '_mow_fn_vote_total';
			}else if($of_orderby =='vote_diff'){
				$query_args['orderby'] = 'meta_value_num';
				$query_args['meta_key'] = '_mow_fn_vote_diff';
			}else{
				$query_args['orderby'] = $of_orderby;
			}
		}

		$dateTimeArray = array();
		// Date Query
		$date_filter = $settings['bpo_date__switcher'];
		if($date_filter == 'yes' && !empty($settings['bpod_list'])){
			$date_filters = $settings['bpod_list'];

			foreach($date_filters as $filter){
				$type = $filter['bpod_type'];
				if($type == 'range'){
					$range = $filter['bpod_range'];
					if($range == 'today'){
						$today = getdate();
						$dateTimeArray[] = array(
							'year'  => $today['year'],
							'month' => $today['mon'],
							'day'   => $today['mday'],
						);
					}else if($range == 'yesterday'){
						$date = strtotime("-1 days");
						$dateTimeArray[] = array(
							'year'  => date('Y',$date),
							'month' => date('m',$date),
							'day'   => date('d',$date),
						);
					}else if($range == 'this_week'){
						$dateTimeArray[] = array(
							'year' => date( 'Y' ),
							'week' => date( 'W' ),
						);
					}else if($range == 'last_week'){
						$date = strtotime("last week");
						$dateTimeArray[] = array(
							'year' => date( 'Y', $date ),
							'week' => date( 'W', $date ),
						);
					}else if($range == 'this_month'){
						$dateTimeArray[] = array(
							'year' => date( 'Y' ),
							'month' => date( 'm' ),
						);
					}else if($range == 'last_month'){
						$date = strtotime("-1 month");
						$dateTimeArray[] = array(
							'year' => date( 'Y', $date ),
							'month' => date( 'm', $date ),
						);
					}else if($range == 'this_year'){
						$dateTimeArray[] = array(
							'year' => date( 'Y' )
						);
					}else if($range == 'last_year'){
						$dateTimeArray[] = array(
							'year' => date("Y", strtotime("-1 year"))
						);
					}else if($range == 'last_7d'){
						$date = strtotime("-7 days");
						$dateTimeArray[] = array(
							'after' => [
								'year' => date("Y", $date),
								'month' => date("m", $date),
								'day' => date("d", $date),
							]
						);
					}else if($range == 'last_30d'){
						$date = strtotime("-30 days");
						$dateTimeArray[] = array(
							'after' => [
								'year' => date("Y", $date),
								'month' => date("m", $date),
								'day' => date("d", $date),
							]
						);
					}else if($range == 'last_60d'){
						$date = strtotime("-60 days");
						$dateTimeArray[] = array(
							'after' => [
								'year' => date("Y", $date),
								'month' => date("m", $date),
								'day' => date("d", $date),
							]
						);
					}else if($range == 'last_90d'){
						$date = strtotime("-90 days");
						$dateTimeArray[] = array(
							'after' => [
								'year' => date("Y", $date),
								'month' => date("m", $date),
								'day' => date("d", $date),
							]
						);
					}else if($range == 'last_365d'){
						$date = strtotime("-365 days");
						$dateTimeArray[] = array(
							'after' => [
								'year' => date("Y", $date),
								'month' => date("m", $date),
								'day' => date("d", $date),
							]
						);
					}
				}else if($type == 'period'){
					$from = strtotime($filter['bpod_from']);
					$to = strtotime($filter['bpod_to']);
					if($to > $from){
						$dateTimeArray[] = array(
							'after' => [
								'year' => date("Y", $from),
								'month' => date("m", $from),
								'day' => date("d", $from),
							]
						);
						$dateTimeArray[] = array(
							'before' => [
								'year' => date("Y", $to),
								'month' => date("m", $to),
								'day' => date("d", $to),
							]
						);
					}
				}else if($type == 'last'){
					$last_count = $filter['bpod_last_count'];
					$last_type = $filter['bpod_last_type'];
					$date = strtotime("-".(int)$last_count." ".$last_type);
					$dateTimeArray[] = array(
						'after' => [
							'year' => date("Y", $date),
							'month' => date("m", $date),
							'day' => date("d", $date),
						]
					);
				}else if($type == 'before'){
					$date = strtotime($filter['bpod_before']);
					$dateTimeArray[] = array(
						'before' => [
							'year' => date("Y", $date),
							'month' => date("m", $date),
							'day' => date("d", $date),
						]
					);
				}else if($type == 'after'){
					$date = strtotime($filter['bpod_after']);
					$dateTimeArray[] = array(
						'after' => [
							'year' => date("Y", $date),
							'month' => date("m", $date),
							'day' => date("d", $date),
						]
					);
				}else if($type == 'date'){
					$date = strtotime($filter['bpod_date']);
					$dateTimeArray[] = array(
						'before' => [
							'year' => date("Y", $date),
							'month' => date("m", $date),
							'day' => date("d", $date),
						]
					);
				}else if($type == 'year'){
					$year = $filter['bpod_year'];
					if($year > 0){
						$dateTimeArray[] = array(
							'year' => $year,
						);
					}
				}else if($type == 'month'){
					$month = $filter['bpod_month'];
					if($month > 0){
						$dateTimeArray[] = array(
							'month' => $month,
						);
					}
				}else if($type == 'day'){
					$day = $filter['bpod_day'];
					if($day > 0){
						$dateTimeArray[] = array(
							'day' => $day,
						);
					}
				}else if($type == 'week'){
					$week = $filter['bpod_week'];
					if($week > 0){
						$dateTimeArray[] = array(
							'week' => $week,
						);
					}
				}else if($type == 'week_days'){
					$wdays = $filter['bpod_week_days'];
					$dateTimeArray[] = array(
						'dayofweek' => $wdays,
						'compare' => 'IN',
					);
				}
			}
		}



		// Time Query
		$time_filter = $settings['bpo_time__switcher'];
		if($time_filter == 'yes' && !empty($settings['bpot_list'])){

			$from 	= $settings['bpot_from'];
			$to 	= $settings['bpot_to'];
			$dateTimeArray[] = array(
				'hour' => intdiv($from , 60),
				'minute' => $from % 60,
				'compare' => '>='
			);
			$dateTimeArray[] = array(
				'hour' => intdiv($to , 60),
				'minute' => $to % 60,
				'second' => $to % 60,
				'compare' => '<='
			);
		}
		if(!empty($dateTimeArray)){
			$query_args['date_query'] = $dateTimeArray;
		}

		// !! Warning !! please use it at the end of wordpress query
		// Offset loop
		$post_offset 	= $settings['blog_post_offset'];
		if($post_offset > 0){
			$query_args['posts_per_page'] = (int)$post_offset;
			$offset_query = new \WP_Query($query_args);
			$post__not_in = array();

			if ($offset_query->have_posts()) : while ($offset_query->have_posts()) : $offset_query->the_post();
				$post__not_in[] = get_the_ID();
			endwhile; endif; wp_reset_postdata();
			if(isset($query_args['post__not_in'])){
				$query_args['post__not_in'] = array_merge($query_args['post__not_in'], $post__not_in); 
			}else{
				$query_args['post__not_in'] = $post__not_in;
			}
		}

		
		$query_args['posts_per_page'] = $post_number;
		$loop = new \WP_Query($query_args);
			
		/***********************************************************************************/
		/* RENDER STARTS */
		$html  = Frel_Helper::frel_open_wrap();
		$html .= '<div class="fn__w_posts" data-hlight-color="'.$settings['hlight_custom_color'].'" data-readmore-color="'.$settings['read_more_custom_color'].'">';


		$recent_posts = $settings['posts_recent_filter_switcher'];
		$filter_left_text = $settings['posts_filter_left_text'];
		$filter_right_text = $settings['posts_filter_right_text'];

		$meta_display = $settings['meta_display'];
		


		
		if($layout == 'alpha'){
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$html .= '<div class="fn__widget_posts_alpha" data-title-size="'.$settings['alpha_title_size'].'" data-color="'.$settings['alpha_custom_color'].'" data-layout="'.$settings['alpha_layout'].'" data-border="'.$settings['alpha_border'].'" data-img-pos="'.$settings['alpha_img_pos'].'" data-text-pos="'.$settings['alpha_text_pos'].'">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			// first list
			$html .= '<ul class="first_item alpha_items active">';
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
				$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
				$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
				$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
				$gallery_count = mow_fn_get_rating_number($post_id, 'xs');
				if($gallery_count == ''){
					$gallery_count = mow_fn_gallery_count($post_id,'s');
				}

				if($post_image != ''){
					$image_holder = '<div class="img_holder">'.$gallery_count.'<div class="item_img"><a href="'.$post_permalink.'"  aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'thumbnail', ['loading' => 'lazy']).'</a></div></div>';
				}else{
					$image_holder = '<div class="img_holder">'.$gallery_count.'<div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
				}

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';

				$html .= '<li class="alpha_item"><div class="alpha__item">'.$image_holder.$title_holder.'</div></li>';
				wp_reset_postdata();
			}
			$html .= '</ul>';

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$html .= '<ul class="second_item alpha_items">';
				foreach ( $loop->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
					$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
					$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
					$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
					$gallery_count = mow_fn_get_rating_number($post_id, 'xs');
					if($gallery_count == ''){
						$gallery_count = mow_fn_gallery_count($post_id,'s');
					}
	
					if($post_image != ''){
						$image_holder = '<div class="img_holder">'.$gallery_count.'<div class="item_img"><a href="'.$post_permalink.'"  aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'thumbnail', ['loading' => 'lazy']).'</a></div></div>';
					}else{
						$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'"></a>'.$gallery_count.'</div></div>';
					}
	
					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';
	
					$html .= '<li class="alpha_item"><div class="alpha__item">'.$image_holder.$title_holder.'</div></li>';
					wp_reset_postdata();
				}
				$html .= '</ul>';
			}

			$html .= '</div>';

			$html .= '</div>';
		}else if($layout == 'interactive'){
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$html .= '<div class="fn__widget_posts_interactive_wrapper">';
			$html .= '<div class="fn__widget_posts_interactive">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			$hlight_switcher = $settings['hlight_switcher'];
			if($hlight_switcher == 'yes'){
				$hlight_list = $settings['hlight_list'];
			}

			$hlight_type = '';
			if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
				$hlight_type = 'data-outside';
			}
			// first list
			$query_args['posts_per_page'] = 3;
			$loop = new \WP_Query($query_args);
			$html .= mow_fn_post__interactive($loop,$settings);

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => 3,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop2 = new \WP_Query( $query_args );
				$html .= mow_fn_post__interactive($loop,$settings,'second');
			}

			$html .= '</div></div>';
			$html .= '</div>';
		}else if($layout == 'beta'){
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$html .= '<div class="fn__widget_posts_beta">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			// first list
			$html .= '<ul class="first_item beta_items active">';
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
				$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
				$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

				$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
				$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';

				$html .= '<li class="beta_item"><div class="beta__item">'.$count_holder.$title_holder.'</div></li>';
				wp_reset_postdata();
			}
			$html .= '</ul>';

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$html .= '<ul class="second_item beta_items">';
				foreach ( $loop->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
					$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
					$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

					$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
					$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';

					$html .= '<li class="beta_item"><div class="beta__item">'.$count_holder.$title_holder.'</div></li>';
					wp_reset_postdata();
				}
				$html .= '</ul>';
			}

			$html .= '</div>';

			$html .= '</div>';
		}else if($layout == 'zeta'){
			if($settings['delta_pagination_filter'] == 'yes'){
				$per_page = $settings['delta_pagination_pp']['size'];
				$query_args['posts_per_page'] = $per_page;
				$loop = new \WP_Query( $query_args );
			}
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$html .= '<div class="fn__widget_posts_zeta" data-layout="'.$settings['zeta_layout'].'" data-title-size="'.$settings['zeta_title_size'].'" data-marker="'.$settings['zeta_marker'].'">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			// first list
			$html .= '<ul class="first_item zeta_items active">';
			$html .= mow_fn_post__zeta($loop,$settings);
			$html .= '</ul>';
			if ( $settings['delta_pagination_filter'] == 'yes' && $loop->max_num_pages > 1 ) { 
			$html .= '<div class="fn__ajax_more">
						<input type="hidden" class="paged" value="2">
						<a href="#">
							<span class="text">'.$settings['load_more_text'].'</span>
							<span class="icon"></span>
						</a>
					</div>
					<script>
						var MowPostsZetaFilterArgs = '. json_encode($query_args) .';
						var MowPostsZetaSettings = '. json_encode($settings) .';
					</script>';
			}

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$html .= '<ul class="second_item zeta_items">';
				$html .= mow_fn_post__zeta($loop,$settings);
				$html .= '</ul>';
			}

			$html .= '</div>';

			$html .= '</div>';
		}else if($layout == 'gamma'){
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$html .= '<div class="fn__widget_posts_gamma" data-layout="'.$settings['gamma_layout'].'" data-color="'.$settings['gamma_custom_color'].'">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			// first list
			$html .= '<ul class="first_item gamma_items active">';
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
				$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
				$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
				$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
				$gallery_count = mow_fn_gallery_count($post_id,'s');
				$gallery_count .= mow_fn_get_rating_number($post_id, 's');

				$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
				$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

				if($post_image != ''){
					$image_holder = '<div class="img_holder"><div class="item_img">'.$count_holder.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'thumbnail', ['loading' => 'lazy']).'</a></div></div>';
				}else{
					$image_holder = '<div class="img_holder"><div class="item_space">'.$count_holder.'<a href="'.$post_permalink.'"></a>'.$gallery_count.'</div></div>';
				}

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';

				$html .= '<li class="gamma_item"><div class="gamma__item">'.$image_holder.$title_holder.'</div></li>';
				wp_reset_postdata();
			}
			$html .= '</ul>';

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop = new \WP_Query( $query_args );
				$html .= '<ul class="second_item gamma_items">';
				foreach ( $loop->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
					$post_image = get_the_post_thumbnail_url($post_id,'thumbnail');
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
					$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
					$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
					$gallery_count = mow_fn_gallery_count($post_id,'s');
					$gallery_count .= mow_fn_get_rating_number($post_id, 's');
					
					$key++; $myKey = $key; if($key < 10){ $myKey = '0'.$key; }
					$count_holder = '<div class="count_holder"><span>'.$myKey.'</span></div>';

					if($post_image != ''){
						$image_holder = '<div class="img_holder"><div class="item_img">'.$count_holder.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'thumbnail', ['loading' => 'lazy']).'</a></div></div>';
					}else{
						$image_holder = '<div class="img_holder"><div class="item_space">'.$count_holder.'<a href="'.$post_permalink.'"></a>'.$gallery_count.'</div></div>';
					}
	
					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';
	
					$html .= '<li class="gamma_item"><div class="gamma__item">'.$image_holder.$title_holder.'</div></li>';
					wp_reset_postdata();
				}
				$html .= '</ul>';
			}

			$html .= '</div>';

			$html .= '</div>';
		}else if($layout == 'delta'){
			if($settings['delta_pagination_filter'] == 'yes'){
				$per_page = $settings['delta_pagination_pp']['size'];
				$query_args['posts_per_page'] = $per_page;
				$loop = new \WP_Query( $query_args );
			}
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$container_start = $container_end = '';
			if($settings['show_container'] == 'yes'){
				$container_start = '<div class="container">';
				$container_end = '</div>';
			}
			$html .= '<div class="fn__widget_posts_delta_wrapper">'.$container_start;
			$html .= '<div class="fn__widget_posts_delta" data-layout="'.$settings['delta_layout'].'" data-spacing="'.$settings['delta_custom_spacing'].'" data-color="'.$settings['delta_custom_color'].'" data-title-size="'.$settings['delta_title_size'].'" data-cols="'.$settings['delta_col_count'].'" data-inline-cols="'.$settings['delta_inline_col_count'].'" data-inline-border="'.$settings['delta_inline_border'].'" data-row-border="'.$settings['delta_row_border'].'" data-imax-image="'.$settings['delta_inline_max_img_pos'].'" data-imax-text="'.$settings['delta_inline_max_text_pos'].'" data-imax-vtext="'.$settings['delta_inline_max_text_vpos'].'">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			$hlight_switcher = $settings['hlight_switcher'];
			if($hlight_switcher == 'yes'){
				$hlight_list = $settings['hlight_list'];
			}

			$hlight_type = '';
			if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
				$hlight_type = 'data-outside';
			}
			// first list
			$html .= '<ul class="first_item delta_items active">';
			$html .= mow_fn_post__delta($loop,$settings);
			$html .= '</ul>';
			if ( $settings['delta_pagination_filter'] == 'yes' && $loop->max_num_pages > 1 ) { 
			$html .= '<div class="fn__ajax_more">
						<input type="hidden" class="paged" value="2">
						<a href="#">
							<span class="text">'.$settings['load_more_text'].'</span>
							<span class="icon"></span>
						</a>
					</div>
					<script>
						var MowPostsDeltaFilterArgs = '. json_encode($query_args) .';
						var MowPostsDeltaSettings = '. json_encode($settings) .';
					</script>';
			} 

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop2 = new \WP_Query( $query_args );
				$html .= '<ul class="second_item delta_items">';
				$html .= mow_fn_post__delta($loop,$settings);
				$html .= '</ul>';
			}

			$html .= '</div></div>';
			$html .= $container_end.'</div>';
		}else if($layout == 'epsilon'){
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$ratio = 1;
			if(isset($settings['epsilon_img_ratio']['size'])){
				$ratio = $settings['epsilon_img_ratio']['size'];
			}
			$epsilon_img_size = 'large';
			if(isset($settings['epsilon_img_size'])){
				$epsilon_img_size = $settings['epsilon_img_size'];
			}
			$html .= '<div class="fn__widget_posts_epsilon" data-title-size="'.$settings['epsilon_title_size'].'">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			// first list
			$html .= '<div class="first_item epsilon_items active">';

			$slider_switcher = false;
			if(count($loop->posts) > 1){
				$slider_switcher = true;
				$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
				$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
			}
			foreach ( $loop->posts as $key => $fn_post ) {
				setup_postdata( $fn_post );
				$post_id = $fn_post->ID;
				$post_title = $fn_post->post_title;
				$post_permalink = get_permalink($post_id);
				$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
				$post_image = get_the_post_thumbnail_url($post_id,$epsilon_img_size);
				$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
				$gallery_count = mow_fn_gallery_count($post_id);
				$gallery_count .= mow_fn_get_rating_number($post_id);

				$image_holder = '';
				if(get_post_format($post_id) == 'video'){
					$video_autoplay = true;
					if(isset($mow_fn_option['video_autoplay'])){
						$video_autoplay = $mow_fn_option['video_autoplay'];
					}
					$video_autoplay_local = $settings['video_autoplay'];
					if($video_autoplay_local == 'enable'){
						$video_autoplay = true;
					}else if($video_autoplay_local == 'disable'){
						$video_autoplay = false;
					}
					$image_holder = mow_fn_get_video($post_id,$video_autoplay, 5, $ratio);
				}
				if($image_holder == ''){
					if($post_image != ''){
						$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, $epsilon_img_size, ['loading' => 'lazy']).'</a></div></div>';
					}else{
						$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'"></a></div></div>';
					}
				}
				

				$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

				if($slider_switcher){$html .= '<div class="swiper-slide">';}
				$html .= '<div class="epsilon_item"><div class="epsilon__item">'.$image_holder.$title_holder.'</div></div>';
				if($slider_switcher){$html .= '</div>';}
				wp_reset_postdata();
			}
			if($slider_switcher){$html .= '</div></div></div>';}


			$html .= '</div>';

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop2 = new \WP_Query( $query_args );
				$html .= '<div class="second_item epsilon_items">';

				$slider_switcher = false;
				if(count($loop->posts) > 1){
					$slider_switcher = true;
					$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
					$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
				}
				foreach ( $loop2->posts as $key => $fn_post ) {
					setup_postdata( $fn_post );
					$post_id = $fn_post->ID;
					$post_title = $fn_post->post_title;
					$post_permalink = get_permalink($post_id);
					$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
					$post_image = get_the_post_thumbnail_url($post_id,$epsilon_img_size);
					$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'">'.$post_title.'</a></h3>';
					$gallery_count = mow_fn_gallery_count($post_id);
					$gallery_count .= mow_fn_get_rating_number($post_id);


					$image_holder = '';
					if(get_post_format($post_id) == 'video'){
						$video_autoplay = true;
						if(isset($mow_fn_option['video_autoplay'])){
							$video_autoplay = $mow_fn_option['video_autoplay'];
						}
						$video_autoplay_local = $settings['video_autoplay'];
						if($video_autoplay_local == 'enable'){
							$video_autoplay = true;
						}else if($video_autoplay_local == 'disable'){
							$video_autoplay = false;
						}
						$image_holder = mow_fn_get_video($post_id,$video_autoplay, 5, $ratio);
					}
					if($image_holder == ''){
						if($post_image != ''){
							$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, $epsilon_img_size, ['loading' => 'lazy']).'</a></div></div>';
						}else{
							$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'"></a></div></div>';
						}
					}

					$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

					if($slider_switcher){$html .= '<div class="swiper-slide">';}
					$html .= '<div class="epsilon_item"><div class="epsilon__item">'.$image_holder.$title_holder.'</div></div>';
					if($slider_switcher){$html .= '</div>';}
					wp_reset_postdata();
				}
				if($slider_switcher){$html .= '</div></div></div>';}
				$html .= '</div>';
			}

			$html .= '</div>';

			$html .= '</div>';
		}else if($layout == 'fslider'){
			$html .= mow_fn_post__fslider($loop,$settings);
		}else if($layout == 'cslider'){
			$html .= mow_fn_post__cslider($loop,$settings);
		}else if($layout == 'gcarousel'){
			$html .= mow_fn_post__gcarousel($loop,$settings);
		}else if($layout == 'fcarousel'){
			$html .= mow_fn_post__fcarousel($loop,$settings);
		}else if($layout == 'mcarousel'){
			$html .= mow_fn_post__mcarousel($loop,$settings);
		}else if($layout == 'yota_1' || $layout == 'yota_2'){
			$html .= mow_fn_post__yota($loop,$settings);
		}else if($layout == 'date_1'){
			if($settings['delta_pagination_filter'] == 'yes'){
				$per_page = $settings['delta_pagination_pp']['size'];
				$query_args['posts_per_page'] = $per_page;
				$loop = new \WP_Query( $query_args );
			}
			if($settings['posts_recent_filter_switcher'] == 'yes'){
				$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
			}else{
				$widget_title_holder = '';
			}
			$container_start = $container_end = '';
			if($settings['show_container'] == 'yes'){
				$container_start = '<div class="container">';
				$container_end = '</div>';
			}
			$html .= '<div class="fn__widget_posts_date_1_wrapper">'.$container_start;
			$html .= '<div class="fn__widget_posts_date_1">';
			$html .= $widget_title_holder;
			$html .= '<div class="fn__widget_filter_content">';

			$hlight_switcher = $settings['hlight_switcher'];
			if($hlight_switcher == 'yes'){
				$hlight_list = $settings['hlight_list'];
			}

			$hlight_type = '';
			if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
				$hlight_type = 'data-outside';
			}
			// first list
			$html .= '<ul class="first_item date_1_items active">';
			$html .= mow_fn_post__date_1($loop,$settings);
			$html .= '</ul>';
			if ( $settings['delta_pagination_filter'] == 'yes' && $loop->max_num_pages > 1 ) { 
			$html .= '<div class="fn__ajax_more">
						<input type="hidden" class="paged" value="2">
						<a href="#">
							<span class="text">'.$settings['load_more_text'].'</span>
							<span class="icon"></span>
						</a>
					</div>
					<script>
						var MowPostsDate1FilterArgs = '. json_encode($query_args) .';
						var MowPostsDate1Settings = '. json_encode($settings) .';
					</script>';
			} 

			// second list
			if($recent_posts == 'yes'){
				$query_args = array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
					'posts_per_page'      => $post_number,
					'orderby'             => 'date',
					'order'               => 'DESC',
				);
				$loop2 = new \WP_Query( $query_args );
				$html .= '<ul class="second_item date_1_items">';
				$html .= mow_fn_post__date_1($loop,$settings);
				$html .= '</ul>';
			}

			$html .= '</div></div>';
			$html .= $container_end.'</div>';
		}

		
		
		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= '</div>';
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
