<?php
namespace Frel\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Color;
use Elementor\Core\Schemes\Typography;
use Elementor\Utils;
use Frel\Frel_Helper;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) { exit; }



class Frel_Title extends Widget_Base {

	public function get_name() {
		return 'frel-title';
	}

	public function get_title() {
		return __( 'Title', MOW_TEXT_DOMAIN );
	}

	public function get_icon() {
		return 'eicon-animated-headline frenifyicon-elementor';
	}

	public function get_categories() {
		return [ 'frel-elements' ];
	}
	
	public function get_keywords() {
        return [
            'frenify',
            MOW_TEXT_DOMAIN
        ];
    }

	protected function register_controls(): void {
		
		$this->start_controls_section(
			'section1',
			[
				'label' => __( 'Content', MOW_TEXT_DOMAIN ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' 		=> __( 'Layout', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'decor',
				'options' 		=> [
					'simple'		=> __( 'Simple Title', MOW_TEXT_DOMAIN ),
					'decor'			=> __( 'Decor Title', MOW_TEXT_DOMAIN ),
					'd_decor'		=> __( 'Double Decor Title', MOW_TEXT_DOMAIN ),
					'lined'  		=> __( 'Lined Title', MOW_TEXT_DOMAIN ),
					'marquee'  		=> __( 'Big Marquee', MOW_TEXT_DOMAIN ),
					's_marquee' 	=> __( 'Small Marquee', MOW_TEXT_DOMAIN ),
				],
			]
		);

		$this->add_control(
			'tag',
			[
				'label' 		=> __( 'Tag', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'h3',
				'options' 		=> [
					'h1'		=> 'H1',
					'h2'		=> 'H2',
					'h3'		=> 'H3',
					'h4'		=> 'H4',
					'h5'		=> 'H5',
					'h6'		=> 'H6',
					'p'			=> 'P',
					'span'		=> 'SPAN',
				],
			]
		);

		$this->add_control(
			'text_align',
			[
				'label' => esc_html__( 'Alignment', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', MOW_TEXT_DOMAIN ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', MOW_TEXT_DOMAIN ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', MOW_TEXT_DOMAIN ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'left',
				'toggle' => true,
				'condition' => [
					'layout' => ['decor','d_decor'],
				]
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
					'layout!' => ['marquee', 's_marquee'],
				]
			]
		);

		$this->add_control(
			's_marquee_separator',
			[
				'label' 		=> __( 'Separator', MOW_TEXT_DOMAIN ),
				'type' 			=> \Elementor\Controls_Manager::SELECT,
				'default' 		=> 'star',
				'options' 		=> [
					'star'			=> __( 'Star', MOW_TEXT_DOMAIN ),
					'console'		=> __( 'Console', MOW_TEXT_DOMAIN ),
				],
				'condition' => [
					'layout' => 's_marquee',
				]
			]
		);


		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'marquee_title',
			[
				'label' => __( 'Marquee Title', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);


		$this->add_control(
			'marquee_list',
			[
				'label' => __( 'Marquee List', MOW_TEXT_DOMAIN ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ marquee_title }}}',
				'condition' => [
					'layout' => ['marquee','s_marquee'],
				]
			]
		);

		$this->add_control(
			'custom_color',
			[
				'label' => esc_html__( 'Custom Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'decor_decor_color',
			[
				'label' => esc_html__( 'Decor Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .fn__decor_title[data-color="yes"] .text:before,{{WRAPPER}} .fn__decor_title[data-color="yes"] .text:after, {{WRAPPER}} .fn__decor_title[data-color="yes"][data-layout="d_decor"] .r_decor:before,{{WRAPPER}} .fn__decor_title[data-color="yes"][data-layout="d_decor"] .r_decor:after' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'custom_color' => 'yes',
					'layout' => ['decor','d_decor'],
				]
			]
		);

		$this->add_control(
			'decor_text_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .fn__decor_title[data-color="yes"]' => 'color: {{VALUE}}',
				],
				'condition' => [
					'custom_color' => 'yes',
					'layout' => ['decor','d_decor'],
				]
			]
		);

		$this->add_control(
			'simple_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .fn__simple_title[data-color="yes"]' => 'color: {{VALUE}}',
					'{{WRAPPER}}  .fn__simple_title[data-stroke="yes"][data-color="yes"]' => 'color: transparent;-webkit-text-stroke: 2px {{VALUE}};',
				],
				'condition' => [
					'layout' => 'simple',
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'marquee_color',
			[
				'label' => esc_html__( 'Text Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .fn_cs_cats_big_marquee[data-color="yes"] .item, {{WRAPPER}}  .fn__cs_title_smarquee[data-color="yes"] .item' => 'color: {{VALUE}}',
					'{{WRAPPER}} .fn_cs_cats_big_marquee .item_sep, {{WRAPPER}} .fn_cs_cats_big_marquee[data-color="yes"] .item_sep:after,{{WRAPPER}} .fn_cs_cats_big_marquee[data-color="yes"] .item_sep:before' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => ['marquee','s_marquee'],
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'marquee_icon_color',
			[
				'label' => esc_html__( 'Icon Color', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .fn__cs_title_smarquee[data-color="yes"] .icon' => 'color: {{VALUE}}',
					'{{WRAPPER}}  .fn__cs_title_smarquee[data-color="yes"] .icon:before,{{WRAPPER}}  .fn__cs_title_smarquee[data-color="yes"] .icon:after' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'layout' => 's_marquee',
					'custom_color' => 'yes',
				]
			]
		);

		$this->add_control(
			'show_container',
			[
				'label' => esc_html__( 'Container Switcher', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
			]
		);

		$this->add_control(
			'simple_custom_ff',
			[
				'label' => esc_html__( 'Custom Font Family', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'simple',
				]
			]
		);

		$this->add_control(
			'simple_font_family',
			[
				'label' => esc_html__( 'Font Family', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::FONT,
				'default' => "'Heebo', sans-serif",
				'selectors' => [
					'{{WRAPPER}} .fn__simple_title' => 'font-family: {{VALUE}}',
				],
				'condition' => [
					'layout' => 'simple',
					'simple_custom_ff' => 'yes',
				]
			]
		);

		$this->add_control(
			'simple_stroke',
			[
				'label' => esc_html__( 'Stroke', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', MOW_TEXT_DOMAIN ),
				'label_off' => esc_html__( 'Hide', MOW_TEXT_DOMAIN ),
				'return_value' => 'yes',
				'default' => '',
				'condition' => [
					'layout' => 'simple',
				]
			]
		);

		$this->add_control(
			'opacity',
			[
				'label' => esc_html__( 'Opacity', MOW_TEXT_DOMAIN ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .fn__cs_title_wrapper' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->end_controls_section();
		
	}


	protected function render() {
		$settings 			= $this->get_settings();
		$html 				= Frel_Helper::frel_open_wrap();
		$layout				= $settings['layout'];
		$custom_color		= $settings['custom_color'];

		
		$container_start = $container_end = '';
		if($settings['show_container'] == 'yes'){
			$container_start = '<div class="container">';
			$container_end = '</div>';
		}
		$html .= '<div class="fn__cs_title_wrapper">'.$container_start;

		if($layout == 'decor' || $layout == 'd_decor'){
			$html .= '<'.$settings['tag'].' class="fn__decor_title" data-color="'.$custom_color.'" data-layout="'.$layout.'" data-align="'.$settings['text_align'].'"><span class="text">'.$settings['title'].'<span class="r_decor"></span></span></'.$settings['tag'].'>';
		}else if($layout == 'lined'){
			$html .= '<'.$settings['tag'].' class="fn__lined_title"><span>'.$settings['title'].'</span></'.$settings['tag'].'>';
		}else if($layout == 'simple'){
			$html .= '<'.$settings['tag'].' class="fn__simple_title" data-color="'.$custom_color.'" data-stroke="'.$settings['simple_stroke'].'">'.$settings['title'].'</'.$settings['tag'].'>';
		}else if($layout == 'marquee'){
			$marquee_list	= $settings['marquee_list'];
			$list = '';
			if(!empty($marquee_list)){
				foreach($marquee_list as $item){
					$list .= '<div class="item">'.$item['marquee_title'].'<div class="item_sep"></div></div>';
				}
			}
			$html .= '<div class="fn__cs_title_big_marquee fn_cs_cats_big_marquee" data-color="'.$custom_color.'"><div class="marquee">'.$list.'</div></div>';
		}else if($layout == 's_marquee'){
			$marquee_list	= $settings['marquee_list'];
			$separator	= $settings['s_marquee_separator'];
			$list = '';
			if($separator == 'star'){
				$icon = mow_fn_svg('svg__star');
			}else{
				$icon = '<span class="icon">'.mow_fn_svg('svg__'.$separator).'</span>';
			}
			
			if(!empty($marquee_list)){
				foreach($marquee_list as $item){
					$list .= '<div class="item">'.$item['marquee_title'].$icon.'</div>';
				}
			}
			$html .= '<div class="fn__cs_title_smarquee" data-color="'.$custom_color.'"><div class="marquee">'.$list.'</div></div>';
		}
		
		$html .= $container_end.'</div>';
		/***********************************************************************************/
		/* RENDER ENDS */
		$html .= Frel_Helper::frel_close_wrap();
		echo $html;
	}

}
