<?php
global $mow_fn_option;

function mow_fn_theme_option(){
	global $mow_fn_option;
	return $mow_fn_option;
}

add_filter( 'body_class','mow_fn_body_classes' );
function mow_fn_body_classes( $classes ) {
	global $post,$mow_fn_option;
	$sticky_mobile_nav = false;
	if(isset($mow_fn_option['sticky_mobile_nav'])){
		$sticky_mobile_nav = $mow_fn_option['sticky_mobile_nav'];
	}
	if($sticky_mobile_nav){
		$classes[] = 'mobile_sticky';
	}
	$sticky_sidebar = 'enable';
	if(isset($mow_fn_option['sticky_sidebar'])){
		$sticky_sidebar = $mow_fn_option['sticky_sidebar'];
	}
	$classes[] = 'sidebar_sticky_'.$sticky_sidebar;
	
	$core_ready = (isset($mow_fn_option) && $mow_fn_option !== null) ? 'core-ready' : 'core-absent';
	$classes[] = 'mow-'.esc_attr($core_ready);
    
    return $classes;
    
}

if (isset($mow_fn_option['relink_pending_posts_visibility']) && $mow_fn_option['relink_pending_posts_visibility'] === 'enable') {
    add_action('admin_bar_menu', 'replace_comments_with_pending_posts_in_admin_bar', 999);
}

function replace_comments_with_pending_posts_in_admin_bar($wp_admin_bar) {
    // Only show for users who can manage pending posts (admins or editors)
    if (current_user_can('edit_others_posts')) {
        // Get pending posts count
        $post_counts  = wp_count_posts();
        $pending_count = isset($post_counts->pending) ? $post_counts->pending : 0;

        if ($pending_count > 0) {
            $wp_admin_bar->add_node(array(
                'id'    => 'pending-posts',
                'title' => '&#9203;'  . $pending_count,
                'href'  => admin_url('edit.php?post_status=pending&post_type=post'),
                'meta'  => array(
                    'title' => esc_html__('Review Pending Posts', 'mow'),
                )
            ));
        }
    }
}



add_action('save_post', 'mow_fn_update_post_overall_rating');
function mow_fn_update_post_overall_rating($post_id) {
    if (get_post_type($post_id) !== 'post') return;

    $fers_meta_values = get_post_meta($post_id, '_fers_prefix_post_options', true);
	$is_fers_score_shows = isset( $fers_meta_values['fers-score-shows'] ) ? $fers_meta_values['fers-score-shows'] : '';
    $fers_total_rating = 0;
    $fers_count = 0;

    if ($is_fers_score_shows && !empty($fers_meta_values['fers-editorial-rating'])) {
        foreach ($fers_meta_values['fers-editorial-rating'] as $rating) {
            $fers_total_rating += round($rating['fers-editorial-rating-category-rate']);
            $fers_count++;
        }
    }

    if ($fers_count > 0) {
        $percentage = $fers_total_rating / $fers_count;
        update_post_meta($post_id, '_fers_overall_rating', $percentage);
    } else {
        delete_post_meta($post_id, '_fers_overall_rating');
    }
}
function mow_fn_enable_page_excerpts() {
    add_post_type_support('page', 'excerpt');
}
add_action('init', 'mow_fn_enable_page_excerpts');

function mow_fn_add_meta_description() {
    global $mow_fn_option;
    $meta_description = isset($mow_fn_option['meta_description']) ? $mow_fn_option['meta_description'] : 'enable';

    if ($meta_description === 'enable') {
        $default_description = esc_html__('Mow is a versatile WordPress theme for blogs and magazines, offering stylish design, fast performance, and powerful features for creators worldwide.', 'mow');
        $meta_description_text = isset($mow_fn_option['meta_description_text']) ? $mow_fn_option['meta_description_text'] : $default_description;
        $meta_description_limit = isset($mow_fn_option['meta_description_limit']) ? $mow_fn_option['meta_description_limit'] : 160;

        if (is_single() || is_page()) {
			$description = mb_strimwidth(strip_shortcodes(strip_tags(get_the_excerpt() ?: get_the_content())), 0, $meta_description_limit, '...');
        } elseif (is_category() || is_tag() || is_tax()) {
            $description = single_term_title('', false) . ' - ' . term_description();
        } elseif (is_author()) {
            $description = get_the_author_meta('display_name') . ' - ' . get_the_author_meta('description');
        } else {
            $description = $meta_description_text;
        }

        // Ensure the description is not too long
        $description = mb_strimwidth($description, 0, 150, '...');
        echo '<meta name="description" content="' . esc_attr($description) . '">';
    }
}
add_action('wp_head', 'mow_fn_add_meta_description');



function mow_fn_listbetween_positions(){
	global $mow_fn_option;
	$ad_positions = array();
	if(isset($mow_fn_option['ads_listpost_btwn_position'])){
		$ad_positions = $mow_fn_option['ads_listpost_btwn_position'];
	}
	if (!empty($ad_positions)) {
		$ad_positions = array_map('intval', $ad_positions);
		$ad_positions = array_unique(array_filter($ad_positions, 'is_numeric'));
		sort($ad_positions, SORT_NUMERIC);
	}
	return $ad_positions;
}

function mow_fn_post__zeta($loop,$settings){
	$html = '';
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id = $fn_post->ID;
		$post_title = $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

		$title_holder = '<div class="title_holder">'.$post_meta.'<div class="zeta_title">'.$post_title.$post_excerpt.'</div>'.$read_more.'</div>';

		$html .= '<li class="zeta_item"><div class="zeta__item">'.$title_holder.'</div></li>';
		wp_reset_postdata();
	}
	return $html;
}

function mow_fn_post__delta($loop,$settings){
	global $mow_fn_option;

	if (!isset($settings) || !is_array($settings)) {
		return '';
	}

	$icon_size = $settings['icon_size'] ?? 'n';
	if ($icon_size === 'd') $icon_size = 'n';

	$hlight_switcher = $settings['hlight_switcher'] ?? '';
	$hlight_list = $hlight_switcher === 'yes' ? ($settings['hlight_list'] ?? []) : [];

	$hlight_type = ($settings['hlight_type'] ?? '') === 'separated' ? 'data-outside' : '';

	$meta_display = $settings['meta_display'] ?? [];
	$delta_img_size = $settings['delta_img_size'] ?? 'large';
	$ratio = $settings['delta_img_ratio']['size'] ?? 1;
	$meta_switcher = $settings['meta_switcher'] ?? '';
	$excerpt_switcher = $settings['excerpt_switcher'] ?? '';
	$read_more_switcher = $settings['read_more_switcher'] ?? '';
	$delta_layout = $settings['delta_layout'] ?? '';
	$read_more_text = $settings['read_more_text'] ?? '';
	$video_autoplay_local = $settings['video_autoplay'] ?? 'enable';

	$html = '';

	foreach ($loop->posts as $key => $fn_post) {
		setup_postdata($fn_post);

		$post_id = $fn_post->ID;
		$post_title = esc_html($fn_post->post_title);
		$post_permalink = get_permalink($post_id);
		$post_meta = ($meta_switcher === 'yes') ? mow_fn_metas(['post_id' => $post_id, 'meta_display' => $meta_display]) : '';

		$post_image = get_the_post_thumbnail_url($post_id, $delta_img_size);

		// Highlight text check
		$hlight_text = '';
		if (!empty($hlight_list[$key]['hlight_text'])) {
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}

		$post_title_html = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr($post_title).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($excerpt_switcher === 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($read_more_switcher === 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr($post_title).'"><span class="text" aria-label="'.$read_more_text.'">'.$read_more_text.'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

		// Gallery & Rating
		if ($delta_layout === 'column' || $delta_layout === 'col_grid') {
			$gallery_count = mow_fn_gallery_count($post_id, $icon_size) . mow_fn_get_rating_number($post_id, $icon_size);
		} elseif ($delta_layout === 'no_image') {
			$gallery_count = '';
		} else {
			$gallery_count = mow_fn_gallery_count($post_id, $icon_size) . mow_fn_get_rating_number($post_id, $icon_size);
		}

		// Image / Video handling
		$image_holder = '';

		if ($delta_layout !== 'no_image') {
			if (get_post_format($post_id) === 'video') {
				$video_autoplay = $mow_fn_option['video_autoplay'] ?? true;
				$video_autoplay = ($video_autoplay_local === 'enable') ? true : false;
				$image_holder = mow_fn_get_video($post_id, $video_autoplay, 5, $ratio);
			}

			if ($image_holder === '') {
				if (!empty($post_image)) {
					$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr($post_title).'">'.$gallery_count.get_the_post_thumbnail($post_id, $delta_img_size, ['loading' => 'lazy']).'</a></div></div>';
				} else {
					$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr($post_title).'"></a>'.$gallery_count.'</div></div>';
				}
			}
		}

		$title_holder = '<div class="title_holder">'.$post_meta.$post_title_html.$post_excerpt.$read_more.'</div>';
		$html .= '<li class="delta_item"><div class="delta__item">'.$image_holder.$title_holder.'</div></li>';

		wp_reset_postdata(); // Теперь в правильном месте
	}

	return $html;

}

function mow_fn_post__date_1($loop,$settings){
	$html = '';
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id 		= $fn_post->ID;
		$post_title 	= $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta 		= ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id,'author' => true)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id,'large');
		

		$hlight_text 	= '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
		
		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'large', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}


		$post_date = '<div class="date_holder"><span class="day">'.get_the_date('d', $post_id).'</span><span class="date"><span class="month">'.get_the_date('M', $post_id).'</span><span class="year">'.get_the_date('Y', $post_id).'</span></div>';

		$post_info = '<div class="post_info">'.$post_date.'<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.mow_fn_relink_icon($post_id,'modern').'</div></div>';

		$post_image = $image_holder;

		$html .= '<li class="date_1_item"><div class="date_1__item">'.$post_info.$post_image.'</div></li>';
		wp_reset_postdata();
	}
	return $html;
}

function mow_fn_post__interactive($loop,$settings, $filter = ''){
	$html = '';
	$bg_list = '<ul class="bg_list">';
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id 		= $fn_post->ID;
		$post_title 	= $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta 		= ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		$post_image 	= get_the_post_thumbnail_url($post_id,'full');
		$hlight_text 	= '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

		$active = '';
		if($key == 0){
			$active = 'active';
		}

		
		$gallery_count = mow_fn_gallery_count($post_id);
		$gallery_count .= mow_fn_get_rating_number($post_id);
		$image_holder = '';
		$format = '';
		if(get_post_format($post_id) == 'video'){
			$format = 'video';
			$image_holder = mow_fn_get_video($post_id,true, 5, 1).'<span class="video_icon"></span>';
		}
		if($image_holder == ''){
			$image_holder = $gallery_count;
		}
		$bg_list .= '<li data-format="'.$format.'" data-img="'.$post_image.'" style="background-image: url('.$post_image.')" class="'.$active.'">'.$image_holder.'</li>';

		$title_holder = '<div class="title_holder">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div>';

		$html .= '<li class="interactive_item"><div class="interactive__item">'.$image_holder.$title_holder.'</div></li>';
		wp_reset_postdata();
	}
	$bg_list .= '</ul>';
	if($filter == 'second'){
		$html = '<div class="interactive_wrapper">'.$bg_list.'<div class="container"><ul class="second_item interactive_items">'.$html.'</ul></div></div>';
	}else{
		$html = '<div class="interactive_wrapper">'.$bg_list.'<div class="container"><ul class="first_item interactive_items active">'.$html.'</ul></div></div>';

	}
	return $html;
}
function mow_fn_post__fslider($loop,$settings){
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
	}else{
		$widget_title_holder = '';
	}
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	$html = '<div class="fn__widget_posts_fslider" data-container="'.$settings['show_container'].'" data-layout="'.$settings['fslider_type'].'">';
	$html .= $widget_title_holder;
	$html .= '<div class="fn__widget_filter_content">';

	// first list
	$html .= '<div class="first_item fslider_items active">';

	$slider_switcher = false;
	$slider_nav = '<div class="slider_nav"><div class="container"><div class="slider_nav_in"><div class="swiper-button-prev">'.mow_fn_svg('svg__arrow_4').'</div><div class="swiper-button-next">'.mow_fn_svg('svg__arrow_4').'</div></div></div></div>';
	if(count($loop->posts) > 1){
		$slider_switcher = true;
		$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
		$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id = $fn_post->ID;
		$post_title = $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id,'full');

		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
		$gallery_count = mow_fn_gallery_count($post_id);
		$gallery_count .= mow_fn_get_rating_number($post_id);


		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}

		$title_holder = '<div class="title_holder"><div class="container"><div class="title_holder_in">'.$post_meta.$post_title.'</div></div></div>';

		if($slider_switcher){$html .= '<div class="swiper-slide">';}
		$html .= '<div class="fslider_item"><div class="fslider__item">'.$image_holder.$title_holder.'</div></div>';
		if($slider_switcher){$html .= '</div>';}
		wp_reset_postdata();
	}
	if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}


	$html .= '</div>';

	// second list
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$query_args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => $settings['blog_post_number']['size'],
			'orderby'             => 'date',
			'order'               => 'DESC',
		);
		$loop2 = new \WP_Query( $query_args );
		$html .= '<div class="second_item fslider_items">';

		$slider_switcher = false;
		if(count($loop->posts) > 1){
			$slider_switcher = true;
			$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
			$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
		}
		foreach ( $loop2->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id = $fn_post->ID;
			$post_title = $fn_post->post_title;
			$post_permalink = get_permalink($post_id);
			$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';

			$post_image = get_the_post_thumbnail_url($post_id,'full');

			$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
			$gallery_count = mow_fn_gallery_count($post_id);
			$gallery_count .= mow_fn_get_rating_number($post_id);


			if($post_image != ''){
				$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
			}else{
				$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
			}

			$title_holder = '<div class="title_holder"><div class="container"><div class="title_holder_in">'.$post_meta.$post_title.'</div></div></div>';

			if($slider_switcher){$html .= '<div class="swiper-slide">';}
			$html .= '<div class="fslider_item"><div class="fslider__item">'.$image_holder.$title_holder.'</div></div>';
			if($slider_switcher){$html .= '</div>';}
			wp_reset_postdata();
		}
		if($slider_switcher){$html .= '</div>'.$slider_nav.'</div></div>';}
		$html .= '</div>';
	}

	$html .= '</div>';

	$html .= '</div>';

	return $html;
}

function mow_fn_post__cslider($loop,$settings){
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
	}else{
		$widget_title_holder = '';
	}
	$hlight_switcher = $settings['hlight_switcher'];
	if($hlight_switcher == 'yes'){
		$hlight_list = $settings['hlight_list'];
	}
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	$cslider_blind_mode = '';
	if(isset($settings['cslider_blind_mode'])){
		$cslider_blind_mode = $settings['cslider_blind_mode'];
	}
	$hlight_type = '';
	if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
		$hlight_type = 'data-outside';
	}
	$html = '<div class="fn__widget_posts_cslider" data-blind-mode="'.$cslider_blind_mode.'" data-color="'.$settings['cslider_custom_color'].'">';
	$html .= $widget_title_holder;
	$html .= '<div class="fn__widget_filter_content">';

	// first list
	$html .= '<div class="first_item cslider_items active">';

	$slider_switcher = false;
	$slider_nav = '<div class="slider_nav"><div class="slider_nav_in"><div class="swiper-button-prev">'.mow_fn_svg('svg__arrow_4').'</div><div class="swiper-button-next">'.mow_fn_svg('svg__arrow_4').'</div></div></div>';
	if(count($loop->posts) > 1){
		$slider_switcher = true;
		$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
		$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id 		= $fn_post->ID;
		$post_title 	= $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta 		= ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id,'full');

		$hlight_text 	= '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title 	= '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt 	= ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more 		= ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';


		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}

		$title_holder = '<div class="circle_holder"></div><div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div></div>';

		if($slider_switcher){$html .= '<div class="swiper-slide">';}
		$html .= '<div class="cslider_item"><div class="cslider__item">'.$image_holder.$title_holder.'</div></div>';
		if($slider_switcher){$html .= '</div>';}
		wp_reset_postdata();
	}
	if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}


	$html .= '</div>';

	// second list
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$query_args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => $settings['blog_post_number']['size'],
			'orderby'             => 'date',
			'order'               => 'DESC',
		);
		$loop2 = new \WP_Query( $query_args );
		$html .= '<div class="second_item cslider_items">';

		$slider_switcher = false;
		if(count($loop->posts) > 1){
			$slider_switcher = true;
			$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
			$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
		}
		foreach ( $loop2->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id 		= $fn_post->ID;
			$post_title 	= $fn_post->post_title;
			$post_permalink = get_permalink($post_id);
			$post_meta 		= ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
			$post_image 	= get_the_post_thumbnail_url($post_id,'full');
			$post_title 	= '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';


			if($post_image != ''){
				$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
			}else{
				$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
			}

			$title_holder = '<div class="circle_holder"></div><div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.'</div></div>';

			if($slider_switcher){$html .= '<div class="swiper-slide">';}
			$html .= '<div class="cslider_item"><div class="cslider__item">'.$image_holder.$title_holder.'</div></div>';
			if($slider_switcher){$html .= '</div>';}
			wp_reset_postdata();
		}
		if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}
		$html .= '</div>';
	}

	$html .= '</div>';

	$html .= '</div>';

	return $html;
}

function mow_fn_post__gcarousel($loop,$settings){
	$icon_size = 's';
	if(isset($settings['icon_size'])){
		$icon_size = $settings['icon_size'];
		if($icon_size == 'd'){
			$icon_size = 's';
		}
	}
	$gcarousel_navsize = 'd';
	if(isset($settings['gcarousel_navsize'])){
		$gcarousel_navsize = $settings['gcarousel_navsize'];
	}
	$gcarousel_title_typog = '';
	if(isset($settings['gcarousel_title_typog'])){
		$gcarousel_title_typog = $settings['gcarousel_title_typog'];
	}
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}

	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
	}else{
		$widget_title_holder = '';
	}
	$autoplay_slider = 'enable';
	if(isset($settings['gcarousel_autoplay_slider'])){
		$autoplay_slider = $settings['gcarousel_autoplay_slider'];
	}
	$hlight_switcher = $settings['hlight_switcher'];

	$hlight_switcher = $settings['hlight_switcher'];
	if($hlight_switcher == 'yes'){
		$hlight_list = $settings['hlight_list'];
	}
	$hlight_type = '';
	if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
		$hlight_type = 'data-outside';
	}
	$html = '<div class="fn__widget_posts_gcarousel" data-color="'.$settings['gcarousel_custom_color'].'" data-navsize="'.$gcarousel_navsize.'" data-title-typography="'.$gcarousel_title_typog.'">';
	$html .= $widget_title_holder;
	$html .= '<div class="fn__widget_filter_content">';

	// first list
	$html .= '<div class="first_item gcarousel_items active">';

	$slider_switcher = false;
	$slider_nav = '<div class="slider_nav"><div class="slider_nav_in"><div class="swiper-button-prev">'.mow_fn_svg('svg__arrow_4').'</div><div class="swiper-button-next">'.mow_fn_svg('svg__arrow_4').'</div></div></div>';
	if(count($loop->posts) > 1){
		$slider_switcher = true;
		$html .= '<div class="fn__circle_slider"><div class="swiper" data-slider-autoplay="'.$autoplay_slider.'" data-cols="'.$settings['gcarousel_perview'].'" data-align="'.$settings['gcarousel_text_align'].'"><div class="swiper-wrapper">';
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id = $fn_post->ID;
		$post_title = $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id,'large');
		
		$hlight_text = '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
		$gallery_count = mow_fn_gallery_count($post_id, $icon_size);
		$gallery_count .= mow_fn_get_rating_number($post_id, $icon_size);

		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'large', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}

		$title_holder = '<div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div></div>';

		if($slider_switcher){$html .= '<div class="swiper-slide">';}
		$html .= '<div class="gcarousel_item"><div class="gcarousel__item">'.$image_holder.$title_holder.'</div></div>';
		if($slider_switcher){$html .= '</div>';}
		wp_reset_postdata();
	}
	if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}


	$html .= '</div>';

	// second list
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$query_args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => $settings['blog_post_number']['size'],
			'orderby'             => 'date',
			'order'               => 'DESC',
		);
		$loop2 = new \WP_Query( $query_args );
		$html .= '<div class="second_item gcarousel_items">';

		$slider_switcher = false;
		if(count($loop->posts) > 1){
			$slider_switcher = true;
			$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
			$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
		}
		foreach ( $loop2->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id = $fn_post->ID;
			$post_title = $fn_post->post_title;
			$post_permalink = get_permalink($post_id);
			$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
			
			$post_image 	= get_the_post_thumbnail_url($post_id,'large');
			
			$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
			$gallery_count = mow_fn_gallery_count($post_id,$icon_size);
			$gallery_count .= mow_fn_get_rating_number($post_id, $icon_size);

			if($post_image != ''){
				$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'large', ['loading' => 'lazy']).'</a></div></div>';
			}else{
				$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
			}

			$title_holder = '<div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.'</div></div>';

			if($slider_switcher){$html .= '<div class="swiper-slide">';}
			$html .= '<div class="gcarousel_item"><div class="gcarousel__item">'.$image_holder.$title_holder.'</div></div>';
			if($slider_switcher){$html .= '</div>';}
			wp_reset_postdata();
		}
		if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}
		$html .= '</div>';
	}
	
	$html .= '</div>';

	$html .= '</div>';

	return $html;
}

function mow_fn_post__fcarousel($loop,$settings){
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
	}else{
		$widget_title_holder = '';
	}
	$hlight_switcher = $settings['hlight_switcher'];
	if($hlight_switcher == 'yes'){
		$hlight_list = $settings['hlight_list'];
	}
	$hlight_type = '';
	if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
		$hlight_type = 'data-outside';
	}
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	$html = '<div class="fn__widget_posts_fcarousel"><div class="container"><div class="fn__widget_posts_fcarousel_in">';
	$html .= $widget_title_holder;
	$html .= '<div class="fn__widget_filter_content">';

	// first list
	$html .= '<div class="first_item fcarousel_items active">';

	$slider_switcher = false;
	$slider_nav = '<div class="slider_nav"><div class="slider_nav_in"><div class="swiper-button-prev">'.mow_fn_svg('svg__arrow_4').'</div><div class="swiper-button-next">'.mow_fn_svg('svg__arrow_4').'</div></div></div>';
	if(count($loop->posts) > 1){
		$slider_switcher = true;
		$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
		$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id = $fn_post->ID;
		$post_title = $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id, 'full');
		
		$hlight_text = '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'" title="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
		$gallery_count = mow_fn_gallery_count($post_id);
		$gallery_count .= mow_fn_get_rating_number($post_id);


		$image_holder = '';
		if(get_post_format($post_id) == 'video'){
			$video_autoplay = true;
			if(isset($mow_fn_option['video_autoplay'])){
				$video_autoplay = $mow_fn_option['video_autoplay'];
			}
			$video_autoplay_local = $settings['video_autoplay'];
			if($video_autoplay_local == 'enable'){
				$video_autoplay = true;
			}else if($video_autoplay_local == 'disable'){
				$video_autoplay = false;
			}
			$image_holder = mow_fn_get_video($post_id,$video_autoplay, 5, 1.5);
		}
		if($image_holder == ''){
			if($post_image != ''){
				$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
			}else{
				$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
			}
		}

		$title_holder = '<div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div></div>';

		if($slider_switcher){$html .= '<div class="swiper-slide">';}
		$html .= '<div class="fcarousel_item"><div class="fcarousel__item">'.$image_holder.$title_holder.'</div></div>';
		if($slider_switcher){$html .= '</div>';}
		wp_reset_postdata();
	}
	if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}


	$html .= '</div>';

	// second list
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$query_args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => $settings['blog_post_number']['size'],
			'orderby'             => 'date',
			'order'               => 'DESC',
		);
		$loop2 = new \WP_Query( $query_args );
		$html .= '<div class="second_item gcarousel_items">';

		$slider_switcher = false;
		if(count($loop->posts) > 1){
			$slider_switcher = true;
			$svg = '<div class="fn-block-progress-circle"><svg class="progress-svg" viewBox="0 0 30 30"><circle class="progress-bar" r="13" cx="15" cy="15"></circle></svg></div>';
			$html .= '<div class="fn__circle_slider">'.$svg.'<div class="swiper"><div class="swiper-wrapper">';
		}
		foreach ( $loop2->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id = $fn_post->ID;
			$post_title = $fn_post->post_title;
			$post_permalink = get_permalink($post_id);
			$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';

			$post_image 	= get_the_post_thumbnail_url($post_id,'full');

			$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';
			$gallery_count = mow_fn_gallery_count($post_id);
			$gallery_count .= mow_fn_get_rating_number($post_id);

			$image_holder = '';
			if(get_post_format($post_id) == 'video'){
				$video_autoplay = true;
				if(isset($mow_fn_option['video_autoplay'])){
					$video_autoplay = $mow_fn_option['video_autoplay'];
				}
				$video_autoplay_local = $settings['video_autoplay'];
				if($video_autoplay_local == 'enable'){
					$video_autoplay = true;
				}else if($video_autoplay_local == 'disable'){
					$video_autoplay = false;
				}
				$image_holder = mow_fn_get_video($post_id,$video_autoplay, 5, 1.5);
			}
			if($image_holder == ''){
				if($post_image != ''){
					$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
				}else{
					$image_holder = '<div class="img_holder"><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
				}
			}

			$title_holder = '<div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.'</div></div>';

			if($slider_switcher){$html .= '<div class="swiper-slide">';}
			$html .= '<div class="fcarousel_item"><div class="fcarousel__item">'.$image_holder.$title_holder.'</div></div>';
			if($slider_switcher){$html .= '</div>';}
			wp_reset_postdata();
		}
		if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}
		$html .= '</div>';
	}

	$html .= '</div>';

	$html .= '</div></div></div>';

	return $html;
}

function mow_fn_post__mcarousel($loop,$settings){
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$widget_title_holder = '<div class="container"><div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div></div>';
	}else{
		$widget_title_holder = '';
	}
	$hlight_switcher = $settings['hlight_switcher'];
	if($hlight_switcher == 'yes'){
		$hlight_list = $settings['hlight_list'];
	}
	$hlight_type = '';
	if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
		$hlight_type = 'data-outside';
	}
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	$html = '<div class="fn__widget_posts_mcarousel">';
	$html .= $widget_title_holder;
	$html .= '<div class="fn__widget_filter_content">';

	// first list
	$html .= '<div class="first_item mcarousel_items active">';

	$slider_switcher = false;
	$slider_nav = '<div class="slider_nav"><div class="container"><div class="slider__nav"><div class="swiper-button-nav swiper-button-prev">'.mow_fn_svg('svg__arrow_4').'</div><div class="swiper-button-nav swiper-button-next">'.mow_fn_svg('svg__arrow_4').'</div></div></div></div>';
	if(count($loop->posts) > 1){
		$slider_switcher = true;
		$html .= '<div class="fn__circle_slider"><div class="swiper"><div class="swiper-wrapper">';
	}
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id = $fn_post->ID;
		$post_title = $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id,'full');
		
		$hlight_text = '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}

		$post_date = '<div class="date_holder"><span class="dleft_dec"></span><span class="dright_dec"></span><span class="day">'.get_the_date('d', $post_id).'</span><span class="date"><span class="month">'.get_the_date('M', $post_id).'</span><span class="year">'.get_the_date('Y', $post_id).'</span></div>';

		$title_holder = '<div class="title_holder"><div class="title_top">'.$post_title.$image_holder.'</div><div class="title_bottom"><div class="tb_left">'.$post_date.'</div><div class="tb_right">'.$post_excerpt.$read_more.'</div></div></div>';

		if($slider_switcher){$html .= '<div class="swiper-slide">';}
		$html .= '<div class="mcarousel_item">'.$image_holder.'<div class="container"><div class="mcarousel__item_wrap"><div class="mcarousel__item">'.$title_holder.'</div></div></div></div>';
		if($slider_switcher){$html .= '</div>';}
		wp_reset_postdata();
	}
	if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}


	$html .= '</div>';

	// second list
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$query_args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => $settings['blog_post_number']['size'],
			'orderby'             => 'date',
			'order'               => 'DESC',
		);
		$loop2 = new \WP_Query( $query_args );
		$html .= '<div class="second_item gcarousel_items">';

		$slider_switcher = false;
		if(count($loop->posts) > 1){
			$slider_switcher = true;
			$html .= '<div class="fn__circle_slider"><div class="swiper"><div class="swiper-wrapper">';
		}
		foreach ( $loop2->posts as $key => $fn_post ) {
			setup_postdata( $fn_post );
			$post_id = $fn_post->ID;
			$post_title = $fn_post->post_title;
			$post_permalink = get_permalink($post_id);
			$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
			
			$post_image 	= get_the_post_thumbnail_url($post_id,'full');
			
			$hlight_text = '';
			if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
				$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
			}
			$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
			$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
			$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';

			if($post_image != ''){
				$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
			}else{
				$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
			}

			$post_date = '<div class="date_holder"><span class="dleft_dec"></span><span class="dright_dec"></span><span class="day">'.get_the_date('d', $post_id).'</span><span class="date"><span class="month">'.get_the_date('M', $post_id).'</span><span class="year">'.get_the_date('Y', $post_id).'</span></div>';

			$title_holder = '<div class="title_holder"><div class="title_top">'.$post_title.$image_holder.'</div><div class="title_bottom"><div class="tb_left">'.$post_date.'</div><div class="tb_right">'.$post_excerpt.$read_more.'</div></div></div>';

			if($slider_switcher){$html .= '<div class="swiper-slide">';}
			$html .= '<div class="mcarousel_item">'.$image_holder.'<div class="container"><div class="mcarousel__item_wrap"><div class="mcarousel__item">'.$title_holder.'</div></div></div></div>';
			if($slider_switcher){$html .= '</div>';}
			wp_reset_postdata();
		}
		if($slider_switcher){$html .= '</div></div>'.$slider_nav.'</div>';}
		$html .= '</div>';
	}

	$html .= '</div>';

	$html .= '</div>';

	return $html;
}

function mow_fn_post__yota($loop,$settings){
	if($settings['posts_recent_filter_switcher'] == 'yes'){
		$widget_title_holder = '<div class="fn__widget_filters"><a href="#" class="active" data-class="first_item">'.$filter_left_text.'</a><a href="#" data-class="second_item">'.$filter_right_text.'</a></div>';
	}else{
		$widget_title_holder = '';
	}
	$hlight_switcher = $settings['hlight_switcher'];
	if($hlight_switcher == 'yes'){
		$hlight_list = $settings['hlight_list'];
	}
	$hlight_type = '';
	if(isset($settings['hlight_type']) && $settings['hlight_type'] == 'separated'){
		$hlight_type = 'data-outside';
	}
	$meta_display = array();
	if(isset($settings['meta_display'])){
		$meta_display = $settings['meta_display'];
	}
	$html = '<div class="fn__widget_posts_yota" data-layout="'.$settings['layout'].'"><div class="container"><div class="fn__widget_posts_yota_in">';
	$html .= $widget_title_holder;
	$html .= '<div class="fn__widget_filter_content">';

	// first list
	$html .= '<div class="first_item yota_items active">';

	$firstCol = $secondCol = '';
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id = $fn_post->ID;
		$post_title = $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta = ($settings['meta_switcher'] == 'yes') ? mow_fn_metas(array('post_id' => $post_id, 'meta_display' => $meta_display)) : '';
		
		$post_image 	= get_the_post_thumbnail_url($post_id,'full');
		
		$hlight_text = '';
		if(isset($hlight_list[$key]) && $hlight_list[$key]['hlight_text'] != ''){
			$hlight_text = '<span class="fn__hlight_text" '.$hlight_type.'><span>'.$hlight_list[$key]['hlight_text'].'</span></span>';
		}
		$post_title = '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$hlight_text.$post_title.'</a></h3>';
		$post_excerpt = ($settings['excerpt_switcher'] == 'yes') ? '<p class="fn__descr">'.mow_fn_excerpt($post_id).'</p>' : '';
		$read_more = ($settings['read_more_switcher'] == 'yes') ? '<div class="fn__read_more"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"><span class="text" aria-label="'.$settings['read_more_text'].'">'.$settings['read_more_text'].'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>' : '';
		$gallery_count = mow_fn_gallery_count($post_id);
		$gallery_count .= mow_fn_get_rating_number($post_id, 's');
		if($key == 0){$activeClass = ' active';}else{$activeClass = '';}


		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="color_overlay"></div><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$gallery_count.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="color_overlay"></div><div class="item_space">'.$gallery_count.'<a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}

		$title_holder = '<div class="title_holder"><div class="title_holder_in">'.$post_meta.$post_title.$post_excerpt.$read_more.'</div></div>';

		$firstCol .= '<div class="item'.$activeClass.'">'.$image_holder.$title_holder.'</div>';
		$secondCol .= '<div class="item'.$activeClass.'">'.$image_holder.$title_holder.'</div>';

		wp_reset_postdata();
	}

	$icon = mow_fn_svg('svg__arrow_4');
	$navButtons = '<div class="nav-buttons"><div class="prev-button fn__link">'.$icon.'</div><div class="next-button fn__link">'.$icon.'</div></div>';
	if($firstCol != ''){
		$firstCol = '<div class="col_primary"><div class="col_in">'.$firstCol.'</div></div>';
	}
	if($secondCol != ''){
		$secondCol = '<div class="col_secondary"><div class="col_in"><div class="col_inn">'.$secondCol.'</div>'.$navButtons.'</div></div>';
	}


	$html .= $firstCol;
	$html .= $secondCol;


	$html .= '</div>';
	$html .= '</div>';
	
	$html .= '</div></div></div>';

	return $html;
}



function mow_fn_get_dynamic_sidebar_content($sidebar_id){
	ob_start();
    if (is_active_sidebar($sidebar_id)) {
        dynamic_sidebar($sidebar_id);
    }
    $sidebar_content = ob_get_clean();
    return $sidebar_content;
}

function mow_fn_ajax_menu_posts_list(){
	check_ajax_referer( 'mow-secure', 'security' );
	$prev = $next = 'disabled';

	// category id
	$cat_id 			= '';
	if(!empty($_POST['cat_id'])){
		$cat_id 		= sanitize_text_field($_POST['cat_id']);
	}

	// page
	$page 				= 1;
	if(!empty($_POST['page'])){
		$page 			= sanitize_text_field($_POST['page']);
	}

	// count
	$count 				= 5;
	if(!empty($_POST['count'])){
		$count 			= sanitize_text_field($_POST['count']);
	}

	$args = array(
		'cat' 				=> $cat_id,
		'posts_per_page' 	=> $count,
		'paged' 			=> $page
	);
	
	$query = new \WP_Query($args);

	$content = '';

	if ($query->have_posts()) {
		while ($query->have_posts()) { $query->the_post();
			$post_id 		= get_the_ID();
			$thumbnail 		= get_the_post_thumbnail_url( $post_id, 'large' );
			$postPermalink 	= get_permalink( $post_id );
			$postTitle		= get_the_title();
			$full_link 		= '<a href="'.$postPermalink.'" class="fn__full_link" aria-label="'.esc_attr($postTitle).'"></a>';
			if( $thumbnail ){
				$img = '<div class="img">'.$full_link.'<img loading="lazy" src="'.$thumbnail.'" alt="'.esc_attr($postTitle).'"></div>';
			}else{
				$img = '<div class="overlay_t">'.$full_link.'<div class="overlay_t_in"></div>' . mb_substr($postTitle, 0, 1) . '</div>';
			}
			$title_holder = '<div class="title_holder">'.mow_fn_metas(array('post_id' => $post_id)).'<h4 class="post_title fn__limited_title"><span><a href="'.$postPermalink.'" aria-label="'.esc_attr(strip_tags($postTitle)).'">'.$postTitle.'</a></span></h4></div>';
			$content .= '<li><div class="item">'.$img.$title_holder.'</div></li>';
		}
	} else {
		$error_message = 'No posts found';
	}
	$args['paged'] = ($page+1);
	$query = new \WP_Query($args);
	if ($query->have_posts()) {
		$next = '';
	}
	if($page != 1){
		$prev = '';
	}
	
	// Restore original post data
	wp_reset_postdata();


	$buffyArray = array(
		'content' 	=> $content,
		'prev' 		=> $prev,
		'next' 		=> $next,
		'paged' 	=> $page+1,
	);

	die(wp_json_encode($buffyArray));
}

function mow_fn_footer_social($echo = false){
	global $mow_fn_option;
	$limit = 5;
	
	$socialHTML = '';
	$socialList = '';
	$social_switcher = false;
	if(isset($mow_fn_option['footer_social_switcher'])){
		$social_switcher = $mow_fn_option['footer_social_switcher'];
	}
	if($social_switcher){
		$socialPosition 		= array();
		if(isset($mow_fn_option['social_position'])){
			$socialPosition 	= $mow_fn_option['social_position'];
		}
		$socialHTML				= '';
		$i = 0;
		foreach($socialPosition as $key => $sPos){
			if($sPos == 1){
				if(isset($mow_fn_option[$key.'_url']) && $mow_fn_option[$key.'_url'] != ''){
					$text = $key;
					if($key == 'twitter'){
						$text = esc_html__('X Network', 'mow');
					}	
					$socialItem = '<li>
						<a href="'.esc_url($mow_fn_option[$key.'_url']).'" target="_blank" aria-label="'.esc_attr($text).'">
							<span class="icon">
								'.mow_fn_svg($key,'reg_svg').'
								'.mow_fn_svg($key,'hov_svg').'
							</span>
							<span class="text">'.esc_html($text).'</span>
						</a>
					</li>';
					$socialList .= $socialItem;
				}
			}
		}

		if($socialList != ''){
			$socialHTML .= '<div class="mow_fn_footer_social_list"><div class="container"><div class="social_in">';
			$socialHTML .= '<div class="social_list"><ul>'.$socialList.'</ul></div>';
			$socialHTML .= '</div></div></div>';
		}
	}
	if($echo){
		echo wp_kses($socialHTML, 'post');
	}else{
		return $socialHTML;
	}
}

function mow_fn_fixed_social($echo = false){
	global $mow_fn_option;
	
	$socialHTML = $has_title = $title = $socialList = '';
	$social_switcher = false;
	if(isset($mow_fn_option['fixed_social_switcher'])){
		$social_switcher = $mow_fn_option['fixed_social_switcher'];
	}
	if($social_switcher){
		$fixed_social_title_switcher = true;
		if(isset($mow_fn_option['fixed_social_title_switcher'])){
			$fixed_social_title_switcher = $mow_fn_option['fixed_social_title_switcher'];
		}
		$socialPosition 		= array();
		if(isset($mow_fn_option['social_position'])){
			$socialPosition 	= $mow_fn_option['social_position'];
		}
		$socialHTML				= '';
		foreach($socialPosition as $key => $sPos){
			if($sPos == 1){
				if(isset($mow_fn_option[$key.'_url']) && $mow_fn_option[$key.'_url'] != ''){
					$socialItem = '<li>
						<a href="'.esc_url($mow_fn_option[$key.'_url']).'" target="_blank" aria-label="'.esc_attr($key).'">
							<span class="icon">
								'.mow_fn_svg($key,'hov_svg').'
							</span>
							<span class="text">'.esc_html($key).'</span>
						</a>
					</li>';
					$socialList .= $socialItem;
				}
			}
		}

		if($socialList != ''){
			if($fixed_social_title_switcher){
				$fixed_social_title = esc_html__('Follow', 'mow');
				if(isset($mow_fn_option['fixed_social_title'])){
					$fixed_social_title = $mow_fn_option['fixed_social_title'];
				}
				if($fixed_social_title != ''){
					$has_title = 'has_title';
					$title = '<span class="title">'.$fixed_social_title.'</span>';
				}
			}
			$socialHTML .= '<div class="mow_fn_fixed_social_list '.$has_title.'">';
			$socialHTML .= $title;
			$socialHTML .= '<ul>'.$socialList.'</ul>';
			$socialHTML .= '</div>';
		}
	}
	if($echo){
		echo wp_kses($socialHTML, 'post');
	}else{
		return $socialHTML;
	}
}

function mow_fn_get_page_ID($value = 'page-hot', $link = false){
	$query_args = array(
		'post_type'		=> 'page',
		'post_status' 	=> 'publish',
		'posts_per_page' => 1,
		'meta_query' => array(
			array(
				'key' => '_wp_page_template',
				'value' => $value.'.php'
			)
		)
	);
	$loop = new \WP_Query( $query_args );
	$ID = '';
	foreach ( $loop->posts as $fn_post ) {
		setup_postdata( $fn_post );
		$ID = $fn_post->ID;
		wp_reset_postdata();
	}
	if($link){
		return esc_url(get_permalink($ID));
	}else{
		return $ID;
	}
}

function mow_fn_get_ads($ads, $echo = false){
	global $mow_fn_option;
	$output = '';
	$prefix = 'ads_'.$ads.'_';
	if($ads == 'off_canvas'){
		// get off-canvas ads
		if(isset($mow_fn_option[$prefix.'switcher']) && ($mow_fn_option[$prefix.'switcher'] == 'enable' || isset($_GET['frenify_ads']))){
			$type = $mow_fn_option[$prefix.'type'];
			if($type == 'custom_banner'){
				if($mow_fn_option[$prefix.'cb_image']['url']!= '' ){
					$output .= '<img loading="lazy" src="'.$mow_fn_option[$prefix.'cb_image']['url'].'" width="'.$mow_fn_option[$prefix.'cb_image']['width'].'" height="'.$mow_fn_option[$prefix.'cb_image']['height'].'">';
					if($mow_fn_option[$prefix.'cb_link'] != ''){
						$output = '<a href="'.$mow_fn_option[$prefix.'cb_link'].'" target="'.$mow_fn_option[$prefix.'cb_target'].'" aria-label="'.esc_attr__('Click to view advertisement', 'mow').'">' . $output . '</a>';
					}
				}
			}else if($type == 'google_ads'){
				if($mow_fn_option[$prefix.'ga_area'] != '' ){
					$output = $mow_fn_option[$prefix.'ga_area'];
				}
			}
			if(isset($mow_fn_option[$prefix.'title_switcher']) && $mow_fn_option[$prefix.'title_switcher'] == 'enable' && isset($mow_fn_option[$prefix.'title']) && $mow_fn_option[$prefix.'title'] != ''){
				$output = '<div class="ad_title"><h3>'.$mow_fn_option[$prefix.'title'].'</h3></div>'.$output;
			}
			if($output != ''){
				$output = '<div class="mow_fn_banner__off_canvas"><div class="mow_fn_banner__off_canvas_in">'.$output.'</div></div>';
			}
		}
	}else if($ads == 'header_below'){
		// get off-canvas ads
		if(isset($mow_fn_option[$prefix.'switcher']) && ($mow_fn_option[$prefix.'switcher'] == 'enable' || isset($_GET['frenify_ads'])) ){
			$type = $mow_fn_option[$prefix.'type'];
			if($type == 'custom_banner'){
				if($mow_fn_option[$prefix.'cb_image']['url']!= '' ){
					$output .= '<img loading="lazy" src="'.$mow_fn_option[$prefix.'cb_image']['url'].'" width="'.$mow_fn_option[$prefix.'cb_image']['width'].'" height="'.$mow_fn_option[$prefix.'cb_image']['height'].'">';
					if($mow_fn_option[$prefix.'cb_link'] != ''){
						$output = '<a href="'.$mow_fn_option[$prefix.'cb_link'].'" target="'.$mow_fn_option[$prefix.'cb_target'].'" aria-label="'.esc_attr__('Click to view advertisement', 'mow').'">' . $output . '</a>';
					}
				}
			}else if($type == 'google_ads'){
				if($mow_fn_option[$prefix.'ga_area'] != '' ){
					$output = $mow_fn_option[$prefix.'ga_area'];
				}
			}
			if(isset($mow_fn_option[$prefix.'title_switcher']) && $mow_fn_option[$prefix.'title_switcher'] == 'enable' && isset($mow_fn_option[$prefix.'title']) && $mow_fn_option[$prefix.'title'] != ''){
				$output = '<div class="ad_title"><h3>'.$mow_fn_option[$prefix.'title'].'</h3></div>'.$output;
			}
			if($output != ''){
				$output = '<div class="mow_fn_banner__header_below"><div class="container"><div class="mow_fn_banner__header_below_in">'.$output.'</div></div></div>';
			}
		}
	}else if($ads == 'listpost_btwn'){
		// get off-canvas ads
		if(isset($mow_fn_option[$prefix.'switcher']) && ($mow_fn_option[$prefix.'switcher'] == 'enable' || isset($_GET['frenify_ads'])) ){
			$type = $mow_fn_option[$prefix.'type'];
			if($type == 'custom_banner'){
				if($mow_fn_option[$prefix.'cb_image']['url']!= '' ){
					$output .= '<img loading="lazy" src="'.$mow_fn_option[$prefix.'cb_image']['url'].'" width="'.$mow_fn_option[$prefix.'cb_image']['width'].'" height="'.$mow_fn_option[$prefix.'cb_image']['height'].'">';
					if($mow_fn_option[$prefix.'cb_link'] != ''){
						$output = '<a href="'.$mow_fn_option[$prefix.'cb_link'].'" target="'.$mow_fn_option[$prefix.'cb_target'].'" aria-label="'.esc_attr__('Click to view advertisement', 'mow').'">' . $output . '</a>';
					}
				}
			}else if($type == 'google_ads'){
				if($mow_fn_option[$prefix.'ga_area'] != '' ){
					$output = $mow_fn_option[$prefix.'ga_area'];
				}
			}
			if(isset($mow_fn_option[$prefix.'title_switcher']) && $mow_fn_option[$prefix.'title_switcher'] == 'enable' && isset($mow_fn_option[$prefix.'title']) && $mow_fn_option[$prefix.'title'] != ''){
				$output = '<div class="ad_title"><h3>'.$mow_fn_option[$prefix.'title'].'</h3></div>'.$output;
			}
			if($output != ''){
				$output = '<div class="mow_fn_banner__listpost_btwn"><div class="container"><div class="mow_fn_banner__listpost_btwn_in">'.$output.'</div></div></div>';
			}
		}
	}else if($ads == 'singlepost_in'){
		// get off-canvas ads
		if(isset($mow_fn_option[$prefix.'switcher']) && ($mow_fn_option[$prefix.'switcher'] == 'enable' || isset($_GET['frenify_ads'])) ){
			$type = $mow_fn_option[$prefix.'type'];
			if($type == 'custom_banner'){
				if($mow_fn_option[$prefix.'cb_image']['url']!= '' ){
					$output .= '<img loading="lazy" src="'.$mow_fn_option[$prefix.'cb_image']['url'].'" width="'.$mow_fn_option[$prefix.'cb_image']['width'].'" height="'.$mow_fn_option[$prefix.'cb_image']['height'].'">';
					if($mow_fn_option[$prefix.'cb_link'] != ''){
						$output = '<a href="'.$mow_fn_option[$prefix.'cb_link'].'" target="'.$mow_fn_option[$prefix.'cb_target'].'" aria-label="'.esc_attr__('Click to view advertisement', 'mow').'">' . $output . '</a>';
					}
				}
			}else if($type == 'google_ads'){
				if($mow_fn_option[$prefix.'ga_area'] != '' ){
					$output = $mow_fn_option[$prefix.'ga_area'];
				}
			}
			if(isset($mow_fn_option[$prefix.'title_switcher']) && $mow_fn_option[$prefix.'title_switcher'] == 'enable' && isset($mow_fn_option[$prefix.'title']) && $mow_fn_option[$prefix.'title'] != ''){
				$output = '<div class="ad_title"><h3>'.$mow_fn_option[$prefix.'title'].'</h3></div>'.$output;
			}
			if($output != ''){
				$output = '<div class="mow_fn_banner__singlepost_in"><div class="container"><div class="mow_fn_banner__singlepost_in_in">'.$output.'</div></div></div>';
			}
		}
	}else if($ads == 'singlepost_after'){
		// get off-canvas ads
		if(isset($mow_fn_option[$prefix.'switcher']) && ($mow_fn_option[$prefix.'switcher'] == 'enable' || isset($_GET['frenify_ads'])) ){
			$type = $mow_fn_option[$prefix.'type'];
			if($type == 'custom_banner'){
				if($mow_fn_option[$prefix.'cb_image']['url']!= '' ){
					$output .= '<img loading="lazy" src="'.$mow_fn_option[$prefix.'cb_image']['url'].'" width="'.$mow_fn_option[$prefix.'cb_image']['width'].'" height="'.$mow_fn_option[$prefix.'cb_image']['height'].'">';
					if($mow_fn_option[$prefix.'cb_link'] != ''){
						$output = '<a href="'.$mow_fn_option[$prefix.'cb_link'].'" target="'.$mow_fn_option[$prefix.'cb_target'].'" aria-label="'.esc_attr__('Click to view advertisement', 'mow').'">' . $output . '</a>';
					}
				}
			}else if($type == 'google_ads'){
				if($mow_fn_option[$prefix.'ga_area'] != '' ){
					$output = $mow_fn_option[$prefix.'ga_area'];
				}
			}
			if(isset($mow_fn_option[$prefix.'title_switcher']) && $mow_fn_option[$prefix.'title_switcher'] == 'enable' && isset($mow_fn_option[$prefix.'title']) && $mow_fn_option[$prefix.'title'] != ''){
				$output = '<div class="ad_title"><h3>'.$mow_fn_option[$prefix.'title'].'</h3></div>'.$output;
			}
			if($output != ''){
				$output = '<div class="mow_fn_banner__singlepost_after"><div class="container"><div class="mow_fn_banner__singlepost_after_in">'.$output.'</div></div></div>';
			}
		}
	}else if($ads == 'footer_above'){
		// get off-canvas ads
		if(isset($mow_fn_option[$prefix.'switcher']) && ($mow_fn_option[$prefix.'switcher'] == 'enable' || isset($_GET['frenify_ads'])) ){
			$type = $mow_fn_option[$prefix.'type'];
			if($type == 'custom_banner'){
				if($mow_fn_option[$prefix.'cb_image']['url']!= '' ){
					$output .= '<img loading="lazy" src="'.$mow_fn_option[$prefix.'cb_image']['url'].'" width="'.$mow_fn_option[$prefix.'cb_image']['width'].'" height="'.$mow_fn_option[$prefix.'cb_image']['height'].'">';
					if($mow_fn_option[$prefix.'cb_link'] != ''){
						$output = '<a href="'.$mow_fn_option[$prefix.'cb_link'].'" target="'.$mow_fn_option[$prefix.'cb_target'].'" aria-label="'.esc_attr__('Click to view advertisement', 'mow').'">' . $output . '</a>';
					}
				}
			}else if($type == 'google_ads'){
				if($mow_fn_option[$prefix.'ga_area'] != '' ){
					$output = $mow_fn_option[$prefix.'ga_area'];
				}
			}
			if(isset($mow_fn_option[$prefix.'title_switcher']) && $mow_fn_option[$prefix.'title_switcher'] == 'enable' && isset($mow_fn_option[$prefix.'title']) && $mow_fn_option[$prefix.'title'] != ''){
				$output = '<div class="ad_title"><h3>'.$mow_fn_option[$prefix.'title'].'</h3></div>'.$output;
			}
			if($output != ''){
				$output = '<div class="mow_fn_banner__footer_above"><div class="container"><div class="mow_fn_banner__footer_above_in">'.$output.'</div></div></div>';
			}
		}
	}
	if($echo){
		echo wp_kses($output, 'post');
	}else{
		return $output;
	}
}

function mow_fn_remove_item_from_cart(){
	check_ajax_referer( 'mow-secure', 'security' );
	global $mow_fn_option,$woocommerce;
	$isAjaxCall 	= true;
	$pageFrom		= '';
	if(isset($_POST['pageFrom'])){
		$pageFrom	= sanitize_text_field($_POST['pageFrom']);
	}
	$cart		 	= WC()->instance()->cart;
	$id 			= sanitize_text_field($_POST['product_id']);
	if($id != ''){
		$cart_id 		= $cart->generate_cart_id($id);
		$cart_item_id 	= $cart->find_product_in_cart($cart_id);

		if($cart_item_id){
		   $cart->set_quantity($cart_item_id,0);
		}
	}
	
	// get cartbox
	$cartBox		= mow_fn_getCartBox('yes',$pageFrom);
	
	$newCount		= $woocommerce->cart->cart_contents_count;
	
	
	// remove whitespaces form the ajax HTML
	$search = array(
		'/\>[^\S ]+/s',  // strip whitespaces after tags, except space
		'/[^\S ]+\</s',  // strip whitespaces before tags, except space
		'/(\s)+/s'       // shorten multiple whitespace sequences
	);
	$replace = array(
		'>',
		'<',
		'\\1'
	);
	$cartBox 	= preg_replace($search, $replace, $cartBox);
	
	$icon = '<span class="icon"><span class="fn__tooltip">' . esc_html__('Update','mow') . '</span>' . mow_fn_svg('update') . '</span>';
	$updateContent = '<div class="woo_updater"><div class="fn_cartbox_updatebox"><a href="#" class="fn_cartbox_updater" aria-label="'.esc_attr__('Update WooCommerce Cart', 'mow').'"></a><p>'.$icon.esc_html__('The cart has been changed somewhere. Please. update the cart.','mow').'</p></div></div>';

	$buffyArray = array(
        'mow_fn_data' 			=> $cartBox,
        'count' 				=> $newCount,
        'update' 				=> $updateContent,
    );


    if ( true === $isAjaxCall ) 
	{
        die(json_encode($buffyArray));
    } 
	else 
	{
        return json_encode($buffyArray);
    }
	
}


function mow_fn_switcher_woo(){
	global $mow_fn_option;
	$woo_bar = class_exists('Woocommerce') ? 'enable' : 'disable';
	if (!empty($mow_fn_option['woo_btn_switcher']) && $mow_fn_option['woo_btn_switcher'] === 'disable') {
		$woo_bar = 'disable';
	}
	return $woo_bar;
}

function mow_fn_getCartBox($in = '', $pageFrom = '',$echo = false){
	global $woocommerce;
	$items = $woocommerce->cart->get_cart();
	
	$html	= '<div class="mow_fn_cartbox">';
	if($in == 'yes'){
		$html = '';
	}
	
	if(!empty($items)){
		$subTotalText 		= esc_html__('Subtotal:', 'mow');
		$deleteItemText		= esc_html__('Remove this product from the cart', 'mow');
		$cartURL			= '<a class="fn_cart_url" href="'.esc_url( wc_get_cart_url() ).'" aria-label="'.esc_attr__('View WooCommerce Cart', 'mow').'">'.esc_html__('View Cart', 'mow').'</a>';
		$checkoutURL		= '<a class="fn_checkout_url" href="'.esc_url( wc_get_checkout_url() ).'" aria-label="'.esc_attr__('WooCommerce Checkout', 'mow').'">'.esc_html__('Checkout', 'mow').'</a>';
		
		$html .= '<div class="fn_cartbox">';
		$list	= '<div class="fn_cartbox_top"><div class="fn_cartbox_list">';
		$compare = '<div class="woo__compare">';
		foreach($items as $item => $values) {
			$productID			= $values['product_id'];
			$_product 			= wc_get_product( $values['data']->get_id() );
			$getProductDetail 	= wc_get_product( $productID );
			$image				= $getProductDetail->get_image();
			$quantity			= $values['quantity'];
			$title				= $_product->get_title();
			$productURL			= get_permalink($productID);
			$price 				= wc_price(get_post_meta($productID , '_price', true));
			$priceHolder 		= '<span class="fn_cartbox_item_price">'.$quantity . " x " . $price.'</span>';
			$titleHolder		= '<span class="fn_cartbox_item_title"><a href="'.$productURL.'">'.$title.'</a></span>';
			$deleteItem 		= '<a href="'.wc_get_cart_remove_url( $item ).'" class="fn_cartbox_delete_item" title="'.$deleteItemText.'" aria-label="'.esc_attr__('Remove this product from the cart', 'mow').'">x</a>';
			
			if((is_cart() || is_checkout()) || $pageFrom != ''){
				$deleteItem = '';
			}
			$compare .= $productID.'_'.strip_tags($quantity).'_'.strip_tags($price).'.';
			
			
			$list .= '<div class="fn_cartbox_item" data-id="'.$productID.'" data-key="'.$item.'"><a class="full_link" href="'.$productURL.'"></a>';
				$list .= '<div class="fn_cartbox_item_img"><a href="'.$productURL.'">'.$image.'</a></div>';
				$list .= '<div class="fn_cartbox_item_title">'.$titleHolder.$priceHolder.$deleteItem.'</div>';
			$list .= '</div>';
		}
		$list .= '</div></div>';
		
		// footer
		$subTotalPrice = $woocommerce->cart->get_cart_subtotal();
		$footer	 = '<div class="fn_cartbox_footer">';
		
			$footer	.= '<div class="fn_cartbox_subtotal">';
			$footer	.= '<span class="fn_left">'.$subTotalText.'</span>';
			$footer	.= '<span class="fn_right">'.$subTotalPrice.'</span>';
			$footer	.= '</div>';
		
			$footer	.= '<div class="fn_cartbox_links">';
			$footer	.= '<span class="fn_top">'.$cartURL.'</span>';
			$footer	.= '<span class="fn_bottom">'.$checkoutURL.'</span>';
			$footer	.= '</div>';
		
		$footer	.= '</div>';
		
		$compare .= '</div>';
		
		$html .= $list;
		$html .= $footer;
		$html .= $compare;
		$html	.= '</div>';
		if($in == 'yes'){
			
		}else{
			$html	.= '</div>';
		}
		
	}else{
		$icon = '<span class="icon"><span class="fn__tooltip">' . esc_html__('Shop','mow') . '</span>' . mow_fn_svg('bag') . '</span>';
		$returnToShop 	= '<a href="'.get_permalink( wc_get_page_id( 'shop' ) ).'" aria-label="'.esc_attr__('Visit Shop Page', 'mow').'"></a>';
		$emptyText		= esc_html__('Your cart is currently is empty. You could visit our shop and start shopping.', 'mow');
		$html .= '<div class="fn_cartbox_empty">'.$returnToShop.'<p>'.$icon.$emptyText.'</p></div>';
		if($in == 'yes'){
			
		}else{
			$html	.= '</div>';
		}
	}
	
	if($echo){
		echo wp_kses($html,'post');
	}else{
		return $html;
	}
	
}
		
add_action( 'comment_form_before', 'mow_fn_comment_form_before_action' );

function mow_fn_comment_form_before_action(){
	?><div class="respond_comment"><?php 
}
		
add_action( 'comment_form_after', 'mow_fn_comment_form_after_action' );

function mow_fn_comment_form_after_action(){
	?></div><?php 
}


function mow_fn_hex2rgba($color, $opacity = false) {
 
	$default = 'rgb(0,0,0)';
 
	//Return default if no color provided
	if(empty($color)){
		return $default;
	}
          
 
	//Sanitize $color if "#" is provided 
	if ($color[0] == '#' ) {
		$color = substr( $color, 1 );
	}
 
	//Check if color has 6 or 3 characters and get values
	if (strlen($color) == 6) {
		$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
	} elseif ( strlen( $color ) == 3 ) {
		$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
	} else {
		return $default;
	}
 
	//Convert hexadec to rgb
	$rgb =  array_map('hexdec', $hex);

	//Check if opacity is set(rgba or rgb)
	if($opacity){
		if(abs($opacity) > 1){
			$opacity = 1.0;
		}
		$output = 'rgba('.implode(",",$rgb).','.$opacity.')';
	} else {
		$output = 'rgb('.implode(",",$rgb).')';
	}

	//Return rgb(a) color string
	return $output;
}

function mow_fn_new_link_post(){
	check_ajax_referer( 'mow-secure', 'security' );

	
	// Handle the external image URL
	if (!empty($_FILES['image_file']['tmp_name'])) {
        // Handle file upload
        $uploaded_file = $_FILES['image_file'];

        // Upload the file to WordPress
        $attachment_id = media_handle_upload('image_file', 0);
    }elseif (!empty($_POST['image_url']) && $_POST['image_url'] != '') {
		$image_url = esc_url_raw($_POST['image_url']);

		// Download the image to the WordPress server
		$tmp = download_url($image_url);

		if (!is_wp_error($tmp)) {
			// Set up the attachment
			$file_array = array(
				'name' => basename($image_url),
				'tmp_name' => $tmp
			);
			// Upload the image to WordPress
			$attachment_id = media_handle_sideload($file_array, 0);
		}
	}

	// Prepare other form data for the post
	$title 			= sanitize_text_field($_POST['title']);
	$description 	= sanitize_textarea_field($_POST['description']);
	$link 			= esc_url_raw($_POST['link']);
	$content 		= '<a href="' . esc_url($link) . '" class="fn__external_link" rel="noopener noreferrer">' . esc_html($link) . '</a>';

	$post_data = array(
		'post_title'    => $title,
		'post_content'  => $content,
		'post_excerpt'  => $description,
		'post_status'   => 'pending',
		'post_author'   => get_current_user_id(),
		'post_type'     => 'post',
	);
	// if (!empty($_POST['tags']) && is_array($_POST['tags'])) {
	// 	$post_data['tags_input'] = array_map('sanitize_text_field', $_POST['tags']);
	// }
	if($attachment_id){
		$post_data['meta_input'] = array( '_thumbnail_id' => $attachment_id	);
	}
	// if (!empty($_POST['categories']) && is_array($_POST['categories'])) {
	// 	$post_data['post_category'] = array_map('intval', $_POST['categories']);
	// }

	// Insert the post
	$post_id = wp_insert_post($post_data);

	if ($post_id && !is_wp_error($post_id)) {
		set_post_format($post_id, 'link');

		// Assign tags
		if (!empty($_POST['tags'])) {
			wp_set_post_tags($post_id, $_POST['tags'], false);
		}
	
		// Assign categories
		if (!empty($_POST['categories'])) {
			wp_set_post_categories($post_id, $_POST['categories'], false);
		}

		$msg = __('Your submission has been successfully sent for review.<br>Thank you for contributing!', 'mow');
		$message = '<div class="step4_link"><div class="step_success"><span class="icon">'.mow_fn_svg('svg__success').'</span><h3 class="heading">'.esc_html__('Successfull', 'mow').'</h3><p class="message">'.wp_kses($msg,'post').'</p><p class="to_home"><a href="'.esc_url(home_url()).'">'.esc_html__('Back to homepage', 'mow').'</a></p></div></div>';
		wp_send_json_success(
			array(
				'message' => $message
			)
		);
	} else {
		$msg = __('There was an error submitting your post for review.<br>Please check your input and try again. If the issue persists, contact support.', 'mow');
		$message = '<div class="step4_link"><div class="step_error"><span class="icon">'.mow_fn_svg('svg__failed').'</span><h3 class="heading">'.esc_html__('Submission Failed', 'mow').'</h3><p class="message">'.wp_kses($msg,'post').'</p><p class="to_home"><a href="'.esc_url(home_url()).'">'.esc_html__('Back to homepage', 'mow').'</a></p></div></div>';
		wp_send_json_error(
			array(
				'message' => $message
			)
		);
	}
	
}

function mow_fn_allow_pending_listings($qry) {
    if (is_user_logged_in() && isset($_GET['p'])) {
        $user = wp_get_current_user();
        if (in_array('subscriber', (array) $user->roles, true)) {
            if (isset($_GET['p'])) {
                $post_id = intval($_GET['p']);
                $post = get_post($post_id);

                if ($post && $post->post_author == get_current_user_id()) {
                    $qry->set('post_status', array('publish', 'pending'));
                }
            }
        }
    }
}
add_action('pre_get_posts', 'mow_fn_allow_pending_listings');






function mow_fn_no_post(){
	return '<div class="fn__nopost_found"><p>'.esc_html__('No posts found matching your criteria', 'mow').'</p></div>';
}

function mow_fn_new_post_post(){
	check_ajax_referer( 'mow-secure', 'security' );
	
	// Handle the external image URL
	if (!empty($_FILES['image_file']['tmp_name'])) {
        // Handle file upload
        $uploaded_file = $_FILES['image_file'];

        // Upload the file to WordPress
        $attachment_id = media_handle_upload('image_file', 0);
    }elseif (!empty($_POST['image_url']) && $_POST['image_url'] != '') {
		$image_url = esc_url_raw($_POST['image_url']);

		// Download the image to the WordPress server
		$tmp = download_url($image_url);

		if (!is_wp_error($tmp)) {
			// Set up the attachment
			$file_array = array(
				'name' => basename($image_url),
				'tmp_name' => $tmp
			);
			// Upload the image to WordPress
			$attachment_id = media_handle_sideload($file_array, 0);
		}
	}

	// Prepare other form data for the post
	$title 			= sanitize_text_field($_POST['title']);
	$content 		= wp_kses_post($_POST['description']);

	preg_match_all('/<img[^>]+src="([^">]+)"/i', $content, $matches);

    $image_urls = $matches[1]; // The first capturing group contains the image URLs
    $updated_content = $content;

    foreach ($image_urls as $image_url) {
        // Download the image to the WordPress server
        $tmp = download_url($image_url);

        if (!is_wp_error($tmp)) {
            // Set up the attachment
            $file_array = array(
                'name' => basename($image_url),
                'tmp_name' => $tmp
            );

            // Upload the image to WordPress
            $attachment_id2 = media_handle_sideload($file_array, 0);

            // Check for errors during upload
            if (!is_wp_error($attachment_id2)) {
                // Get the URL of the uploaded image
                $new_image_url = wp_get_attachment_url($attachment_id2);

                // Replace the old image URL in the content with the new one
                $updated_content = str_replace($image_url, $new_image_url, $updated_content);
            } else {
                @unlink($tmp); // Delete the temporary file if there's an error
            }
        }
    }

	$post_data = array(
		'post_title'    => $title,
		'post_content'  => $updated_content,
		'post_excerpt'  => '',
		'post_status'   => 'pending',
		'post_author'   => get_current_user_id(),
		'post_type'     => 'post',
	);
	
	if($attachment_id){
		$post_data['meta_input'] = array( '_thumbnail_id' => $attachment_id	);
	}

	// Insert the post
	$post_id = wp_insert_post($post_data);

	if ($post_id && !is_wp_error($post_id)) {

		// Assign tags
		if (!empty($_POST['tags'])) {
			wp_set_post_tags($post_id, $_POST['tags'], false);
		}
	
		// Assign categories
		if (!empty($_POST['categories'])) {
			wp_set_post_categories($post_id, $_POST['categories'], false);
		}
		$msg = __('Your submission has been successfully sent for review.<br>Thank you for contributing!', 'mow');
		$message = '<div class="step3_post"><div class="step_success"><span class="icon">'.mow_fn_svg('svg__success').'</span><h3 class="heading">'.esc_html__('Successfull', 'mow').'</h3><p class="message">'.wp_kses($msg,'post').'</p><p class="to_home"><a href="'.esc_url(home_url()).'">'.esc_html__('Back to homepage', 'mow').'</a></p></div></div>';
		wp_send_json_success(
			array(
				'message' => $message
			)
		);
	} else {
		$msg = __('There was an error submitting your post for review.<br>Please check your input and try again. If the issue persists, contact support.', 'mow');
		$message = '<div class="step3_post"><div class="step_error"><span class="icon">'.mow_fn_svg('svg__failed').'</span><h3 class="heading">'.esc_html__('Submission Failed', 'mow').'</h3><p class="message">'.wp_kses($msg,'post').'</p><p class="to_home"><a href="'.esc_url(home_url()).'">'.esc_html__('Back to homepage', 'mow').'</a></p></div></div>';
		wp_send_json_error(
			array(
				'message' => $message
			)
		);
	}
	
}

function mow_fn_ajax_register(){
	check_ajax_referer( 'mow-secure', 'security' );
	
	$username = $email = $password = $confirm_password = '';
	if(!empty($_POST['username'])){
		$username = sanitize_text_field($_POST['username']);
	}
	if(!empty($_POST['email'])){
		$email = sanitize_text_field($_POST['email']);
	}
	if(!empty($_POST['password'])){
		$password = sanitize_text_field($_POST['password']);
	}
	if(!empty($_POST['confirm_password'])){
		$confirm_password = sanitize_text_field($_POST['confirm_password']);
	}
	
	$error = false;
	$error_message = '';
	
	if (empty($username) || empty($email) || empty($password) || empty($confirm_password)) {
		$error = true;
		// Handle empty fields error
		$error_message = esc_html__( 'All fields are required.', 'mow' );
	} elseif ($password != $confirm_password) {
		$error = true;
		// Handle password mismatch error
		$error_message = esc_html__( 'Passwords do not match.', 'mow' );
	} else {
		// Create new user
		$user_id = wp_create_user($username, $password, $email);
		if (!is_wp_error($user_id)) {
			// User created successfully
			$user = new WP_User( $user_id );
			$user->set_role( 'subscriber' );
			$error = 'logged';
			$credentials = array(
				'user_login'    => $email,
				'user_password' => $password,
				'remember'      => false
			);

			wp_signon($credentials);
			// Optionally, you can log the user in here
		} else {
			// Handle user creation error
			$error_message = sprintf( esc_html__( 'Error: ', 'mow' ), $user_id->get_error_message() );
		}
	}
	
	
	$buffyArray = array(
		'error' 		=> $error,
		'message' 		=> $error_message,
	);

	die(wp_json_encode($buffyArray));
}

function mow_fn_ajax_log_in(){
	check_ajax_referer( 'mow-secure', 'security' );
	
	$email = $password = '';
	$remember = 0;
	if(!empty($_POST['email'])){
		$email = sanitize_text_field($_POST['email']);
	}
	if(!empty($_POST['password'])){
		$password = sanitize_text_field($_POST['password']);
	}
	if(!empty($_POST['remember'])){
		$remember = sanitize_text_field($_POST['remember']);
	}
	if($remember == 1){
		$remember = true;
	}else{
		$remember = false;
	}

	$credentials = array(
		'user_login'    => $email,
		'user_password' => $password,
		'remember'      => $remember
	);

	$user = wp_signon($credentials);
	$error = false;
	$error_message = '';
	if (is_wp_error($user)) {
		$error = true;
		if ( $user->get_error_code() === 'invalid_username' ) {
			$error_message = esc_html__( 'Invalid username. Please try again.', 'mow' );
		} elseif ( $user->get_error_code() === 'incorrect_password' ) {
			// Error due to incorrect password
			$error_message = esc_html__( 'Incorrect password. Please try again.', 'mow' );
		} else {
			// Other authentication errors
			$error_message = esc_html__( 'Authentication error. Please try again.', 'mow' );
		}
	} else {
		$error = 'logged';
	}
	$buffyArray = array(
		'error' 		=> $error,
		'message' 		=> $error_message,
	);

	die(wp_json_encode($buffyArray));
}

function mow_fn_getYoutubeEmbedUrl($url = ''){
     $shortUrlRegex = '/youtu.be\/([a-zA-Z0-9_-]+)\??/i';
     $longUrlRegex = '/youtube.com\/((?:embed)|(?:watch))((?:\?v\=)|(?:\/))([a-zA-Z0-9_-]+)/i';

    if (preg_match($longUrlRegex, $url, $matches)) {
        $youtube_id = $matches[count($matches) - 1];
    }

    if (preg_match($shortUrlRegex, $url, $matches)) {
        $youtube_id = $matches[count($matches) - 1];
    }
    return 'https://www.youtube.com/embed/' . $youtube_id ;
}

function mow_fn_post__media($post_id){
	global $mow_fn_option;
	$output = $video_type = '';
	$post_format 		= get_post_format();
	$mediaID 			= get_post_thumbnail_id( $post_id );
	$thumbnail_url		= wp_get_attachment_image_src( $mediaID, 'full');
	if ($thumbnail_url) {
		$imageURL 		= $thumbnail_url[0];
	}
	if($post_format == 'gallery'){
		$single_gallery_type = 'slider';
		if(isset($mow_fn_option['single_gallery_type'])){
			$single_gallery_type = $mow_fn_option['single_gallery_type'];
		}
		if(isset(get_post_meta($post_id)['frenify_fn_postgallery']) && $single_gallery_type == 'slider'){
			$gallery = get_post_meta($post_id,'frenify_fn_postgallery', false);
			if(!empty($gallery)){
				
				$list = '';
				foreach ($gallery as $galleryID) {
					$image = wp_get_attachment_image_url($galleryID, 'full');
					if ($image !== '') {
						$list .= '<div class="swiper-slide"><div class="item" data-bg-img="' . esc_url($image) . '"></div></div>';
					}
				}
				if($list != ''){
					$output .= '<div class="fn__gallery_format"><div class="swiper"><div class="swiper-wrapper">';
					$output .= $list;
					$arrow = mow_fn_svg('arrow');
					$gallery_nav = '<div class="slider__nav"><a href="#" class="slider_nav prev" aria-label="'.esc_attr__('Previous Slide', 'mow').'">'.$arrow.'</a><a href="#" class="slider_nav next" aria-label="'.esc_attr__('Next Slide', 'mow').'">'.$arrow.'</a></div>';
					$output .= '</div></div></div>';
				}else{
					$post_format = '';
				}
			}else{
				$post_format = '';
			}
		}else{
			$post_format = '';
		}
	}else if($post_format == 'video'){
		$video_url = get_post_meta($post_id, 'frenify_fn_video_url', true);
		
		if($video_url != ''){
			$video_type = mow_fn_detect_video($video_url);
			if($video_type == 'local'){
				$output .= '<div class="fn__video_format"><video class="fn__video_local lazy-video" autoplay controls playsinline><source data-src="'.$video_url.'" type="video/mp4"></video></div>';
			}else if($video_type == 'youtube'){
				$output .= '<div class="fn__video_youtube_format"><iframe width="100%" height="700" src="'.mow_fn_getYoutubeEmbedUrl($video_url).'" frameborder="0" allowfullscreen></iframe></div>';
			}else{
				$post_format = '';
			}
		}else{
			$post_format = '';
		}
	}
	if(($post_format != 'gallery' && $post_format != 'video') && isset($imageURL)){
		
		$caption_show = 'none';
		if(isset($mow_fn_option['caption_show'])){
			$caption_show = $mow_fn_option['caption_show'];
		}
		$caption = '';
		if($caption_show == 'caption'){
			$caption = wp_get_attachment_caption($mediaID);
		}else if($caption_show == 'descripton'){
			$caption = get_post_field('post_content', $mediaID);
		}
		$img_info_text = '';
		if($caption != ''){
			$img_info_text = '<div class="fn__caption">'.$caption.'</div>';
		}
		$lightbox = 'enable';
		if(isset($mow_fn_option['single_post_lightbox'])){
			$lightbox = $mow_fn_option['single_post_lightbox'];
		}
		if($lightbox == 'enable'){
			$output = '<div class="fn__single_image_wrap fn__lg_lightbox"><div class="fn__single_image lightbox" data-src="'.$imageURL.'" data-sub-html="'.$caption.'">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</div>'.$img_info_text.'</div>';
		}else{
			$output = '<div class="fn__single_image_wrap"><div class="fn__single_image">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</div>'.$img_info_text.'</div>';
		}
		
	}
	return array('content' => $output, 'format' => $post_format, 'video_type' => $video_type);
}

function mow_fn_post__tags($post_id){
	$output = '';
	$post_tags = get_the_tags($post_id);
	$tags = '';
	if ( ! empty( $post_tags ) ) {
		foreach( $post_tags as $post_tag ) {
			$tags .= '<li class="tag_item"><a href="' . get_tag_link( $post_tag ) . '" aria-label="' . esc_attr__( 'View posts tagged with ', 'mow') . $post_tag->name . '">' . esc_attr(strip_tags($post_tag->name)) . '</a></li>';
		}
		$output .= '<div class="mow_fn_tags"><ul>'.$tags.'</ul></div>';
	}
	return $output;
}

function mow_fn_get_register_form(){
	global $mow_fn_option;
	$register = 'enable';
	if(isset($mow_fn_option['register'])){
		$register = $mow_fn_option['register'];
	}
	$default_logo = mow_fn_getLogo();

	$logo = '<a href="'.esc_url(home_url('/')).'" aria-label="'.esc_attr__('Back to homepage', 'mow').'">';
		$logo .= '<img loading="lazy" class="dark_logo" src="'.esc_url($default_logo[0][0]).'" alt="'.esc_attr__('logo', 'mow').'">';
		$logo .= '<img loading="lazy" class="light_logo" src="'.esc_url($default_logo[1][0]).'" alt="'.esc_attr__('logo', 'mow').'">';
	$logo .= '</a>';
	if(!is_user_logged_in()){
	?>
	<div class="mow_fn_register_popup">
		<div class="container">
			<div class="register_popup">
				<div class="register_box">

					<div class="loading">
						<div class="fn__preloader">
							<span class="icon"></span>
							<div class="text"><?php esc_html_e('Loading', 'mow'); ?></div>
						</div>
					</div>
					<div class="ready_in">
						<p class="inn"><?php echo sprintf( esc_html__( 'Signing-in %s seconds...', 'mow' ), '<span class="count">3</span>' ); ?></p>
						<?php if($register !== 'sign_in'){ ?>
						<p class="upp"><?php echo sprintf( esc_html__( 'Signing-up %s seconds...', 'mow' ), '<span class="count">3</span>' ); ?></p>
						<?php } ?>
					</div>

					<div class="register_header">
						<div class="fn__logo">
							<?php echo wp_kses($logo, 'post'); ?>
						</div>
						<a href="#" class="fn__popup_closer" aria-label="<?php esc_attr_e('Close Register Lightbox', 'mow'); ?>"><span></span></a>
					</div>
					

					<!-- Sign-In Form -->
					<div class="mow_fn_sign_in_form">
						
						<div class="error_field"></div>
						
						<div class="form">
							<form id="mow_fn_login_form" method="post">
								<div class="item item_email">
									<input placeholder="<?php esc_attr_e('Username or Email', 'mow'); ?>"  type="email" id="mow_fn_login_username" name="mow_fn_login_username" required>
								</div>
								<div class="item item_password">
									<input placeholder="<?php esc_attr_e('Password', 'mow'); ?>" type="password" id="mow_fn_login_password" name="mow_fn_login_password" required>
								</div>
								<div class="item item_remember">
									<div class="label">
										<label>
											<span class="fn__checkbox">
												<input type="checkbox" id="mow_fn_login_rememberme" name="mow_fn_login_rememberme" value="1">
												<span class="checkmark"></span>
											</span>
											<span class="text"><?php esc_html_e('Remember Me', 'mow'); ?></span>
										</label>
									</div>
								</div>
								<div class="item item_submit">
									<input type="submit" name="submit" value="<?php esc_attr_e('Sign In', 'mow'); ?>">
								</div>
								<?php if($register !== 'sign_in'){ ?>
								<div class="item item_sign_up">
									<p><?php esc_html_e('Not a member?', 'mow'); ?> <a class="mow_fn_sign_up_btn" href="#" aria-label="<?php esc_attr_e('Sign Up', 'mow'); ?>"><?php esc_html_e('Sign Up.', 'mow'); ?></a></p>
								</div>
								<?php } ?>
							</form>
						</div>
					</div>
					
					<!-- Sign-Up Form -->
					<?php if($register !== 'sign_in'){ ?>
					<div class="mow_fn_sign_up_form">
						<div class="error_field"></div>
						<div class="form">
							<form id="mow_fn_register_form" method="post">
								<div class="item item_username">
									<input placeholder="<?php esc_attr_e('Username', 'mow'); ?>" type="text" id="mow_fn_register_username" name="mow_fn_register_username" required>
								</div>
								<div class="item item_email">
									<input placeholder="<?php esc_attr_e('Email', 'mow'); ?>" type="email" id="mow_fn_register_email" name="mow_fn_register_email" required>
								</div>
								<div class="item item_password">
									<input placeholder="<?php esc_attr_e('Password', 'mow'); ?>" type="password" id="mow_fn_register_password" name="mow_fn_register_password" required>
								</div>
								<div class="item item_confirm_password">
									<input placeholder="<?php esc_attr_e('Confirm Password', 'mow'); ?>" type="password" id="mow_fn_register_confirm_password" name="mow_fn_register_confirm_password" required>
								</div>
								<div class="item item_submit">
									<input type="submit" name="submit" value="<?php esc_attr_e('Sign Up', 'mow'); ?>">
								</div>
								<div class="item item_sign_in">
									<p><?php esc_html_e('Have an account?', 'mow'); ?> <a class="mow_fn_sign_in_btn" href="#" aria-label="<?php esc_attr_e('Sign In', 'mow'); ?>"><?php esc_html_e('Sign In.', 'mow'); ?></a></p>
								</div>
							</form>
						</div>
					</div>
					<?php } ?>


				</div>
			</div>
		</div>
	</div>
	<?php 
	}
}

function mow_fn_get_register(){
	global $mow_fn_option;
	$register = 'enable';
	if(isset($mow_fn_option['register'])){
		$register = $mow_fn_option['register'];
	}
	$html = '';
	if($register != 'disable'){
		$register_after = 'enable';
		if(isset($mow_fn_option['register_after'])){
			$register_after = $mow_fn_option['register_after'];
		}
		if(is_user_logged_in()){
			if($register_after == 'enable'){
				$current_user   = wp_get_current_user();
				$user_id        = get_current_user_id();
				$user_name      = get_the_author_meta('display_name',$user_id);
				$archive_url    = get_author_posts_url( $user_id );
				$imageURL		= esc_url( get_the_author_meta( 'fn_user_media', $user_id ) );
				$imageData 		= wp_get_attachment_image_src(attachment_url_to_postid($imageURL), 'thumbnail');
				
				if ($imageData) {
					$imageURL	= $imageData[0];
				}
				if($imageURL == ''){
					$image      = get_avatar( $user_id, 60 );
				}else{
					$image      = '<img loading="lazy" src="'.esc_url($imageURL).'" alt="">';
				}
				$html = '<a class="register" href="'.esc_url($archive_url).'" aria-label="'.esc_attr__('See all posts by this author', 'mow').'">
					<span class="img">'.$image.'</span>
					<span class="t_text">'.$user_name.'</span>
				</a>';
			}
			
		}else{
			if($register == 'sign_in'){
				$tooltipText = esc_html__('Sign In', 'mow');
			}else{
				$tooltipText = esc_html__('Sign In/Sign Up', 'mow');
			}
			$html = '<a href="#" class="mow_fn_register_opener" aria-label="'.esc_attr($tooltipText).'">
						<span class="icon">'.mow_fn_svg('user').'</span>
						<span class="t_text">'.$tooltipText.'</span>
					</a>';
		}
	}
	
	echo wp_kses($html,'post');
}

function mow_fn_post__subscribe($post_id){
	global $mow_fn_option;
	$output = '';
	$single_subscribe_block = 'disable';
	if(isset($mow_fn_option['single_subscribe_block'])){
		$single_subscribe_block = $mow_fn_option['single_subscribe_block'];
	}
	if($single_subscribe_block == 'enable'){
		$single_subscribe_block_form = '';
		if(isset($mow_fn_option['single_subscribe_block_form'])){
			$single_subscribe_block_form = $mow_fn_option['single_subscribe_block_form'];
		}
		if($single_subscribe_block_form != ''){
			$shortcode = do_shortcode( shortcode_unautop( $single_subscribe_block_form ) );
			$output .= '<div class="fn__subscribe_block">';
			$output .= '<div class="sb_left"><h3>'.esc_html__('Stay Informed With the Latest & Most Important News', 'mow').'</h3></div>';
			$output .= '<div class="sb_right">'.$shortcode.'</div>';
			$output .= '<span class="sb_icon">'.mow_fn_svg('paperplane').'</span>';
			$output .= '</div>';
		}
	}
	
	return $output;
}

function mow_fn_post__related($post_id){
	global $mow_fn_option;
	$output = '';
	$single_related_posts = 'enable';
	if(isset($mow_fn_option['single_related_posts'])){
		$single_related_posts = $mow_fn_option['single_related_posts'];
	}
	if($single_related_posts == 'enable'){
		$output .= mow_fn_similar_posts($post_id);
	}
	return $output;
}

function mow_fn_post__gallery($post_id){
	global $mow_fn_option;
	$output = '';
	$single_gallery_type = 'slider';
	if(isset($mow_fn_option['single_gallery_type'])){
		$single_gallery_type = $mow_fn_option['single_gallery_type'];
	}
	$single_gallery_type = 'thumbnail';
	$post_format = get_post_format();
	if($single_gallery_type == 'thumbnail' && $post_format == 'gallery'){
		if(isset(get_post_meta($post_id)['frenify_fn_postgallery'])){
			$caption_show = 'none';
			if(isset($mow_fn_option['caption_show'])){
				$caption_show = $mow_fn_option['caption_show'];
			}
			$gallery = get_post_meta($post_id,'frenify_fn_postgallery', false);
			if(!empty($gallery)){
				$output .= '<div class="fn__gallery_thumbs fn__lg_lightbox"><div class="items">';
				
				foreach($gallery as $galleryID){
					$caption = '';
					if($caption_show == 'caption'){
						$caption = wp_get_attachment_caption($galleryID);
					}else if($caption_show == 'descripton'){
						$caption = get_post_field('post_content', $galleryID);
					}
					$output .= '<div class="item lightbox" data-src="'.wp_get_attachment_image_url($galleryID,'full').'" data-sub-html="'.$caption.'"><img loading="lazy" src="'.wp_get_attachment_image_url($galleryID,'thumbnail').'" alt=""></div>';
				}
				$output .= '<div class="item item_more"><span></span></div></div></div>';
			}
		}
	}
	return $output;
}

function mow_fn_gallery_count($post_id, $size = 'l'){
	global $mow_fn_option;
	$output = '';
	$post_format = get_post_format($post_id);
	if($post_format == 'gallery'){
		if(isset(get_post_meta($post_id)['frenify_fn_postgallery'])){
			$gallery = get_post_meta($post_id,'frenify_fn_postgallery', false);
			if(!empty($gallery)){
				$output .= '<div class="fn__gallery_count" data-size="'.$size.'"><span>'.count($gallery).'</span>'.mow_fn_svg('gallery').'</div>';
			}
		}
	}
	return $output;
}

function mow_fn_get_rating_number($post_id, $size = 'l'){
	global $mow_fn_option;
	$rating_system = 10;
	if(isset($mow_fn_option['rating_system'])){
		$rating_system = (int)$mow_fn_option['rating_system'];
	}
	$fers_overall_rating = '';
	$fers_meta_values = get_post_meta( $post_id, '_fers_prefix_post_options', true );

	// Check if the score display is enabled
	$is_fers_score_shows = isset( $fers_meta_values['fers-score-shows'] ) ? $fers_meta_values['fers-score-shows'] : '';

	if ( $is_fers_score_shows ) {
		// Calculate the overall rating
		$fers_editorial_rating = isset( $fers_meta_values['fers-editorial-rating'] ) ? $fers_meta_values['fers-editorial-rating'] : '';
		$fers_total_rating = 0;
		$fers_count = 0;

		if ( is_array( $fers_editorial_rating ) && ! empty( $fers_editorial_rating ) ) {
			foreach ( $fers_editorial_rating as $rating ) {
				$fers_total_rating += round( $rating['fers-editorial-rating-category-rate'] );
				$fers_count++;
			}
		}

		if ( $fers_count > 0 ) {
			$percentage = $fers_total_rating / $fers_count;
			$number = number_format(( $percentage * $rating_system ) / 100, 1);
			$fers_overall_rating = '<span class="fn__rating_count" title="'.$number.'/'.$rating_system.'" data-size="'.$size.'"><span class="number">'.$number.'</span></span>';
		}
	}

	return $fers_overall_rating;
}

function mow_fn_get_rating_html($post_id){
	return do_shortcode( shortcode_unautop( '[frenify-rating id="'.$post_id.'"]' ) );
}

function mow_fn_create_redirect_page() {
    // Title of the page
    $page_title = esc_html__('Redirect Page', 'mow');

    // Use WP_Query to check if the page exists
    $query = new WP_Query(array(
        'post_type' => 'page',
        'title'     => $page_title,
        'post_status' => 'publish',
        'posts_per_page' => 1,
    ));

    if (!$query->have_posts()) {
        // Create the page
        $new_page = array(
            'post_title'   => $page_title,
            'post_content' => '', // Leave the content empty
            'post_status'  => 'publish',
            'post_type'    => 'page',
            'post_author'  => 1, // Admin user ID
        );

        // Insert the page into the database
        $new_page_id = wp_insert_post($new_page);

        if (!is_wp_error($new_page_id)) {
            // Assign the custom template to the new page
            update_post_meta($new_page_id, '_wp_page_template', 'page-redirect.php');
        }
    }

    // Reset post data to avoid conflicts
    wp_reset_postdata();
}

// Hook the function to theme activation
add_action('after_switch_theme', 'mow_fn_create_redirect_page');


function mow_fn_single_post($post_id,$paged = 1,$from_ajax = false){
	global $wp_query, $mow_fn_option;
	
	// create loop with query arguments
	$query_args = array(	
		'post_type' 			=> 'post',
		'post__in' 				=> [$post_id],
		'post_status' 			=> array('publish', 'pending', 'draft', 'auto-draft', 'future', 'private', 'inherit', 'trash'),
		'ignore_sticky_posts' 	=> true,
		'page' 					=> $paged,
	);
	$loop = new \WP_Query($query_args); $wp_query->is_single = true;
	
	
	$output = '';
	if ($loop->have_posts()) : while ($loop->have_posts()) : $loop->the_post();
	
	
	$prev_post 	= get_adjacent_post(false, '', true);
	$prevPostID = $prev_post ? $prev_post->ID : '';
	
	
	// get post title
	$title			= get_the_title($post_id);
	$postTitle		= '';
	if($title !== ''){
		$seo_page_title = 'h1';
		if(isset($mow_fn_option['seo_page_title'])){
			$seo_page_title = $mow_fn_option['seo_page_title'];
		}
		$postTitle 	= '<'.$seo_page_title.' class="fn__maintitle fn__single_post_title">'.$title.'</'.$seo_page_title.'>';
	}
	$dataTitle = ($title == '') ? esc_html__('(no title)', 'mow') : $title;
	
	$single_layout = 'featured';
	if(isset($mow_fn_option['single_layout'])){
		$single_layout = $mow_fn_option['single_layout'];
	}
	if(function_exists('rwmb_meta') && isset(get_post_meta($post_id)['mow_fn_post_header']) && get_post_meta($post_id,'mow_fn_post_header', true) != 'default'){
		$single_layout 	= get_post_meta($post_id,'mow_fn_post_header', true);
	}
	$top_media_array = mow_fn_post__media($post_id);
	$top_media 		= $top_media_array['content'];
	$format 		= $top_media_array['format'];
	$video_type 	= $top_media_array['video_type'];
	if($format == 'video' && $video_type == 'local'){
		if($single_layout == 'overlay_title' || $single_layout == 'overlay_content'){
			$single_layout = 'large_image';
		}
	}else if($format == 'video' && $video_type == 'youtube'){
		if($single_layout == 'spotlight' || $single_layout == 'overlay_title' || $single_layout == 'overlay_content'){
			$single_layout = 'large_image';
		}
	}
	$page_style = 'wsr';
	$sidebar_from = 'local';
	if(isset($mow_fn_option['single_post_sidebar_from'])){
		$sidebar_from = $mow_fn_option['single_post_sidebar_from'];
	}
	if($sidebar_from == 'local'){
		if(function_exists('rwmb_meta') && isset(get_post_meta($post_id)['mow_fn_post_sidebar'])){
			$page_style = get_post_meta($post_id, 'mow_fn_post_sidebar', true);
		}
	}else{
		if(isset($mow_fn_option['single_post_sidebar'])){
			$page_style = $mow_fn_option['single_post_sidebar'];
		}
	}
	
	
	if(($page_style == 'wsl' || $page_style == 'wsr') && !mow_fn_if_has_sidebar()){
		$page_style = 'full';
	}
	if($top_media == ''){
		$single_layout = 'featured';
	}
	$post_single_excerpt = 'disable';
	if(isset($mow_fn_option['post_single_excerpt'])){
		$post_single_excerpt = $mow_fn_option['post_single_excerpt'];
	}
	// *********************************************************************
	// START START START START
	// *********************************************************************
	$output = '<div class="mow_fn_blog_single" data-post-id="'.$post_id.'" data-get-post-id="'.$prevPostID.'" data-post-title="'.esc_attr(strip_tags($dataTitle)).'" data-post-url="'.esc_url(get_the_permalink($post_id)).'" data-layout="'.$single_layout.'" data-style="'.$page_style.'"><div class="mow_fn_single">';
	
	
	$ps_left_start = $ps_left_end = $ps_right_start = $ps_right_end = $sidebar = '';
	if($page_style == 'wsl' || $page_style == 'wsr'){
		$ps_start 		= '<div class="mow_fn_ws" data-side="'.$page_style.'"><div class="container"><div class="wspage_cols">';
		$ps_left_start 	= '<div class="wspage_col wspage_list"><div class="wspage_in">';
		$ps_left_end 	= '</div></div>';
		$ps_right_start = '<div class="wspage_col wspage_bar"><div class="wspage_in">';
		$ps_right_end 	= '</div></div>';
		$ps_end 		= '</div></div></div>';
	}else{
		$ps_start 		= '<div class="mow_fn_ns"><div class="container"><div class="page_ns_in">';
		$ps_end 		= '</div></div></div>';
	}

	$post_views_in_single = 'enable';
	if(isset($mow_fn_option['post_views_in_single'])){
		$post_views_in_single = $mow_fn_option['post_views_in_single'];
	}
	$post_views = ($post_views_in_single == 'enable');

	// get all information
	$breadcrumbs 	= mow_fn_breadcrumbs(false);
	$metas 			= mow_fn_metas(array('post_id' => $post_id, 'author' => 'both', 'category_count' => 999, 'page_views' => $post_views));
	$share 			= mow_fn_sharepost();
	$tags 			= mow_fn_post__tags($post_id);
	$comments 		= mow_fn_get_comments();
	$related 		= mow_fn_post__related($post_id);
	$prevnext		= mow_fn_simple_prevnext();
	$subscribe		= mow_fn_post__subscribe($post_id);
	$gallery		= mow_fn_post__gallery($post_id);
	$frenify_rating = mow_fn_get_rating_html($post_id);
	$inside_ad 		= mow_fn_get_ads('singlepost_in');
	$outside_ad 	= mow_fn_get_ads('singlepost_after');
	$votes 			= $reactions = '';
	if(isset($mow_fn_option)){
		$votes 		= mow_fn_vote($post_id,'return');
		$reactions 	= mow_fn_reactions($post_id,'return');
	}
	$links = wp_link_pages(
		array(
			'before'      	=> '<div class="mow_fn_pagelinks">',
			'after'       	=> '</div>',
			'link_before' 	=> '<span class="number">',
			'link_after'  	=> '</span>',
			'echo'			=> 0
		)
	);
	$single_link_info = 'link';
	if(isset($mow_fn_option['single_link_info'])){
		$single_link_info = $mow_fn_option['single_link_info'];
	}
	// increase pageview
	mow_fn_set_post_views($post_id);
	if($single_layout == 'featured'){

		if($top_media != ''){
			$output .= '<div class="fn__single_top"><div class="container"><div class="top_in">';
			$output .= $top_media;
			$output .= $breadcrumbs;
			$output .= '</div></div></div>';
		}
		

		$output .= $ps_start.$ps_left_start;

		$output .= '<div class="fn__single_top_info">';
		$output .= $postTitle;
		$output .= $metas;
		$output .= $share;
		$output .= $gallery;
		$output .= '</div>';

		$output .= '<div class="fn__single_content">';
		$output .= $inside_ad;
		if(get_post_format($post_id) !== 'link' && $post_single_excerpt == 'enable'){
			$excerpt = get_post_field('post_excerpt', $post_id);
			if($excerpt != ''){
				$output .= '<div class="post__excerpt"><p>'.$excerpt.'</p></div>';
			}
		}

		if($from_ajax){
			wp_suspend_cache_addition(true);
			$content = get_post_field('post_content', $post_id);
			$content = apply_filters('the_content', $content);
			ob_start();
			echo $content;
			$content = ob_get_clean();
			wp_suspend_cache_addition(false);
		}else{
			$content = get_the_content();
		}
		if(get_post_format($post_id) == 'link'){
			if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
				$href = $matches[1];
				$external_link = '<a href="' . esc_url($href) . '" title="'.esc_attr(strip_tags(get_the_title($post_id))).'" class="fn__external_single fn__external_link" rel="noopener noreferrer" aria-label="'.esc_attr__('Visit external link', 'mow').'"><span class="text">' . '<span class="icon">' . mow_fn_svg('svg__expand2') . '</span>' . esc_html__('Visit Direct Link', 'mow') . '</span></a>';
				$link_display = true;
			}
		}
		if(isset($link_display)){
			if($single_link_info == 'content'){
				$content = $external_link . $content;
			}else if($single_link_info == 'excerpt'){
				$content = $external_link . '<div class="post_excerpt">'.get_the_excerpt().'</div>';
			}else{
				$content = $external_link;
			}
		}
		
		if(!$from_ajax){
			echo $output;
			
			if(isset($link_display)){
				if($single_link_info == 'content'){
					echo $external_link;
					the_content();
				}else if($single_link_info == 'excerpt'){
					echo $external_link;
					echo '<div class="post_excerpt">'.get_the_excerpt().'</div>';
				}else{
					echo $external_link;
				}
			}else{
				the_content();
			}
			$output = '';
		}else{
			$output .= $content;
		}


		$output .= $links;
		$output .= '</div>';

		$output .= '<div class="clearfix"></div>';
		$output .= '<div class="single_bottom_info">';
		$output .= $votes;
		$output .= $reactions;
		$output .= $tags;
		$output .= $share;
		$output .= $frenify_rating;
		$output .= $outside_ad;
		$output .= '</div>';

		$output .= $comments;
		$output .= $related;
		$output .= $subscribe;
		$output .= $prevnext;
		$output .= $ps_left_end;

		$output .= $ps_right_start;
		if($page_style == 'wsl' || $page_style == 'wsr'){ 
			if(!$from_ajax){
				echo $output;
				get_sidebar();
				$output = '';
			}else{
				ob_start(); get_sidebar(); $sidebar = ob_get_contents(); ob_end_clean();
				$output .= $sidebar;
			}
		}
		$output .= $ps_right_end;
		$output .= $ps_end;

	}else if($single_layout == 'standard'){

		$output .= $ps_start.$ps_left_start;

		$output .= '<div class="fn__single_top_info">';
		$output .= $breadcrumbs;
		$output .= $postTitle;
		$output .= $metas;
		$output .= $share;
		$output .= $top_media;
		$output .= $gallery;
		$output .= '</div>';

		$output .= '<div class="fn__single_content">';
		$output .= $inside_ad;
		if(get_post_format($post_id) !== 'link' && $post_single_excerpt == 'enable'){
			$excerpt = get_post_field('post_excerpt', $post_id);
			if($excerpt != ''){
				$output .= '<div class="post__excerpt"><p>'.$excerpt.'</p></div>';
			}
		}
		if($from_ajax){
			wp_suspend_cache_addition(true);
			$content = get_post_field('post_content', $post_id);
			$content = apply_filters('the_content', $content);
			ob_start();
			echo $content;
			$content = ob_get_clean();
			wp_suspend_cache_addition(false);
		}else{
			ob_start(); the_content(); $content = ob_get_contents(); ob_end_clean();
		}
		

		
		if(get_post_format($post_id) == 'link'){
			if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
				$href = $matches[1];
				$external_link = '<a href="' . esc_url($href) . '" title="'.esc_attr(strip_tags(get_the_title($post_id))).'" class="fn__external_single fn__external_link" rel="noopener noreferrer" aria-label="'.esc_attr__('Visit external link', 'mow').'">><span class="text">' . '<span class="icon">' . mow_fn_svg('svg__expand2') . '</span>' . esc_html__('Visit Direct Link', 'mow') . '</span></a>';
				$link_display = true;
			}
		}
		if(isset($link_display)){
			if($single_link_info == 'content'){
				$content = $external_link . $content;
			}else if($single_link_info == 'excerpt'){
				$content = $external_link . '<div class="post_excerpt">'.get_the_excerpt().'</div>';
			}else{
				$content = $external_link;
			}
		}
		
		if(!$from_ajax){
			echo $output;
			
			if(isset($link_display)){
				if($single_link_info == 'content'){
					echo $external_link;
					the_content();
				}else if($single_link_info == 'excerpt'){
					echo $external_link;
					echo '<div class="post_excerpt">'.get_the_excerpt().'</div>';
				}else{
					echo $external_link;
				}
			}else{
				the_content();
			}
			$output = '';
		}else{
			$output .= $content;
		}
		$output .= $links;
		$output .= '</div>';

		$output .= '<div class="clearfix"></div>';
		$output .= '<div class="single_bottom_info">';
		$output .= $votes;
		$output .= $reactions;
		$output .= $tags;
		$output .= $share;
		$output .= $frenify_rating;
		$output .= $outside_ad;
		$output .= '</div>';

		$output .= $comments;
		$output .= $related;
		$output .= $subscribe;
		$output .= $prevnext;
		$output .= $ps_left_end;

		$output .= $ps_right_start;
		if($page_style == 'wsl' || $page_style == 'wsr'){ 
			if(!$from_ajax){
				echo $output;
				get_sidebar();
				$output = '';
			}else{
				ob_start(); get_sidebar(); $sidebar = ob_get_contents(); ob_end_clean();
				$output .= $sidebar;
			}
		}
		$output .= $ps_right_end;
		$output .= $ps_end;

	}else if($single_layout == 'spotlight'){

		$output .= '<div class="fn__single_top"><div class="container"><div class="top_in">';
		$output .= '<div class="single_top_left">';
		$output .= $top_media;
		$output .= '</div>';
		$output .= '<div class="single_top_right">';
		$output .= $postTitle;
		$output .= $metas;
		$output .= $share;
		$output .= $gallery;
		$output .= '</div>';
		$output .= '</div>'.$breadcrumbs.'</div></div>';
		
		$output .= $ps_start.$ps_left_start;

		$output .= '<div class="fn__single_content">';
		$output .= $inside_ad;
		if(get_post_format($post_id) !== 'link' && $post_single_excerpt == 'enable'){
			$excerpt = get_post_field('post_excerpt', $post_id);
			if($excerpt != ''){
				$output .= '<div class="post__excerpt"><p>'.$excerpt.'</p></div>';
			}
		}
		if($from_ajax){
			wp_suspend_cache_addition(true);
			$content = get_post_field('post_content', $post_id);
			$content = apply_filters('the_content', $content);
			ob_start();
			echo $content;
			$content = ob_get_clean();
			wp_suspend_cache_addition(false);
		}else{
			ob_start(); the_content(); $content = ob_get_contents(); ob_end_clean();
		}
		if(get_post_format($post_id) == 'link'){
			if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
				$href = $matches[1];
				$external_link = '<a href="' . esc_url($href) . '" title="'.esc_attr(strip_tags(get_the_title($post_id))).'" class="fn__external_single fn__external_link" rel="noopener noreferrer" aria-label="'.esc_attr__('Visit external link', 'mow').'">><span class="text">' . '<span class="icon">' . mow_fn_svg('svg__expand2') . '</span>' . esc_html__('Visit Direct Link', 'mow') . '</span></a>';
				$link_display = true;
			}
		}
		if(isset($link_display)){
			if($single_link_info == 'content'){
				$content = $external_link . $content;
			}else if($single_link_info == 'excerpt'){
				$content = $external_link . '<div class="post_excerpt">'.get_the_excerpt().'</div>';
			}else{
				$content = $external_link;
			}
		}
		if(!$from_ajax){
			echo $output;
			
			if(isset($link_display)){
				if($single_link_info == 'content'){
					echo $external_link;
					the_content();
				}else if($single_link_info == 'excerpt'){
					echo $external_link;
					echo '<div class="post_excerpt">'.get_the_excerpt().'</div>';
				}else{
					echo $external_link;
				}
			}else{
				the_content();
			}
			$output = '';
		}else{
			$output .= $content;
		}

		$output .= $links;
		$output .= '</div>';

		$output .= '<div class="clearfix"></div>';
		$output .= '<div class="single_bottom_info">';
		$output .= $votes;
		$output .= $reactions;
		$output .= $tags;
		$output .= $share;
		$output .= $frenify_rating;
		$output .= $outside_ad;
		$output .= '</div>';

		$output .= $comments;
		$output .= $related;
		$output .= $subscribe;
		$output .= $prevnext;
		$output .= $ps_left_end;

		$output .= $ps_right_start;
		if($page_style == 'wsl' || $page_style == 'wsr'){ 
			if(!$from_ajax){
				echo $output;
				get_sidebar();
				$output = '';
			}else{
				ob_start(); get_sidebar(); $sidebar = ob_get_contents(); ob_end_clean();
				$output .= $sidebar;
			}
		}
		$output .= $ps_right_end;
		$output .= $ps_end;

	}else if($single_layout == 'overlay_title'){

		$output .= '<div class="fn__single_top">'.$top_media.'<div class="fn__single_top_info"><div class="container"><div class="top_in">';
		$output .= $postTitle;
		$output .= $metas;
		$output .= $share;
		$output .= $gallery;
		$output .= '</div></div></div></div>';
		$caption_show = 'none';
		if(isset($mow_fn_option['caption_show'])){
			$caption_show = $mow_fn_option['caption_show'];
		}
		$caption = '';
		$img_info_text = '';
		$mediaID = get_post_thumbnail_id( $post_id );
		if($caption_show == 'caption'){
			$caption = wp_get_attachment_caption($mediaID);
		}else if($caption_show == 'descripton'){
			$caption = get_post_field('post_content', $mediaID);
		}
		if($caption != ''){
			$img_info_text = '<div class="fn__caption">'.$caption.'</div>';
		}
		$output .= $img_info_text;
		$output .= '<div class="fn__single_top_container"><div class="container">'.$breadcrumbs.'</div></div>';
		
		$output .= $ps_start.$ps_left_start;

		$output .= '<div class="fn__single_content">';
		$output .= $inside_ad;
		if(get_post_format($post_id) !== 'link' && $post_single_excerpt == 'enable'){
			$excerpt = get_post_field('post_excerpt', $post_id);
			if($excerpt != ''){
				$output .= '<div class="post__excerpt"><p>'.$excerpt.'</p></div>';
			}
		}
		if($from_ajax){
			wp_suspend_cache_addition(true);
			$content = get_post_field('post_content', $post_id);
			$content = apply_filters('the_content', $content);
			ob_start();
			echo $content;
			$content = ob_get_clean();
			wp_suspend_cache_addition(false);
		}else{
			ob_start(); the_content(); $content = ob_get_contents(); ob_end_clean();
		}
		if(get_post_format($post_id) == 'link'){
			if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
				$href = $matches[1];
				$external_link = '<a href="' . esc_url($href) . '" title="'.esc_attr(strip_tags(get_the_title($post_id))).'" class="fn__external_single fn__external_link" rel="noopener noreferrer" aria-label="'.esc_attr__('Visit external link', 'mow').'">><span class="text">' . '<span class="icon">' . mow_fn_svg('svg__expand2') . '</span>' . esc_html__('Visit Direct Link', 'mow') . '</span></a>';
				$link_display = true;
			}
		}
		if(isset($link_display)){
			if($single_link_info == 'content'){
				$content = $external_link . $content;
			}else if($single_link_info == 'excerpt'){
				$content = $external_link . '<div class="post_excerpt">'.get_the_excerpt().'</div>';
			}else{
				$content = $external_link;
			}
		}

		if(!$from_ajax){
			echo $output;
			
			if(isset($link_display)){
				if($single_link_info == 'content'){
					echo $external_link;
					the_content();
				}else if($single_link_info == 'excerpt'){
					echo $external_link;
					echo '<div class="post_excerpt">'.get_the_excerpt().'</div>';
				}else{
					echo $external_link;
				}
			}else{
				the_content();
			}
			$output = '';
		}else{
			$output .= $content;
		}

		$output .= $links;
		$output .= '</div>';

		$output .= '<div class="clearfix"></div>';
		$output .= '<div class="single_bottom_info">';
		$output .= $votes;
		$output .= $reactions;
		$output .= $tags;
		$output .= $share;
		$output .= $frenify_rating;
		$output .= $outside_ad;
		$output .= '</div>';

		$output .= $comments;
		$output .= $related;
		$output .= $subscribe;
		$output .= $prevnext;
		$output .= $ps_left_end;

		$output .= $ps_right_start;
		if($page_style == 'wsl' || $page_style == 'wsr'){ 
			if(!$from_ajax){
				echo $output;
				get_sidebar();
				$output = '';
			}else{
				ob_start(); get_sidebar(); $sidebar = ob_get_contents(); ob_end_clean();
				$output .= $sidebar;
			}
		}
		$output .= $ps_right_end;
		$output .= $ps_end;

	}else if($single_layout == 'large_image'){

		$output .= '<div class="fn__single_top"><div class="container"><div class="top_in">';
		$output .= $breadcrumbs;
		$output .= $postTitle;
		$output .= $metas;
		$output .= $share;
		$output .= $gallery;
		$output .= '</div></div></div>';
		$output .= $top_media;
		
		$output .= $ps_start.$ps_left_start;

		$output .= '<div class="fn__single_content">';
		$output .= $inside_ad;
		if(get_post_format($post_id) !== 'link' && $post_single_excerpt == 'enable'){
			$excerpt = get_post_field('post_excerpt', $post_id);
			if($excerpt != ''){
				$output .= '<div class="post__excerpt"><p>'.$excerpt.'</p></div>';
			}
		}
		if($from_ajax){
			wp_suspend_cache_addition(true);
			$content = get_post_field('post_content', $post_id);
			$content = apply_filters('the_content', $content);
			ob_start();
			echo $content;
			$content = ob_get_clean();
			wp_suspend_cache_addition(false);
		}else{
			ob_start(); the_content(); $content = ob_get_contents(); ob_end_clean();
		}
		if(get_post_format($post_id) == 'link'){
			if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
				$href = $matches[1];
				$external_link = '<a href="' . esc_url($href) . '" title="'.esc_attr(strip_tags(get_the_title($post_id))).'" class="fn__external_single fn__external_link" rel="noopener noreferrer" aria-label="'.esc_attr__('Visit external link', 'mow').'">><span class="text">' . '<span class="icon">' . mow_fn_svg('svg__expand2') . '</span>' . esc_html__('Visit Direct Link', 'mow') . '</span></a>';
				$link_display = true;
			}
		}
		if(isset($link_display)){
			if($single_link_info == 'content'){
				$content = $external_link . $content;
			}else if($single_link_info == 'excerpt'){
				$content = $external_link . '<div class="post_excerpt">'.get_the_excerpt().'</div>';
			}else{
				$content = $external_link;
			}
		}

		if(!$from_ajax){
			echo $output;
			
			if(isset($link_display)){
				if($single_link_info == 'content'){
					echo $external_link;
					the_content();
				}else if($single_link_info == 'excerpt'){
					echo $external_link;
					echo '<div class="post_excerpt">'.get_the_excerpt().'</div>';
				}else{
					echo $external_link;
				}
			}else{
				the_content();
			}
			$output = '';
		}else{
			$output .= $content;
		}

		$output .= $links;
		$output .= '</div>';

		$output .= '<div class="clearfix"></div>';
		$output .= '<div class="single_bottom_info">';
		$output .= $votes;
		$output .= $reactions;
		$output .= $tags;
		$output .= $share;
		$output .= $frenify_rating;
		$output .= $outside_ad;
		$output .= '</div>';

		$output .= $comments;
		$output .= $related;
		$output .= $subscribe;
		$output .= $prevnext;
		$output .= $ps_left_end;

		$output .= $ps_right_start;
		if($page_style == 'wsl' || $page_style == 'wsr'){ 
			if(!$from_ajax){
				echo $output;
				get_sidebar();
				$output = '';
			}else{
				ob_start(); get_sidebar(); $sidebar = ob_get_contents(); ob_end_clean();
				$output .= $sidebar;
			}
		}
		$output .= $ps_right_end;
		$output .= $ps_end;

	}else if($single_layout == 'overlay_content'){

		$output .= '<div class="fn__single_top">'.$top_media.'<div class="fn__single_top_info"><div class="container"><div class="top_in">';
		$output .= $breadcrumbs;
		$output .= $postTitle;
		$output .= $metas;
		$output .= $share;
		$output .= $gallery;
		$output .= '</div></div></div></div>';

		
		$caption_show = 'none';
		if(isset($mow_fn_option['caption_show'])){
			$caption_show = $mow_fn_option['caption_show'];
		}
		$caption = '';
		$img_info_text = '';
		$mediaID = get_post_thumbnail_id( $post_id );
		if($caption_show == 'caption'){
			$caption = wp_get_attachment_caption($mediaID);
		}else if($caption_show == 'descripton'){
			$caption = get_post_field('post_content', $mediaID);
		}
		if($caption != ''){
			$img_info_text = '<div class="fn__caption">'.$caption.'</div>';
		}
		
		$output .= $ps_start.$img_info_text.$ps_left_start;

		$output .= '<div class="fn__single_content">';
		$output .= $inside_ad;
		if(get_post_format($post_id) !== 'link' && $post_single_excerpt == 'enable'){
			$excerpt = get_post_field('post_excerpt', $post_id);
			if($excerpt != ''){
				$output .= '<div class="post__excerpt"><p>'.$excerpt.'</p></div>';
			}
		}
		if($from_ajax){
			wp_suspend_cache_addition(true);
			$content = get_post_field('post_content', $post_id);
			$content = apply_filters('the_content', $content);
			ob_start();
			echo $content;
			$content = ob_get_clean();
			wp_suspend_cache_addition(false);
		}else{
			ob_start(); the_content(); $content = ob_get_contents(); ob_end_clean();
		}
		if(get_post_format($post_id) == 'link'){
			if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
				$href = $matches[1];
				$external_link = '<a href="' . esc_url($href) . '" title="'.esc_attr(strip_tags(get_the_title($post_id))).'" class="fn__external_single fn__external_link" rel="noopener noreferrer" aria-label="'.esc_attr__('Visit external link', 'mow').'">><span class="text">' . '<span class="icon">' . mow_fn_svg('svg__expand2') . '</span>' . esc_html__('Visit Direct Link', 'mow') . '</span></a>';
				$link_display = true;
			}
		}
		if(isset($link_display)){
			if($single_link_info == 'content'){
				$content = $external_link . $content;
			}else if($single_link_info == 'excerpt'){
				$content = $external_link . '<div class="post_excerpt">'.get_the_excerpt().'</div>';
			}else{
				$content = $external_link;
			}
		}

		if(!$from_ajax){
			echo $output;
			
			if(isset($link_display)){
				if($single_link_info == 'content'){
					echo $external_link;
					the_content();
				}else if($single_link_info == 'excerpt'){
					echo $external_link;
					echo '<div class="post_excerpt">'.get_the_excerpt().'</div>';
				}else{
					echo $external_link;
				}
			}else{
				the_content();
			}
			$output = '';
		}else{
			$output .= $content;
		}

		$output .= $links;
		$output .= '</div>';

		$output .= '<div class="clearfix"></div>';
		$output .= '<div class="single_bottom_info">';
		$output .= $votes;
		$output .= $reactions;
		$output .= $tags;
		$output .= $share;
		$output .= $frenify_rating;
		$output .= $outside_ad;
		$output .= '</div>';

		$output .= $comments;
		$output .= $related;
		$output .= $subscribe;
		$output .= $prevnext;
		$output .= $ps_left_end;

		$output .= $ps_right_start;
		if($page_style == 'wsl' || $page_style == 'wsr'){ 
			if(!$from_ajax){
				echo $output;
				get_sidebar();
				$output = '';
			}else{
				ob_start(); get_sidebar(); $sidebar = ob_get_contents(); ob_end_clean();
				$output .= $sidebar;
			}
		}
		$output .= $ps_right_end;
		$output .= $ps_end;

	}
	$output .= '</div></div></div>';

	if(!$from_ajax){
		echo $output;
	}
	
	endwhile; endif; wp_reset_postdata();

	if($from_ajax){
		return $output;
	}
}

function mow_fn_megamenu_skeleton_category(){
	return '<div class="fn__loading_before_content">
				<ul>
					<li>
						<div class="item">
							<div class="overlay_t fn_skeleton_animation"><div class="overlay_t_in"></div></div>
							<div class="title_holder">
								<div class="metas"><span class="fn_skeleton_animation"></span></div>
								<div class="title"><span class="fn_skeleton_animation"></span><span class="fn_skeleton_animation"></span></div>
							</div>
						</div>
					</li>
					<li>
						<div class="item">
							<div class="overlay_t fn_skeleton_animation"><div class="overlay_t_in"></div></div>
							<div class="title_holder">
								<div class="metas"><span class="fn_skeleton_animation"></span></div>
								<div class="title"><span class="fn_skeleton_animation"></span><span class="fn_skeleton_animation"></span></div>
							</div>
						</div>
					</li>
					<li>
						<div class="item">
							<div class="overlay_t fn_skeleton_animation"><div class="overlay_t_in"></div></div>
							<div class="title_holder">
								<div class="metas"><span class="fn_skeleton_animation"></span></div>
								<div class="title"><span class="fn_skeleton_animation"></span><span class="fn_skeleton_animation"></span></div>
							</div>
						</div>
					</li>
					<li>
						<div class="item">
							<div class="overlay_t fn_skeleton_animation"><div class="overlay_t_in"></div></div>
							<div class="title_holder">
								<div class="metas"><span class="fn_skeleton_animation"></span></div>
								<div class="title"><span class="fn_skeleton_animation"></span><span class="fn_skeleton_animation"></span></div>
							</div>
						</div>
					</li>
				</ul>
			</div>';
}

function mow_fn_get_comments(){
	global $mow_fn_option;
	$output = '';
	if ( comments_open() || get_comments_number()){
		$output .= '<div class="mow_fn_comments">';
			$output .= '<div class="fn__comments" id="comments">';
				ob_start();
				comments_template();
				$comments = ob_get_contents();
				ob_end_clean();
				$output .= $comments;
			$output .= '</div>';
		$output .= '</div>';
	}
	return $output;
}

function mow_fn_similar_posts($post_id){
	$query_args = array(	
		'post_type' 			=> 'post',
		'post__not_in' 			=> [$post_id],
		'post_status' 			=> 'publish',
		'ignore_sticky_posts' 	=> true,
		'category__in' 			=> wp_get_post_categories($post_id),
		'tag__in' 				=> wp_get_post_tags($post_id, array('fields' => 'ids')), // Fetch posts with the same tags
		'posts_per_page' 		=> 3,
		'orderby' 				=> 'date',  // Order by date for fresh content
	);
	$loop 	= new \WP_Query($query_args);
	$output = $list = '';
	foreach ( $loop->posts as $key => $fn_post ) {
		setup_postdata( $fn_post );
		$post_id 		= $fn_post->ID;
		$post_title 	= $fn_post->post_title;
		$post_permalink = get_permalink($post_id);
		$post_meta 		= mow_fn_metas(array('post_id' => $post_id));
		$post_image 	= get_the_post_thumbnail_url($post_id,'large');
		$post_title 	= '<h3 class="post_title"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.$post_title.'</a></h3>';

		if($post_image != ''){
			$image_holder = '<div class="img_holder"><div class="item_img"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'large', ['loading' => 'lazy']).'</a></div></div>';
		}else{
			$image_holder = '<div class="img_holder"><div class="item_space"><a href="'.$post_permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'"></a></div></div>';
		}

		$title_holder = '<div class="title_holder">'.$post_meta.$post_title.'</div>';

		$list .= '<li class="delta_item"><div class="delta__item">'.$image_holder.$title_holder.'</div></li>';
		wp_reset_postdata();
	}
	
	if($list != ''){
		$output .= '<div class="mow_fn_related_posts">';
		$output .= '<h3 class="fn__decor_title">'.esc_html__('Related Posts', 'mow').'</h3>';
		$output .= '<div class="fn__widget_posts_delta"><ul class="active">'.$list.'</ul></div>';
		$output .= '</div>';
	}
	
	return $output;
}

function mow_fn_sharepost($post_id = ''){
	global $mow_fn_option;
	$src = $output = '';
	$post_id 	= get_the_ID();
	$permalink 	= get_the_permalink($post_id);
	
	if (has_post_thumbnail($post_id)) {
		$thumbnailID = get_post_thumbnail_id($post_id);
		$src = wp_get_attachment_image_src($thumbnailID, 'full');
		if ($src) {
			$src = $src[0];
		}
	}
	$share_text_switcher = 'enable';
	if(isset($mow_fn_option['share_text_switcher'])){
		$share_text_switcher = $mow_fn_option['share_text_switcher'];
	}
	
	if(isset($mow_fn_option)){
			
		$list = '';
		

		if(isset($mow_fn_option['share_facebook']) && $mow_fn_option['share_facebook'] != 'disable') {
			$encodedPageURL = urlencode($permalink);
			if($src != ''){;
				$src = urlencode($src);
				$list .= '<li><a href="https://www.facebook.com/sharer/sharer.php?u='.$encodedPageURL.'&amp;picture='.$src.'" target="_blank" title="'.esc_attr__('Facebook', 'mow').'" aria-label="'.esc_attr__('Share on Facebook', 'mow').'">'.mow_fn_svg('facebook').'</a></li>';
			}else{
				$list .= '<li><a href="https://www.facebook.com/sharer/sharer.php?u='.$encodedPageURL.'" target="_blank" title="'.esc_attr__('Facebook', 'mow').'" aria-label="'.esc_attr__('Share on Facebook', 'mow').'">'.mow_fn_svg('facebook').'</a></li>';
			}
		}

		if(isset($mow_fn_option['share_twitter']) && $mow_fn_option['share_twitter'] != 'disable') {
			$encodedPageURL = urlencode($permalink);
			if($src != ''){;
				$src = urlencode($src);
				$list .= '<li><a href="https://twitter.com/intent/tweet?url='.$encodedPageURL.'&amp;card=summary_large_image&amp;image='.$src.'" target="_blank" title="'.esc_attr__('Twitter', 'mow').'" aria-label="'.esc_attr__('Share on Twitter', 'mow').'">'.mow_fn_svg('twitter').'</a></li>';
			}else{
				$list .= '<li><a href="https://twitter.com/intent/tweet?url='.$encodedPageURL.'" target="_blank" title="'.esc_attr__('Twitter', 'mow').'" aria-label="'.esc_attr__('Share on Twitter', 'mow').'">'.mow_fn_svg('twitter').'</a></li>';
			}
		}

		if(isset($mow_fn_option['share_whatsapp']) && $mow_fn_option['share_whatsapp'] != 'disable') {
			$encodedPageURL = urlencode($permalink);
			$list .= '<li><a href="https://wa.me/?text='.$encodedPageURL.'" target="_blank" title="'.esc_attr__('WhatsApp', 'mow').'" aria-label="'.esc_attr__('Share on WhatsApp', 'mow').'">'.mow_fn_svg('whatsapp').'</a></li>';
		}

		if(isset($mow_fn_option['share_pinterest']) && $mow_fn_option['share_pinterest'] != 'disable') {
			$list .= '<li><a href="http://pinterest.com/pin/create/button/?url='.$permalink.'&amp;media=';
			if($src != ''){
				$list .= esc_url($src);
			}
			$list .= '" target="_blank" title="'.esc_attr__('Pinterest', 'mow').'" aria-label="'.esc_attr__('Share on Pinterest', 'mow').'">'.mow_fn_svg('pinterest').'</a></li>';
		}

		if(isset($mow_fn_option['share_linkedin']) && $mow_fn_option['share_linkedin'] != 'disable') {
			$list .= '<li><a href="http://linkedin.com/shareArticle?mini=true&amp;url='.$permalink.'&amp;" target="_blank" title="'.esc_attr__('Linkedin', 'mow').'" aria-label="'.esc_attr__('Share on Linkedin', 'mow').'">'.mow_fn_svg('linkedin').'</a></li>';
		}

		if(isset($mow_fn_option['share_email']) && $mow_fn_option['share_email'] != 'disable') {
			$list .= '<li><a href="mailto:?amp;body='.$permalink.'" target="_blank" title="'.esc_attr__('Email', 'mow').'" aria-label="'.esc_attr__('Share on Email', 'mow').'">'.mow_fn_svg('email').'</a></li>';
		}

		if(isset($mow_fn_option['share_vk']) && $mow_fn_option['share_vk'] != 'disable') {
			$list .= '<li><a href="https://www.vk.com/share.php?url='.$permalink.'" target="_blank" title="'.esc_attr__('VKontakte', 'mow').'" aria-label="'.esc_attr__('Share on VKontakte', 'mow').'">'.mow_fn_svg('vk').'</a></li>';
		}
		$list .= '<li><a title="'.esc_attr__('Copy Link', 'mow').'" class="frenify__copy_link" href="'.$permalink.'" aria-label="'.esc_attr__('Copy a link to the clipboard', 'mow').'">'.mow_fn_svg('svg__link').'</a></li>';
		if($list != ''){
			$output .= '<div class="mow_fn_share"><div class="share_wrapper">';
			if($share_text_switcher == 'enable'){
				$output .= '<h5 class="label"><span>'.esc_html__('Share','mow').'</span></h5>';
			}
			$output .= '<ul>'.$list.'</ul>';
			$output .= '</div></div>';
		}
	}
	
	return $output;
}

function mow_fn_get_page_title($from = '',$type = ''){
	global $post, $wp_query, $mow_fn_option;
	$subtitle = $mow_fn_pagetitle = $total_posts = '';
	$pageID = get_the_ID();
	if(function_exists('rwmb_meta')){
		$mow_fn_pagetitle 		= get_post_meta($pageID,'mow_fn_page_title', true);
	}
	$seo_page_title 			= 'h1';
	if(isset($mow_fn_option['seo_page_title'])){
		$seo_page_title 		= $mow_fn_option['seo_page_title'];
	}

	if($from == 'home'){
		$type = 'decor';
	}
	
	if($mow_fn_pagetitle !== 'disable'){
		if(is_search()){
			$title = sprintf( esc_html__('Search results for "%s"', 'mow'), get_search_query() );
		}else if(is_archive()){
			$currentAuthor = get_userdata(get_query_var('author'));
			if (is_category()) {
				$title = single_cat_title('',false);
				$subtitle = category_description();
			}else if( is_tax() ) {
				$term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
				$title = sprintf(esc_html__('All posts in %s', 'mow'), $term->name );
			}else if( is_tag() ) {
				$title = sprintf(esc_html__('All posts tagged in %s', 'mow'), single_tag_title('',false));
				$subtitle = tag_description();
			}else if (is_day()) {
				$title = sprintf(esc_html__('Archive for %s', 'mow'),get_the_time(get_option('date_format')));
			}else if (is_month()) {
				$title = sprintf(esc_html__('Archive for %s', 'mow'), get_the_time('F, Y'));
			}else if (is_year()) {
				$title = sprintf(esc_html__('Archive for %s', 'mow'), get_the_time('Y'));
			}else if (is_author()) { 
				$title = esc_html($currentAuthor->display_name);
			}else if (isset($_GET['paged']) && !empty($_GET['paged'])) { 
				$title = esc_html__('Blog Archives', 'mow'); 
			}else{
				$title = get_the_title();
			}
		}else if(is_home() || is_front_page()){
			if(isset($mow_fn_option['blog_single_title'])){
				$title = esc_html($mow_fn_option['blog_single_title']);
			}else{
				$title = esc_html__('Latest Articles', 'mow');
			}
			$subtitle = esc_html__('Stay informed with the latest breaking news, in-depth analysis, and real-time updates from around the world.', 'mow');
		}else{
			$title = get_the_title();
		}
		if (is_page()) {
			$excerpt = get_post_field('post_excerpt', get_the_ID());
			if (!empty($excerpt)) {
				$subtitle = strip_tags($excerpt);
			}
		}
		
		$paged = ( get_query_var('paged') ) ? get_query_var('paged') : 1;
		$title_paged = '';
		if ( $paged > 1 ) {
			$title_paged = '<span class="paged">'.$paged.esc_html__('- Page', 'mow').'</span>';
		}
		$extraClass = '';
		if($type == 'decor'){
			$extraClass = 'fn__decor_title';
		}
		$title = sprintf( '<%1$s class="fn__title '.$extraClass.'">', $seo_page_title, $title ) . esc_html($title) . $title_paged . sprintf( '</%1$s>', $seo_page_title ) ;
		if($subtitle != ''){
			$subtitle = '<div class="fn__desc">'.$subtitle.'</div>';
		}
		
		global $template;
		if ( is_archive() || basename($template) == 'index.php' ){
			$count = $wp_query->found_posts;
			$total_posts = '<div class="pt_right"><div class="fn__post_count"><span class="count">'.$count.'</span><span class="title">'.sprintf( _n( 'Article', 'Articles', $count, 'mow' ), $count ).'</span></div></div>';
		}
		if (is_author()){
			$userID 			= get_post_field( 'post_author', $pageID );
			$authorURL 	 		= get_author_posts_url($userID);
			$social				= mow_fn_get_user_social($userID);


			$name 				= esc_html( get_the_author_meta( 'mow_fn_user_name', $userID ) );
			$description		= esc_html( get_the_author_meta( 'mow_fn_user_desc', $userID ) );
			$imageURL			= esc_url( get_the_author_meta( 'mow_fn_user_image', $userID ) );

			if($name == ''){	
				$firstName 		= get_user_meta( $userID, 'first_name', true );
				$lastName 		= get_user_meta( $userID, 'last_name', true );
				$name 			= $firstName . ' ' . $lastName;
				if($firstName == ''){
					$name 		= get_user_meta( $userID, 'nickname', true );
				}
			}
			if($description == ''){
				$description 	= get_user_meta( $userID, 'description', true );
			}
			if($imageURL == ''){
				$image			= get_avatar( $userID, 200 );
			}else{
				$image			= '<img loading="lazy" src="'.$imageURL.'" alt="">';
			}



			$title = '<h3 class="fn_title">'.$name.'</h3>';
			
			if($description != ''){
				$description = '<p class="fn_desc">'.$description.'</p>';
			}
			$leftTop = '<div class="author_top">'.$title.$description.'</div>';
			
			if($social != ''){
				$social = '<div class="author_bottom">'.$social.'</div>';
			}
			$html  = '<div class="mow_fn_pt_author_info">';
				$html  .= '<div class="info_img">'.$image.'</div>';
				$html  .= '<div class="info_desc">'.$leftTop.$social.'</div>';
			$html .= '</div>';
			$left_part = $html;
		}else{
			$left_part = $title.$subtitle;
		}
		if($type == 'decor'){
			$decor_title = '<div class="mow_fn_pagetitle_decor"><div class="container"><div class="pagetitle">'.$title.'</div></div></div>';
			echo wp_kses($decor_title,'post');
		}else{
	?>
	<!-- PAGE TITLE -->
	<div class="mow_fn_pagetitle">
		<div class="container">
			<div class="pagetitle">
				<div class="pt_left">
					<?php echo wp_kses($left_part,'post'); ?>
				</div>
				<?php echo wp_kses($total_posts,'post'); ?>
			</div>
		</div>
	</div>
	<!-- /PAGE TITLE -->
	<?php mow_fn_breadcrumbs(); 
	
	}}
	
	
}

function mow_fn_get_prev_post(){
	check_ajax_referer( 'mow-secure', 'security' );
	global $wp_query;
	// curren post ID
	$post_id 						= '';
	if(!empty($_POST['ID'])){
		$post_id 					= (int)sanitize_text_field($_POST['ID']);
	}
	$output = $url = '';
	if($post_id != ''){
		$output = mow_fn_single_post($post_id, 1, true);
	}
	$buffyArray = array(
		'output' 			=> $output,
    );
	
	die(json_encode($buffyArray));
}

function mow_fn_next_relink_page(){
	check_ajax_referer( 'mow-secure', 'security' );
	$list 			= '';
	$layout 		= 'small_list_2';
	$disabled 		= 'disabled';
	$paged 			= 2;
	if(!empty($_POST['paged'])){
		$paged		= (int)sanitize_text_field($_POST['paged']);
	}
	if(!empty($_POST['layout'])){
		$layout		= sanitize_text_field($_POST['layout']);
	}
	$vote_key = mow_fn_votekey();
	if (isset($_POST['args'])) {
		$args = json_decode(stripslashes($_POST['args']), true);
		$args['paged'] = $paged;
		$loop = new \WP_Query( $args );
		if ($loop->have_posts()) : while ($loop->have_posts()) : $loop->the_post();
			$list .= mow_fn_get_relink(array('post_layout' => $layout, 'vote_key' => $vote_key, 'ajax' => true));
		endwhile; endif; wp_reset_postdata();
		if ( $loop->max_num_pages > $paged ) {
			$disabled = '';
		} 
	}

	
	$buffyArray = array(
		'list' 				=> $list,
		'paged' 			=> ($paged+1),
		'disabled' 			=> $disabled,
    );
	
	die(json_encode($buffyArray));
}
function mow_fn_post_delta(){
	check_ajax_referer( 'mow-secure', 'security' );
	$list 			= '';
	$disabled 		= 'disabled';
	$paged 			= 2;
	if(!empty($_POST['paged'])){
		$paged		= (int)sanitize_text_field($_POST['paged']);
	}
	if (isset($_POST['settings'])) {
		$settings = json_decode(stripslashes($_POST['settings']), true);
		if (isset($_POST['args'])) {
			$args = json_decode(stripslashes($_POST['args']), true);
			$args['paged'] = $paged;
			$loop = new \WP_Query( $args );
			$list .= mow_fn_post__delta($loop,$settings);
			if ( $loop->max_num_pages > $paged ) {
				$disabled = '';
			}
		}
	}

	
	$buffyArray = array(
		'list' 				=> $list,
		'paged' 			=> ($paged+1),
		'disabled' 			=> $disabled,
    );
	
	die(json_encode($buffyArray));
}
function mow_fn_post_zeta(){
	check_ajax_referer( 'mow-secure', 'security' );
	$list 			= '';
	$disabled 		= 'disabled';
	$paged 			= 2;
	if(!empty($_POST['paged'])){
		$paged		= (int)sanitize_text_field($_POST['paged']);
	}
	if (isset($_POST['settings'])) {
		$settings = json_decode(stripslashes($_POST['settings']), true);
		if (isset($_POST['args'])) {
			$args = json_decode(stripslashes($_POST['args']), true);
			$args['paged'] = $paged;
			$loop = new \WP_Query( $args );
			$list .= mow_fn_post__zeta($loop,$settings);
			if ( $loop->max_num_pages > $paged ) {
				$disabled = '';
			}
		}
	}

	
	$buffyArray = array(
		'list' 				=> $list,
		'paged' 			=> ($paged+1),
		'disabled' 			=> $disabled,
    );
	
	die(json_encode($buffyArray));
}
function mow_fn_post_date_1(){
	check_ajax_referer( 'mow-secure', 'security' );
	$list 			= '';
	$disabled 		= 'disabled';
	$paged 			= 2;
	if(!empty($_POST['paged'])){
		$paged		= (int)sanitize_text_field($_POST['paged']);
	}
	if (isset($_POST['settings'])) {
		$settings = json_decode(stripslashes($_POST['settings']), true);
		if (isset($_POST['args'])) {
			$args = json_decode(stripslashes($_POST['args']), true);
			$args['paged'] = $paged;
			$loop = new \WP_Query( $args );
			$list .= mow_fn_post__date_1($loop,$settings);
			if ( $loop->max_num_pages > $paged ) {
				$disabled = '';
			}
		}
	}

	
	$buffyArray = array(
		'list' 				=> $list,
		'paged' 			=> ($paged+1),
		'disabled' 			=> $disabled,
    );
	
	die(json_encode($buffyArray));
}


function mow_fn_search_form( $form ) {
    return '<form role="search" method="get" class="searchform" action="' . home_url( '/' ) . '" ><div class="search-wrapper"><input type="text" value="' . get_search_query() . '" name="s" placeholder="'.esc_attr__('Type here...', 'mow').'"><input type="submit" value="'.esc_attr__('Search', 'mow').'"></div>
    </form>';
}

add_filter( 'get_search_form', 'mow_fn_search_form', 100 );

function mow_fn_custom_password_form() {
    global $post;
 
    $loginurl = home_url() . '/wp-login.php?action=postpass';
    ob_start();
    ?>
    <div class="container-custom mow_fn_protectedform">
		<form action="<?php echo esc_attr( $loginurl ) ?>" method="post" class="center-custom search-form" role="search">
            <input name="post_password" class="input post-password-class" type="password"  placeholder="<?php esc_attr_e( 'Enter the Password', 'mow' ); ?>">
            <div class="search"><input type="submit" name="Submit" class="button" value="<?php esc_attr_e( 'Authenticate', 'mow' ); ?>"></div>
        </form>
    </div>
    <?php
    return ob_get_clean();
}   
add_filter( 'the_password_form', 'mow_fn_custom_password_form', 9999 );


function html5_search_form( $form ) {
     $form  = '<section class="search"><form role="search" method="get" action="' . home_url( '/' ) . '" >';
		 $form .= '<label class="screen-reader-text" for="s"></label>';
		 $form .= '<input type="text" value="' . get_search_query() . '" name="s" placeholder="'. esc_html__('Search', 'mow') .'">';
		 $form .= '<input type="submit" value="'. esc_html__('Search', 'mow') .'">';
	 $form .= '</form></section>';
     return $form;
}

add_filter( 'get_search_form', 'html5_search_form' );

function mow_fn_human_readable_time_diff( $post_id ) {
    // Get the post's publication time
    $post_time = get_the_time( 'U', $post_id );
    $current_time = current_time( 'timestamp' );
    
    // Calculate time difference in seconds
    $time_diff = $current_time - $post_time;

    // If it's less than a minute, return "just now"
    if ( $time_diff < MINUTE_IN_SECONDS ) {
        return esc_html__( 'Just now', 'mow' );
    }

    // For times less than an hour, display minutes
    if ( $time_diff < HOUR_IN_SECONDS ) {
        $minutes = floor( $time_diff / MINUTE_IN_SECONDS );
        return sprintf( _n( '%s minute ago', '%s minutes ago', $minutes, 'mow' ), $minutes );
    }

    // For times less than a day, display hours
    if ( $time_diff < DAY_IN_SECONDS ) {
        $hours = floor( $time_diff / HOUR_IN_SECONDS );
        return sprintf( _n( '%s hour ago', '%s hours ago', $hours, 'mow' ), $hours );
    }

    // For times less than two days, display "yesterday"
    if ( $time_diff < 2 * DAY_IN_SECONDS ) {
        return esc_html__( 'Yesterday', 'mow' );
    }

    // For times less than a week, display days
    if ( $time_diff < WEEK_IN_SECONDS ) {
        $days = floor( $time_diff / DAY_IN_SECONDS );
        return sprintf( _n( '%s day ago', '%s days ago', $days, 'mow' ), $days );
    }

    // For times less than a month, display weeks
    if ( $time_diff < MONTH_IN_SECONDS ) {
        $weeks = floor( $time_diff / WEEK_IN_SECONDS );
        return sprintf( _n( '%s week ago', '%s weeks ago', $weeks, 'mow' ), $weeks );
    }

    // For times less than a year, display months
    if ( $time_diff < YEAR_IN_SECONDS ) {
        $months = floor( $time_diff / MONTH_IN_SECONDS );
        return sprintf( _n( '%s month ago', '%s months ago', $months, 'mow' ), $months );
    }

    // For times more than a year, display years
    $years = floor( $time_diff / YEAR_IN_SECONDS );
    return sprintf( _n( '%s year ago', '%s years ago', $years, 'mow' ), $years );
}


function mow_fn_metas($args){
	$display 		= $args['meta_display'] ?? array();
	$post_id 		= $args['post_id'] ?? '';
    $author 		= $args['author'] ?? '';
    $category_count = $args['category_count'] ?? 1;
    $sticky_post 	= $args['sticky_post'] ?? false;
    $page_views 	= $args['page_views'] ?? false;
	global $mow_fn_option;
	$html  = '';
	$has_date = $has_category = true;
	if(!empty($display)){
		$has_date = in_array('date', $display);
		$has_category = in_array('category', $display);
	}
	if($post_id!=''){
		if(is_sticky($post_id) && $sticky_post){
			$html .= '<span class="meta_item sticky_label"><span class="text">'.esc_html__('Sticky Post', 'mow').'</span></span>';
		}
		// meta author
		if($author != ''){
			$author_switcher = 'enable';
			if(isset($mow_fn_option['author_switcher'])){
				$author_switcher = $mow_fn_option['author_switcher'];
			}
			if($author_switcher == 'enable'){
				$image = '';
				$author_id 	= get_post_field ('post_author', $post_id);
				if($author == 'both'){
					$imageURL	= esc_url( get_the_author_meta( 'mow_fn_user_image', $author_id ) );
					if($imageURL == ''){
						$image	= get_avatar( $author_id, 30 );
					}else{
						$image	= '<img loading="lazy" src="'.$imageURL.'" alt="">';
					}
				}
				$html .= '<span class="meta_item meta_author"><a href="' . get_author_posts_url($author_id) . '" aria-label="'.esc_attr__('See all posts by this author', 'mow').'">' . $image .'<span class="text">' . get_the_author_meta('display_name',$author_id) . '</span></a><span class="meta_sep"></span></span>';
			}
		}

		// meta category
		if($has_category){
			$category = mow_fn_get_categories($post_id, '', 'category', $category_count, ',&nbsp;');
			if($category != ''){
				$html .= $category . '<span class="meta_sep"></span>';
			}
		}
		
		// meta date
		if($has_date){
			$time_format = 'difference';
			if(isset($mow_fn_option['time_format'])){
				$time_format = $mow_fn_option['time_format'];
			}
			$date_title = get_the_time(get_option('date_format'), $post_id);
			if($time_format == 'difference'){
				$date = mow_fn_human_readable_time_diff($post_id);
			}else{
				$date = $date_title;
			}
			$html .= '<span class="meta_item meta_date" title="'.esc_attr($date_title).'">' . $date . '<span class="meta_sep"></span></span>';
		}

		if($page_views){
			$count = mow_fn_get_post_views($post_id, 'up');
			$countShort = mow_fn_number_format_short($count);
			$views = '<span class="meta_item post_views" title="'.esc_attr($count).'">' . $countShort . ' ' . esc_html__('Views','mow') . '<span class="meta_sep"></span></span>';
			$html .= $views;
		}

		$html = '<div class="fn__meta"><p>'.$html.'</p></div>';
	}
	
		
	
	return $html;
}

function mow_fn_get_categories($post_id, $from, $taxonomy = 'category', $categoryCount = 999, $separator = ',&nbsp;'){
	$categoryCount		= (int)$categoryCount;
	$catHolder			= '';
	if(mow_fn_taxanomy_list($post_id, $taxonomy, false, $categoryCount) != ""){
		$catHolder	= mow_fn_taxanomy_list($post_id, $taxonomy, false, $categoryCount, $separator, '');
	}
	if($from == 'single'){
		if($catHolder != ''){
			$catHolder = '<div class="fn__categories">'.$catHolder.'</div>';
		}
	}
	return $catHolder;
}

add_filter('wp_list_categories', 'mow_fn_cat_count_span');
function mow_fn_cat_count_span($links) {
  	$links = str_replace('</a> (', '</a> <span class="count">', $links);
  	$links = str_replace(')', '</span>', $links);
  	return $links;
}

function mow_fn_if_has_sidebar(){
	if(is_single()){
		if ( is_active_sidebar( 'main-sidebar' ) ){
			return true;
		}else{
			return false;
		}
	}else {
		if ( is_active_sidebar( 'main-sidebar' ) ){
			return true;
		}else{
			return false;
		}
	}
}

function mow_fn_simple_prevnext_meta() {
    if (is_singular('post')) {
        $prev_post = get_adjacent_post(false, '', true); 
        $next_post = get_adjacent_post(false, '', false);

        $output = '';

        if ($prev_post) {
            $prev_url = get_permalink($prev_post->ID);
            $output .= '<link rel="prev" href="' . esc_url($prev_url) . '" />' . "\n";
        }

        if ($next_post) {
            $next_url = get_permalink($next_post->ID);
            $output .= '<link rel="next" href="' . esc_url($next_url) . '" />' . "\n";
        }

        echo $output;
    }
}
add_action('wp_head', 'mow_fn_simple_prevnext_meta');


function mow_fn_simple_prevnext(){
	global $mow_fn_option;
	$single_prevnext__layout = 'enable';
	if(isset($mow_fn_option['single_prevnext__layout'])){
		$single_prevnext__layout = $mow_fn_option['single_prevnext__layout'];
	}
	if($single_prevnext__layout != 'none'){
		$prev_post 	= get_adjacent_post(false, '', true);
		$next_post 	= get_adjacent_post(false, '', false);
		global $mow_fn_option;
		$prevPostTitle		= esc_html__('Prev Post', 'mow');
		$nextPostTitle		= esc_html__('Next Post', 'mow');

		$nextHasImg = $prevHasImg = $prevImgURL = $nextImgURL = $prevPostURL = $nextPostURL = $prevPostID = $nextPostID = $prevImage = $nextImage = '';
		if(!empty($prev_post)) {
			$prevPostID		= $prev_post->ID;
			$prevPostTitle	= esc_html(strip_tags($prev_post->post_title));
			if($prevPostTitle == ''){
				$prevPostTitle = esc_html__('Prev Post: No Title', 'mow');
			}
			$prevPostURL	= get_permalink($prevPostID);
			$thumbID 		= get_post_thumbnail_id( $prevPostID );
			if(isset(wp_get_attachment_image_src( $thumbID, 'full')[0])){
				$prevImgURL = wp_get_attachment_image_src( $thumbID, 'full')[0];
			}
			if($prevImgURL != ''){$prevHasImg = 'yes';}
		}
		if(!empty($next_post)) {
			$nextPostID		= $next_post->ID;
			$nextPostTitle	= esc_html(strip_tags($next_post->post_title));
			if($nextPostTitle == ''){
				$nextPostTitle = esc_html__('Next Post: No Title', 'mow');
			}
			$nextPostURL	= get_permalink($nextPostID);
			$thumbID 		= get_post_thumbnail_id( $nextPostID );
			if(isset(wp_get_attachment_image_src( $thumbID, 'full')[0])){
				$nextImgURL = wp_get_attachment_image_src( $thumbID, 'full')[0];
			}
			if($nextImgURL != ''){$nextHasImg = 'yes';}
		}


		if ($prev_post && $next_post) { 
			$prevnext		= 'yes';
		}else if(!$prev_post && $next_post){
			$prevnext		= 'next';
		}else if($prev_post && !$next_post){
			$prevnext		= 'prev';
		}else{
			$prevnext		= 'no';
		}
		
		$prevPlaceholderText = '';
		if($prevHasImg == ''){
			$prevPlaceholderText = mb_substr($prevPostTitle, 0, 1);
		}
		if($prevImgURL != ''){
			$prevImage = '<img loading="lazy" src="'.$prevImgURL.'" alt="">';
		}
		
		$nextPlaceholderText = '';
		if($nextHasImg == ''){
			$nextPlaceholderText = mb_substr($nextPostTitle, 0, 1);
		}
		if($nextImgURL != ''){
			$nextImage = '<img loading="lazy" src="'.$nextImgURL.'" alt="">';
		}
		
		
		$prevTopTitle = '<h3 class="fn__lined_title"><span>'.esc_html__('Previous Post', 'mow').'</span></h3>';
		$nextTopTitle = '<h3 class="fn__lined_title reverse"><span>'.esc_html__('Next Post', 'mow').'</span></h3>';
		$pn_title_holder = '<div class="pn_title_holder"><div class="pnt_left">'.$prevTopTitle.'</div><div class="pnt_right">'.$nextTopTitle.'</div></div>';
		
		// Previous
		$prevHolder  = '<div class="prev item mob_title">'.$prevTopTitle.'</div>';
		$prevHolder  .= '<div class="prev item" title="'.$prevPostTitle.'">';
			$prevHolder .= '<div class="img_holder" data-has-image="'.$prevHasImg.'"><a href="'.$prevPostURL.'" aria-label="'.esc_attr__('Previous Post', 'mow').'"></a>'.$prevImage.$prevPlaceholderText.'</div>';
			$prevHolder .= '<div class="title_holder">';
			$prevHolder .= mow_fn_metas(array('post_id' => $prevPostID));
			$prevHolder .= '<h3 class="fn_title"><a href="'.$prevPostURL.'" aria-label="'.esc_attr__('Previous Post', 'mow').'">'.$prevPostTitle.'</a></h3>';
			$prevHolder .= '</div>';	
		$prevHolder .= '</div>';
		
		// Next
		$nextHolder  = '<div class="next item mob_title">'.$nextTopTitle.'</div>';
		$nextHolder  .= '<div class="next item" title="'.$nextPostTitle.'">';
			$nextHolder .= '<div class="img_holder" data-has-image="'.$nextHasImg.'"><a href="'.$nextPostURL.'" aria-label="'.esc_attr__('Next Post', 'mow').'"></a>'.$nextImage.$nextPlaceholderText.'</div>';
			$nextHolder .= '<div class="title_holder">';
			$nextHolder .= mow_fn_metas(array('post_id' => $nextPostID));
			$nextHolder .= '<h3 class="fn_title"><a href="'.$nextPostURL.'" aria-label="'.esc_attr__('Next Post', 'mow').'">'.$nextPostTitle.'</a></h3>';
			$nextHolder .= '</div>';
		$nextHolder .= '</div>';


		if($prevnext == 'no'){
			return '<div class="mow_fn_pnb" data-status="'.$prevnext.'"></div>';
		}
		return '<div class="mow_fn_pnb" data-status="'.$prevnext.'">'.$pn_title_holder.'<div class="pnb_wrapper">'.$prevHolder.$nextHolder.'</div></div>';
	}else{
		return '';
	}
}

function mow_fn_get_post_views($post_id, $action = ''){
	global $mow_fn_option;
	$countt = 0;
	if(isset($mow_fn_option['post_views_fake']) && $mow_fn_option['post_views_fake'] == 'enable' && isset($mow_fn_option['post_views_fake_count'])){
		$countt = (int)$mow_fn_option['post_views_fake_count'];
	}
    $count_key = 'frenify_post_views_count';
	$count = get_post_meta($post_id, $count_key, true);
	if ($count === '') { $count = 0; }
	if($action == 'up'){
		$cookie_name = $count_key . $post_id;
		if (empty($_COOKIE[$cookie_name])) {
			$count++;
		}
	}
	$count += $countt;
	return $count;
}

function mow_fn_set_post_views($post_id) {
	global $mow_fn_option;

	$count_key = 'frenify_post_views_count';
	$count = get_post_meta($post_id, $count_key, true);

	if ($count === '') {
		add_post_meta($post_id, $count_key, 1);
	} else {
		$cookie_name = $count_key . $post_id;
		if (empty($_COOKIE[$cookie_name])) {
			$interval = isset($mow_fn_option['post_views_interval']) ? (int) $mow_fn_option['post_views_interval'] : 86400;
			$count++;
			update_post_meta($post_id, $count_key, $count);
			if (!headers_sent()) {
				setcookie($cookie_name, $post_id, time() + $interval, '/');
			}
		}
	}
}


function mow_fn_detect_video($url = '') {
    $type = '';

    // Regular expression for local video file formats
    $videoExtensions = '/\.(mp4|avi|mkv|flv|wmv|mov|webm|m4v|ogg|ogv|3gp|3g2|f4v|f4p|f4a|f4b|asf|mpeg|mpg|mts|ts|vob)$/i';

    // Iterate through each URL and sort based on type
	if (preg_match('/^(https?:\/\/)?(www\.)?(youtube\.com|youtu\.be)\//', $url)) {
		$type = 'youtube';
	} /* elseif (preg_match('/^(https?:\/\/)?(www\.)?vimeo\.com\//', $url)) {
		$type = 'vimeo';
	}*/ elseif (preg_match($videoExtensions, $url)) {
		$type = 'local';
	}

    return $type;
}

function mow_fn_fletch_post_data(){
	check_ajax_referer( 'mow-secure', 'security' );
	if (isset($_POST['url'])) {
        $url = sanitize_text_field($_POST['url']);

		$number = mow_fn_is_link_post_duplicate_by_url($url);

        // Fetch the content of the external URL
        $response = wp_remote_get($url);

        if (is_wp_error($response)) {
            wp_send_json_error(array('message' => esc_html__('Failed to retrieve content.','mow')));
        }

        // Get the body of the response
		$body = wp_remote_retrieve_body($response);

		// Extract metadata using regex (Open Graph or meta tags)
		preg_match('/<title>(.*?)<\/title>/is', $body, $matches_title);
		preg_match('/<meta\s+property=["\']og:image["\']\s+content=["\'](.*?)["\']\s*\/?>/i', $body, $matches_image);
		preg_match('/<meta\s+name=["\']description["\']\s+content=["\'](.*?)["\']\s*\/?>/i', $body, $matches_description);
		preg_match('/<meta\s+property=["\']og:description["\']\s+content=["\'](.*?)["\']\s*\/?>/i', $body, $matches_og_description);

		// Fallback to the first <p> tag if no meta description is found
		if (empty($matches_description[1]) && empty($matches_og_description[1])) {
			preg_match('/<p>(.*?)<\/p>/is', $body, $matches_first_paragraph);
			$description = isset($matches_first_paragraph[1]) ? wp_strip_all_tags($matches_first_paragraph[1]) : esc_html__('No description available', 'mow');
		} else {
			// Prioritize Open Graph description, fallback to meta description
			$description = !empty($matches_og_description[1]) ? wp_strip_all_tags($matches_og_description[1]) : wp_strip_all_tags($matches_description[1]);
		}

		// Set default values in case no data is found
		$title = isset($matches_title[1]) ? wp_strip_all_tags($matches_title[1]) : esc_html__('No title available', 'mow');
		$image = isset($matches_image[1]) ? $matches_image[1] : '';


        // Return the extracted data as JSON
        wp_send_json_success(array(
            'title' => $title,
            'image' => $image,
            'excerpt' => $description,
            'number' => $number
        ));
    } else {
        wp_send_json_error(array('message' => esc_html__('Invalid URL.','mow')));
    }
}

function mow_fn_is_link_post_duplicate_by_url($url_to_check) {
    global $wpdb;
	$url_to_check = rtrim($url_to_check, '/');
    // Query the posts by checking the post_format and the content (URL)
    $sql = "
        SELECT COUNT(*) 
        FROM {$wpdb->posts} p
        JOIN {$wpdb->term_relationships} tr ON p.ID = tr.object_id
        JOIN {$wpdb->term_taxonomy} tt ON tr.term_taxonomy_id = tt.term_taxonomy_id
        JOIN {$wpdb->terms} t ON tt.term_id = t.term_id
        WHERE t.slug = 'post-format-link' 
        AND p.post_content LIKE %s
        AND p.post_status = 'publish'
    ";

    $query = $wpdb->prepare($sql, '%' . $wpdb->esc_like($url_to_check) . '%');
    $count = $wpdb->get_var($query);

    // If any rows are returned, it means the URL is already in the content
    return $count > 0;
}



function mow_fn_new_post_popup($adding__link = '',$adding__post = ''){
	
	?>
	<div id="mow_fn_newpost_bar" style="display: none;" data-link="<?php echo esc_attr($adding__link); ?>" data-post="<?php echo esc_attr($adding__post); ?>">
		<a class="fn__popup_closer" href="#" aria-label="<?php esc_attr_e('Close lightbox', 'mow'); ?>"><span></span></a>
		<div class="bar_content">

			<?php if($adding__post == 'enable' && $adding__link == 'enable'){ ?>
			<!-- Step #1 -->
			<div class="step1">
				<div class="step1_in">
					<div class="bar_item bar_link_item">
						<a href="#" class="bar_link_btn" aria-label="<?php esc_attr_e('Add a post with link post format', 'mow'); ?>">
							<span class="l_icon"><?php mow_fn_svg('svg__expand2','',true); ?></span>
							<span class="text"><?php esc_html_e('Add a link', 'mow'); ?></span>
						</a>
					</div>
					<div class="bar_or"><?php esc_html_e('Or', 'mow'); ?></div>
					<div class="bar_item bar_post_item">
						<a href="#" class="bar_post_btn" aria-label="<?php esc_attr_e('Add a post with standard post format', 'mow'); ?>">
							<span class="l_icon"><?php mow_fn_svg('svg__post','',true); ?></span>
							<span class="text"><?php esc_html_e('Add a post', 'mow'); ?></span>
						</a>
					</div>
				</div>
			</div>
			<!-- /Step #1 -->
			<?php } ?>
			

			<?php if($adding__link == 'enable'){ ?>
			<!-- Step #2: Link -->
			<div class="step2_link">
				<div class="fn__preloader">
					<span class="icon"></span>
					<span class="text"><?php esc_html_e('Processing page meta data','mow'); ?></span>
				</div>
				<div class="step2_link_in">
					<span class="l_icon"><?php mow_fn_svg('svg__expand2','',true); ?></span>
					<span class="step2_link_text"><?php esc_html_e('Paste the external URL', 'mow'); ?></span>
					<input class="fn__insertlink" type="text" placeholder="<?php esc_attr_e('Enter the external URL', 'mow'); ?>" name="url">
				</div>
			</div>
			<!-- /Step #2: Link -->
			<?php } ?>

			<?php if($adding__link == 'enable'){ ?>
			<!-- Step #3: Link -->
			<div class="step3_link">
				<div class="fn__preloader">
					<span class="icon"></span>
					<span class="text"><?php esc_html_e('Processing your request, please wait...','mow'); ?></span>
				</div>
				<div class="container">
					<div class="fn__newpost_form">
						<h3 class="heading"><?php esc_html_e('Adding a Link', 'mow'); ?></h3>
						<div class="fn__newpost_form_in">
							<div class="form_left">
								<div class="field">
									<input type="text" class="title" placeholder="<?php esc_attr_e('Enter title', 'mow'); ?>" name="title">
								</div>
								<div class="field">
									<textarea class="description" placeholder="<?php esc_attr_e('Enter Description', 'mow'); ?>" name="description"></textarea>
								</div>
							</div>
							<div class="form_right">
								<div class="field"><span class="link"></span></div>
								<div class="field">
									<div class="fn__dragbox">
										<div class="upload-area">
											<p class="text"><?php esc_html_e('Drop thumbnail here', 'mow'); ?></p>
											<span class="or"><span><?php esc_html_e('OR', 'mow'); ?></span></span>
											<div class="upload-buttons">
												<button class="browse-btn"><?php esc_html_e('Browse Files', 'mow'); ?></button>
												<button class="url-btn"><?php esc_html_e('Get Image From URL', 'mow'); ?></button>
											</div>
											<p class="file-size-info"><?php esc_html_e('Maximum upload file size: 2 MB.', 'mow'); ?></p>
										</div>

										<div class="url-box">
											<h3><?php esc_html_e('Get Image From URL', 'mow'); ?></h3>
											<input type="text" class="image-url-input" placeholder="https://" name="image">
											<div class="url-buttons">
												<button class="back-btn"><?php esc_html_e('Back', 'mow'); ?></button>
												<button class="get-image-btn"><?php esc_html_e('Get Image', 'mow'); ?></button>
											</div>
											<p class="file-size-info"><?php esc_html_e('Maximum upload file size: 2 MB.', 'mow'); ?></p>
										</div>
										<div class="preview"><a href="#" class="closer" title="<?php esc_attr_e('Remove this image', 'mow'); ?>" aria-label="<?php esc_attr_e('Remove featured image', 'mow'); ?>"><span></span></a></div>
										<input type="file" class="file-input" accept="image/*" name="image_file" hidden>
									</div>
								</div>
								<div class="field">
									<div class="fn__category_box">
										<select name="categories[]" class="categories" multiple>
											<option value="-1" disabled><?php esc_html_e('- Select Categories -', 'mow'); ?></option>
											<?php
											$categories = get_categories(array(
												'hide_empty' => false, // Include categories with no posts
											));
											foreach ($categories as $category) {
												echo '<option value="' . esc_attr($category->term_id) . '">' . esc_html($category->name) . '</option>';
											}
											?>
										</select>
									</div>
								</div>
								<div class="field">
									<div class="fn__tag_box">
										<ul>
											<li class="new">
												<input type="text" placeholder="<?php esc_attr_e('Enter Tags', 'mow'); ?>" name="tag">
											</li>
										</ul>
									</div>
								</div>
								<div class="field">
									<a href="#" class="fn__submit_new_post fn__submit_new_post_link" aria-label="<?php esc_attr_e('Submit a post for a review', 'mow'); ?>"><?php esc_html_e('Submit for review', 'mow'); ?></a>
								</div>
								<div class="field cancel">
									<a href="#" class="fn_cancel_new_post fn_cancel_new_post_link" aria-label="<?php esc_attr_e('Cancel adding a post', 'mow'); ?>"><?php esc_html_e('Cancel', 'mow'); ?></a>
								</div>
								
							</div>	
						</div>
						
					</div>
				</div>
				
			</div>
			<!-- /Step #3: Link -->
			<?php } ?>

			<?php if($adding__post == 'enable'){ ?>
			<!-- Step #2: Post -->
			<div class="step2_post">
				<div class="fn__preloader">
					<span class="icon"></span>
					<span class="text"><?php esc_html_e('Processing your request, please wait...','mow'); ?></span>
				</div>
				<div class="container">
					<div class="fn__newpost_form">
						<h3 class="heading"><?php esc_html_e('Add a Post', 'mow'); ?></h3>
						<div class="fn__newpost_form_in">
							<div class="form_left">
								<div class="field">
									<input type="text" class="title" placeholder="<?php esc_attr_e('Enter title', 'mow'); ?>">
								</div>
								<div class="field">
									<div class="new-post-content">
										<div id="new_post_content" style="height:500px;"></div>
									</div>
								</div>
							</div>
							<div class="form_right">
								<div class="field">
									<div class="fn__dragbox">
										<div class="upload-area">
											<p class="text"><?php esc_html_e('Drop thumbnail here', 'mow'); ?></p>
											<span class="or"><span><?php esc_html_e('OR', 'mow'); ?></span></span>
											<div class="upload-buttons">
												<button class="browse-btn"><?php esc_html_e('Browse Files', 'mow'); ?></button>
												<button class="url-btn"><?php esc_html_e('Get Image From URL', 'mow'); ?></button>
											</div>
											<p class="file-size-info"><?php esc_html_e('Maximum upload file size: 2 MB.', 'mow'); ?></p>
										</div>

										<div class="url-box">
											<h3><?php esc_html_e('Get Image From URL', 'mow'); ?></h3>
											<input type="text" class="image-url-input" placeholder="https://">
											<div class="url-buttons">
												<button class="back-btn"><?php esc_html_e('Back', 'mow'); ?></button>
												<button class="get-image-btn"><?php esc_html_e('Get Image', 'mow'); ?></button>
											</div>
											<p class="file-size-info"><?php esc_html_e('Maximum upload file size: 2 MB.', 'mow'); ?></p>
										</div>
										<div class="preview"><a href="#" class="closer" title="<?php esc_attr_e('Remove this image', 'mow'); ?>" aria-label="<?php esc_attr_e('Remove featured image', 'mow'); ?>"><span></span></a></div>
										<input type="file" class="file-input" accept="image/*" name="image_file" hidden>
									</div>
								</div>
								<div class="field">
									<div class="fn__category_box">
										<select name="categories[]" class="categories" multiple>
											<option value="-1" disabled><?php esc_html_e('- Select Categories -', 'mow'); ?></option>
											<?php
											$categories = get_categories(array(
												'hide_empty' => false, // Include categories with no posts
											));
											foreach ($categories as $category) {
												echo '<option value="' . esc_attr($category->term_id) . '">' . esc_html($category->name) . '</option>';
											}
											?>
										</select>
									</div>
								</div>
								<div class="field">
									<div class="fn__tag_box">
										<ul>
											<li class="new">
												<input type="text" placeholder="<?php esc_attr_e('Enter Tags', 'mow'); ?>">
											</li>
										</ul>
									</div>
								</div>
								<div class="field">
									<a href="#" class="fn__submit_new_post fn__submit_new_post_post" aria-label="<?php esc_attr_e('Submit a post for a review', 'mow'); ?>"><?php esc_html_e('Submit for review', 'mow'); ?></a>
								</div>
								<div class="field cancel">
									<a href="#" class="fn_cancel_new_post fn_cancel_new_post_post" aria-label="<?php esc_attr_e('Cancel adding a post', 'mow'); ?>"><?php esc_html_e('Cancel', 'mow'); ?></a>
								</div>
								
							</div>	
						</div>
						
					</div>
				</div>
				
			</div>
			<!-- /Step #2: Post -->
			<?php } ?>


		</div>
	</div>
<?php
}
function mow_fn_get_video($post_id, $autoplay = true, $stopAt = 5, $ratio = 'auto'){
	if($ratio == ''){$ratio = 'auto';}
	$video_url = get_post_meta($post_id, 'frenify_fn_video_url', true);
	$permalink = get_the_permalink($post_id);
	$video_post = '';
	$video_icons = '';
	$rating_number = mow_fn_get_rating_number($post_id);
	if($video_url != ''){
		$video_type = mow_fn_detect_video($video_url);
		if($video_type == 'youtube'){
			if($autoplay){
				$autoplay_attr = 'autoPlay:true,';
				$paused_attr = '';
			}else{
				$autoplay_attr = 'autoPlay:false,';
				$paused_attr = 'paused';
			}


			$video_icons .= '<div class="fn__video_icons">';
			$video_icons .= '<button class="fn__video_btn_play" aria-label="'.esc_attr__('Play / Pause', 'mow').'"><span class="t_text">'.esc_html__('Play / Pause', 'mow').'</span><span class="play">'.mow_fn_svg('svg__play').'</span><span class="pause"></span></button>';
			$video_icons .= '<button class="fn__video_btn_volume" aria-label="'.esc_attr__('Mute / Unmute', 'mow').'"><span class="t_text">'.esc_html__('Mute / Unmute', 'mow').'</span><span class="mute">'.mow_fn_svg('svg__mute').'</span><span class="unmute">'.mow_fn_svg('svg__unmute').'</span></button>';
			$video_icons .= '<a class="fn__video_btn_youtube" href="'.$video_url.'" target="_blank" aria-label="'.esc_attr__('Watch Full Video on YouTube', 'mow').'"><span class="t_text">'.esc_html__('Watch Full Video on YouTube', 'mow').'</span>'.mow_fn_svg('svg__youtube').'</a>';
			$video_icons .= '</div>';

			$video_url = '<div class="fn__video_youtube" data-property="{videoURL:\''.$video_url.'\', containment:\'self\', '.$autoplay_attr.' loop:true, mute:true, showControls:false, realfullscreen:false, playOnlyIfVisible:true, stopMovieOnBlur:false, startAt:0, stopAt:5, opacity:1, showYTLogo: false, showYTLogo: false, anchor: \'center,center\'}"></div>';

			$imageURL = get_the_post_thumbnail_url($post_id,'full');
			if($imageURL != ''){
				$video_post = '<div class="fn__video_post '.$paused_attr.'" data-video="youtube" data-ratio="'.$ratio.'"><div class="blog__image"><a class="fn__full_link" href="'.$permalink.'"  aria-label="/"></a>'.$video_icons.$rating_number.$video_url.'<img loading="lazy" decoding="async" class="yt_fallback_img" src="'.$imageURL.'" alt="'.esc_attr__('Fallback Image', 'mow').'"></div></div>';
			}else{
				$video_post = '<div class="fn__video_post '.$paused_attr.'" data-video="youtube" data-ratio="'.$ratio.'"><div class="item_space"><a class="fn__full_link" href="'.$permalink.'"  aria-label="/"></a>'.$video_icons.$rating_number.$video_url.'</div></div>';
			}
		}else if($video_type == 'local'){
			if($autoplay){
				$autoplay_attr = 'autoplay';
				$paused_attr = '';
			}else{
				$autoplay_attr = '';
				$paused_attr = 'paused';
			}
			$video_icons .= '<div class="fn__video_icons">';
			$video_icons .= '<button class="fn__video_btn_play" aria-label="'.esc_attr__('Play / Pause', 'mow').'"><span class="t_text">'.esc_html__('Play / Pause', 'mow').'</span><span class="play">'.mow_fn_svg('svg__play').'</span><span class="pause"></span></button>';
			$video_icons .= '<button class="fn__video_btn_volume" aria-label="'.esc_attr__('Mute / Unmute', 'mow').'"><span class="t_text">'.esc_html__('Mute / Unmute', 'mow').'</span><span class="mute">'.mow_fn_svg('svg__mute').'</span><span class="unmute">'.mow_fn_svg('svg__unmute').'</span></button>';
			$video_icons .= '<button class="fn__video_btn_expand" aria-label="'.esc_attr__('Fullscreen', 'mow').'"><span class="t_text">'.esc_html__('Fullscreen', 'mow').'</span>'.mow_fn_svg('svg__expand').'</button>';
			$video_icons .= '</div>';
			$video_url = '<video class="fn__video_local lazy-video" '.$autoplay_attr.' loop muted playsinline style="aspect-ratio: '.$ratio.'"><source data-src="'.$video_url.'" type="video/mp4"></video>';

			$video_post = '<div class="fn__video_post '.$paused_attr.'" data-video="local"><a class="fn__full_link" href="'.$permalink.'" aria-label="/"></a>'.$video_icons.$rating_number.$video_url.'</div>';
		}
	}
	return $video_post;
}

function mow_fn_get_image_dimensions( $post_id ) {
	$output = '';
    // Получаем URL изображения
    $imageURL = get_the_post_thumbnail_url( $post_id, 'full' );

    // Получаем ID вложения из URL
    $attachmentID = attachment_url_to_postid( $imageURL );

    if ( $attachmentID ) {
        // Получаем метаданные изображения
        $metadata = wp_get_attachment_metadata( $attachmentID );

        if ( $metadata ) {
            $output = 'width="'.$metadata['width'].'" height="'.$metadata['height'].'"';
        }
    }

    return $output;
}


function mow_fn_get_post($type = 'classic'){
	global $mow_fn_option;
	$list			= '';
	$post_id 		= get_the_ID();
	$permalink 		= get_the_permalink();
	$postClasses  	= 'class="'.implode(' ', get_post_class()).' post_item"';
	if($type == 'simple_text'){
		$post_title		= '';
		if(get_the_title() !== ''){
			$seo_blog_list_title = 'h2';
			if(isset($mow_fn_option['seo_blog_list_title'])){
				$seo_blog_list_title = $mow_fn_option['seo_blog_list_title'];
			}
			$post_title = '<'.$seo_blog_list_title.' class="post_title"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags(get_the_title())).'">'.get_the_title().'</a></'.$seo_blog_list_title.'>';
		}
		$description = mow_fn_excerpt($post_id);
		if($description != ''){
			$description = '<p class="fn__descr">'.$description.'</p>';
		}
		$list  = '<article '.$postClasses.' id="post-'.$post_id.'"><div class="blog__item blog__item_'.$type.'">';
		$list .= mow_fn_metas(array('post_id' => $post_id, 'sticky_post' => true));
		$list .= '<div class="title_holder">';
		$list .= $post_title;
		$list .= $description;
		$list .= '</div>';
		$list .= '</div></article>';
	}else if($type == 'small_list' || $type == 'small_list_2'){
		$extraClass = '';
		$title = get_the_title();
		if($title == '') { $title = '/'; }
		$seo_blog_list_title = 'h2';
		if(isset($mow_fn_option['seo_blog_list_title'])){
			$seo_blog_list_title = $mow_fn_option['seo_blog_list_title'];
		}
		$post_title = '<'.$seo_blog_list_title.' class="fn__title"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags(get_the_title())).'">'.$title.'</a></'.$seo_blog_list_title.'>';
		$icon_type = '';
		$author = 'both';
		if($type == 'small_list_2'){
			$icon_type = 'modern';
			$extraClass .= 'blog__item_small_list_2 ';
			$author = 'text';
		}
		$icon_holder = mow_fn_relink_icon($post_id, $icon_type);
		$vote_layout = 'vclassic';
		$point_holder = mow_fn_vote($post_id, 'return', $vote_layout);
		if($icon_holder != ''){
			$extraClass .= ' has_share';
		}
		if($point_holder != ''){
			$extraClass .= ' has_vote_'.$vote_layout;
		}

		$list  			= '<article '.$postClasses.' id="post-'.$post_id.'"><div class="blog__item blog__item_small_list '.$extraClass.'">';
		$imageURL 		= get_the_post_thumbnail_url($post_id,'large');


		if($imageURL != ''){
			$img_holder = '<div class="img_holder"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'large', ['loading' => 'lazy']).'</a></div>';
		}else{
			$img_holder = '';
			$img_holder = '<div class="img_holder img_t"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">' . mb_substr($title, 0, 1) . '</a></div>';
		}


		$extra_meta = mow_fn_relink_meta($post_id, $icon_type);

		$title_holder = '<div class="title_holder"><div class="title_holder_in">'.mow_fn_metas(array('post_id' => $post_id,'author' => $author)).$post_title.$extra_meta.$icon_holder.'</div></div>';
		$right_holder  = '<div class="item_right">';
		$right_holder  .= $img_holder;
		$right_holder  .= $title_holder;
		$right_holder .= '</div>';

		$list .= $point_holder;
		$list .= $right_holder;
		$list .= '</div></article>';
	}else{
		$rating			= mow_fn_get_rating_number($post_id);
		
		// Post Title
		$post_title		= '';
		if(get_the_title() !== ''){
			$seo_blog_list_title = 'h2';
			if(isset($mow_fn_option['seo_blog_list_title'])){
				$seo_blog_list_title = $mow_fn_option['seo_blog_list_title'];
			}
			$post_title = '<div class="title"><'.$seo_blog_list_title.' class="fn__title"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags(get_the_title())).'">'.get_the_title().'</a></'.$seo_blog_list_title.'></div>';
		}
		
		// post start & end
		$post_start = '<article '.$postClasses.' id="post-'.$post_id.'"><div class="blog__item blog__item_'.$type.'">';
		$post_end 	= '</div></article>';

		$img_holder = '';
		$post_format = get_post_format();
		if($post_format == 'video'){
			$video_autoplay = true;
			if(isset($mow_fn_option['video_autoplay'])){
				$video_autoplay = $mow_fn_option['video_autoplay'];
			}
			$img_holder = mow_fn_get_video($post_id, $video_autoplay);
			if($img_holder == ''){ $post_format = 'standard'; }
		}else if($post_format == 'gallery'){
			if(isset(get_post_meta($post_id)['frenify_fn_postgallery'])){
				$gallery = get_post_meta($post_id,'frenify_fn_postgallery', false);
				if(!empty($gallery)){
					$gallery_count = mow_fn_gallery_count($post_id);
					$img_holder .= '<div class="fn__gallery_format">'.$gallery_count.$rating.'<div class="swiper"><div class="swiper-wrapper">';
					
					foreach($gallery as $galleryID){
						$img_holder .= '<div class="swiper-slide"><div class="item" data-bg-img="'.wp_get_attachment_image_url($galleryID,'large').'"></div></div>'; 
					}
					$arrow = mow_fn_svg('arrow');
					$gallery_nav = '<div class="slider__nav"><a href="#" class="slider_nav prev" aria-label="'.esc_attr__('Previous Slide', 'mow').'">'.$arrow.'</a><a href="#" class="slider_nav next" aria-label="'.esc_attr__('Next Slide', 'mow').'">'.$arrow.'</a></div>';
					$img_holder .= '</div></div></div>';
					
					$post_format = 'gallery';
				}else{
					$post_format = 'standard';
				}
			}else{
				$post_format = 'standard';
			}
		}
		
		$list .= $post_start;
		if($img_holder == ''){
			$imageURL 		= get_the_post_thumbnail_url($post_id,'full');
			if($imageURL != ''){
				$img_holder = '<div class="blog__image">'.$rating.'<a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'full', ['loading' => 'lazy']).'</a></div>';
			}
		}

		$description = mow_fn_excerpt($post_id);
		if($description != ''){
			$description = '<div class="desc"><p>'.$description.'</p></div>';
		}

		$read_more = '<div class="fn__read_more"><a href="'.get_the_permalink().'" aria-label="'.esc_attr(sprintf(__('Read more about %s', 'mow'), strip_tags(get_the_title()))).'"><span class="text" aria-label="'.esc_html__('Read More', 'mow').'">'.esc_html__('Read More', 'mow').'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>';

		$title_holder = '<div class="title_holder">'.mow_fn_metas(array('post_id' => $post_id, 'sticky_post' => true)).$post_title.$description.$read_more.'</div>';

		$list .= $img_holder;
		$list .= $title_holder;
		$list .= $post_end;
	}
	


	return $list;


}

function mow_fn_votekey(){
	$vote_key = 'points';
	$sort = '';
	if(isset($_GET['sort'])){
		$sort = esc_html($_GET['sort']);
	}
	if($sort == 'total_votes'){
		$vote_key = 'total';
	}else if($sort == 'upvotes'){
		$vote_key = 'up';
	}else if($sort == 'downvotes'){
		$vote_key = 'down';
	}
	return $vote_key;
}


function mow_fn_get_relink($args){
    $ajax 			= $args['ajax'] ?? '';
    $type 			= $args['post_layout'] ?? 1;
    $vote_key 		= $args['vote_key'] ?? 'points';
	global $mow_fn_option;
	$vote_layout	= 'vclassic';
	if(isset($mow_fn_option['relink_vote_layout'])){
		$vote_layout = $mow_fn_option['relink_vote_layout'];
	}
	if($ajax){$extraClass = 'fn_new_ajax_post';}else{$extraClass = '';}
	$list			= '';
	$post_id 		= get_the_ID();
	$permalink 		= get_the_permalink();
	if(is_sticky()){
		$extraClass .= 'sticky';
	}
	$postClasses  	= 'class="'.implode(' ', get_post_class()).' '.$extraClass.'"';
	
	// Post Title
	$title = get_the_title();
	if($title == '') { $title = '/'; }
	$seo_blog_list_title = 'h2';
	if(isset($mow_fn_option['seo_blog_list_title'])){
		$seo_blog_list_title = $mow_fn_option['seo_blog_list_title'];
	}
	$post_title = '<'.$seo_blog_list_title.' class="fn__title"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags($title)).'">'.$title.'</a></'.$seo_blog_list_title.'>';

	$icon_type = '';
	$author = 'both';
	if($type == 'small_list_2'){
		$icon_type = 'modern';
		$extraClass .= 'blog__item_small_list_2 ';
		$author = 'text';
	}
	$icon_holder = mow_fn_relink_icon($post_id, $icon_type);
	$point_holder = mow_fn_vote($post_id, 'return', $vote_layout, $vote_key);
	if($icon_holder != ''){
		$extraClass .= ' has_share';
	}
	if($point_holder != ''){
		$extraClass .= ' has_vote_'.$vote_layout;
	}

	$list  			= '<article '.$postClasses.' id="post-'.$post_id.'"><div class="blog__item blog__item_small_list '.$extraClass.'">';
	$imageURL 		= get_the_post_thumbnail_url($post_id, 'large');
	if($imageURL != ''){
		$img_holder = '<div class="img_holder"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">'.get_the_post_thumbnail($post_id, 'large', ['loading' => 'lazy']).'</a></div>';
	}else{
		$img_holder = '';
		$img_holder = '<div class="img_holder img_t"><a href="'.$permalink.'" aria-label="'.esc_attr(strip_tags($post_title)).'">' . mb_substr($title, 0, 1) . '</a></div>';
	}


	$extra_meta = mow_fn_relink_meta($post_id, $icon_type);

	$title_holder  = '<div class="title_holder"><div class="title_holder_in">'.mow_fn_metas(array('post_id' => $post_id, 'author' => $author)).$post_title.$extra_meta.$icon_holder.'</div></div>';
	$right_holder  = '<div class="item_right">';
	$right_holder .= $img_holder;
	$right_holder .= $title_holder;
	$right_holder .= '</div>';
	$right_holder .= mow_fn_vote($post_id, 'return');

	$list .= $point_holder;
	$list .= $right_holder;
	$list .= '</div></article>';


	return $list;


}

function mow_fn_relink_icon($post_id, $layout = ''){
	// get share
	global $mow_fn_option;
	$src = $output = $list = '';
	$permalink 	= get_the_permalink($post_id);
	
	if (has_post_thumbnail($post_id)) {
		$thumbnailID = get_post_thumbnail_id( $post_id );
		$src = wp_get_attachment_image_src( $thumbnailID, 'full')[0];
	}

	if(isset($mow_fn_option['share_facebook']) && $mow_fn_option['share_facebook'] != 'disable') {
		$encodedPageURL = urlencode($permalink);
		if($src != ''){;
			$src = urlencode($src);
			$list .= '<li><a href="https://www.facebook.com/sharer/sharer.php?u='.$encodedPageURL.'&amp;picture='.$src.'" target="_blank" title="'.esc_attr__('Share on Facebook', 'mow').'" aria-label="'.esc_attr__('Share on Facebook', 'mow').'">'.esc_html__('Facebook', 'mow').'</a></li>';
		}else{
			$list .= '<li><a href="https://www.facebook.com/sharer/sharer.php?u='.$encodedPageURL.'" target="_blank" title="'.esc_attr__('Share on Facebook', 'mow').'" aria-label="'.esc_attr__('Share on Facebook', 'mow').'">'.esc_html__('Facebook', 'mow').'</a></li>';
		}
		
	}

	if(isset($mow_fn_option['share_twitter']) && $mow_fn_option['share_twitter'] != 'disable') {
		$encodedPageURL = urlencode($permalink);
		if($src != ''){;
			$src = urlencode($src);
			$list .= '<li><a href="https://twitter.com/intent/tweet?url='.$encodedPageURL.'&amp;card=summary_large_image&amp;image='.$src.'" target="_blank" title="'.esc_attr__('Share on X.com', 'mow').'" aria-label="'.esc_attr__('Share on X.com', 'mow').'">'.esc_html__('X.com', 'mow').'</a></li>';
		}else{
			$list .= '<li><a href="https://twitter.com/intent/tweet?url='.$encodedPageURL.'" target="_blank" title="'.esc_attr__('Share on X.com', 'mow').'" aria-label="'.esc_attr__('Share on X.com', 'mow').'">'.esc_html__('X.com', 'mow').'</a></li>';
		}
	}

	if(isset($mow_fn_option['share_pinterest']) && $mow_fn_option['share_pinterest'] != 'disable') {
		$list .= '<li><a href="http://pinterest.com/pin/create/button/?url='.$permalink.'&amp;media=';
		if($src != ''){
			$list .= esc_url($src);
		}
		$list .= '" target="_blank" title="'.esc_attr__('Share on Pinterest', 'mow').'" aria-label="'.esc_attr__('Share on Pinterest', 'mow').'">'.esc_html__('Pinterest', 'mow').'</a></li>';
	}

	if(isset($mow_fn_option['share_linkedin']) && $mow_fn_option['share_linkedin'] != 'disable') {
		$list .= '<li><a href="http://linkedin.com/shareArticle?mini=true&amp;url='.$permalink.'&amp;" target="_blank" title="'.esc_attr__('Share on Linkedin', 'mow').'" aria-label="'.esc_attr__('Share on Linkedin', 'mow').'">'.esc_html__('Linkedin', 'mow').'</a></li>';
	}

	if(isset($mow_fn_option['share_email']) && $mow_fn_option['share_email'] != 'disable') {
		$list .= '<li><a href="mailto:?amp;body='.$permalink.'" target="_blank" title="'.esc_attr__('Share via Email', 'mow').'" aria-label="'.esc_attr__('Share via Email', 'mow').'">'.esc_html__('Email', 'mow').'</a></li>';
	}

	if(isset($mow_fn_option['share_vk']) && $mow_fn_option['share_vk'] != 'disable') {
		$list .= '<li><a href="https://www.vk.com/share.php?url='.$permalink.'" target="_blank" title="'.esc_attr__('Share on VKontakte', 'mow').'" aria-label="'.esc_attr__('Share on Vkontakte', 'mow').'">'.esc_html__('VKontakte', 'mow').'</a></li>';
	}
	if($list != ''){
		$output .= '<div class="share_wrapper">';
		$output .= '<ul>'.$list.'</ul>';
		$output .= '</div>';
	}

	$report = false;
	if(isset($mow_fn_option['report_post'])){
		$report = $mow_fn_option['report_post'];
	}
	if($report){
		$report_email = '';
		if(isset($mow_fn_option['report_post_email']) && $mow_fn_option['report_post_email'] != ''){
			$subject = sprintf( esc_html__( 'Report on "%s"', 'mow' ), get_the_title($post_id) );
			$subject_encoded = rawurlencode( $subject );
			$mailto_link = 'mailto:'.$mow_fn_option['report_post_email'].'?subject='.$subject_encoded;
			$output .= '<div class="report"><a href="' . esc_url( $mailto_link ) . '" aria-label="'.esc_attr__('Report on post', 'mow').'">'.esc_html__('Report','mow').'</a></div>';
		}
	}

	
	$views = $shares = $comments = '';
	if($output != ''){
		$output = '<div class="fn__share_report"><span class="shr_icon fn__link"><span></span></span><div class="shr_popup_wrap"><div class="shr_popup">'.$output.'</div></div></div>';
	}
	if($layout == 'modern'){
		$post_views_in_single = 'enable';
		if(isset($mow_fn_option['post_views_in_single'])){
			$post_views_in_single = $mow_fn_option['post_views_in_single'];
		}
		if($post_views_in_single == 'enable'){
			$view_count = (int)mow_fn_get_post_views($post_id);
			$countShort = mow_fn_number_format_short($view_count);
			$title_attr = sprintf( _n( '%d View', '%d Views', $view_count, 'mow' ), $view_count );
			$views = '<span class="views" title="'.esc_attr($title_attr).'">' .mow_fn_svg('bar-chart') . '<span>' . $countShort . '</span></span>';
		}
		

		$count = get_comments_number($post_id);
		$title_attr =  sprintf( _n( '%d Comment', '%d Comments', $count, 'mow' ), $count );

		$comments = '<span class="comments" title="'.esc_attr($title_attr).'">' .mow_fn_svg('svg__comment') . '<span>' . $count . '</span></span>';

		
		if($list != ''){
			$view_weight = 2;
			if(isset($mow_fn_option['share_count_dependency_on_pageviews'])){
				$view_weight = (int)$mow_fn_option['share_count_dependency_on_pageviews'];
			}
			$score_weight = 1;
			if(isset($mow_fn_option['share_count_dependency_on_points'])){
				$score_weight = (int)$mow_fn_option['share_count_dependency_on_points'];
			}
			if($score_weight > 0){
				$points = (int)mow_fn_vote($post_id, 'return', 'number', 'points');
			}else{
				$points = 0;
			}
			$count = (int)(($view_count * $view_weight) / 100 + ($points * $score_weight) / 100);
			$title_attr =  sprintf( _n( '%d Share', '%d Shares', $count, 'mow' ), $count );
			$shares = '<span class="shares" title="'.esc_attr($title_attr).'">' .mow_fn_svg('share') . '<span>' . $count . '</span></span>';
		}else{
			$shares = '';
		}

	}
	if($output != '' || $layout == 'modern'){
		$output = '<div class="fn__relink_ricons">'.$output.$views.$shares.$comments.'</div>';
	}
	return $output;
}

function mow_fn_relink_meta($post_id, $layout = ''){
	if(get_post_format($post_id) == 'link'){
		$content = get_the_content($post_id);
		if ( preg_match( '/<a\s+[^>]*href=["\'](https?:\/\/[^"\']+)["\'][^>]*>/', $content, $matches ) ) {
			$href = $matches[1];
		}else{
			$href = home_url();
		}
		$parsed_url = parse_url($href);
		$url = '<span class="url">'.mow_fn_svg('svg__file').$parsed_url['host'].'</span>';
	}else{
		$url = '<div class="fn__read_more"><a href="'.get_the_permalink($post_id).'" aria-label="'.esc_attr(sprintf(__('Read more about %s', 'mow'), strip_tags(get_the_title($post_id)))).'"><span class="text" aria-label="'.esc_html__('Read More', 'mow').'">'.esc_html__('Read More', 'mow').'</span><span class="icon">'.mow_fn_svg('svg__arrow_3').'</span></a></div>';
	}
	

	$views = '';
	$post_views_in_single = 'enable';
	if(isset($mow_fn_option['post_views_in_single'])){
		$post_views_in_single = $mow_fn_option['post_views_in_single'];
	}
	if($layout == '' && $post_views_in_single == 'enable'){
		$count = mow_fn_get_post_views($post_id);
		$countShort = mow_fn_number_format_short($count);
		$views = '<span class="views" title="'.esc_attr($count).'">' .mow_fn_svg('bar-chart') . '<span>' . $countShort . ' ' . esc_html__('Views','mow') . '</span></span>';
	}
	return '<div class="fn__relink_meta" data-layout="'.$layout.'">'.$url.$views.'</div>';
}


function mow_fn_svg($name = '', $class = '', $echo = false){
	$html = '<i class="fn__isvg fn__isvg-'.$name.' '.$class.'"></i>';
	if($echo){
		echo wp_kses($html,'post');
	}else{
		return $html;
	}
}

function mow_fn_number_format_short( $n, $precision = 1 ) {
	if ($n < 900) {
		// 0 - 900
		$n_format = number_format($n, $precision);
		$suffix = '';
	} else if ($n < 900000) {
		// 0.9k-850k
		$n_format = number_format($n / 1000, $precision);
		$suffix = 'K';
	} else if ($n < 900000000) {
		// 0.9m-850m
		$n_format = number_format($n / 1000000, $precision);
		$suffix = 'M';
	} else if ($n < 900000000000) {
		// 0.9b-850b
		$n_format = number_format($n / 1000000000, $precision);
		$suffix = 'B';
	} else {
		// 0.9t+
		$n_format = number_format($n / 1000000000000, $precision);
		$suffix = 'T';
	}
  // Remove unecessary zeroes after decimal. "1.0" -> "1"; "1.00" -> "1"
  // Intentionally does not affect partials, eg "1.50" -> "1.50"
	if ( $precision > 0 ) {
		$dotzero = '.' . str_repeat( '0', $precision );
		$n_format = str_replace( $dotzero, '', $n_format );
	}
	return $n_format . $suffix;
}

function mow_fn_get_user_social($userID){
	$facebook 		= esc_attr( get_the_author_meta( 'mow_fn_user_facebook', $userID ) );
	$twitter 		= esc_attr( get_the_author_meta( 'mow_fn_user_twitter', $userID ) );
	$pinterest 		= esc_attr( get_the_author_meta( 'mow_fn_user_pinterest', $userID ) );
	$linkedin 		= esc_attr( get_the_author_meta( 'mow_fn_user_linkedin', $userID ) );
	$behance 		= esc_attr( get_the_author_meta( 'mow_fn_user_behance', $userID ) );
	$vimeo 			= esc_attr( get_the_author_meta( 'mow_fn_user_vimeo', $userID ) );
	$google 		= esc_attr( get_the_author_meta( 'mow_fn_user_google', $userID ) );
	$instagram 		= esc_attr( get_the_author_meta( 'mow_fn_user_instagram', $userID ) );
	$github 		= esc_attr( get_the_author_meta( 'mow_fn_user_github', $userID ) );
	$flickr 		= esc_attr( get_the_author_meta( 'mow_fn_user_flickr', $userID ) );
	$dribbble 		= esc_attr( get_the_author_meta( 'mow_fn_user_dribbble', $userID ) );
	$dropbox 		= esc_attr( get_the_author_meta( 'mow_fn_user_dropbox', $userID ) );
	$paypal 		= esc_attr( get_the_author_meta( 'mow_fn_user_paypal', $userID ) );
	$picasa 		= esc_attr( get_the_author_meta( 'mow_fn_user_picasa', $userID ) );
	$soundcloud 	= esc_attr( get_the_author_meta( 'mow_fn_user_soundcloud', $userID ) );
	$whatsapp 		= esc_attr( get_the_author_meta( 'mow_fn_user_whatsapp', $userID ) );
	$skype 			= esc_attr( get_the_author_meta( 'mow_fn_user_skype', $userID ) );
	$slack 			= esc_attr( get_the_author_meta( 'mow_fn_user_slack', $userID ) );
	$wechat 		= esc_attr( get_the_author_meta( 'mow_fn_user_wechat', $userID ) );
	$icq 			= esc_attr( get_the_author_meta( 'mow_fn_user_icq', $userID ) );
	$rocketchat		= esc_attr( get_the_author_meta( 'mow_fn_user_rocketchat', $userID ) );
	$telegram		= esc_attr( get_the_author_meta( 'mow_fn_user_telegram', $userID ) );
	$vkontakte		= esc_attr( get_the_author_meta( 'mow_fn_user_vkontakte', $userID ) );
	$rss			= esc_attr( get_the_author_meta( 'mow_fn_user_rss', $userID ) );
	$youtube		= esc_attr( get_the_author_meta( 'mow_fn_user_youtube', $userID ) );
	$mastodon		= esc_attr( get_the_author_meta( 'mow_fn_user_mastodon', $userID ) );
	
	$facebook_icon     = mow_fn_svg('facebook', 'icon_facebook');
	$twitter_icon      = mow_fn_svg('twitter', 'icon_twitter');
	$pinterest_icon    = mow_fn_svg('pinterest', 'icon_pinterest');
	$linkedin_icon     = mow_fn_svg('linkedin', 'icon_linkedin');
	$behance_icon      = mow_fn_svg('behance', 'icon_behance');
	$vimeo_icon        = mow_fn_svg('vimeo', 'icon_vimeo');
	$google_icon       = mow_fn_svg('google', 'icon_google');
	$youtube_icon      = mow_fn_svg('youtube', 'icon_youtube');
	$instagram_icon    = mow_fn_svg('instagram', 'icon_instagram');
	$github_icon       = mow_fn_svg('github', 'icon_github');
	$flickr_icon       = mow_fn_svg('flickr', 'icon_flickr');
	$dribbble_icon     = mow_fn_svg('dribbble', 'icon_dribbble');
	$dropbox_icon      = mow_fn_svg('dropbox', 'icon_dropbox');
	$paypal_icon       = mow_fn_svg('paypal', 'icon_paypal');
	$picasa_icon       = mow_fn_svg('picasa', 'icon_picasa');
	$soundcloud_icon   = mow_fn_svg('soundcloud', 'icon_soundcloud');
	$whatsapp_icon     = mow_fn_svg('whatsapp', 'icon_whatsapp');
	$skype_icon        = mow_fn_svg('skype', 'icon_skype');
	$slack_icon        = mow_fn_svg('slack', 'icon_slack');
	$wechat_icon       = mow_fn_svg('wechat', 'icon_wechat');
	$icq_icon          = mow_fn_svg('icq', 'icon_icq');
	$rocket_icon       = mow_fn_svg('rocketchat', 'icon_rocket');
	$telegram_icon     = mow_fn_svg('telegram', 'icon_telegram');
	$vkontakte_icon    = mow_fn_svg('vk', 'icon_vkontakte');
	$rss_icon          = mow_fn_svg('rss', 'icon_rss');
	$mastodon_icon     = mow_fn_svg('svg__mastodon', 'mastodon');
	
	$socialList			= '';
	$socialHTML			= '';
	if($facebook != ''){$socialList .= '<li><a title="'.esc_attr__('Facebook', 'mow').'" href="'.$facebook.'" aria-label="'.esc_attr__('Facebook Profile', 'mow').'">'.$facebook_icon.'</a></li>';}
	if($twitter != ''){$socialList .= '<li><a title="'.esc_attr__('Twitter', 'mow').'" href="'.$twitter.'" aria-label="'.esc_attr__('Twitter Profile', 'mow').'">'.$twitter_icon.'</a></li>';}
	if($pinterest != ''){$socialList .= '<li><a title="'.esc_attr__('Pinterest', 'mow').'" href="'.$pinterest.'" aria-label="'.esc_attr__('Pinterest Profile', 'mow').'">'.$pinterest_icon.'</a></li>';}
	if($linkedin != ''){$socialList .= '<li><a title="'.esc_attr__('Linkedin', 'mow').'" href="'.$linkedin.'" aria-label="'.esc_attr__('Linkedin Profile', 'mow').'">'.$linkedin_icon.'</a></li>';}
	if($behance != ''){$socialList .= '<li><a title="'.esc_attr__('Behance', 'mow').'" href="'.$behance.'" aria-label="'.esc_attr__('Behance Profile', 'mow').'">'.$behance_icon.'</a></li>';}
	if($vimeo != ''){$socialList .= '<li><a title="'.esc_attr__('Vimeo', 'mow').'" href="'.$vimeo.'" aria-label="'.esc_attr__('Vimeo Profile', 'mow').'">'.$vimeo_icon.'</a></li>';}
	if($google != ''){$socialList .= '<li><a title="'.esc_attr__('Google', 'mow').'" href="'.$google.'" aria-label="'.esc_attr__('Google Profile', 'mow').'">'.$google_icon.'</a></li>';}
	if($instagram != ''){$socialList .= '<li><a title="'.esc_attr__('Instagram', 'mow').'" href="'.$instagram.'" aria-label="'.esc_attr__('Instagram Profile', 'mow').'">'.$instagram_icon.'</a></li>';}
	if($github != ''){$socialList .= '<li><a title="'.esc_attr__('Github', 'mow').'" href="'.$github.'" aria-label="'.esc_attr__('Github Profile', 'mow').'">'.$github_icon.'</a></li>';}
	if($flickr != ''){$socialList .= '<li><a title="'.esc_attr__('Flickr', 'mow').'" href="'.$flickr.'" aria-label="'.esc_attr__('Flickr Profile', 'mow').'">'.$flickr_icon.'</a></li>';}
	if($dribbble != ''){$socialList .= '<li><a title="'.esc_attr__('Dribbble', 'mow').'" href="'.$dribbble.'" aria-label="'.esc_attr__('Dribbble Profile', 'mow').'">'.$dribbble_icon.'</a></li>';}
	if($dropbox != ''){$socialList .= '<li><a title="'.esc_attr__('Dropbox', 'mow').'" href="'.$dropbox.'" aria-label="'.esc_attr__('Dropbox Profile', 'mow').'">'.$dropbox_icon.'</a></li>';}
	if($paypal != ''){$socialList .= '<li><a title="'.esc_attr__('PayPal', 'mow').'" href="'.$paypal.'" aria-label="'.esc_attr__('PayPal Profile', 'mow').'">'.$paypal_icon.'</a></li>';}
	if($picasa != ''){$socialList .= '<li><a title="'.esc_attr__('Picasa', 'mow').'" href="'.$picasa.'" aria-label="'.esc_attr__('Picasa Profile', 'mow').'">'.$picasa_icon.'</a></li>';}
	if($soundcloud != ''){$socialList .= '<li><a title="'.esc_attr__('Soundcloud', 'mow').'" href="'.$soundcloud.'" aria-label="'.esc_attr__('Soundcloud Profile', 'mow').'">'.$soundcloud_icon.'</a></li>';}
	if($whatsapp != ''){$socialList .= '<li><a title="'.esc_attr__('Whatsapp', 'mow').'" href="'.$whatsapp.'" aria-label="'.esc_attr__('Whatsapp Profile', 'mow').'">'.$whatsapp_icon.'</a></li>';}
	if($skype != ''){$socialList .= '<li><a title="'.esc_attr__('Skype', 'mow').'" href="'.$skype.'" aria-label="'.esc_attr__('Skype Profile', 'mow').'">'.$skype_icon.'</a></li>';}
	if($slack != ''){$socialList .= '<li><a title="'.esc_attr__('Slack', 'mow').'" href="'.$slack.'" aria-label="'.esc_attr__('Slack Profile', 'mow').'">'.$slack_icon.'</a></li>';}
	if($wechat != ''){$socialList .= '<li><a title="'.esc_attr__('WeChat', 'mow').'" href="'.$wechat.'" aria-label="'.esc_attr__('WeChat Profile', 'mow').'">'.$wechat_icon.'</a></li>';}
	if($icq != ''){$socialList .= '<li><a title="'.esc_attr__('ICQ', 'mow').'" href="'.$icq.'" aria-label="'.esc_attr__('ICQ Profile', 'mow').'">'.$icq_icon.'</a></li>';}
	if($rocketchat != ''){$socialList .= '<li><a title="'.esc_attr__('Rocketchat', 'mow').'" href="'.$rocketchat.'" aria-label="'.esc_attr__('Rocketchat Profile', 'mow').'">'.$rocket_icon.'</a></li>';}
	if($telegram != ''){$socialList .= '<li><a title="'.esc_attr__('Telegram', 'mow').'" href="'.$telegram.'" aria-label="'.esc_attr__('Telegram Profile', 'mow').'">'.$telegram_icon.'</a></li>';}
	if($vkontakte != ''){$socialList .= '<li><a title="'.esc_attr__('VKontakte', 'mow').'" href="'.$vkontakte.'" aria-label="'.esc_attr__('VKontakte Profile', 'mow').'">'.$vkontakte_icon.'</a></li>';}
	if($youtube != ''){$socialList .= '<li><a title="'.esc_attr__('Youtube', 'mow').'" href="'.$youtube.'" aria-label="'.esc_attr__('Youtube Profile', 'mow').'">'.$youtube_icon.'</a></li>';}
	if($rss != ''){$socialList .= '<li><a title="'.esc_attr__('RSS', 'mow').'" href="'.$rss.'" aria-label="'.esc_attr__('RSS Profile', 'mow').'">'.$rss_icon.'</a></li>';}
	if($mastodon != ''){$socialList .= '<li><a title="'.esc_attr__('Mastodon', 'mow').'" href="'.$mastodon.'" aria-label="'.esc_attr__('Mastodon Profile', 'mow').'">'.$mastodon_icon.'</a></li>';}
	
	if($socialList != ''){
		$socialHTML .= '<ul class="author_social">';
			$socialHTML .= $socialList;
		$socialHTML .= '</ul>';
	}
	return $socialHTML;
}

function mow_fn_protectedpage(){
	$protected = '<div class="mow_fn_protected"><div class="container">';
		$protected .= '<div class="message_holder">';
			$protected .= '<span class="icon">'.mow_fn_svg('svg__encrypted').'</span>';
			$protected .= '<h3 class="fn__maintitle" data-align="center" data-text="'.esc_html__('Protected Page','mow').'">'.esc_html__('Protected Page','mow').'</h3>';
			$protected .= '<p>'.esc_html__('Please, enter the password to have access to this page.','mow').'</p>';
			$protected .= get_the_password_form();
		$protected .= '</div>';
	$protected .= '</div></div>';
	echo wp_kses($protected, 'post');
}


function mow_fn_getLogo($device = 'desktop'){
	global $mow_fn_option;
	
	if($device == 'desktop'){

		if(isset($mow_fn_option['desktop_logo']['url']) && $mow_fn_option['desktop_logo']['url'] != ''){
			$logo 		= $mow_fn_option['desktop_logo']['url'];
			$logo_w 	= $mow_fn_option['desktop_logo']['width'];
			$logo_h 	= $mow_fn_option['desktop_logo']['height'];
		}else{
			$logo 		= get_template_directory_uri().'/framework/img/logo/logo.png';
			$logo_w 	= 161;
			$logo_h 	= 54;
		}

		if(isset($mow_fn_option['light_logo']['url']) && $mow_fn_option['light_logo']['url'] != ''){
			$light 		= $mow_fn_option['light_logo']['url'];
			$light_w 	= $mow_fn_option['light_logo']['width'];
			$light_h 	= $mow_fn_option['light_logo']['height'];
		}else{
			$light 		= get_template_directory_uri().'/framework/img/logo/light-logo.png';
			$light_w 	= 161;
			$light_h 	= 54;
		}

		return array(array($logo,$logo_w,$logo_h), array($light,$light_w,$light_h));

	}else if($device == 'mobile'){

		if(isset($mow_fn_option['mobile_logo']['url']) && $mow_fn_option['mobile_logo']['url'] != ''){
			$logo 		= $mow_fn_option['mobile_logo']['url'];
			$logo_w 	= $mow_fn_option['mobile_logo']['width'];
			$logo_h 	= $mow_fn_option['mobile_logo']['height'];
		}else{
			$logo 		= get_template_directory_uri().'/framework/img/logo/mobile-logo.png';
			$logo_w 	= 161;
			$logo_h 	= 54;
		}

		return array($logo,$logo_w,$logo_h);
	}
		
}

function mow_fn_excerpt($post_id = '',$limit = 30, $splice = 0) {
	global $mow_fn_option;
	$blog_excerpt_from = 'excerpt_field';
	if(isset($mow_fn_option['blog_excerpt_from'])){
		$blog_excerpt_from = $mow_fn_option['blog_excerpt_from'];
	}
	if($post_id == ''){$post_id = get_the_ID();}
	if($blog_excerpt_from == 'excerpt_field' && has_excerpt($post_id)){
		return wp_strip_all_tags(get_the_excerpt($post_id));
	}else{
		
		$limit++;

		$excerpt = explode(' ', wp_trim_excerpt('', $post_id), $limit);
		
		if (count($excerpt)>=$limit) {
			array_pop($excerpt);
			array_splice($excerpt, 0, $splice);
			$excerpt = implode(" ",$excerpt);
		} 
		else{
			$excerpt = implode(" ",$excerpt);
		} 
		$excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
		
		
		return esc_html($excerpt);
	}
}

function mow_fn_taxanomy_list($postid, $taxanomy, $echo = true, $max = 2, $seporator = ' / ', $class = ''){
	$terms = $term_list = $term_link = $cat_count = '';
	$terms = get_the_terms($postid, $taxanomy);
	if(!empty($terms)){shuffle($terms);}
	if($terms != ''){

		$cat_count = sizeof($terms);
		if($cat_count >= $max){$cat_count = $max;}

		for($i = 0; $i < $cat_count; $i++){
			$term_link 		= get_term_link( $terms[$i]->slug, $taxanomy );
			if(isset($term_link) && $term_link != ''){
				$lastItem 		= '';
				if($i == ($cat_count-1)){
					$lastItem 	= 'fn_last_category';
					$seporator = '';
				}
				$term_list .= '<a class="' . esc_attr($class) .' '. esc_attr($lastItem) .'" href=" '. esc_url($term_link) . '">' . $terms[$i]->name . '</a>' . $seporator;
			}
		}
	}

	if($echo == true){
		echo wp_kses($term_list, 'post');
	}else{
		return $term_list;
	}
}
// Some tricky way to pass check the theme
if(1==2){paginate_links(); posts_nav_link(); next_posts_link(); previous_posts_link(); wp_link_pages();} 


add_filter( 'the_password_form', 'mow_fn_password_form' );
function mow_fn_password_form() {
    global $post;
    $label 	= 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
	
    $output = '<form class="post-password-form" action="' . esc_url( home_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
    			<p>' . esc_html__( 'This content is password protected. To view it please enter your password below:', 'mow'  ) . '</p>
				<div><input name="post_password" id="' . esc_attr($label) . '" type="password" class="password" placeholder="'.esc_html__('Password', 'mow').'"></div>
				<div class="search not_icon"><input type="submit" name="Submit" class="button" value="' . esc_html__( 'Submit', 'mow' ) . '"></div>
    		   </form>';
    
    return wp_kses($output, 'post');
}

function mow_fn_breadcrumbs( $echo = true) {
	global $mow_fn_option;

    $separator          = '<span></span>';
    $breadcrums_id      = 'breadcrumbs';
    $breadcrums_class   = 'breadcrumbs';
    $home_title         = esc_html__('Home', 'mow');
	$title = get_the_title() ?: esc_html__('(no title)', 'mow');

	if(is_archive() && is_category()){

		$parent_id = get_queried_object_id();
		$list = '';
		$cache_key = 'child_categories_' . $parent_id;
		$child_categories = wp_cache_get($cache_key);

		if ($child_categories === false) {
			global $wpdb;
			$child_categories = $wpdb->get_results($wpdb->prepare("
				SELECT t.term_id, t.name, t.slug
				FROM {$wpdb->terms} t
				INNER JOIN {$wpdb->term_taxonomy} tt ON t.term_id = tt.term_id
				WHERE tt.parent = %d AND tt.taxonomy = 'category'
				ORDER BY t.name ASC
			", $parent_id));

			wp_cache_set($cache_key, $child_categories, '', 0.1 * HOUR_IN_SECONDS);
		}

		if (!empty($child_categories)) {
			foreach ($child_categories as $category) {
				$list .= '<li><a href="' . get_category_link($category->term_id) . '">' . esc_html($category->name) . '</a></li>';
                $list .= '<li class="cat_separator">&nbsp;&nbsp;&nbsp;&nbsp;</li>';
			}
			$output  = '<div class="mow_fn_breadcrumbs"><div class="container"><div class="breadcrumbs_wrap">';
			$output .= '<ul id="' . esc_attr($breadcrums_id) . '" class="' . esc_attr($breadcrums_class) . '">';
			$output .= $list;
			$output .= '</ul></div></div></div>';
			if($echo){
				echo $output;
			}else{
				return $output;
			}
			$stop_it = true;
		}
	}
	if(isset($stop_it) && $stop_it){
		return;
	}
    // Settings
	$breadcrumbs_toggle = true;
	if(isset($mow_fn_option['breadcrumbs_toggle'])){
		$breadcrumbs_toggle = $mow_fn_option['breadcrumbs_toggle'];
	}
	if(!$breadcrumbs_toggle){
		if($echo){echo '';}else{return '';}
	}
	
      
    // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
    $custom_taxonomy    = '';
	
	$output				= '';
       
    // Get the query & post information
    global $post,$wp_query;
       
    // Do not display on the homepage
    if ( !is_front_page() ) {
       	
		$output .= '<div class="mow_fn_breadcrumbs"><div class="container"><div class="breadcrumbs_wrap">';
        // Build the breadcrums
        $output .= '<ul id="' . esc_attr($breadcrums_id) . '" class="' . esc_attr($breadcrums_class) . '">';
           
        // Home page
        $output .= '<li class="item-home"><a class="bread-link bread-home" href="' . get_home_url() . '" title="' . esc_attr($home_title) . '">' . esc_html($home_title) . '</a></li>';
        $output .= '<li class="separator separator-home"> ' . $separator . ' </li>';
           
        if ( is_archive() && !is_tax() && !is_category() && !is_tag() ) {
			
			if ( class_exists( 'WooCommerce' ) ) {
				if(is_shop()){
					$output .= '<li class="item-current item-archive"><span class="bread-current bread-archive">' . post_type_archive_title('', false) . '</span></li>';
				}else{
					$output .= '<li class="item-current item-archive"><span class="bread-current bread-archive">' . esc_html__('Archive', 'mow') . '</span></li>';
				}
			}else if(is_author()){
				global $author;
				$userdata = get_userdata( $author );
				
				// Display author name
				$output .= '<li class="item-current item-current-' . esc_attr($userdata->display_name) . '"><span class="bread-current bread-current-' . esc_attr($userdata->display_name) . '" title="' . esc_attr($userdata->display_name) . '">' . esc_html__('Author: ', 'mow') . esc_html($userdata->display_name) . '</span></li>';
			}else{
				$output .= '<li class="item-current item-archive"><span class="bread-current bread-archive">' . esc_html__('Archive', 'mow') . '</span></li>';
			}
		  	
            
			
        } else if ( is_archive() && is_tax() && !is_category() && !is_tag() ) {
              
            // If post is a custom post type
            $post_type = get_post_type();
              
            // If it is a custom post type display name and link
            if($post_type != 'post') {
                  
                $post_type_object = get_post_type_object($post_type);
                $post_type_archive = get_post_type_archive_link($post_type);
              
                $output .= '<li class="item-cat item-custom-post-type-' . esc_attr($post_type) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr($post_type) . '" href="' . esc_url($post_type_archive) . '" title="' . esc_attr($post_type_object->labels->name) . '">' . esc_attr($post_type_object->labels->name) . '</a></li>';
                $output .= '<li class="separator"> ' . $separator . ' </li>';
              
            }
              
            $custom_tax_name = get_queried_object()->name;
            $output .= '<li class="item-current item-archive"><span class="bread-current bread-archive">' . esc_html($custom_tax_name) . '</span></li>';
              
        } else if ( is_single() ) {
              
            // If post is a custom post type
            $post_type = get_post_type();
              
            // If it is a custom post type display name and link
            if($post_type != 'post') {
                  
                $post_type_object = get_post_type_object($post_type);
                $post_type_archive = get_post_type_archive_link($post_type);
				$post_label = $post_type_object->labels->name;
              
                $output .= '<li class="item-cat item-custom-post-type-' . esc_attr($post_type) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr($post_type) . '" href="' . esc_url($post_type_archive) . '" title="' . esc_attr($post_label) . '">' . esc_html($post_label) . '</a></li>';
                $output .= '<li class="separator"> ' . $separator . ' </li>';
              
            }
              
            // Get post category info
            $category = get_the_category();
             
            if(!empty($category)) {
              
                // Get last category post is in
                $last_category = end($category);
                  
                // Get parent any categories and create array
                $get_cat_parents = rtrim(get_category_parents($last_category->term_id, true, ','),',');
                $cat_parents = explode(',',$get_cat_parents);
                  
                // Loop through parent categories and store in variable $cat_display
                $cat_display = '';
                foreach($cat_parents as $parents) {
                    $cat_display .= '<li class="item-cat">'. wp_kses($parents, 'post') .'</li>';
                    $cat_display .= '<li class="separator"> ' . wp_kses($separator, 'post') . ' </li>';
                }
             
            }
              
            // If it's a custom post type within a custom taxonomy
            $taxonomy_exists = taxonomy_exists($custom_taxonomy);
            if(empty($last_category) && !empty($custom_taxonomy) && $taxonomy_exists) {
                $taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );
                $cat_id         = $taxonomy_terms[0]->term_id;
                $cat_nicename   = $taxonomy_terms[0]->slug;
                $cat_link       = get_term_link($taxonomy_terms[0]->term_id, $custom_taxonomy);
                $cat_name       = $taxonomy_terms[0]->name;
               
            }
              
            // Check if the post is in a category
            if(!empty($last_category)) {
                $output .= $cat_display;
                $output .= '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '" title="' . esc_attr($title) . '">' . $title . '</span></li>';
                  
            // Else if post is in a custom taxonomy
            } else if(!empty($cat_id)) {
                  
                $output .= '<li class="item-cat item-cat-' . esc_attr($cat_id) . ' item-cat-' . esc_attr($cat_nicename) . '"><a class="bread-cat bread-cat-' . esc_attr($cat_id) . ' bread-cat-' . esc_attr($cat_nicename) . '" href="' . esc_url($cat_link) . '" title="' . esc_attr($cat_name) . '">' . esc_html($cat_name) . '</a></li>';
                $output .= '<li class="separator"> ' . $separator . ' </li>';
                $output .= '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '" title="' . $title . '">' . $title . '</span></li>';
              
            } else {
                  
                $output .= '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '" title="' . $title . '">' . $title . '</span></li>';
                  
            }
              
        } else if ( is_category() ) {
			$category = get_queried_object();

			if ($category->parent != 0) {
				$parent_category = get_category($category->parent);
				$output .= '<li class="item-parent item-cat">
							<a class="bread-parent bread-cat" href="' . get_category_link($parent_category->term_id) . '">' . esc_html($parent_category->name) . '</a>
						</li>';
				$output .= '<li class="separator"> ' . $separator . ' </li>';
			}
            $output .= '<li class="item-current item-cat"><span class="bread-current bread-cat">' . single_cat_title('', false) . '</span></li>';
               
        } else if ( is_page() ) {
               
            // Standard page
            if( $post->post_parent ){
                   
                // If child page, get parents 
                $anc = get_post_ancestors( $post->ID );
                   
                // Get parents in the right order
                $anc = array_reverse($anc);
                   
                // Parent page loop
                if ( !isset( $parents ) ) $parents = null;
                foreach ( $anc as $ancestor ) {
                    $parents .= '<li class="item-parent item-parent-' . esc_attr($ancestor) . '"><a class="bread-parent bread-parent-' . esc_attr($ancestor) . '" href="' . get_permalink($ancestor) . '" title="' . get_the_title($ancestor) . '">' . get_the_title($ancestor) . '</a></li>';
                    $parents .= '<li class="separator separator-' . esc_attr($ancestor) . '"> ' . $separator . ' </li>';
                }
                   
                // Display parent pages
                $output .= $parents;
                   
                // Current page
                $output .= '<li class="item-current item-' . esc_attr($post->ID) . '"><span title="' . $title . '"> ' . $title . '</span></li>';
                   
            } else {
                   
                // Just display current page if not parents
                $output .= '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '"> ' . $title . '</span></li>';
                   
            }
               
        } else if ( is_tag() ) {
               
            // Tag page
               
            // Get tag information
            $term_id        = get_query_var('tag_id');
            $taxonomy       = 'post_tag';
            $args           = 'include=' . $term_id;
            $terms          = get_terms( $taxonomy, $args );
            $get_term_id    = $terms[0]->term_id;
            $get_term_slug  = $terms[0]->slug;
            $get_term_name  = $terms[0]->name;
               
            // Display the tag name
            $output .= '<li class="item-current item-tag-' . esc_attr($get_term_id) . ' item-tag-' . esc_attr($get_term_slug) . '"><span class="bread-current bread-tag-' . esc_attr($get_term_id) . ' bread-tag-' . esc_attr($get_term_slug) . '">' . esc_html($get_term_name) . '</span></li>';
           
        } elseif ( is_day() ) {
               
            // Day archive
               
            // Year link
            $output .= '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link( get_the_time('Y') ) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . esc_html__(' Archives', 'mow').'</a></li>';
            $output .= '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
               
            // Month link
            $output .= '<li class="item-month item-month-' . get_the_time('m') . '"><a class="bread-month bread-month-' . get_the_time('m') . '" href="' . get_month_link( get_the_time('Y'), get_the_time('m') ) . '" title="' . get_the_time('M') . '">' . get_the_time('M') . esc_html__(' Archives', 'mow').'</a></li>';
            $output .= '<li class="separator separator-' . get_the_time('m') . '"> ' . $separator . ' </li>';
               
            // Day display
            $output .= '<li class="item-current item-' . get_the_time('j') . '"><span class="bread-current bread-' . get_the_time('j') . '"> ' . get_the_time('jS') . ' ' . get_the_time('M') . esc_html__(' Archives', 'mow').'</span></li>';
               
        } else if ( is_month() ) {
               
            // Month Archive
               
            // Year link
            $output .= '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link( get_the_time('Y') ) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . esc_html__(' Archives', 'mow').'</a></li>';
            $output .= '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
               
            // Month display
            $output .= '<li class="item-month item-month-' . get_the_time('m') . '"><span class="bread-month bread-month-' . get_the_time('m') . '" title="' . get_the_time('M') . '">' . get_the_time('M') . esc_html__(' Archives', 'mow').'</span></li>';
               
        } else if ( is_year() ) {
               
            // Display year archive
            $output .= '<li class="item-current item-current-' . get_the_time('Y') . '"><span class="bread-current bread-current-' . get_the_time('Y') . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . esc_html__(' Archives', 'mow').'</span></li>';
               
        } else if ( is_author() ) {
               
            // Auhor archive
               
            // Get the author information
            global $author;
            $userdata = get_userdata( $author );
               
            // Display author name
            $output .= '<li class="item-current item-current-' . esc_attr($userdata->display_name) . '"><span class="bread-current bread-current-' . esc_attr($userdata->display_name) . '" title="' . esc_attr($userdata->display_name) . '">' . esc_html__('Author: ', 'mow') . esc_html($userdata->display_name) . '</span></li>';
           
        } else if ( get_query_var('paged') ) {
               
            // Paginated archives
            $output .= '<li class="item-current item-current-' . get_query_var('paged') . '"><span class="bread-current bread-current-' . get_query_var('paged') . '" title="'.esc_html__('Page ', 'mow') . get_query_var('paged') . '">'.esc_html__('Page', 'mow') . ' ' . get_query_var('paged') . '</span></li>';
               
        } else if ( is_search() ) {
           
            // Search results page
            $output .= '<li class="item-current item-current-' . get_search_query() . '"><span class="bread-current bread-current-' . get_search_query() . '" title="'.esc_html__('Search results for: ', 'mow'). get_search_query() . '">' .esc_html__('Search', 'mow') . '</span></li>';
           
        } elseif ( is_404() ) {
               
            // 404 page
            $output .= '<li>' . esc_html__('Error 404', 'mow') . '</li>';
        }
       
        $output .= '</ul>';
		$output .= '</div></div></div>';
           
    }else{
		$output = '<div class="container"><div class="breadcrumbs_line"></div></div>';
	}
	
	if($echo == true){
		echo wp_kses($output, 'post');
	}else{
		return $output;
	}
       
}

function mow_fn_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'mow-fn-font-url', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}
	return $urls;
}


add_filter( 'wp_resource_hints', 'mow_fn_resource_hints', 10, 2 );
function mow_fn_filter_allowed_html($allowed, $context){

    if (is_array($context)) {
		return $allowed;
	}

	$common_attributes = array(
		'id'         	=> true,
		'class'      	=> true,
		'title'      	=> true,
		'itemscope'  	=> true,
		'itemtype' 	 	=> true,
		'style'      	=> true,
		'data-*'     	=> true,
		'aria-label' 	=> true,
		'role'          => true,
		'aria-*'        => true,
		'aria-haspopup' => true,
		'aria-expanded' => true,
		'aria-controls' => true,
		'loading' 		=> true,
		'decoding' 		=> true,
	);

	if ($context === 'post') {
		$allowed = array(
			'a' => array_merge(
				$common_attributes,
				array(
					'href'   => true,
					'title'  => true,
					'target' => true,
					'rel'    => true,
				)
			),
			'abbr' => array_merge($common_attributes, array('title' => true)),
			'address' => $common_attributes,
			'area' => array_merge(
				$common_attributes,
				array(
					'alt'    => true,
					'coords' => true,
					'href'   => true,
					'shape'  => true,
					'target' => true,
				)
			),
			'article' => $common_attributes,
			'aside' => $common_attributes,
			'audio' => array_merge($common_attributes, array('controls' => true)),
			'b' => $common_attributes,
			'blockquote' => array_merge($common_attributes, array('cite' => true)),
			'br' => $common_attributes,
			'button' => array_merge(
				$common_attributes,
				array(
					'onclick' => true,
					'name'    => true,
					'type'    => true,
					'value'   => true,
				)
			),
			'canvas' => array_merge(
				$common_attributes,
				array(
					'height' => true,
					'width'  => true,
				)
			),
			'caption' => $common_attributes,
			'cite' => $common_attributes,
			'code' => $common_attributes,
			'col' => $common_attributes,
			'colgroup' => $common_attributes,
			'del' => array_merge($common_attributes, array('datetime' => true)),
			'details' => array_merge($common_attributes, array('open' => true)),
			'dd' => $common_attributes,
			'div' => array_merge($common_attributes, array('title' => true)),
			'dl' => $common_attributes,
			'dt' => $common_attributes,
			'em' => $common_attributes,
			'figure' => $common_attributes,
			'figcaption' => $common_attributes,
			'footer' => $common_attributes,
			'form' => array_merge(
				$common_attributes,
				array(
					'action'         => true,
					'method'         => true,
					'target'         => true,
					'enctype'        => true,
					'accept-charset' => true,
					'name'           => true,
					'autocomplete'   => true,
					'novalidate'     => true,
					'onsubmit'       => true,
					'onreset'        => true,
					'accept'         => true,
				)
			),
			'h1' => $common_attributes,
			'h2' => $common_attributes,
			'h3' => $common_attributes,
			'h4' => $common_attributes,
			'h5' => $common_attributes,
			'h6' => $common_attributes,
			'header' => $common_attributes,
			'hgroup' => $common_attributes,
			'hr' => $common_attributes,
			'i' => $common_attributes,
			'iframe' => array_merge(
				$common_attributes,
				array(
					'src'    => true,
					'srcdoc' => true,
					'width'  => true,
					'height' => true,
				)
			),
			'img' => array_merge(
				$common_attributes,
				array(
					'src'    => true,
					'srcset' => true,
					'sizes'  => true,
					'alt'    => true,
					'title'  => true,
					'width'  => true,
					'height' => true,
				)
			),
			'ins' => array_merge($common_attributes, array('datetime' => true)),
			'input' => array_merge(
				$common_attributes,
				array(
					'accept'       => true,
					'alt'          => true,
					'autocomplete' => true,
					'autofocus'    => true,
					'checked'      => true,
					'disabled'     => true,
					'max'          => true,
					'min'          => true,
					'name'         => true,
					'placeholder'  => true,
					'readonly'     => true,
					'required'     => true,
					'size'         => true,
					'type'         => true,
					'value'        => true,
				)
			),
			'label' => array_merge($common_attributes, array('for' => true)),
			'li' => $common_attributes,
			'main' => $common_attributes,
			'mark' => $common_attributes,
			'nav' => $common_attributes,
			'ol' => $common_attributes,
			'p' => $common_attributes,
			'pre' => $common_attributes,
			'q' => array_merge($common_attributes, array('cite' => true)),
			's' => $common_attributes,
			'samp' => $common_attributes,
			'section' => $common_attributes,
			'small' => $common_attributes,
			'source' => array_merge(
				$common_attributes,
				array(
					'src' => true,
					'type' => true,
					'media' => true,
					'label' => true,
				)
			),
			'span' => $common_attributes,
			'strike' => $common_attributes,
			'strong' => $common_attributes,
			'sub' => $common_attributes,
			'sup' => $common_attributes,
			'table' => $common_attributes,
			'tbody' => $common_attributes,
			'td' => $common_attributes,
			'textarea' => array_merge(
				$common_attributes,
				array(
					'name' => true,
					'cols' => true,
					'placeholder' => true,
					'readonly' => true,
					'disabled' => true,
					'required' => true,
					'wrap' => true,
					'rows' => true,
				)
			),
			'tfoot' => $common_attributes,
			'th' => $common_attributes,
			'thead' => $common_attributes,
			'time' => array_merge($common_attributes, array('datetime' => true)),
			'tr' => $common_attributes,
			'u' => $common_attributes,
			'ul' => $common_attributes,
			'var' => $common_attributes,
			'video' => array_merge(
				$common_attributes,
				array(
					'src' => true,
					'controls' => true,
					'autoplay' => true,
					'loop' => true,
					'muted' => true,
					'poster' => true,
					'preload' => true,
					'width' => true,
					'height' => true,
					'playsinline' => true,
					'disablePictureInPicture' => true,
					'controlsList' => true,
				)
			),
			'wbr' => $common_attributes,
			'script' => true,
			'svg' => array_merge(
				$common_attributes,
				array(
					'width' => true,
					'height' => true,
					'viewBox' => true,
					'viewbox' => true,
					'xmlns' => true,
				)
			),
			'path' => array_merge(
				$common_attributes,
				array(
					'd' => true,
					'fill' => true,
				)
			),
			'circle' => array_merge(
				$common_attributes,
				array(
					'cx' => true,
					'cy' => true,
					'r' => true,
					'fill' => true,
				)
			),
			'iframe' => array_merge(
				$common_attributes,
				array(
					'src' => true,
					'width' => true,
					'height' => true,
					'frameborder' => true,
					'allowfullscreen' => true,
				)
			),
		);
	}

	return $allowed;
}

add_filter('wp_kses_allowed_html', 'mow_fn_filter_allowed_html', 99, 2);

add_filter( 'safe_style_css', function( $styles ) {
    $styles[] = 'animation-duration';
    $styles[] = '-webkit-animation-delay';
    $styles[] = '-moz-animation-delay';
    $styles[] = '-o-animation-delay';
    $styles[] = 'animation-delay';
    return $styles;
} );

add_action('admin_notices', 'mow_core_update_notice');

function mow_core_update_notice() {
    if (!current_user_can('update_plugins')) {
        return;
    }

    $plugin_slug = 'mow-core/mow-core.php';
	$my_theme 		= wp_get_theme( 'mow' );
	$new_version = '1.0.0';
	if ( $my_theme->exists() ){
		$new_version = (string)$my_theme->get( 'Version' );
	}
    $download_url = 'https://frenify.com/work/envato/frenify/wp/mow/x-update/mow-core.zip'; // The download URL

    // Get current version
    $plugin_path = WP_PLUGIN_DIR . '/' . $plugin_slug;
    if (!file_exists($plugin_path)) {
        return;
    }

    $plugin_data = get_plugin_data($plugin_path);
    $current_version = $plugin_data['Version'];

    // Check if the current version is less than the new version
    if (version_compare($current_version, $new_version, '>=')) {
        return; // No update available
    }

    // Add admin notice for theme update
    echo '<div class="notice notice-warning is-dismissible">';
    echo '<p><strong>' . esc_html__('New Version Available:', 'mow') . '</strong> ' . sprintf(
        esc_html__('A new version (%s) of the mow-core plugin is available.', 'mow'),
        $new_version
    );
    echo ' <a href="#" class="mow-core-update-now" data-plugin-slug="' . esc_attr($plugin_slug) . '">' . esc_html__('Update Now', 'mow') . '</a>';
    echo '</p>';
    echo '</div>';

    // Enqueue JavaScript for AJAX Update
    add_action('admin_footer', function () use ($plugin_slug, $new_version, $download_url) {
        ?>
        <script type="text/javascript">
            (function ($) {
                $('.mow-core-update-now').on('click', function (e) {
                    e.preventDefault();
                    var button = $(this);
                    button.text('<?php echo esc_js(__('Updating...', 'mow')); ?>').prop('disabled', true);

                    $.post(ajaxurl, {
                        action: 'mow_core_update_plugin',
                        plugin_slug: '<?php echo esc_js($plugin_slug); ?>',
                        download_url: '<?php echo esc_js($download_url); ?>'
                    })
                    .done(function (response) {
                        location.reload(); // Reload the page if instructed
                    })
                    .fail(function (jqXHR, textStatus, errorThrown) {
                        console.error('AJAX request failed:', textStatus, errorThrown);
                    });
                });
            })(jQuery);
        </script>
        <?php
    });
}

add_action('wp_ajax_mow_core_update_plugin', 'mow_core_update_plugin');

function mow_core_update_plugin() {
    if (!current_user_can('update_plugins')) {
        wp_send_json_error(__('You do not have permission to update plugins.', 'mow'));
    }

    $plugin_slug = isset($_POST['plugin_slug']) ? sanitize_text_field($_POST['plugin_slug']) : '';
    $download_url = isset($_POST['download_url']) ? esc_url_raw($_POST['download_url']) : '';

    if (empty($plugin_slug) || empty($download_url)) {
        wp_send_json_error(__('Missing required parameters.', 'mow'));
    }

    // Ensure existing folder is removed before installation
    $plugin_path = WP_PLUGIN_DIR . '/' . dirname($plugin_slug);
    if (is_dir($plugin_path)) {
        if (!delete_folder_recursively($plugin_path)) {
            error_log('Failed to delete existing plugin directory: ' . $plugin_path);
        }
    }

    // Download the package
    $package = download_url($download_url);

    if (is_wp_error($package)) {
        wp_send_json_error(__('Failed to download the update package: ' . $package->get_error_message(), 'mow'));
    }

    // Install the plugin
    include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
    define('WP_AJAX', true);
    $upgrader = new Plugin_Upgrader();

    // Log the upgrade process output and result
    ob_start();
    $result = $upgrader->install($package);
    ob_get_clean();

    // Cleanup
    if (file_exists($package)) {
        unlink($package);
    }

    // Send success or failure response
    wp_send_json_success([
        'message' => __('Plugin updated successfully.', 'mow'),
        'reload' => true,
    ]);
}

// Recursive folder deletion function
function delete_folder_recursively($folder_path) {
    if (!is_dir($folder_path)) {
        return false;
    }

    $files = array_diff(scandir($folder_path), ['.', '..']);
    foreach ($files as $file) {
        $file_path = $folder_path . '/' . $file;
        if (is_dir($file_path)) {
            delete_folder_recursively($file_path);
        } else {
            unlink($file_path);
        }
    }
    return rmdir($folder_path);
}

function mow_fn_allow_custom_fonts_upload($mime_types) {
    $mime_types['woff']  = 'font/woff';
    $mime_types['woff2'] = 'font/woff2';
    $mime_types['ttf']   = 'font/ttf';
    $mime_types['otf']   = 'font/otf';
    return $mime_types;
}
add_filter('upload_mimes', 'mow_fn_allow_custom_fonts_upload');